% This is an ACE text set (i.e. APE regression testset and bug database).
%
% Each text is contained in a Prolog fact 
%
% text_drs_eval(Evaluation, Id, Text, DRS, Trees, Timestamp, Author, Comment)
%
% where
% Evaluation is either 0 (correct analysis i.e. a regression testcase) or 1 (incorrect analysis i.e. a bug),
% Id is an id-number of the ACE text,
% Text is an ACE text,
% DRS its corresponding DRS,
% Trees are its corresponding syntax trees,
% Timestamp shows the time when the entry was added,
% Author shows the IP of the author of the evaluation,
% Comment shows the comment by the author.
%
% The facts are not in any particular order.
%
% Those texts are based on data sent by the XMLHttpRequest client.
% The users of the client have been instructed to send the data only if they
% are sure that the Text-DRS pair is either correct (0) or incorrect (1).
% In case the DRS for a given Text has been sent more than once, then only the most
% recently sent DRS is included in the text set.

:- op(400, fx, -).
:- op(400, fx, ~).
:- op(500, xfx, =>).
:- op(500, xfx, v).

:- encoding(utf8).

text_drs_eval(0, 1, 'there is a man.', drs([A], [object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']]], '2006-07-26-16-15-20', amadeus, '').
text_drs_eval(0, 2, 'a flat mate runs.', drs([A, B], [object(A, mate, countable, na, eq, 1)-1, property(A, flat, pos)-1, predicate(B, run, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [flat]], [nbar, [n, [mate]]]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2005-08-03-12-55-49', blade17, '').
text_drs_eval(0, 3, 'a dog is good.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, good, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]]], ['.']]], '2005-04-20-16-32-33', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 4, 'A man waits in a bank.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1, modifier_pp(C, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-07-22-12-14-55', '80-218-104-121.dclient.hispeed.ch', '').
text_drs_eval(0, 5, 'A dummy Dummy dummy a dummy.', drs([], []), [], '2005-08-31-20-09-30', blade17, '').
text_drs_eval(0, 6, 'a man Kaarel works hard.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['Kaarel']]]]]], [vp, [vbar, [vbar, [v, [works]]], [adv, [hard]]]]], ['.']]], '2006-08-12-18-09-32', amadeus, '').
text_drs_eval(0, 7, 'a man Kaarel works extremely fast.', drs([], []), [], '2005-08-10-12-07-22', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 8, 'There is a man John. A man Bob brings him his pencil and his own computer.', drs([], []), [], '2005-08-31-20-18-04', blade17, '').
text_drs_eval(0, 9, 'A man runs and walks or sleeps.', drs([A], [drs([B, C], [predicate(B, walk, A)-1, predicate(C, run, A)-1])v drs([D], [predicate(D, sleep, A)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [runs]]]], [coord, [and]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-06-09-11-17-11', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 10, 'there is some absinth.', drs([A], [object(A, absinth, mass, na, na, na)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [absinth]]]]]], ['.']]], '2005-10-04-17-09-46', blade17, '').
text_drs_eval(0, 11, 'is there some absinth?', drs([], [question(drs([A], [object(A, absinth, mass, na, na, na)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, some], [nbar, [n, absinth]]]]], ?], '.']], '2009-05-13-13-30-23', '130.60.155.177', '').
text_drs_eval(0, 12, 'a n:sdfsdfsdfsdfsdf waits.', drs([A, B], [object(A, sdfsdfsdfsdfsdf, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [sdfsdfsdfsdfsdf]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-04-20-15-47-57', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 13, 'a /* man */ dog barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-04-20-15-50-34', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 14, '/** * This ACE text tests APE\'s comment support. */ #The program APE supports the comments of language Perl. /* The program APE supports the comments of language C. */ A /* big */ man walks. #fast. A woman /* who sees him */ smiles. A dog /* who # sees her */ barks. A cat # /* who sees her eats a cake. A rat # */ who sees her eats a cheese. /* /* C-comment inside a C-comment */ */ /* # Perl-comment inside a C-comment */ /* This is a large ACE text, which has been commented out. This is a large ACE text, which has been commented out. This is a large ACE text, which has been commented out. */', drs([], []), [], '2007-12-20-12-20-38', '130.60.155.177', '').
text_drs_eval(0, 15, 'is there a man?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, a], [nbar, [n, man]]]]], ?], '.']], '2009-05-13-13-30-33', '130.60.155.177', '').
text_drs_eval(0, 16, 'are there some men?', drs([], [question(drs([A], [object(A, man, countable, na, geq, 2)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'are there'], [np, [det, some], [nbar, [n, men]]]]], ?], '.']], '2009-05-13-13-30-43', '130.60.155.177', '').
text_drs_eval(0, 17, 'does a man wait?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/3, predicate(B, wait, A)-1/4]))]), [[sentence, [query, [question, does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-30-54', '130.60.155.177', '').
text_drs_eval(0, 18, 'do some men wait?', drs([], [question(drs([A, B], [object(A, man, countable, na, geq, 2)-1/3, predicate(B, wait, A)-1/4]))]), [[sentence, [query, [question, do, [np, [det, some], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-31-04', '130.60.155.177', '').
text_drs_eval(0, 19, 'a man does not wait in a bank.', drs([A], [-drs([B, C], [object(B, bank, countable, na, eq, 1)-1, modifier_pp(C, in, B)-1, predicate(C, wait, A)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [vbar, [v, [wait]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-04-20-17-09-39', blade17, '').
text_drs_eval(0, 20, 'a man is happy a dog.', drs([], []), [], '2005-06-11-22-39-53', unknown, '').
text_drs_eval(0, 21, 'where does a man wait?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, wait, A)-1/5, query(B, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-31-38', '130.60.155.177', '').
text_drs_eval(0, 22, 'John waits.', drs([A, B], [object(B, 'John', named, na, eq, 1)-1, predicate(A, wait, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-28-15-18-23', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 23, 'The flat mate of John is a clerk.', drs([A, B, C, D], [object(A, clerk, countable, na, eq, 1)-1, object(C, mate, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, relation(C, of, D)-1, property(C, flat, pos)-1, predicate(B, be, C, A)-1]), [[specification, [s, [np, [det, [the]], [nbar, [adj, [flat]], [nbar, [n, [mate]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [clerk]]]]]]], ['.']]], '2005-08-04-15-03-44', blade17, '').
text_drs_eval(0, 24, 'the customer John enters a card.', drs([], []), [], '2005-08-31-20-19-37', blade17, '').
text_drs_eval(0, 25, 'the screen blinks and John waits.', drs([A, B, C, D], [object(A, screen, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, predicate(B, wait, C)-1, predicate(D, blink, A)-1]), [[specification, [s_coord, [s, [np, [det, [the]], [nbar, [n, [screen]]]], [vp, [vbar, [v, [blinks]]]]], [coord, [and]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-04-22-17-48-24', blade17, '').
text_drs_eval(0, 26, 'the surface of the card has a green color.', drs([A, B, C, D], [object(C, color, countable, na, eq, 1)-1, object(D, surface, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-1, relation(D, of, A)-1, predicate(B, have, D, C)-1, property(C, green, pos)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [surface]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [card]]]]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [adj, [green]], [nbar, [n, [color]]]]]]]], ['.']]], '2005-04-22-17-49-23', blade17, '').
text_drs_eval(0, 27, 'John \' s car is fast.', drs([A, B, C, D], [object(B, car, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, fast, pos)-1, relation(B, of, D)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [car]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]], ['.']]], '2005-04-23-15-36-24', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 28, 'John\'s car is fast.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, car, countable, na, eq, 1)-1, property(C, fast, pos)-1, predicate(D, be, B, C)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [car]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]], ['.']]], '2006-12-20-17-32-54', '130.60.155.211', '').
text_drs_eval(0, 29, 'A n:aaa v:bbb the n:ccc.', drs([A, B, C], [object(B, aaa, countable, na, eq, 1)-1, object(C, ccc, countable, na, eq, 1)-1, predicate(A, bbb, B, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [aaa]]]], [vp, [vbar, [v, [bbb]], [np, [det, [the]], [nbar, [n, [ccc]]]]]]], ['.']]], '2005-04-23-15-38-54', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 30, 'a man waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-04-23-15-50-19', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 31, 'A man X waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-18-59-46', blade17, '').
text_drs_eval(0, 32, 'John beats the donkey of his own wife\'s brother.', drs([], []), [], '2008-08-12-10-09-49', '130.60.206.55', '').
text_drs_eval(0, 33, 'some money is green.', drs([A, B, C], [object(A, money, mass, na, na, na)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [money]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2005-10-04-17-10-16', blade17, '').
text_drs_eval(0, 34, 'A man hits a dog that runs in a park.', drs([A, B, C, D, E], [predicate(E, hit, A, B)-1, modifier_pp(D, in, C)-1, predicate(D, run, B)-1, object(C, park, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]]]]]]]]]], ['.']]], '2007-11-13-15-00-18', '130.60.155.161', '').
text_drs_eval(0, 35, 'A man gives a cat which gives a bone to a dog.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, bone, countable, na, eq, 1)-1, predicate(D, give, B, C)-1, object(E, dog, countable, na, eq, 1)-1, predicate(F, give, A, B, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [bone]]]]]]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-08-14-18-41-12', amadeus, '').
text_drs_eval(0, 36, 'a man is taller than a woman.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [det, [a]], [nbar, [n, [woman]]]]]|E]]]], ['.']]], '2007-05-09-12-11-46', '130.60.156.229', '').
text_drs_eval(0, 37, 'a man hits a dog that is smaller than a cat.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, property(D, small, comp_than, C)-1, predicate(E, be, B, D)-1, predicate(F, hit, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [smaller]], [conj, [than]], [np, [det, [a]], [nbar, [n, [cat]]]]]|G]]]]]]]]], ['.']]], '2007-05-09-12-11-54', '130.60.156.229', '').
text_drs_eval(0, 38, 'An animal X eats an animal Y that is smaller than X.', drs([A, B, C, D, E], [object(A, animal, countable, na, eq, 1)-1, object(B, animal, countable, na, eq, 1)-1, property(C, small, comp_than, A)-1, predicate(D, be, B, C)-1, predicate(E, eat, A, B)-1]), [[specification, [s, [np, [det, an], [nbar, [n, animal], [appos, [var, 'X']]]], [vp, [vbar, [v, eats], [np, [det, an], [nbar, [n, animal], [appos, [var, 'Y']], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, smaller], [conj, than], [np, [var, 'X']]]]]]]]]]]], '.']], '2008-08-15-20-36-40', '130.60.204.15', '').
text_drs_eval(0, 39, 'Every animal X eats an animal Y that is smaller than X.', drs([], [drs([A], [object(A, animal, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, animal, countable, na, eq, 1)-1, property(C, small, comp_than, A)-1, predicate(D, be, B, C)-1, predicate(E, eat, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, animal], [appos, [var, 'X']]]], [vp, [vbar, [v, eats], [np, [det, an], [nbar, [n, animal], [appos, [var, 'Y']], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, smaller], [conj, than], [np, [var, 'X']]]]]]]]]]]], '.']], '2008-08-15-20-36-56', '130.60.204.15', '').
text_drs_eval(0, 40, 'A man is a:reich-an a dog.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, property(C, 'reich-an', pos, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['reich-an']], [np, [det, [a]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-06-12-09-55-01', '130.60.156.66', '').
text_drs_eval(0, 41, '5 clerks\' codes are valid.', drs([A, B, C, D], [object(A, clerk, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, code, countable, na, geq, 2)-1, property(C, valid, pos)-1, predicate(D, be, B, C)-1]), [[specification, [s, [np, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [clerks]]], ['|', [gen_marker, ['\'']]]], [nbar, [n, [codes]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2006-12-20-17-34-40', '130.60.155.211', '').
text_drs_eval(0, 42, 'each of 5 clerks\' codes is valid.', drs([A, B], [object(B, clerk, countable, na, eq, 5)-1, relation(A, of, B)-1, object(A, code, countable, na, geq, 2)-1, drs([C], [has_part(A, C)-1])=>drs([D, E], [property(D, valid, pos)-1, predicate(E, be, C, D)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [clerks]]], ['|', [gen_marker, ['\'']]]], [nbar, [n, [codes]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2006-04-06-21-42-49', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 43, 'A man A waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['A']]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-19-00-06', blade17, '').
text_drs_eval(0, 44, 'A man John gives an apple to a woman Mary. Mary accepts the apple and eats it. She is happy and he has no apples.', drs([], []), [], '2005-08-31-21-09-44', blade17, '').
text_drs_eval(0, 45, 'A man John waits.', drs([], []), [], '2005-08-31-20-19-55', blade17, '').
text_drs_eval(0, 46, 'There is a man B. B waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['B']]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['B']]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-19-00-23', blade17, '').
text_drs_eval(0, 47, 'A man waits. He is happy.', drs([A, B, C, D], [object(C, man, countable, na, eq, 1)-1, predicate(D, be, C, A)-2, property(A, happy, pos)-2, predicate(B, wait, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-04-27-11-22-22', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 48, 'Some men wait. They are happy.', drs([A, B, C, D], [object(A, man, countable, na, geq, 2)-1, predicate(B, wait, A)-1, property(C, happy, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2006-04-07-14-41-11', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 49, 'There is 1 man D. There is 1 park B. D waits in B.', drs([A, B, C], [object(A, park, countable, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-3, modifier_pp(C, in, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [numberp, [gen_quant, [[]]], [number, [1]]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['D']]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [numberp, [gen_quant, [[]]], [number, [1]]], [nbar, [n, [park]], [appos_coord, [appos, [var, ['B']]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['D']]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [np, [var, ['B']]]]]]]], ['.']]], '2005-08-26-19-00-46', blade17, '').
text_drs_eval(0, 50, 'Every man waits-for some women who are happy or are sad.', drs([], []), [], '2005-08-17-18-45-14', blade17, '').
text_drs_eval(0, 51, 'If there is a man then there is 1 woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [object(B, woman, countable, na, eq, 1)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [top_s, [topic, [quant, ['{there is}']], [np, [numberp, [gen_quant, [[]]], [number, [1]]], [nbar, [n, [woman]]]]]]], ['.']]], '2005-04-27-11-52-57', blade17, '').
text_drs_eval(0, 52, 'If there is a man then there is more than 1 woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [object(B, woman, countable, na, greater, 1)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [top_s, [topic, [quant, ['{there is}']], [np, [numberp, [gen_quant, ['{more than}']], [number, [1]]], [nbar, [n, [woman]]]]]]], ['.']]], '2007-04-30-17-44-49', '130.60.155.177', '').
text_drs_eval(0, 53, 'There is a man A. A are happy.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['A']]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-08-29-19-16-47', blade17, '').
text_drs_eval(0, 54, 'There is not some water.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [some]], [nbar, [n, [water]]]]]]], ['.']]], '2005-08-25-21-42-30', blade17, '').
text_drs_eval(0, 55, 'There are no laundries.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [no]], [nbar, [n, [laundries]]]]]], ['.']]], '2007-04-17-21-50-49', '130.60.155.177', '').
text_drs_eval(0, 56, 'There is no laundry.', drs([], [-drs([A], [object(A, laundry, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [laundry]]]]]], ['.']]], '2006-08-17-22-37-44', amadeus, '').
text_drs_eval(0, 57, 'There is some laundry.', drs([A], [object(A, laundry, mass, na, na, na)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']]], '2005-10-04-17-10-34', blade17, '').
text_drs_eval(0, 58, 'There is a laundry.', drs([A], [object(A, laundry, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [laundry]]]]]], ['.']]], '2005-04-28-11-02-10', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 59, 'There is a button "Go!".', drs([], []), [], '2007-04-10-16-05-18', '130.60.155.177', '').
text_drs_eval(0, 60, 'There is a button "John\'s doorbell".', drs([], []), [], '2007-04-10-16-05-28', '130.60.155.177', '').
text_drs_eval(0, 61, '2 men see themselves.', drs([A, B], [object(A, man, countable, na, eq, 2)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [see]], [np, [pn, [themselves]]]]]], ['.']]], '2006-04-07-14-43-38', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 62, '2 men see their own card.', drs([A, B, C], [object(B, card, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 2)-1, relation(B, of, C)-1, predicate(A, see, C, B)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [see]], [np, [poss_pn_coord, [posspn, ['{their own}']]], [nbar, [n, [card]]]]]]], ['.']]], '2005-07-06-12-47-37', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 63, 'The train arrives in the station in the morning.', drs([A, B, C, D], [object(C, train, countable, na, eq, 1)-1, object(D, station, countable, na, eq, 1)-1, object(A, morning, countable, na, eq, 1)-1, modifier_pp(B, in, A)-1, modifier_pp(B, in, D)-1, predicate(B, arrive, C)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [train]]]], [vp, [vbar, [vbar, [v, [arrives]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [station]]]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [morning]]]]]]]], ['.']]], '2005-04-28-18-40-59', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 64, 'For each process P there is a process Q such that P relates-to Q.', drs([], [drs([A], [object(A, process, countable, na, eq, 1)-1])=>drs([B, C], [object(B, process, countable, na, eq, 1)-1, predicate(C, 'relate-to', A, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [process]], [appos_coord, [appos, [var, ['P']]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [process]], [appos_coord, [appos, [var, ['Q']]]]]]], [conj, ['{such that}']], [s, [np, [np, [var, ['P']]]], [vp, [vbar, [v, ['relates-to']], [np, [np, [var, ['Q']]]]]]]]], ['.']]], '2007-05-07-16-43-10', '130.60.156.229', '').
text_drs_eval(0, 65, 'Some money is green.', drs([A, B, C], [object(A, money, mass, na, na, na)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [money]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2005-10-04-17-11-50', blade17, '').
text_drs_eval(0, 66, 'All money is green.', drs([], [drs([A], [object(A, money, mass, na, na, na)-1])=>drs([B, C], [property(B, green, pos)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [money]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2005-10-04-17-11-40', blade17, '').
text_drs_eval(0, 67, 'For all money a man waits.', drs([], [drs([A], [object(A, money, mass, na, na, na)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [money]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-10-04-17-11-24', blade17, '').
text_drs_eval(0, 68, 'If there is some money then a man waits.', drs([], [drs([A], [object(A, money, mass, na, na, na)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [money]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-10-04-17-11-21', blade17, '').
text_drs_eval(0, 69, 'There are some men.', drs([A], [object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']]], '2005-08-15-14-36-21', blade17, '').
text_drs_eval(0, 70, 'Every man is happy.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, be, A, C)-1, property(C, happy, pos)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-04-29-13-18-33', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 71, 'Each man is happy.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, be, A, C)-1, property(C, happy, pos)-1])]), [[specification, [s, [np, [det, [each]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-04-29-13-18-52', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 72, 'No man is sad.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [property(B, sad, pos)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']]], '2006-08-12-18-11-01', amadeus, '').
text_drs_eval(0, 73, 'No men are sad.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [property(B, sad, pos)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [men]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']]], '2007-07-18-14-34-56', '130.60.155.177', '').
text_drs_eval(0, 74, 'No men wait.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-07-18-14-35-11', '130.60.155.177', '').
text_drs_eval(0, 75, 'There are no men.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [no]], [nbar, [n, [men]]]]]], ['.']]], '2007-04-17-21-51-28', '130.60.155.177', '').
text_drs_eval(0, 76, 'For every man a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-04-29-13-19-15', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 77, 'For each man a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-04-29-13-19-28', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 78, '/* Modus Ponens */ There is a thing A. There is a thing B. If A is true and A implies B then B is true.', drs([A, B], [object(A, thing, countable, na, eq, 1)-2, object(B, thing, countable, na, eq, 1)-1, drs([C, D, E], [property(C, true, pos)-3, predicate(D, be, B, C)-3, predicate(E, imply, B, A)-3])=>drs([F, G], [property(F, true, pos)-3, predicate(G, be, A, F)-3])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [thing]], [appos_coord, [appos, [var, ['A']]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [thing]], [appos_coord, [appos, [var, ['B']]]]]]]], ['.']], [specification, [cond_s, [if], [s_coord, [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [true]]]]]]], [coord, [and]], [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [implies]], [np, [np, [var, ['B']]]]]]]], [then], [s, [np, [np, [var, ['B']]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [true]]]]]]]], ['.']]], '2005-08-26-19-04-40', blade17, '').
text_drs_eval(0, 79, 'What does a man look-at?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, query(B, what)-1/1, predicate(C, 'look-at', A, B)-1/5]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, 'look-at']]]]], ?], '.']], '2009-05-13-13-31-48', '130.60.155.177', '').
text_drs_eval(0, 80, 'A man looks-at a card.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, 'look-at', A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, ['looks-at']], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2007-05-07-16-43-18', '130.60.156.229', '').
text_drs_eval(0, 81, 'There is a form. A man fills-in it.', drs([A, B, C], [object(A, form, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, predicate(C, 'fill-in', B, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [form]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, ['fills-in']], [np, [pn, [it]]]]]], ['.']]], '2007-05-07-16-39-15', '130.60.156.229', '').
text_drs_eval(0, 82, 'What does a man look at?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, query(B, what)-1/1, predicate(C, look, A)-1/5, modifier_pp(C, at, B)-1/6]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, look]], [vmod, [pp, [prep, at]]]]]], ?], '.']], '2009-05-13-13-32-44', '130.60.155.177', '').
text_drs_eval(0, 83, 'A man looks at a card.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, modifier_pp(A, at, C)-1, predicate(A, look, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [looks]]], [pp, [prep, [at]], [np, [det, [a]], [nbar, [n, [card]]]]]]]], ['.']]], '2005-04-29-13-36-12', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 84, 'Every man sees every dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-04-29-14-12-58', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 85, 'For every dog every man sees it.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, B, A)-1])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [dog]]]], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [it]]]]]]], ['.']]], '2005-04-29-14-13-03', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 86, 'A customer inserts 2 cards.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 2)-1, predicate(C, insert, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [cards]]]]]]], ['.']]], '2006-04-07-14-45-48', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 87, 'A card is valid.', drs([A, B, C], [object(B, card, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, valid, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-04-29-17-19-18', blade17, '').
text_drs_eval(0, 88, 'A new customer inserts 2 valid cards.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, property(A, new, pos)-1, object(B, card, countable, na, eq, 2)-1, property(B, valid, pos)-1, predicate(C, insert, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [new]], [nbar, [n, [customer]]]]], [vp, [vbar, [v, [inserts]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [adj, [valid]], [nbar, [n, [cards]]]]]]]], ['.']]], '2006-04-07-14-47-28', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 89, 'John\'s customer inserts a card of Mary.', drs([A, B, C, D, E], [object(C, customer, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-1, object(E, 'John', named, na, eq, 1)-1, object(D, 'Mary', named, na, eq, 1)-1, predicate(B, insert, C, A)-1, relation(A, of, D)-1, relation(C, of, E)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]]]], ['.']]], '2005-04-29-17-21-32', blade17, '').
text_drs_eval(0, 90, 'The customer Mr Miller inserts a card A.', drs([], []), [], '2005-08-30-19-02-39', blade17, '').
text_drs_eval(0, 91, 'A customer who is new inserts a card that he owns.', drs([A, B, C, D, E, F], [object(E, customer, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-1, predicate(B, insert, E, A)-1, predicate(F, own, E, A)-1, predicate(C, be, E, D)-1, property(D, new, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [new]]]]]]]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [that]], [np, [pn, [he]]], [vp, [vbar, [v, [owns]], [np, [[]]]]]]]]]]]], ['.']]], '2005-04-29-17-35-58', blade17, '').
text_drs_eval(0, 92, 'A customer inserts some cards manually.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, geq, 2)-1, predicate(C, insert, A, B)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [vbar, [v, [inserts]], [np, [det, [some]], [nbar, [n, [cards]]]]], [adv, [manually]]]]], ['.']]], '2006-04-07-14-52-11', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 93, 'A customer manually inserts some cards.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, geq, 2)-1, predicate(C, insert, A, B)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [adv, [manually]], [vbar, [v, [inserts]], [np, [det, [some]], [nbar, [n, [cards]]]]]]]], ['.']]], '2006-04-07-14-52-03', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 94, 'A customer inserts some cards into a slot.', drs([A, B, C, D], [object(A, customer, countable, na, eq, 1)-1, object(B, slot, countable, na, eq, 1)-1, object(C, card, countable, na, geq, 2)-1, predicate(D, insert, A, C)-1, modifier_pp(D, into, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [vbar, [v, [inserts]], [np, [det, [some]], [nbar, [n, [cards]]]]], [pp, [prep, [into]], [np, [det, [a]], [nbar, [n, [slot]]]]]]]], ['.']]], '2006-04-07-14-51-29', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 95, 'John\'s customer who is new inserts a valid card of Mary manually into a slot A.', drs([A, B, C, D, E, F, G, H], [object(B, card, countable, na, eq, 1)-1, object(C, slot, countable, na, eq, 1)-1, object(E, customer, countable, na, eq, 1)-1, object(F, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(H, be, E, G)-1, property(G, new, pos)-1, relation(E, of, A)-1, property(B, valid, pos)-1, relation(B, of, F)-1, predicate(D, insert, E, B)-1, modifier_pp(D, into, C)-1, modifier_adv(D, manually, pos)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [customer]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [new]]]]]]]]], [vp, [vbar, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [adj, [valid]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]]], [adv, [manually]], [pp, [prep, [into]], [np, [det, [a]], [nbar, [n, [slot]], [appos_coord, [appos, [var, ['A']]]]]]]]]], ['.']]], '2005-08-26-20-42-53', blade17, '').
text_drs_eval(0, 96, 'A customer inserts a card and enters a code.', drs([A, B, C, D, E], [object(D, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(C, code, countable, na, eq, 1)-1, predicate(E, enter, D, C)-1, predicate(A, insert, D, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]], [coord, [and]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-17-31-11', blade17, '').
text_drs_eval(0, 97, 'An old and a:trusted customer enters a card and a code.', drs([A, B, C, D, E], [object(C, na, countable, na, eq, 2)-1, object(D, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(E, code, countable, na, eq, 1)-1, has_part(C, E)-1, has_part(C, B)-1, predicate(A, enter, D, C)-1, property(D, trusted, pos)-1, property(D, old, pos)-1]), [[specification, [s, [np, [det, [an]], [nbar, [adj_coord, [adj, [old]], [coord, [and]], [adj, [trusted]]], [nbar, [n, [customer]]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-17-33-23', blade17, '').
text_drs_eval(0, 98, 'A customer inserts a card or enters a code.', drs([A], [drs([B, C], [object(B, card, countable, na, eq, 1)-1, predicate(C, insert, A, B)-1])v drs([D, E], [object(D, code, countable, na, eq, 1)-1, predicate(E, enter, A, D)-1]), object(A, customer, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]], [coord, [or]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-17-34-30', blade17, '').
text_drs_eval(0, 99, 'Every customer inserts a card.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1])=>drs([B, C], [object(B, card, countable, na, eq, 1)-1, predicate(C, insert, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2005-04-29-17-38-28', blade17, '').
text_drs_eval(0, 100, 'There is a card that every customer inserts.', drs([A], [drs([B], [object(B, customer, countable, na, eq, 1)-1])=>drs([C], [predicate(C, insert, B, A)-1]), object(A, card, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [that]], [np, [det, [every]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [[]]]]]]]]]]], ['.']]], '2005-04-29-17-39-40', blade17, '').
text_drs_eval(0, 101, 'For every card there is a customer who inserts it.', drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1])=>drs([B, C], [object(B, customer, countable, na, eq, 1)-1, predicate(C, insert, B, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [card]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [customer]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [inserts]], [np, [pn, [it]]]]]]]]]]]], ['.']]], '2005-04-29-17-41-39', blade17, '').
text_drs_eval(0, 102, 'A customer does not insert a card.', drs([A], [-drs([B, C], [object(B, card, countable, na, eq, 1)-1, predicate(C, insert, A, B)-1]), object(A, customer, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [insert]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2005-04-29-17-42-32', blade17, '').
text_drs_eval(0, 103, 'A card is not valid.', drs([A], [-drs([B, C], [predicate(B, be, A, C)-1, property(C, valid, pos)-1]), object(A, card, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-05-16-54-31', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 104, 'No customer inserts more than 2 cards.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, card, countable, na, greater, 2)-1, predicate(C, insert, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [numberp, [gen_quant, ['{more than}']], [number, [2]]], [nbar, [n, [cards]]]]]]], ['.']]], '2006-08-12-18-12-07', amadeus, '').
text_drs_eval(0, 105, 'There is no customer who inserts a card.', drs([], [-drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, insert, A, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [customer]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]]]]]]], ['.']]], '2006-08-17-22-37-29', amadeus, '').
text_drs_eval(0, 106, 'It is not the case that a customer inserts a card.', drs([], []), [], '2007-12-14-16-58-49', '130.60.155.177', '').
text_drs_eval(0, 107, 'A customer inserts a card.', drs([A, B, C], [object(B, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(A, insert, B, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2005-04-29-17-47-50', blade17, '').
text_drs_eval(0, 108, 'Does a customer insert a card?', drs([], [question(drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1/3, object(B, card, countable, na, eq, 1)-1/6, predicate(C, insert, A, B)-1/4]))]), [[sentence, [query, [question, does, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, insert], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-33-23', '130.60.155.177', '').
text_drs_eval(0, 109, 'A new customer inserts a valid card manually.', drs([A, B, C], [object(B, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, modifier_adv(A, manually, pos)-1, predicate(A, insert, B, C)-1, property(C, valid, pos)-1, property(B, new, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [new]], [nbar, [n, [customer]]]]], [vp, [vbar, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [adj, [valid]], [nbar, [n, [card]]]]]], [adv, [manually]]]]], ['.']]], '2005-04-29-17-49-00', blade17, '').
text_drs_eval(0, 110, 'Who inserts a card?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, object(B, card, countable, na, eq, 1)-1/4, predicate(C, insert, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, inserts], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-57-44', '130.60.155.177', '').
text_drs_eval(0, 111, 'Which customer inserts a card?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, customer, countable, na, eq, 1)-1/2, object(B, card, countable, na, eq, 1)-1/5, predicate(C, insert, A, B)-1/3]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, inserts], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-57-58', '130.60.155.177', '').
text_drs_eval(0, 112, 'What does the customer insert?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, predicate(B, insert, C, A)-1/5, object(C, customer, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [det, the], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, insert]]]]], ?], '.']], '2009-05-13-13-58-12', '130.60.155.177', '').
text_drs_eval(0, 113, 'How does the customer insert a card?', drs([], [question(drs([A, B, C], [object(A, card, countable, na, eq, 1)-1/7, predicate(B, insert, C, A)-1/5, query(B, how)-1/1, object(C, customer, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [qpn, how], does, [np, [det, the], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, insert], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-58-33', '130.60.155.177', '').
text_drs_eval(0, 114, 'There is John and there is a card that John enters. Does John enter the card?', drs([], []), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], [coord, [and]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]], [rel_cl, [comp, [that]], [np, [pname, ['John']]], [vp, [vbar, [v, [enters]], [np, [[]]]]]]]]]]], ['.']], [query, [question, [aux, [does]], [np, [pname, ['John']]], [vp, [vbar, [v, [enter]], [np, [det, [the]], [nbar, [n, [card]]]]]]], [?]]], '2006-08-15-21-06-21', amadeus, '').
text_drs_eval(0, 115, 'A customer inserts a card that is valid and opens an account.', drs([A, B, C, D, E, F, G], [object(E, account, countable, na, eq, 1)-1, object(F, card, countable, na, eq, 1)-1, object(A, customer, countable, na, eq, 1)-1, property(B, valid, pos)-1, predicate(C, be, F, B)-1, predicate(D, insert, A, F)-1, predicate(G, open, A, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [opens]], [np, [det, [a]], [nbar, [n, [account]]]]]]]], ['.']]], '2005-08-28-16-16-14', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 116, 'A customer inserts a card that is valid and that opens an account.', drs([A, B, C, D, E, F, G], [object(D, account, countable, na, eq, 1)-1, object(E, card, countable, na, eq, 1)-1, object(A, customer, countable, na, eq, 1)-1, property(B, valid, pos)-1, predicate(C, be, E, B)-1, predicate(F, open, E, D)-1, predicate(G, insert, A, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [opens]], [np, [det, [a]], [nbar, [n, [account]]]]]]]]]]]]], ['.']]], '2005-08-28-16-16-39', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 117, 'The customer inserts a card with a code.', drs([A, B, C, D], [object(C, customer, countable, na, eq, 1)-1, object(A, code, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, modifier_pp(D, with, A)-1, predicate(D, insert, C, B)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [with]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-18-11-11', blade17, '').
text_drs_eval(0, 118, 'The customer inserts a card that carries a code.', drs([A, B, C, D, E], [object(D, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(E, code, countable, na, eq, 1)-1, predicate(A, insert, D, B)-1, predicate(C, carry, B, E)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [carries]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]]]]], ['.']]], '2005-04-29-18-11-45', blade17, '').
text_drs_eval(0, 119, 'The customer inserts a card and a code.', drs([A, B, C, D, E], [object(C, na, countable, na, eq, 2)-1, object(D, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(E, code, countable, na, eq, 1)-1, has_part(C, E)-1, has_part(C, B)-1, predicate(A, insert, D, C)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-18-13-26', blade17, '').
text_drs_eval(0, 120, 'The customer who inserts a card manually enters a code.', drs([A, B, C, D, E], [object(D, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(C, code, countable, na, eq, 1)-1, predicate(E, enter, D, C)-1, modifier_adv(A, manually, pos)-1, predicate(A, insert, D, B)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]], [adv, [manually]]]]]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [code]]]]]]], ['.']]], '2005-04-29-18-14-17', blade17, '').
text_drs_eval(0, 121, 'A customer enters a red card and a blue card. The card is correct.', drs([A, B, C, D, E, F, G], [object(F, na, countable, na, eq, 2)-1, object(G, customer, countable, na, eq, 1)-1, object(E, card, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(A, be, B, D)-2, property(D, correct, pos)-2, has_part(F, B)-1, has_part(F, E)-1, property(B, blue, pos)-1, predicate(C, enter, G, F)-1, property(E, red, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [blue]], [nbar, [n, [card]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]], ['.']]], '2005-06-24-16-45-31', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 122, 'A customer enters a red card and a blue card. The red card is correct.', drs([A, B, C, D, E, F, G], [object(F, na, countable, na, eq, 2)-1, object(G, customer, countable, na, eq, 1)-1, object(E, card, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(A, be, E, D)-2, property(D, correct, pos)-2, has_part(F, B)-1, has_part(F, E)-1, property(B, blue, pos)-1, predicate(C, enter, G, F)-1, property(E, red, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [blue]], [nbar, [n, [card]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]], ['.']]], '2005-06-24-16-45-54', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 123, 'A customer does not enter a card. The card is correct.', drs([A, B, C, D], [object(C, customer, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-2, predicate(B, be, A, D)-2, property(D, correct, pos)-2, -drs([E, F], [object(E, card, countable, na, eq, 1)-1, predicate(F, enter, C, E)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [enter]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]], ['.']]], '2005-04-29-18-26-52', blade17, '').
text_drs_eval(0, 124, 'A customer inserts a card and the machine checks the code.', drs([A, B, C, D, E, F], [object(E, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, object(F, machine, countable, na, eq, 1)-1, object(A, code, countable, na, eq, 1)-1, predicate(D, check, F, A)-1, predicate(B, insert, E, C)-1]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [machine]]]], [vp, [vbar, [v, [checks]], [np, [det, [the]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-18-37-09', blade17, '').
text_drs_eval(0, 125, 'An old and happy customer enters a card and a code.', drs([A, B, C, D, E], [object(C, na, countable, na, eq, 2)-1, object(D, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(E, code, countable, na, eq, 1)-1, has_part(C, E)-1, has_part(C, B)-1, predicate(A, enter, D, C)-1, property(D, happy, pos)-1, property(D, old, pos)-1]), [[specification, [s, [np, [det, [an]], [nbar, [adj_coord, [adj, [old]], [coord, [and]], [adj, [happy]]], [nbar, [n, [customer]]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-04-29-18-39-25', blade17, '').
text_drs_eval(0, 126, 'If a card is valid then a customer inserts it.', drs([], [drs([A, B, C], [object(B, card, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, valid, pos)-1])=>drs([D, E], [object(D, customer, countable, na, eq, 1)-1, predicate(E, insert, D, B)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [pn, [it]]]]]]], ['.']]], '2005-04-29-18-40-25', blade17, '').
text_drs_eval(0, 127, 'A customer enters a card and a code. If a code is valid then SimpleMat accepts a card. If a code is not valid then SimpleMat rejects a card.', drs([A, B, C, D, E, F], [object(D, na, countable, na, eq, 2)-1, object(E, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, object(F, code, countable, na, eq, 1)-1, object(A, 'SimpleMat', named, na, eq, 1)-2, drs([G], [-drs([H, I], [predicate(H, be, G, I)-3, property(I, valid, pos)-3]), object(G, code, countable, na, eq, 1)-3])=>drs([J, K], [object(J, card, countable, na, eq, 1)-3, predicate(K, reject, A, J)-3]), drs([L, M, N], [object(M, code, countable, na, eq, 1)-2, predicate(N, be, M, L)-2, property(L, valid, pos)-2])=>drs([O, P], [object(O, card, countable, na, eq, 1)-2, predicate(P, accept, A, O)-2]), has_part(D, F)-1, has_part(D, C)-1, predicate(B, enter, E, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [code]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [pname, ['SimpleMat']]], [vp, [vbar, [v, [accepts]], [np, [det, [a]], [nbar, [n, [card]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [code]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [pname, ['SimpleMat']]], [vp, [vbar, [v, [rejects]], [np, [det, [a]], [nbar, [n, [card]]]]]]]], ['.']]], '2005-04-29-18-43-16', blade17, '').
text_drs_eval(0, 128, 'A customer enters a card and a code. If it is valid then SimpleMat accepts the card. If it is not valid then SimpleMat rejects the card.', drs([A, B, C, D, E, F], [object(A, 'SimpleMat', named, na, eq, 1)-2, object(B, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, has_part(F, C)-1, predicate(D, enter, B, F)-1, object(E, code, countable, na, eq, 1)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1, drs([G, H], [property(G, valid, pos)-2, predicate(H, be, E, G)-2])=>drs([I], [predicate(I, accept, A, C)-2]), drs([], [-drs([J, K], [property(J, valid, pos)-3, predicate(K, be, A, J)-3])])=>drs([L], [predicate(L, reject, A, C)-3])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [code]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [pname, ['SimpleMat']]], [vp, [vbar, [v, [accepts]], [np, [det, [the]], [nbar, [n, [card]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [pname, ['SimpleMat']]], [vp, [vbar, [v, [rejects]], [np, [det, [the]], [nbar, [n, [card]]]]]]]], ['.']]], '2007-12-11-10-31-31', '130.60.155.231', '').
text_drs_eval(0, 129, 'A customer enters a card CARD and a code CODE. If CODE is valid then SimpleMat accepts CARD. If CODE is not valid then SimpleMat rejects CARD.', drs([], []), [], '2008-07-09-15-20-50', '130.60.155.206', '').
text_drs_eval(0, 130, 'A customer enters a card CARD and a code CODE. If the code CODE is valid then SimpleMat accepts the card CARD. If the code CODE is not valid then SimpleMat rejects the card CARD.', drs([], []), [], '2008-07-09-15-21-30', '130.60.155.206', '').
text_drs_eval(0, 131, 'A clerk enters every card of him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2005-08-26-14-48-59', blade17, '').
text_drs_eval(0, 132, 'It is permitted that John waits.', drs([], []), [], '2006-05-24-18-33-21', amadeus, '').
text_drs_eval(0, 133, 'A clerk enters every card of himself.', drs([A], [object(A, clerk, countable, na, eq, 1)-1, drs([B], [object(B, card, countable, na, eq, 1)-1, relation(B, of, A)-1])=>drs([C], [predicate(C, enter, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-07-14-11-59-29', '80-218-106-3.dclient.hispeed.ch', '').
text_drs_eval(0, 134, 'There are some men. For each of they the card is valid.', drs([], []), [], '2005-08-28-16-26-13', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 135, 'A clerk rejects a card or accepts it.', drs([A], [drs([B, C], [object(B, card, countable, na, eq, 1)-1, predicate(C, reject, A, B)-1])v drs([D], [predicate(D, accept, A, B)-1]), object(A, clerk, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp_coord, [vp, [vbar, [v, [rejects]], [np, [det, [a]], [nbar, [n, [card]]]]]], [coord, [or]], [vp, [vbar, [v, [accepts]], [np, [pn, [it]]]]]]], ['.']]], '2005-05-09-18-22-44', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 136, 'John\'s new customer is happy.', drs([A, B, C, D], [object(B, customer, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, happy, pos)-1, property(B, new, pos)-1, relation(B, of, D)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [adj, [new]], [nbar, [n, [customer]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-05-09-18-46-16', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 137, 'What does a man enter?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, query(B, what)-1/1, predicate(C, enter, A, B)-1/5]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter]]]]], ?], '.']], '2009-05-13-13-58-44', '130.60.155.177', '').
text_drs_eval(0, 138, 'A man sees a dog that barks.', drs([A, B, C, D], [object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(B, see, C, A)-1, predicate(D, bark, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]]]], ['.']]], '2005-05-09-19-20-51', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 139, 'If a clerk enters a card then he does not own it.', drs([], [drs([A, B, C], [object(B, clerk, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(A, enter, B, C)-1])=>drs([], [-drs([D], [predicate(D, own, B, C)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [then], [s, [np, [pn, [he]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [own]], [np, [pn, [it]]]]]]], ['.']]], '2005-05-24-16-12-55', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 140, 'A man enters no card.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, card, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, enter, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [det, [no]], [nbar, [n, [card]]]]]]], ['.']]], '2006-08-12-18-13-16', amadeus, '').
text_drs_eval(0, 141, 'No card is valid.', drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [property(B, valid, pos)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2007-04-30-17-46-01', '130.60.155.177', '').
text_drs_eval(0, 142, 'There is John and there is Mary. He and she wait.', drs([], []), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], [coord, [and]], [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['Mary']]]]]]], ['.']], [specification, [s, [np_coord, [np, [pn, [he]]], [coord, [and]], [np, [pn, [she]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-08-15-21-06-35', amadeus, '').
text_drs_eval(0, 143, 'A man enters every card in the morning.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, drs([B], [object(B, card, countable, na, eq, 1)-1/5])=>drs([C, D], [predicate(C, enter, A, B)-1/3, modifier_pp(C, in, D)-1/6, object(D, morning, countable, na, eq, 1)-1/8])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enters], [np, [det, every], [nbar, [n, card]]]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]]]]], '.']], '2009-06-22-15-17-28', '130.60.155.209', '').
text_drs_eval(0, 144, 'A man enters no card manually.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, card, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, enter, A, B)-1, modifier_adv(C, manually, pos)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [enters]], [np, [det, [no]], [nbar, [n, [card]]]]], [adv, [manually]]]]], ['.']]], '2006-08-12-18-14-13', amadeus, '').
text_drs_eval(0, 145, 'A man walks or a woman sees the man.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1])v drs([C, D], [object(C, woman, countable, na, eq, 1)-1, predicate(D, see, C, A)-1])]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-08-15-21-07-27', amadeus, '').
text_drs_eval(0, 146, 'A man walks or a woman sees the man. There is John.', drs([], []), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], ['.']]], '2006-08-15-21-06-50', amadeus, '').
text_drs_eval(0, 147, 'There is a man. There is a card or the man inserts it.', drs([A], [drs([B], [object(B, card, countable, na, eq, 1)-2])v drs([C], [predicate(C, insert, A, B)-2]), object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], [coord, [or]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [inserts]], [np, [pn, [it]]]]]]], ['.']]], '2005-06-09-11-35-07', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 148, 'A card CARD is green.', drs([], []), [], '2008-07-09-15-21-59', '130.60.155.206', '').
text_drs_eval(0, 149, 'Every dog is evil.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, be, A, C)-1, property(C, evil, pos)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [evil]]]]]]], ['.']]], '2005-06-01-13-27-49', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 150, 'For every dog every man sees the dog.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, B, A)-1])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [dog]]]], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]], ['.']]], '2005-06-01-15-05-18', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 151, 'A man Kaarel tests an ape.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['Kaarel']]]]]], [vp, [vbar, [v, [tests]], [np, [det, [a]], [nbar, [n, [ape]]]]]]], ['.']]], '2006-08-12-22-36-24', amadeus, '').
text_drs_eval(0, 152, 'Where does a man enter a card?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, predicate(C, enter, A, B)-1/5, query(C, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-58-52', '130.60.155.177', '').
text_drs_eval(0, 153, 'How does a man enter a card?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, predicate(C, enter, A, B)-1/5, query(C, how)-1/1]))]), [[sentence, [query, [question, [qpn, how], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-58-58', '130.60.155.177', '').
text_drs_eval(0, 154, 'When does a man enter a card?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, predicate(C, enter, A, B)-1/5, query(C, when)-1/1]))]), [[sentence, [query, [question, [qpn, when], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-13-59-04', '130.60.155.177', '').
text_drs_eval(0, 155, 'Is there a man?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, a], [nbar, [n, man]]]]], ?], '.']], '2009-05-13-13-59-13', '130.60.155.177', '').
text_drs_eval(0, 156, 'It is not the case that some men wait.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]], [np, [[]]]]]]]]]]], ['.']]], '2007-12-14-17-00-11', '130.60.155.177', '').
text_drs_eval(0, 157, 'A number "1" is smaller than a number "2".', drs([], []), [], '2007-04-10-16-05-42', '130.60.155.177', '').
text_drs_eval(0, 158, 'A number "3.14" is a ratio of a circumference of a circle to its diameter.', drs([], []), [], '2007-04-10-16-06-16', '130.60.155.177', '').
text_drs_eval(0, 159, 'There is a number "3.14...".', drs([], []), [], '2007-04-10-16-20-01', '130.60.155.177', '').
text_drs_eval(0, 160, 'A number Pi is a ratio of a circumference of a circle to its diameter.', drs([], []), [], '2008-07-09-15-22-23', '130.60.155.206', '').
text_drs_eval(0, 161, 'A man sees a dog\'s tail.', drs([A, B, C, D], [object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, object(B, tail, countable, na, eq, 1)-1, predicate(D, see, C, B)-1, relation(B, of, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [poss_np, [det, [a]], [nbar, [n, [dog]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [tail]]]]]]], ['.']]], '2005-06-05-16-31-30', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 162, 'A mat on which a cat waits is red.', drs([A, B, C, D, E], [object(D, mat, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, predicate(C, be, D, E)-1, property(E, red, pos)-1, modifier_pp(A, on, D)-1, predicate(A, wait, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [mat]], [rel_cl_coord, [rel_cl, [pp, [prep, [on]], [np, [relpn, [which]]]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [[]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']]], '2005-06-05-16-47-40', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 163, 'A man sees a mat on which a cat sits.', drs([A, B, C, D, E], [object(D, man, countable, na, eq, 1)-1, object(B, mat, countable, na, eq, 1)-1, object(E, cat, countable, na, eq, 1)-1, predicate(A, see, D, B)-1, modifier_pp(C, on, B)-1, predicate(C, sit, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mat]], [rel_cl_coord, [rel_cl, [pp, [prep, [on]], [np, [relpn, [which]]]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [vbar, [v, [sits]]], [pp, [[]]]]]]]]]]]], ['.']]], '2005-06-05-16-48-40', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 164, 'A man sees a mat on which every cat sits.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, object(C, mat, countable, na, eq, 1)-1, predicate(A, see, B, C)-1, drs([D], [object(D, cat, countable, na, eq, 1)-1])=>drs([E], [modifier_pp(E, on, C)-1, predicate(E, sit, D)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mat]], [rel_cl_coord, [rel_cl, [pp, [prep, [on]], [np, [relpn, [which]]]], [np, [det, [every]], [nbar, [n, [cat]]]], [vp, [vbar, [vbar, [v, [sits]]], [pp, [[]]]]]]]]]]]], ['.']]], '2005-06-05-16-49-36', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 165, 'A man sees every mat on which a cat sits.', drs([A], [drs([B, C, D], [object(C, mat, countable, na, eq, 1)-1, object(D, cat, countable, na, eq, 1)-1, modifier_pp(B, on, C)-1, predicate(B, sit, D)-1])=>drs([E], [predicate(E, see, A, C)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [mat]], [rel_cl_coord, [rel_cl, [pp, [prep, [on]], [np, [relpn, [which]]]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [vbar, [v, [sits]]], [pp, [[]]]]]]]]]]]], ['.']]], '2005-06-05-16-51-54', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 166, 'Some cards a green.', drs([], []), [[specification, [s, [np, [np, [var, ['Some']]]], [vp, [vbar, [v, [cards]], [np, [det, [a]], [nbar, [n, [green]]]]]]], ['.']]], '2005-08-26-14-48-03', blade17, '').
text_drs_eval(0, 167, 'A man has 2 kg of apples.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, apple, countable, kg, eq, 2)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]]]]], ['.']]], '2007-12-10-19-37-16', '130.60.155.177', '').
text_drs_eval(0, 168, 'A man has 2 ton of apples.', drs([], []), [], '2007-06-12-09-55-17', '130.60.156.66', '').
text_drs_eval(0, 169, 'John is a rich man.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, predicate(B, be, C, A)-1, property(A, rich, pos)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [adj, [rich]], [nbar, [n, [man]]]]]]]], ['.']]], '2005-06-05-17-59-08', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 170, 'A man enters a card which is green or which is red.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(A, enter, B, C)-1, drs([D, E], [predicate(D, be, C, E)-1, property(E, green, pos)-1])v drs([F, G], [predicate(F, be, C, G)-1, property(G, red, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]]]]]]]]], ['.']]], '2005-06-05-18-01-13', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 171, 'There is a green card or there is a red card such that a man enters it.', drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1, property(A, green, pos)-1])v drs([B, C, D], [object(C, card, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, predicate(B, enter, D, C)-1, property(C, red, pos)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [green]], [nbar, [n, [card]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [card]]]]]], [conj, ['{such that}']], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [pn, [it]]]]]]]], ['.']]], '2005-06-05-18-02-48', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 172, 'For each card which is green or which is red a man enters it.', drs([], [drs([A], [drs([B, C], [predicate(B, be, A, C)-1, property(C, green, pos)-1])v drs([D, E], [predicate(D, be, A, E)-1, property(E, red, pos)-1]), object(A, card, countable, na, eq, 1)-1])=>drs([F, G], [object(F, man, countable, na, eq, 1)-1, predicate(G, enter, F, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]]]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [pn, [it]]]]]]], ['.']]], '2005-06-05-18-04-37', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 173, 'A man is fond-of a dog.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, property(C, 'fond-of', pos, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['fond-of']], [np, [det, [a]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-12-15', '130.60.156.229', '').
text_drs_eval(0, 174, 'Everybody gives something to somebody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C, D], [object(B, something, dom, na, na, na)-1, object(C, somebody, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [gives]], [np, [pn, [something]]], [pp, [prep, [to]], [np, [pn, [somebody]]]]]]], ['.']]], '2006-08-14-18-41-41', amadeus, '').
text_drs_eval(0, 175, 'Everybody gives somebody something.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C, D], [object(B, somebody, countable, na, eq, 1)-1, object(C, something, dom, na, na, na)-1, predicate(D, give, A, C, B)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [gives]], [np, [pn, [somebody]]], [np, [pn, [something]]]]]], ['.']]], '2006-08-14-18-42-24', amadeus, '').
text_drs_eval(0, 176, 'Nobody barks.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, bark, A)-1])])]), [[specification, [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-12-18-14-35', amadeus, '').
text_drs_eval(0, 177, 'Everybody blames somebody and nobody works.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C], [object(B, somebody, countable, na, eq, 1)-1, predicate(C, blame, A, B)-1]), drs([D], [object(D, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([E], [predicate(E, work, D)-1])])]), [[specification, [s_coord, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [blames]], [np, [pn, [somebody]]]]]], [coord, [and]], [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [works]]]]]], ['.']]], '2006-08-12-18-15-18', amadeus, '').
text_drs_eval(0, 178, 'A persona non grata enters a zip code.', drs([], []), [], '2006-08-15-15-12-31', amadeus, '').
text_drs_eval(0, 179, 'John beats his own wife.', drs([A, B, C], [object(C, 'John', named, na, eq, 1)-1, object(A, wife, countable, na, eq, 1)-1, predicate(B, beat, C, A)-1, relation(A, of, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [wife]]]]]]], ['.']]], '2005-06-05-18-22-31', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 180, 'John beats his own wife\'s mother.', drs([], []), [], '2006-08-28-20-59-25', amadeus, '').
text_drs_eval(0, 181, 'John beats a mother of his own wife.', drs([A, B, C, D], [object(B, mother, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, object(C, wife, countable, na, eq, 1)-1, predicate(A, beat, D, B)-1, relation(B, of, C)-1, relation(C, of, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [a]], [nbar, [n, [mother]], [pp, [prep, [of]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [wife]]]]]]]]]], ['.']]], '2005-06-05-18-24-35', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 182, 'John beats a mother of his own wife\'s brother.', drs([], []), [], '2006-08-28-20-59-48', amadeus, '').
text_drs_eval(0, 183, 'No laundries are clean.', drs([], [drs([A], [object(A, laundry, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [property(B, clean, pos)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [laundries]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2007-07-18-14-35-29', '130.60.155.177', '').
text_drs_eval(0, 184, 'No laundry is clean.', drs([], [drs([A], [object(A, laundry, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [property(B, clean, pos)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2006-08-12-18-15-54', amadeus, '').
text_drs_eval(0, 185, 'John\'s laundries are clean.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, property(B, clean, pos)-1, predicate(C, be, D, B)-1, object(D, laundry, countable, na, geq, 2)-1, relation(D, of, A)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [laundries]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2006-04-07-14-55-06', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 186, 'A man eats and he drinks.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, drink, B)-1, predicate(A, eat, B)-1]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-06-06-14-37-27', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 187, 'A man eats, and he drinks.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, drink, B)-1, predicate(A, eat, B)-1]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, and}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-06-06-14-37-43', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 188, 'A man eats or he drinks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1])v drs([C], [predicate(C, drink, A)-1])]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-06-06-14-38-06', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 189, 'A man eats, or he drinks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1])v drs([C], [predicate(C, drink, A)-1])]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, or}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-06-06-14-38-30', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 190, 'A man eats and he drinks or he sleeps.', drs([], [drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, drink, B)-1, predicate(A, eat, B)-1])v drs([D], [predicate(D, sleep, B)-1])]), [[specification, [s_coord, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drinks]]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-06-06-14-41-27', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 191, 'A man eats or he drinks or he sleeps.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1])v drs([], [drs([C], [predicate(C, drink, A)-1])v drs([D], [predicate(D, sleep, A)-1])])]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [drinks]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2005-06-06-17-39-11', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 192, 'There is John.', drs([], []), [], '2008-01-18-14-54-15', '130.60.155.177', '').
text_drs_eval(0, 193, 'Is there John?', drs([], []), [[query, [question, [topic, [quant, ['{is there}']], [np, [np, [var, ['John']]]]]], [?]]], '2006-08-15-20-59-12', amadeus, '').
text_drs_eval(0, 194, 'There is John. There is Mary. His and her card\'s code is valid.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['Mary']]]]]], ['.']], [specification, [s, [np, [poss_spec, [poss_np, [poss_pn_coord, [posspn, [his]], [coord, [and]], [poss_pn_coord, [posspn, [her]]]], [nbar, [n, [card]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [code]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2006-08-15-20-59-39', amadeus, '').
text_drs_eval(0, 195, 'A man that enters a card waits.', drs([A, B, C, D], [object(C, man, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-1, predicate(B, wait, C)-1, predicate(D, enter, C, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-07-16-03-27', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 196, 'A man the card of who is valid waits.', drs([A, B, C, D, E], [object(D, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, wait, D)-1, predicate(E, be, B, A)-1, property(A, valid, pos)-1, relation(B, of, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-07-16-04-27', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 197, 'A card that a man enters is valid.', drs([A, B, C, D, E], [object(D, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, be, D, E)-1, property(E, valid, pos)-1, predicate(A, enter, B, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [[]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-07-16-05-19', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 198, 'A card the code of which a man enters is valid.', drs([A, B, C, D, E, F], [object(F, card, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, object(C, code, countable, na, eq, 1)-1, relation(C, of, F)-1, predicate(E, be, F, A)-1, property(A, valid, pos)-1, predicate(B, enter, D, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [[]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-09-11-36-26', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 199, 'A bank in which a man enters a code is open.', drs([A, B, C, D, E, F], [object(E, bank, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(A, code, countable, na, eq, 1)-1, predicate(B, be, E, D)-1, property(D, open, pos)-1, modifier_pp(F, in, E)-1, predicate(F, enter, C, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [bank]], [rel_cl_coord, [rel_cl, [pp, [prep, [in]], [np, [relpn, [which]]]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [code]]]]], [pp, [[]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [open]]]]]]], ['.']]], '2005-06-07-16-11-41', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 200, 'A man that eats and that drinks is happy.', drs([A, B, C, D, E], [object(D, man, countable, na, eq, 1)-1, predicate(E, be, D, A)-1, property(A, happy, pos)-1, predicate(B, drink, D)-1, predicate(C, eat, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-07-16-12-45', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 201, 'A man that eats or that drinks is happy.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, happy, pos)-1, drs([D], [predicate(D, eat, B)-1])v drs([E], [predicate(E, drink, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-07-16-13-19', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 202, 'A man that eats or that drinks or that talks is happy.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, happy, pos)-1, drs([D], [predicate(D, eat, B)-1])v drs([], [drs([E], [predicate(E, drink, B)-1])v drs([F], [predicate(F, talk, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [talks]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-07-16-13-38', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 203, 'A man that eats or that drinks and that talks is happy.', drs([A, B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, property(A, happy, pos)-1, drs([D], [predicate(D, eat, B)-1])v drs([E, F], [predicate(E, talk, B)-1, predicate(F, drink, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]], [coord, [and]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [talks]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-07-16-14-33', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 204, 'A man that eats and that drinks or that talks is happy.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, predicate(B, be, C, A)-1, property(A, happy, pos)-1, drs([D, E], [predicate(D, drink, C)-1, predicate(E, eat, C)-1])v drs([F], [predicate(F, talk, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [talks]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-09-19-49-11', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 205, 'A man the card of who is valid or the card of who is green waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C, D, E], [object(D, card, countable, na, eq, 1)-1, relation(D, of, A)-1, property(E, valid, pos)-1, predicate(C, be, D, E)-1])v drs([F, G], [property(F, green, pos)-1, predicate(G, be, D, F)-1]), predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [coord, [or]], [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-28-18-11-52', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 206, 'A man the card of who is valid or who is green waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, drs([C, D, E], [object(D, card, countable, na, eq, 1)-1, predicate(E, be, D, C)-1, property(C, valid, pos)-1, relation(D, of, A)-1])v drs([F, G], [predicate(F, be, A, G)-1, property(G, green, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-07-16-35-08', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 207, 'A man the card of who is valid or who is green and that is happy waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C, D, E], [property(C, valid, pos)-1, predicate(D, be, E, C)-1, relation(E, of, A)-1, object(E, card, countable, na, eq, 1)-1])v drs([F, G, H, I], [property(F, green, pos)-1, predicate(G, be, A, F)-1, property(H, happy, pos)-1, predicate(I, be, A, H)-1]), predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-18-17-22-42', '130.60.155.231', '').
text_drs_eval(0, 208, 'A man writes a book the text of which is good.', drs([A, B, C, D, E, F], [object(E, man, countable, na, eq, 1)-1, object(C, book, countable, na, eq, 1)-1, object(A, text, countable, na, eq, 1)-1, predicate(B, write, E, C)-1, predicate(D, be, A, F)-1, property(F, good, pos)-1, relation(A, of, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [writes]], [np, [det, [a]], [nbar, [n, [book]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [text]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]]]]]]]]], ['.']]], '2005-06-07-16-41-35', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 209, 'A man writes a book the hero of which waits.', drs([A, B, C, D, E], [object(D, man, countable, na, eq, 1)-1, object(B, book, countable, na, eq, 1)-1, object(E, hero, countable, na, eq, 1)-1, predicate(A, write, D, B)-1, predicate(C, wait, E)-1, relation(E, of, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [writes]], [np, [det, [a]], [nbar, [n, [book]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [hero]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [vp, [vbar, [v, [waits]]]]]]]]]]], ['.']]], '2005-06-07-16-42-17', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 210, 'For each money a man waits.', drs([], [drs([A], [object(A, money, countable, na, eq, 1)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [money]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-06-07-20-24-23', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 211, 'A man waits-for something.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, 'wait-for', A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, ['waits-for']], [nbar, [pn, [something]]]]]], ['.']]], '2007-05-07-16-39-35', '130.60.156.229', '').
text_drs_eval(0, 212, 'Some cards are green.', drs([A, B, C], [object(A, card, countable, na, geq, 2)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [cards]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2005-07-06-16-22-54', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 213, 'A man is a:reich.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, predicate(B, be, C, A)-1, property(A, reich, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [reich]]]]]]], ['.']]], '2005-06-09-11-20-11', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 214, 'A man is good or is bad.', drs([A], [drs([B, C], [predicate(B, be, A, C)-1, property(C, good, pos)-1])v drs([D, E], [predicate(D, be, A, E)-1, property(E, bad, pos)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-06-09-16-36-59', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 215, 'A man is good, or is bad.', drs([A], [drs([B, C], [predicate(B, be, A, C)-1, property(C, good, pos)-1])v drs([D, E], [predicate(D, be, A, E)-1, property(E, bad, pos)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, ['{, or}']], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-06-09-16-37-12', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 216, 'A man is good and is bad.', drs([A, B, C, D, E], [object(E, man, countable, na, eq, 1)-1, predicate(D, be, E, A)-1, property(A, bad, pos)-1, predicate(B, be, E, C)-1, property(C, good, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, [and]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-06-09-16-37-31', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 217, 'A man is good, and is bad.', drs([A, B, C, D, E], [object(E, man, countable, na, eq, 1)-1, predicate(D, be, E, A)-1, property(A, bad, pos)-1, predicate(B, be, E, C)-1, property(C, good, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, ['{, and}']], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-06-09-16-37-51', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 218, 'A man is good and is nice or is bad.', drs([A], [drs([B, C, D, E], [predicate(B, be, A, C)-1, property(C, nice, pos)-1, predicate(D, be, A, E)-1, property(E, good, pos)-1])v drs([F, G], [predicate(F, be, A, G)-1, property(G, bad, pos)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, [and]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [nice]]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-06-09-16-38-24', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 219, 'A man is good, and is nice or is bad.', drs([A, B, C], [drs([D, E], [predicate(D, be, C, E)-1, property(E, nice, pos)-1])v drs([F, G], [predicate(F, be, C, G)-1, property(G, bad, pos)-1]), object(C, man, countable, na, eq, 1)-1, predicate(B, be, C, A)-1, property(A, good, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, ['{, and}']], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [nice]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]]], ['.']]], '2005-06-09-16-38-54', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 220, 'A man is good or is nice or is bad.', drs([A], [drs([B, C], [predicate(B, be, A, C)-1, property(C, good, pos)-1])v drs([], [drs([D, E], [predicate(D, be, A, E)-1, property(E, nice, pos)-1])v drs([F, G], [predicate(F, be, A, G)-1, property(G, bad, pos)-1])]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, [or]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [nice]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]]], ['.']]], '2005-06-09-16-39-16', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 221, 'A man is good or is nice, or is bad.', drs([A], [drs([], [drs([B, C], [predicate(B, be, A, C)-1, property(C, good, pos)-1])v drs([D, E], [predicate(D, be, A, E)-1, property(E, nice, pos)-1])])v drs([F, G], [predicate(F, be, A, G)-1, property(G, bad, pos)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [nice]]]]]]], [coord, ['{, or}']], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-06-09-16-40-19', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 222, 'There is a man that eats and drinks.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-08-26-14-47-37', blade17, '').
text_drs_eval(0, 223, 'There is a man that eats or drinks.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-08-26-14-47-17', blade17, '').
text_drs_eval(0, 224, 'There is a man that eats and that drinks.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1, predicate(C, drink, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]]]]]]], ['.']]], '2005-08-15-14-50-53', blade17, '').
text_drs_eval(0, 225, 'There is a man the card of who is green and the code of who is valid.', drs([A, B, C, D, E, F, G], [object(G, man, countable, na, eq, 1)-1, object(E, card, countable, na, eq, 1)-1, object(A, code, countable, na, eq, 1)-1, predicate(F, be, A, D)-1, property(D, valid, pos)-1, relation(A, of, G)-1, predicate(B, be, E, C)-1, property(C, green, pos)-1, relation(E, of, G)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], [coord, [and]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]]]], ['.']]], '2005-06-09-17-40-10', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 226, 'There is a man the card of who is green or the code of who is valid.', drs([A], [drs([B, C, D], [object(D, card, countable, na, eq, 1)-1, predicate(C, be, D, B)-1, property(B, green, pos)-1, relation(D, of, A)-1])v drs([E, F, G], [object(G, code, countable, na, eq, 1)-1, predicate(F, be, G, E)-1, property(E, valid, pos)-1, relation(G, of, A)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]]]], ['.']]], '2005-06-09-17-40-34', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 227, 'Is there a man that waits?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, wait, A)-1/6]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]]]], ?], '.']], '2009-05-13-13-59-20', '130.60.155.177', '').
text_drs_eval(0, 228, 'There is a man that eats and that drinks or that sleeps.', drs([A], [drs([B, C], [predicate(B, drink, A)-1, predicate(C, eat, A)-1])v drs([D], [predicate(D, sleep, A)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]]]]]]], ['.']]], '2005-06-09-18-37-06', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 229, 'There is a man that eats, and that drinks or that sleeps.', drs([A, B], [drs([C], [predicate(C, drink, B)-1])v drs([D], [predicate(D, sleep, B)-1]), object(B, man, countable, na, eq, 1)-1, predicate(A, eat, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, and}']], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]]]]]]]], ['.']]], '2005-06-09-18-38-21', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 230, 'There is a man that eats, and that drinks or that sleeps and that waits.', drs([A, B], [drs([C], [predicate(C, drink, B)-1])v drs([D, E], [predicate(D, wait, B)-1, predicate(E, sleep, B)-1]), object(B, man, countable, na, eq, 1)-1, predicate(A, eat, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, and}']], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]]]]], ['.']]], '2005-06-09-18-38-59', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 231, 'There is a man that eats, and that drinks or that sleeps, and that waits.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, predicate(B, wait, C)-1, drs([D], [predicate(D, drink, C)-1])v drs([E], [predicate(E, sleep, C)-1]), predicate(A, eat, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, and}']], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [drinks]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]]], [coord, ['{, and}']], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]]]], ['.']]], '2005-06-09-18-39-28', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 232, 'There is a man the dog of who barks and the cat of who plays or the mouse of who eats.', drs([A], [drs([B, C, D, E], [object(E, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, predicate(D, play, B)-1, relation(B, of, A)-1, predicate(C, bark, E)-1, relation(E, of, A)-1])v drs([F, G], [object(G, mouse, countable, na, eq, 1)-1, predicate(F, eat, G)-1, relation(G, of, A)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [rel_cl, [np, [det, [the]], [nbar, [n, [cat]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [plays]]]]]], [coord, [or]], [rel_cl, [np, [det, [the]], [nbar, [n, [mouse]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [eats]]]]]]]]]], ['.']]], '2005-06-09-18-41-45', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 233, 'There is a man the dog of who barks, and the cat of who plays or the mouse of who eats.', drs([A, B, C], [drs([D, E], [object(E, cat, countable, na, eq, 1)-1, predicate(D, play, E)-1, relation(E, of, C)-1])v drs([F, G], [object(G, mouse, countable, na, eq, 1)-1, predicate(F, eat, G)-1, relation(G, of, C)-1]), object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, relation(A, of, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]], [coord, ['{, and}']], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [cat]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [plays]]]]], [coord, [or]], [rel_cl, [np, [det, [the]], [nbar, [n, [mouse]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [eats]]]]]]]]]]], ['.']]], '2005-06-09-18-42-23', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 234, 'Is there a man that runs or waits?', drs([], []), [], '2005-08-17-18-41-00', blade17, '').
text_drs_eval(0, 235, 'Is there a man that runs or that waits?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4, drs([B], [predicate(B, run, A)-1/6])v drs([C], [predicate(C, wait, A)-1/9])]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, a], [nbar, [n, man], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, runs]]]]], [coord, or], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]]]]], ?], '.']], '2009-05-13-13-59-29', '130.60.155.177', '').
text_drs_eval(0, 236, 'A man who is happy and sad waits.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, predicate(C, wait, D)-1, predicate(A, be, D, B)-1, property(B, sad, pos)-1, property(B, happy, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]], [coord, [and]], [ap_coord, [ap, [adj, [sad]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-09-18-45-34', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 237, 'A man who is happy or who is sad waits.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, wait, B)-1, drs([C, D], [predicate(C, be, B, D)-1, property(D, happy, pos)-1])v drs([E, F], [predicate(E, be, B, F)-1, property(F, sad, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-09-18-46-13', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 238, 'A man who is happy or who is sad and who is rich waits.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, wait, B)-1, drs([C, D], [predicate(C, be, B, D)-1, property(D, happy, pos)-1])v drs([E, F, G, H], [predicate(E, be, B, F)-1, property(F, rich, pos)-1, predicate(G, be, B, H)-1, property(H, sad, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-09-18-47-03', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 239, 'A man who is happy or who is sad, and who is rich waits.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, predicate(C, wait, D)-1, predicate(A, be, D, B)-1, property(B, rich, pos)-1, drs([E, F], [predicate(E, be, D, F)-1, property(F, happy, pos)-1])v drs([G, H], [predicate(G, be, D, H)-1, property(H, sad, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]]], [coord, ['{, and}']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-09-18-47-32', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 240, 'A man who is happy or who is sad, and the dog of who barks waits.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, wait, D)-1, predicate(C, bark, B)-1, relation(B, of, D)-1, drs([E, F], [predicate(E, be, D, F)-1, property(F, happy, pos)-1])v drs([G, H], [predicate(G, be, D, H)-1, property(H, sad, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]]], [coord, ['{, and}']], [rel_cl, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-09-18-49-02', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 241, 'If there is a man who is happy or who is sad, and the dog of who barks then he waits.', drs([], [drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, relation(A, of, C)-1, drs([D, E], [predicate(D, be, C, E)-1, property(E, happy, pos)-1])v drs([F, G], [predicate(F, be, C, G)-1, property(G, sad, pos)-1])])=>drs([H], [predicate(H, wait, C)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]]], [coord, ['{, and}']], [rel_cl, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-06-09-18-50-47', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 242, '2 men Gerold and Kaarel program a n:parser APE the sentences of which nobody understands.', drs([], []), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos_coord, [appos, [var, ['Gerold']]], [coord, [and]], [appos_coord, [appos, [var, ['Kaarel']]]]]]], [vp, [vbar, [v, [program]], [np, [det, [a]], [nbar, [n, [parser]], [appos_coord, [appos, [var, ['APE']]]], [rel_cl, [np, [det, [the]], [nbar, [n, [sentences]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [np, [pn, [nobody]]], [vp, [vbar, [v, [understands]], [np, [[]]]]]]]]]]], ['.']]], '2006-08-12-18-16-31', amadeus, '').
text_drs_eval(0, 243, 'Some men Gerold and Kaarel program a n:parser APE the sentences of which nobody understands.', drs([], []), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]], [appos_coord, [appos, [var, ['Gerold']]], [coord, [and]], [appos_coord, [appos, [var, ['Kaarel']]]]]]], [vp, [vbar, [v, [program]], [np, [det, [a]], [nbar, [n, [parser]], [appos_coord, [appos, [var, ['APE']]]], [rel_cl, [np, [det, [the]], [nbar, [n, [sentences]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [np, [pn, [nobody]]], [vp, [vbar, [v, [understands]], [np, [[]]]]]]]]]]], ['.']]], '2006-08-12-18-18-15', amadeus, '').
text_drs_eval(0, 244, 'John\'s code is red. John\'s code is blue.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, code, countable, na, eq, 1)-1, property(C, red, pos)-1, predicate(D, be, B, C)-1, relation(E, of, A)-2, object(E, code, countable, na, eq, 1)-2, property(F, blue, pos)-2, predicate(G, be, E, F)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [code]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']], [specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [code]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [blue]]]]]]], ['.']]], '2006-08-22-11-32-15', amadeus, '').
text_drs_eval(0, 245, 'John enters every card which is his own card.', drs([], []), [], '2008-10-23-14-59-24', '130.60.155.206', '').
text_drs_eval(0, 246, 'A man sees a dog and a cat.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(E, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, has_part(D, B)-1, has_part(D, C)-1, predicate(A, see, E, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2005-06-09-20-00-19', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 247, 'A man sees a dog and a man.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(E, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, has_part(D, B)-1, has_part(D, C)-1, predicate(A, see, E, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], ['.']]], '2005-06-09-20-00-43', 'ifidyn146.ifi.unizh.ch', '').
text_drs_eval(0, 248, 'A man hits his own dog. The man is happy.', drs([A, B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, hit, C, B)-1, property(D, happy, pos)-2, predicate(E, be, C, D)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-07-06-16-30-15', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 249, 'Who waits?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, wait, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-13-59-40', '130.60.155.177', '').
text_drs_eval(0, 250, 'Who hits who?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, query(B, who)-1/3, predicate(C, hit, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, hits], [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-59-46', '130.60.155.177', '').
text_drs_eval(0, 251, 'Who gives who who?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/1, query(B, who)-1/3, query(C, who)-1/4, predicate(D, give, A, C, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, gives], [np, [qpn, who]], [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-59-53', '130.60.155.177', '').
text_drs_eval(0, 252, 'Who gives who what?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/1, query(B, who)-1/3, query(C, what)-1/4, predicate(D, give, A, C, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, gives], [np, [qpn, who]], [np, [qpn, what]]]]]], ?], '.']], '2009-05-13-14-00-00', '130.60.155.177', '').
text_drs_eval(0, 253, 'Who gives what to who?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/1, query(B, what)-1/3, query(C, who)-1/5, predicate(D, give, A, B, C)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, gives], [np, [qpn, what]], to, [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-14-00-06', '130.60.155.177', '').
text_drs_eval(0, 254, 'A man who a man who a man sees sees sees a man.', drs([A, B, C, D, E, F, G], [object(G, man, countable, na, eq, 1)-1, object(E, man, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, predicate(B, see, G, D)-1, predicate(F, see, E, G)-1, predicate(A, see, C, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2005-06-11-22-21-43', unknown, '').
text_drs_eval(0, 255, 'There is a man whose dog is happy.', drs([A, B, C, D], [object(C, dog, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, relation(C, of, D)-1, property(A, happy, pos)-1, predicate(B, be, C, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]]]]]], ['.']]], '2005-12-24-15-37-48', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 256, 'A man waits at a desk in a bank.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, bank, countable, na, eq, 1)-1, object(C, desk, countable, na, eq, 1)-1, modifier_pp(A, at, C)-1, modifier_pp(A, in, B)-1, predicate(A, wait, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [at]], [np, [det, [a]], [nbar, [n, [desk]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-06-12-14-31-23', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 257, 'Where does a man A wait?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, wait, A)-1/6, query(B, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man], [appos, [var, 'A']]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-14-00-13', '130.60.155.177', '').
text_drs_eval(0, 258, 'A man John gives his own wife Mary a unknownword.', drs([], []), [], '2005-08-31-21-02-05', blade17, '').
text_drs_eval(0, 259, 'A syntactic error is in the sentence.', drs([A, B, C], [object(C, error, countable, na, eq, 1)-1, object(B, sentence, countable, na, eq, 1)-1, property(C, syntactic, pos)-1, predicate(A, be, C)-1, modifier_pp(A, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [syntactic]], [nbar, [n, [error]]]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [sentence]]]]]]]], ['.']]], '2005-08-04-15-06-12', blade17, '').
text_drs_eval(0, 260, 'There is a man A. A sees himself.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, see, A, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['A']]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-08-26-19-18-41', blade17, '').
text_drs_eval(0, 261, 'There are John and Mary.', drs([], []), [], '2008-01-03-16-26-54', '130.60.206.88', '').
text_drs_eval(0, 262, 'There are John and Mary. There are Bill and Mary.', drs([], []), [], '2008-01-03-16-27-05', '130.60.206.88', '').
text_drs_eval(0, 263, 'There is a man. There is the woman.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [woman]]]]]]], ['.']]], '2006-05-24-19-08-12', amadeus, '').
text_drs_eval(0, 264, 'There is the man A.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['A']]]]]]]]], ['.']]], '2006-05-24-19-08-47', amadeus, '').
text_drs_eval(0, 265, 'There is someone. He waits.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [someone]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-07-16-07-11', blade17, '').
text_drs_eval(0, 266, 'There is something. It waits.', drs([A, B], [object(A, something, dom, na, na, na)-1, predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [something]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-07-16-07-29', blade17, '').
text_drs_eval(0, 267, 'Who sees himself?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, see, A, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [pn, himself]]]]]], ?], '.']], '2009-05-13-14-00-23', '130.60.155.177', '').
text_drs_eval(0, 268, 'Somebody sees himself/herself.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [pn, ['himself/herself']]]]]], ['.']]], '2005-11-07-16-07-50', blade17, '').
text_drs_eval(0, 269, 'Who see themselves?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, see, A, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, see], [np, [pn, themselves]]]]]], ?], '.']], '2009-05-13-14-00-30', '130.60.155.177', '').
text_drs_eval(0, 270, 'Who sees themselves?', drs([], []), [[query, [question, [np, [qpn, [who]]], [vp, [vbar, [v, [sees]], [np, [pn, [themselves]]]]]], [?]]], '2005-08-28-22-14-25', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 271, 'There is somebody. They wait.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [somebody]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2005-08-28-09-51-49', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 272, 'Who runs and hits himself?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, predicate(B, run, A)-1/2, predicate(C, hit, A, A)-1/4]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp_coord, [vp, [vbar, [vbar, [v, runs]]]], [coord, and], [vp, [vbar, [vcompl, [v, hits], [np, [pn, himself]]]]]]], ?], '.']], '2009-05-13-14-00-36', '130.60.155.177', '').
text_drs_eval(0, 273, 'Who wait?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, wait, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-14-00-44', '130.60.155.177', '').
text_drs_eval(0, 274, 'John waits. John runs.', drs([A, B, C], [object(C, 'John', named, na, eq, 1)-1, predicate(A, run, C)-2, predicate(B, wait, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2005-06-15-19-32-55', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 275, 'There is a man. There is a boy. He sees him.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, boy, countable, na, eq, 1)-2, predicate(B, see, A, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2005-06-16-16-34-11', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 276, 'There is a man. There is a boy. He sees himself.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, boy, countable, na, eq, 1)-2, predicate(B, see, A, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-06-16-16-34-24', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 277, 'There is a boy. He sees the boy.', drs([A, B], [object(B, boy, countable, na, eq, 1)-1, predicate(A, see, B, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [boy]]]]]]], ['.']]], '2005-06-20-18-02-37', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 278, 'There is a man. There is a boy. The man sees the boy.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, boy, countable, na, eq, 1)-2, predicate(B, see, C, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [boy]]]]]]], ['.']]], '2005-06-16-16-36-00', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 279, 'There is a man. There is a boy. The man sees himself.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, boy, countable, na, eq, 1)-2, predicate(B, see, C, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-06-16-16-36-16', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 280, 'There is a man. There is a boy. The man sees a boy.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, boy, countable, na, eq, 1)-2, object(C, boy, countable, na, eq, 1)-3, predicate(A, see, D, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [boy]]]]]]], ['.']]], '2005-06-16-16-36-39', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 281, 'There are a man and a dog.', drs([A, B, C], [object(B, na, countable, na, eq, 2)-1, object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, has_part(B, A)-1, has_part(B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-06-17-13-25-11', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 282, 'There are a man and he.', drs([], []), [[top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [pn, [he]]]]]]], '2007-11-02-19-26-44', '130.60.155.177', '').
text_drs_eval(0, 283, 'There is a boy. There are a man and he.', drs([], []), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [pn, [he]]]]]]], '2007-11-02-19-26-54', '130.60.155.177', '').
text_drs_eval(0, 284, 'There is a laundry. The laundry is clean.', drs([A, B, C], [object(C, laundry, countable, na, eq, 1)-1, predicate(B, be, C, A)-2, property(A, clean, pos)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [laundry]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-06-17-16-34-08', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 285, 'There is some laundry. The laundry is clean.', drs([A, B, C], [object(A, laundry, mass, na, na, na)-1, property(B, clean, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-10-31-12-13-55', blade17, '').
text_drs_eval(0, 286, 'There is a man John.', drs([], []), [], '2005-08-31-20-20-11', blade17, '').
text_drs_eval(0, 287, 'There is a man John. John sleeps.', drs([], []), [], '2005-08-31-20-20-54', blade17, '').
text_drs_eval(0, 288, 'A man likes a dog. It barks.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, bark, B)-2, predicate(C, like, D, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-18-20-58-09', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 289, 'A man does not like John. He waits.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, A)-2, -drs([D], [predicate(D, like, C, A)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [like]], [np, [pname, ['John']]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-18-20-59-50', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 290, 'A man does not like a man John.', drs([], []), [], '2005-08-31-20-21-12', blade17, '').
text_drs_eval(0, 291, 'A man likes a boy John.', drs([], []), [], '2005-08-31-20-21-29', blade17, '').
text_drs_eval(0, 292, 'For every wolf for every fox the wolf does not eat the fox.', drs([], [drs([A], [object(A, wolf, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, fox, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, eat, A, B)-1])])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [wolf]]]], [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [fox]]]], [s, [np, [det, [the]], [nbar, [n, [wolf]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [eat]], [np, [det, [the]], [nbar, [n, [fox]]]]]]]]], ['.']]], '2005-07-06-16-36-42', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 293, 'If a man owns a donkey then he beats it.', drs([], [drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, donkey, countable, na, eq, 1)-1, predicate(B, own, C, A)-1])=>drs([D], [predicate(D, beat, C, A)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [donkey]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [beats]], [np, [pn, [it]]]]]]], ['.']]], '2005-06-19-18-11-48', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 294, 'If John owns a donkey then he beats it.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [object(B, donkey, countable, na, eq, 1)-1, predicate(C, own, A, B)-1])=>drs([D], [predicate(D, beat, A, B)-1])]), [[specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [donkey]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [beats]], [np, [pn, [it]]]]]]], ['.']]], '2005-07-06-16-37-44', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 295, 'Every farmer who owns a donkey beats it.', drs([], [drs([A, B, C], [object(C, farmer, countable, na, eq, 1)-1, object(A, donkey, countable, na, eq, 1)-1, predicate(B, own, C, A)-1])=>drs([D], [predicate(D, beat, C, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [farmer]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [donkey]]]]]]]]], [vp, [vbar, [v, [beats]], [np, [pn, [it]]]]]], ['.']]], '2005-06-19-18-12-42', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 296, 'John owns a donkey. He beats it.', drs([A, B, C, D], [object(C, donkey, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, predicate(B, beat, D, C)-2, predicate(A, own, D, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [donkey]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [beats]], [np, [pn, [it]]]]]], ['.']]], '2005-06-19-18-13-58', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 297, 'Every man who loves a woman who loves him is happy.', drs([], [drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(A, love, D, B)-1, predicate(C, love, B, D)-1])=>drs([E, F], [predicate(E, be, D, F)-1, property(F, happy, pos)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [loves]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [loves]], [np, [pn, [him]]]]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-19-18-15-12', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 298, 'If there is a man and there is a woman and the man loves the woman and the woman loves the man then the man is happy.', drs([], [drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(A, love, B, D)-1, predicate(C, love, D, B)-1])=>drs([E, F], [predicate(E, be, D, F)-1, property(F, happy, pos)-1])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [and]], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]], [coord, [and]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [loves]], [np, [det, [the]], [nbar, [n, [woman]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [loves]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]]], ['.']]], '2005-06-19-18-19-19', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 299, 'John owns Mary. He beats her.', drs([A, B, C, D], [object(D, 'John', named, na, eq, 1)-1, object(C, 'Mary', named, na, eq, 1)-1, predicate(A, beat, D, C)-2, predicate(B, own, D, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [pname, ['Mary']]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [beats]], [np, [pn, [her]]]]]], ['.']]], '2005-06-19-18-29-54', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 300, 'There is a man who sees himself.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, see, B, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]]]]]], ['.']]], '2005-06-19-18-32-52', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 301, 'There is a boy. There is a man who he sees.', drs([A, B, C], [object(C, boy, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-2, predicate(B, see, C, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]], ['.']]], '2005-06-19-18-34-13', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 302, 'There is a boy. There is a man who sees him.', drs([A, B, C], [object(C, boy, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-2, predicate(B, see, A, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]]]]], ['.']]], '2005-06-19-18-34-55', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 303, 'There is a man who the man sees.', drs([A, B], [predicate(B, see, A, A)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]], ['.']]], '2007-11-10-17-24-07', '84.74.160.172', '').
text_drs_eval(0, 304, 'There is a man who sees the man.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, see, B, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]], ['.']]], '2005-06-20-18-07-14', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 305, 'A man Man1 waits.', drs([], []), [], '2008-07-09-15-22-34', '130.60.155.206', '').
text_drs_eval(0, 306, 'A man Man1 waits. The man Man1 is happy.', drs([], []), [], '2008-07-09-15-22-44', '130.60.155.206', '').
text_drs_eval(0, 307, 'A man Man1 waits. Man1 is happy.', drs([], []), [], '2008-07-09-15-23-04', '130.60.155.206', '').
text_drs_eval(0, 308, 'There is a dog. A man does not see the dog. It is under the bed.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-2, object(D, dog, countable, na, eq, 1)-1, object(C, bed, countable, na, eq, 1)-3, -drs([E], [predicate(E, see, A, D)-2]), predicate(B, be, D)-3, modifier_pp(B, under, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [see]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [pp, [prep, [under]], [np, [det, [the]], [nbar, [n, [bed]]]]]]]], ['.']]], '2005-08-04-15-08-27', blade17, '').
text_drs_eval(0, 309, 'Some abaci are green.', drs([A, B, C], [object(A, abacus, countable, na, geq, 2)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [abacuses]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2006-04-07-14-56-19', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 310, 'A man enters a card manually and waits.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(A, wait, D)-1, modifier_adv(C, manually, pos)-1, predicate(C, enter, D, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]], [adv, [manually]]]], [coord, [and]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-06-20-10-54-22', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 311, 'Which man the dog of who sees a bone is there?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, object(B, bone, countable, na, eq, 1)-1/9, predicate(C, see, D, B)-1/7, relation(D, of, A)-1/5, object(D, dog, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [topic, [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, bone]]]]]]]]], [quant, 'is there']]], ?], '.']], '2009-05-13-14-00-54', '130.60.155.177', '').
text_drs_eval(0, 312, 'Which man the dog of who sees a bone waits?', drs([], [question(drs([A, B, C, D, E], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, object(B, bone, countable, na, eq, 1)-1/9, predicate(C, see, D, B)-1/7, relation(D, of, A)-1/5, object(D, dog, countable, na, eq, 1)-1/4, predicate(E, wait, A)-1/10]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, bone]]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-01-54', '130.60.155.177', '').
text_drs_eval(0, 313, 'Which man who eats waits?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, predicate(B, eat, A)-1/4, predicate(C, wait, A)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, eats]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-04-15', '130.60.155.177', '').
text_drs_eval(0, 314, 'Which man whose dog sees a bone waits?', drs([], [question(drs([A, B, C, D, E], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, object(B, dog, countable, na, eq, 1)-1/4, relation(B, of, A)-1/3, object(C, bone, countable, na, eq, 1)-1/7, predicate(D, see, B, C)-1/5, predicate(E, wait, A)-1/8]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, bone]]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-04-22', '130.60.155.177', '').
text_drs_eval(0, 315, 'A man hits a dog the bone of who is green.', drs([], []), [], '2007-11-20-11-26-51', '130.60.155.231', '').
text_drs_eval(0, 316, 'A man hits a dog whose bone is green.', drs([A, B, C, D, E, F], [object(D, bone, countable, na, eq, 1)-1, object(E, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, relation(D, of, E)-1, property(B, green, pos)-1, predicate(C, be, D, B)-1, predicate(F, hit, A, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [bone]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]]]]]]], ['.']]], '2005-12-24-15-41-47', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 317, 'Which man is there?', drs([], [question(drs([A], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2]))]), [[sentence, [query, [question, [topic, [np, [qdet, which], [nbar, [n, man]]], [quant, 'is there']]], ?], '.']], '2009-05-13-14-04-29', '130.60.155.177', '').
text_drs_eval(0, 318, 'Who does a man hit?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, query(B, who)-1/1, predicate(C, hit, A, B)-1/5]))]), [[sentence, [query, [question, [np, [qpn, who]], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, hit]]]]], ?], '.']], '2009-05-13-14-04-36', '130.60.155.177', '').
text_drs_eval(0, 319, 'A man waits in a room in a bank.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, bank, countable, na, eq, 1)-1, object(C, room, countable, na, eq, 1)-1, modifier_pp(A, in, C)-1, modifier_pp(A, in, B)-1, predicate(A, wait, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [room]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-06-20-11-03-18', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 320, 'A man waits quickly in a bank.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1, modifier_pp(C, in, A)-1, modifier_adv(C, quickly, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [adv, [quickly]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-08-10-12-09-21', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 321, 'A man waits in a bank quickly.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1, modifier_adv(C, quickly, pos)-1, modifier_pp(C, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]], [adv, [quickly]]]]], ['.']]], '2005-08-15-19-19-21', blade17, '').
text_drs_eval(0, 322, 'A man hits a dog which runs fast.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, run, B)-1, modifier_adv(C, fast, pos)-1, predicate(D, hit, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, hits], [np, [det, a], [nbar, [n, dog], [rel_cl, [np, [relpn, which]], [vp, [vbar, [vbar, [v, runs]], [adv, fast]]]]]]]]], '.']], '2008-10-06-15-32-16', '130.60.155.206', '').
text_drs_eval(0, 323, 'A man hits a dog which runs fast quickly.', drs([], []), [], '2008-10-06-13-23-29', '130.60.155.206', '').
text_drs_eval(0, 324, 'A man quickly hits a dog which runs fast.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, modifier_adv(A, quickly, pos)-1, predicate(A, hit, D, B)-1, modifier_adv(C, fast, pos)-1, predicate(C, run, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [adv, [quickly]], [vbar, [v, [hits]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [fast]]]]]]]]]]], ['.']]], '2005-06-20-11-12-27', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 325, 'Whose card is valid?', drs([], [question(drs([A, B, C, D], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, card, countable, na, eq, 1)-1/2, property(C, valid, pos)-1/4, predicate(D, be, B, C)-1/3]))]), [[sentence, [query, [question, [np, [qdet, whose], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-04-46', '130.60.155.177', '').
text_drs_eval(0, 326, 'Is the man\'s card valid?', drs([], [question(drs([A, B, C, D], [relation(A, of, D)-1/4, object(A, card, countable, na, eq, 1)-1/6, property(B, valid, pos)-1/7, predicate(C, be, A, B)-1/1, object(D, man, countable, na, eq, 1)-1/3]))]), [[sentence, [query, [question, is, [np, [poss_np, [det, the], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, card]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-04-53', '130.60.155.177', '').
text_drs_eval(0, 327, 'John is small.', drs([A, B, C], [object(C, 'John', named, na, eq, 1)-1, predicate(A, be, C, B)-1, property(B, small, pos)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [small]]]]]]], ['.']]], '2005-06-20-13-10-10', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 328, 'A man hits a green dog that barks.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, hit, D, B)-1, predicate(C, bark, B)-1, property(B, green, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [det, [a]], [nbar, [adj, [green]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]]]], ['.']]], '2005-06-20-14-06-36', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 329, 'The card of which man is valid?', drs([], [question(drs([A, B, C, D], [property(A, valid, pos)-1/7, predicate(B, be, C, A)-1/6, relation(C, of, D)-1/3, object(D, man, countable, na, eq, 1)-1/5, query(D, which)-1/4, object(C, card, countable, na, eq, 1)-1/2]))]), [[sentence, [query, [question, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-05-03', '130.60.155.177', '').
text_drs_eval(0, 330, 'The card of who is valid?', drs([], [question(drs([A, B, C, D], [property(A, valid, pos)-1/6, predicate(B, be, C, A)-1/5, relation(C, of, D)-1/3, query(D, who)-1/4, object(C, card, countable, na, eq, 1)-1/2]))]), [[sentence, [query, [question, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-05-13', '130.60.155.177', '').
text_drs_eval(0, 331, 'Which card of which man is valid?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, card, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, man, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, property(C, valid, pos)-1/7, predicate(D, be, A, C)-1/6]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-05-20', '130.60.155.177', '').
text_drs_eval(0, 332, 'There is a card of a man which is valid.', drs([], []), [], '2007-08-08-11-07-57', '130.60.155.231', '').
text_drs_eval(0, 333, 'There is a man. If the man enters a card then the card is correct.', drs([A], [drs([B, C], [object(C, card, countable, na, eq, 1)-2, predicate(B, enter, A, C)-2])=>drs([D, E], [predicate(D, be, C, E)-2, property(E, correct, pos)-2]), object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]]], ['.']]], '2005-06-20-15-39-11', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 334, 'There is a man. If the man enters a card then the card is correct. He sleeps.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C, D], [object(C, card, countable, na, eq, 1)-2, predicate(D, enter, A, C)-2])=>drs([E, F], [property(E, correct, pos)-2, predicate(F, be, C, E)-2]), predicate(B, sleep, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-07-06-16-39-17', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 335, 'John eats or John drinks.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, eat, A)-1])v drs([C], [predicate(C, drink, A)-1])]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2005-06-20-17-47-28', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 336, 'John eats or John drinks. Mary eats or Mary drinks or Bill sleeps.', drs([A, B, C], [object(B, 'John', named, na, eq, 1)-1, object(C, 'Mary', named, na, eq, 1)-2, object(A, 'Bill', named, na, eq, 1)-2, drs([D], [predicate(D, eat, C)-2])v drs([], [drs([E], [predicate(E, drink, C)-2])v drs([F], [predicate(F, sleep, A)-2])]), drs([G], [predicate(G, eat, B)-1])v drs([H], [predicate(H, drink, B)-1])]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [drinks]]]]]], ['.']], [specification, [s_coord, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [s_coord, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [drinks]]]]], [coord, [or]], [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2005-06-20-17-55-16', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 337, 'There are John and 2 men.', drs([], []), [], '2008-01-03-16-27-16', '130.60.206.88', '').
text_drs_eval(0, 338, 'There are John and 2 men ManGroup.', drs([], []), [], '2008-01-03-16-27-26', '130.60.206.88', '').
text_drs_eval(0, 339, 'There are John and 2 men ManGroup. ManGroup is happy.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['ManGroup']]]]]]]], ['.']], [specification, [s, [np, [var, ['ManGroup']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2007-12-29-18-02-25', '130.60.204.10', '').
text_drs_eval(0, 340, 'There are a man X and a man Y and a man Z.', drs([A, B, C, D], [object(D, na, countable, na, eq, 3)-1, object(A, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, has_part(D, C)-1, has_part(D, B)-1, has_part(D, A)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [coord, [and]], [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['Y']]]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['Z']]]]]]]]]], ['.']]], '2005-08-26-19-25-26', blade17, '').
text_drs_eval(0, 341, 'There are some men. If they are happy then they wait.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B, C], [property(B, happy, pos)-2, predicate(C, be, A, B)-2])=>drs([D], [predicate(D, wait, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [pn, [they]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]], [then], [s, [np, [pn, [they]]], [vp, [vbar, [v, [wait]]]]]], ['.']]], '2006-04-07-14-57-33', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 342, 'If John waits then John sleeps.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])=>drs([C], [predicate(C, sleep, A)-1])]), [[specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-07-06-16-39-44', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 343, 'If John waits then he sleeps.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])=>drs([C], [predicate(C, sleep, A)-1])]), [[specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-07-06-16-40-05', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 344, 'If a man John waits then he sleeps.', drs([], []), [], '2005-08-31-20-21-51', blade17, '').
text_drs_eval(0, 345, 'John\'s laundry is clean.', drs([A, B, C, D], [object(C, laundry, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, relation(C, of, D)-1, property(A, clean, pos)-1, predicate(B, be, C, A)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-08-26-20-34-22', blade17, '').
text_drs_eval(0, 346, 'Some laundry of John is clean.', drs([A, B, C, D], [object(A, laundry, mass, na, na, na)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, property(C, clean, pos)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [laundry]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-10-04-17-12-36', blade17, '').
text_drs_eval(0, 347, 'A laundry of John is clean.', drs([A, B, C, D], [object(D, laundry, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, be, D, A)-1, property(A, clean, pos)-1, relation(D, of, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [laundry]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-06-21-11-43-59', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 348, 'Something happens. It is good.', drs([A, B, C, D], [object(A, something, dom, na, na, na)-1, predicate(B, happen, A)-1, property(C, good, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [happens]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]]], ['.']]], '2005-11-07-16-08-31', blade17, '').
text_drs_eval(0, 349, 'Nobody waits.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-21-29', amadeus, '').
text_drs_eval(0, 350, 'Nobody sees himself.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, see, A, A)-1])])]), [[specification, [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2006-08-12-18-21-23', amadeus, '').
text_drs_eval(0, 351, 'Every man who sees himself waits.', drs([], [drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, see, B, B)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-22-13-12-23', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 352, 'Each of some men waits.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, wait, B)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-12-12-12-05', '130.60.155.177', '').
text_drs_eval(0, 353, 'Each of some men who eat waits.', drs([A, B], [drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, wait, C)-1]), predicate(B, eat, A)-1, object(A, man, countable, na, geq, 2)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [eat]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-12-12-12-21', '130.60.155.177', '').
text_drs_eval(0, 354, 'Each of some men who see themselves waits.', drs([A, B], [drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, wait, C)-1]), predicate(B, see, A, A)-1, object(A, man, countable, na, geq, 2)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [see]], [np, [pn, [themselves]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-12-12-12-34', '130.60.155.177', '').
text_drs_eval(0, 355, 'A man who walks is happy.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, predicate(C, be, D, A)-1, property(A, happy, pos)-1, predicate(B, walk, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-23-12-01-59', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 356, 'A man who walks is happy. A man who talks is sad. The man waits.', drs([A, B, C, D, E, F, G, H, I], [object(I, man, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-2, predicate(C, wait, D)-3, predicate(H, be, D, A)-2, property(A, sad, pos)-2, predicate(B, talk, D)-2, predicate(E, be, I, F)-1, property(F, happy, pos)-1, predicate(G, walk, I)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-23-12-02-46', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 357, 'A man who walks is happy. A man who talks is sad. The man who walks waits.', drs([A, B, C, D, E, F, G, H, I], [object(I, man, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-2, predicate(C, wait, I)-3, predicate(H, be, D, A)-2, property(A, sad, pos)-2, predicate(B, talk, D)-2, predicate(E, be, I, F)-1, property(F, happy, pos)-1, predicate(G, walk, I)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-23-12-03-57', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 358, 'A dog of a man is happy. A dog of a woman is sad. The dog barks.', drs([A, B, C, D, E, F, G, H, I], [object(I, dog, countable, na, eq, 1)-1, object(G, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-2, object(A, woman, countable, na, eq, 1)-2, predicate(H, bark, C)-3, predicate(B, be, C, F)-2, property(F, sad, pos)-2, relation(C, of, A)-2, predicate(D, be, I, E)-1, property(E, happy, pos)-1, relation(I, of, G)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-23-12-06-02', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 359, 'A dog of a man is happy. A dog of a woman is sad. The dog of a man barks.', drs([A, B, C, D, E, F, G, H, I], [object(I, dog, countable, na, eq, 1)-1, object(G, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-2, object(A, woman, countable, na, eq, 1)-2, predicate(H, bark, I)-3, predicate(B, be, C, F)-2, property(F, sad, pos)-2, relation(C, of, A)-2, predicate(D, be, I, E)-1, property(E, happy, pos)-1, relation(I, of, G)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-23-12-07-23', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 360, 'A dog of a man is happy. A dog of a woman is sad. The dog of the man barks.', drs([A, B, C, D, E, F, G, H, I], [object(E, woman, countable, na, eq, 1)-2, object(C, dog, countable, na, eq, 1)-2, object(D, man, countable, na, eq, 1)-1, object(F, dog, countable, na, eq, 1)-1, relation(F, of, D)-1, property(A, happy, pos)-1, predicate(B, be, F, A)-1, relation(C, of, E)-2, property(G, sad, pos)-2, predicate(H, be, C, G)-2, predicate(I, bark, F)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-11-29-20-40-51', blade17, '').
text_drs_eval(0, 361, 'A dog Muri of a man is happy. A dog of a woman is sad. Muri barks.', drs([], []), [], '2008-07-09-15-23-16', '130.60.155.206', '').
text_drs_eval(0, 362, 'A dog Muri of a man is happy. A dog of a woman is sad. The dog Muri barks.', drs([], []), [], '2008-07-09-15-23-34', '130.60.155.206', '').
text_drs_eval(0, 363, 'A man\'s dog barks. He waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-21-18-19-56', amadeus, '').
text_drs_eval(0, 364, 'A man\'s dog barks. It eats.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, eat, B)-2, predicate(C, bark, B)-1, relation(B, of, D)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-06-23-12-31-52', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 365, 'A small card is green. A big card is red. The small card is valid.', drs([A, B, C, D, E, F, G, H], [object(H, card, countable, na, eq, 1)-1, object(D, card, countable, na, eq, 1)-2, predicate(C, be, H, G)-3, property(G, valid, pos)-3, predicate(A, be, D, B)-2, property(B, red, pos)-2, property(D, big, pos)-2, predicate(E, be, H, F)-1, property(F, green, pos)-1, property(H, small, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [small]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [small]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-23-12-35-36', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 366, 'The small card is green. A big card is red. The small card is valid.', drs([A, B, C, D, E, F, G, H], [object(F, card, countable, na, eq, 1)-2, object(B, card, countable, na, eq, 1)-1, property(B, small, pos)-1, predicate(E, be, B, A)-3, property(A, valid, pos)-3, predicate(C, be, F, D)-2, property(D, red, pos)-2, property(F, big, pos)-2, predicate(G, be, B, H)-1, property(H, green, pos)-1]), [[specification, [s, [np, [det, [the]], [nbar, [adj, [small]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [small]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-23-12-36-04', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 367, 'The small card is green. The big card is red. The small card is valid.', drs([A, B, C, D, E, F, G, H], [object(D, card, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-2, property(A, big, pos)-2, property(D, small, pos)-1, predicate(B, be, D, C)-3, property(C, valid, pos)-3, predicate(E, be, A, F)-2, property(F, red, pos)-2, predicate(G, be, D, H)-1, property(H, green, pos)-1]), [[specification, [s, [np, [det, [the]], [nbar, [adj, [small]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [big]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [small]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-23-12-36-53', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 368, 'A man is happy. A dog is happy.', drs([A, B, C, D, E, F], [object(F, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-2, predicate(A, be, B, E)-2, property(E, happy, pos)-2, predicate(C, be, F, D)-1, property(D, happy, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-23-12-37-49', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 369, 'A man a card of who is valid waits.', drs([A, B, C, D, E], [object(E, man, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(B, wait, E)-1, predicate(D, be, C, A)-1, property(A, valid, pos)-1, relation(C, of, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-06-23-13-39-07', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 370, 'John\'s dog barks. It is happy.', drs([A, B, C, D, E], [object(D, dog, countable, na, eq, 1)-1, object(E, 'John', named, na, eq, 1)-1, predicate(C, be, D, A)-2, property(A, happy, pos)-2, predicate(B, bark, D)-1, relation(D, of, E)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-24-14-05-39', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 371, 'John\'s dog barks. He is happy.', drs([A, B, C, D, E], [object(D, dog, countable, na, eq, 1)-1, object(E, 'John', named, na, eq, 1)-1, predicate(C, be, E, A)-2, property(A, happy, pos)-2, predicate(B, bark, D)-1, relation(D, of, E)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-24-14-06-00', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 372, 'A man\'s man waits. He is happy.', drs([A, B, C, D, E], [object(E, man, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, predicate(B, be, C, D)-2, property(D, happy, pos)-2, predicate(A, wait, C)-1, relation(C, of, E)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-24-14-06-37', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 373, 'A man\'s man waits. The man is happy.', drs([A, B, C, D, E], [object(E, man, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, predicate(B, be, C, D)-2, property(D, happy, pos)-2, predicate(A, wait, C)-1, relation(C, of, E)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-06-24-14-07-06', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 374, 'There is a red card. There is a blue card. The red card is valid.', drs([A, B, C, D], [object(D, card, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-2, predicate(A, be, D, C)-3, property(C, valid, pos)-3, property(B, blue, pos)-2, property(D, red, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [card]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [blue]], [nbar, [n, [card]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-24-16-36-51', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 375, 'There is a red card RC. There is a blue card BC. The red card RC is valid.', drs([], []), [], '2008-07-09-15-23-49', '130.60.155.206', '').
text_drs_eval(0, 376, 'There is a red card RC. There is a blue card BC. The card RC is valid.', drs([], []), [], '2008-07-09-15-24-02', '130.60.155.206', '').
text_drs_eval(0, 377, 'There is a red card RC. There is a blue card BC. The card is valid.', drs([], []), [], '2008-07-09-15-24-18', '130.60.155.206', '').
text_drs_eval(0, 378, 'There is a red card RC. There is a blue card BC. The red card is valid.', drs([], []), [], '2008-07-09-15-24-31', '130.60.155.206', '').
text_drs_eval(0, 379, 'There is a red card RC. There is a blue card BC. RC is valid.', drs([], []), [], '2008-07-09-15-24-47', '130.60.155.206', '').
text_drs_eval(0, 380, 'There are a red card RC and a blue card BC. RC is valid.', drs([], []), [], '2008-07-09-15-25-00', '130.60.155.206', '').
text_drs_eval(0, 381, 'There are a red card RC and a blue card BC. They are valid.', drs([], []), [], '2008-07-09-15-25-14', '130.60.155.206', '').
text_drs_eval(0, 382, 'There are a red card and a blue card. The card is valid.', drs([A, B, C, D, E], [object(A, na, countable, na, eq, 2)-1, object(E, card, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(B, be, C, D)-2, property(D, valid, pos)-2, has_part(A, C)-1, has_part(A, E)-1, property(C, blue, pos)-1, property(E, red, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [blue]], [nbar, [n, [card]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-24-16-43-04', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 383, 'There are a red card and a blue card. The red card is valid.', drs([A, B, C, D, E], [object(A, na, countable, na, eq, 2)-1, object(E, card, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(B, be, E, D)-2, property(D, valid, pos)-2, has_part(A, C)-1, has_part(A, E)-1, property(C, blue, pos)-1, property(E, red, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [blue]], [nbar, [n, [card]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [red]], [nbar, [n, [card]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2005-06-24-16-43-18', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 384, 'There are 384 tests.', drs([A], [object(A, test, countable, na, eq, 384)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [384]]], [nbar, [n, [tests]]]]]], ['.']]], '2006-04-07-14-59-37', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 385, 'There are 3 things and 4 things. Are they 7 things?', drs([A, B, C], [object(A, thing, countable, na, eq, 3)-1/4, has_part(C, A)-1/'', object(B, thing, countable, na, eq, 4)-1/7, has_part(C, B)-1/'', object(C, na, countable, na, eq, 2)-1/'', question(drs([D, E], [object(D, thing, countable, na, eq, 7)-2/4, predicate(E, be, C, D)-2/1]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [nump, 3], [nbar, [n, things]]], [coord, and], [np, [nump, 4], [nbar, [n, things]]]]]], '.'], '.'], [sentence, [query, [question, are, [np, [pn, they]], [vp, [vbar, [vcompl, [np, [nump, 7], [nbar, [n, things]]]]]]], ?], '.']], '2009-05-13-14-05-38', '130.60.155.177', '').
text_drs_eval(0, 386, 'A man\'s dog barks.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, relation(A, of, C)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-27-10-44-55', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 387, 'The man\'s dog barks.', drs([A, B, C], [object(C, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(A, bark, C)-1, relation(C, of, B)-1]), [[specification, [s, [np, [poss_np, [det, [the]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-27-10-45-18', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 388, 'A dog of a man barks.', drs([A, B, C], [object(C, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(B, bark, C)-1, relation(C, of, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-27-10-45-50', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 389, 'The dog of a man barks.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-27-10-46-24', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 390, 'A dog of the man barks.', drs([A, B, C], [object(C, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(A, bark, C)-1, relation(C, of, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-27-10-46-37', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 391, 'The dog of the man barks.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-27-10-47-00', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 392, 'There is a dog. There is a man. The man\'s dog barks.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-2, object(D, dog, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-3, relation(C, of, A)-3, predicate(B, bark, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [poss_np, [det, [the]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-07-11-14-50-04', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 393, 'No man sees himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, see, A, A)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2006-08-12-18-22-40', amadeus, '').
text_drs_eval(0, 394, 'For each man a dog sees the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(C, dog, countable, na, eq, 1)-1, predicate(B, see, C, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']]], '2005-06-27-12-49-04', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 395, 'There is a man who feeds every dog. There is a man who feeds every cat. The man who feeds every dog waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, drs([D], [object(D, dog, countable, na, eq, 1)-1])=>drs([E], [predicate(E, feed, B, D)-1]), drs([F], [object(F, cat, countable, na, eq, 1)-2])=>drs([G], [predicate(G, feed, A, F)-2]), predicate(C, wait, B)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [feeds]], [np, [det, [every]], [nbar, [n, [dog]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [feeds]], [np, [det, [every]], [nbar, [n, [cat]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [feeds]], [np, [det, [every]], [nbar, [n, [dog]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-10-15-13-52', blade17, '').
text_drs_eval(0, 396, 'Everybody sees nobody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, see, A, B)-1])])])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [pn, [nobody]]]]]], ['.']]], '2006-08-12-18-23-15', amadeus, '').
text_drs_eval(0, 397, 'It is not the case that everybody sees somebody.', drs([], []), [], '2007-12-14-17-00-31', '130.60.155.177', '').
text_drs_eval(0, 398, 'Nobody sees everybody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, A, B)-1])])])]), [[specification, [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [sees]], [np, [pn, [everybody]]]]]], ['.']]], '2006-08-12-18-23-52', amadeus, '').
text_drs_eval(0, 399, 'Somebody sees everybody.', drs([A], [object(A, somebody, countable, na, eq, 1)-1, drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, A, B)-1])]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [pn, [everybody]]]]]], ['.']]], '2005-11-30-12-21-26', blade17, '').
text_drs_eval(0, 400, 'A man waits. The man walks.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, predicate(B, walk, C)-2, predicate(A, wait, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2005-06-27-18-52-47', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 401, 'There is a man. His dog eats. There is a woman. Her dog drinks. The dog of the man barks.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, dog, countable, na, eq, 1)-2, predicate(C, eat, B)-2, object(D, woman, countable, na, eq, 1)-3, relation(E, of, D)-4, object(E, dog, countable, na, eq, 1)-4, predicate(F, drink, E)-4, predicate(G, bark, B)-5]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [posspn, his], [nbar, [n, dog]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman]]]]], '.'], [specification, [s, [np, [posspn, her], [nbar, [n, dog]]], [vp, [vbar, [v, drinks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-12-10-32-03', '130.60.206.55', '').
text_drs_eval(0, 402, 'The man John walks. The woman John talks.', drs([], []), [], '2005-08-31-20-22-08', blade17, '').
text_drs_eval(0, 403, 'A man John walks.', drs([], []), [], '2005-08-31-20-22-35', blade17, '').
text_drs_eval(0, 404, 'A man waits. The man talks.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, predicate(B, talk, C)-2, predicate(A, wait, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [talks]]]]], ['.']]], '2005-06-28-11-18-17', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 405, 'A man waits. The man talks and walks.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, predicate(C, walk, D)-2, predicate(A, talk, D)-2, predicate(B, wait, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [talks]]]], [coord, [and]], [vp, [vbar, [v, [walks]]]]]], ['.']]], '2005-06-28-11-18-39', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 406, 'Some men wait. The men talk.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, predicate(B, wait, A)-1, predicate(C, talk, A)-2]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [men]]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-07-06-16-43-22', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 407, 'Some men wait. They talk.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, predicate(B, wait, A)-1, predicate(C, talk, A)-2]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2006-04-07-15-03-30', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 408, 'If John waits then a dog barks.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])=>drs([C, D], [object(D, dog, countable, na, eq, 1)-1, predicate(C, bark, D)-1])]), [[specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-06-28-15-20-47', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 409, 'All laundry waits.', drs([], [drs([A], [object(A, laundry, mass, na, na, na)-1])=>drs([B], [predicate(B, wait, A)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-10-04-17-09-21', blade17, '').
text_drs_eval(0, 410, 'A man M1 eats. A man M2 drinks. M1 waits.', drs([A, B, C, D, E], [object(B, man, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, predicate(A, eat, C)-1, predicate(D, drink, B)-2, predicate(E, wait, C)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['M1']]]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['M2']]]]]], [vp, [vbar, [v, [drinks]]]]], ['.']], [specification, [s, [np, [np, [var, ['M1']]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-19-26-27', blade17, '').
text_drs_eval(0, 411, 'A man M1 eats. A man M2 drinks. The man M1 waits.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1, object(C, man, countable, na, eq, 1)-2, predicate(D, drink, C)-2, predicate(E, wait, A)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'M1']]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'M2']]]], [vp, [vbar, [v, drinks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'M1']]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-33-25', '130.60.204.15', '').
text_drs_eval(0, 412, 'Every man M sees M.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, see, A, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['M']]]]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['M']]]]]]], ['.']]], '2005-08-26-19-27-16', blade17, '').
text_drs_eval(0, 413, 'No man M sees M.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, see, A, A)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['M']]]]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['M']]]]]]], ['.']]], '2006-08-12-18-24-24', amadeus, '').
text_drs_eval(0, 414, 'Someone waits.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [pn, [someone]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-29-21-18-29', blade17, '').
text_drs_eval(0, 415, 'No one waits.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [np, [pn, ['{no one}']]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-24-50', amadeus, '').
text_drs_eval(0, 416, 'It is not the case that no one does not wait.', drs([], []), [], '2007-12-14-17-01-07', '130.60.155.177', '').
text_drs_eval(0, 417, 'It is not the case that no one waits.', drs([], []), [], '2007-12-14-17-01-15', '130.60.155.177', '').
text_drs_eval(0, 418, 'It is not the case that it is not the case that a man waits.', drs([], []), [], '2007-12-14-17-01-24', '130.60.155.177', '').
text_drs_eval(0, 419, 'Not everyone waits.', drs([], [-drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [predicate(B, wait, A)-1])])]), [[specification, [neg_s, [pneg, ['{not}']], [s, [np, [pn, [everyone]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-12-01-16-48-20', blade17, '').
text_drs_eval(0, 420, 'There is someone and he does not wait.', drs([A], [object(A, somebody, countable, na, eq, 1)-1, -drs([B], [predicate(B, wait, A)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [someone]]]]], [coord, [and]], [s, [np, [pn, [he]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [wait]]]]]], ['.']]], '2005-12-01-15-30-34', blade17, '').
text_drs_eval(0, 421, 'It is not the case that if there is someone then he waits.', drs([], []), [], '2007-12-14-17-01-49', '130.60.155.177', '').
text_drs_eval(0, 422, 'At least 3 men wait.', drs([A, B], [object(A, man, countable, na, geq, 3)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-04-07-15-03-18', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 423, 'At least 3 men wait. They drink.', drs([A, B, C], [object(A, man, countable, na, geq, 3)-1, predicate(B, wait, A)-1, predicate(C, drink, A)-2]), [[specification, [s, [np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [drink]]]]], ['.']]], '2006-04-07-15-03-11', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 424, 'Some men M1 and M2 drink. They talk.', drs([A, B, C, D, E], [object(A, man, countable, na, geq, 2)-1, has_part(D, A)-1, predicate(B, drink, D)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, talk, D)-2]), [[specification, [s, [np_coord, [np, [det, some], [nbar, [n, men], [appos, [var, 'M1']]]], [coord, and], [np, [var, 'M2']]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [vbar, [v, talk]]]], '.']], '2008-07-10-10-45-01', '130.60.155.206', '').
text_drs_eval(0, 425, 'A man and a dog wait. They talk.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(E, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, talk, D)-2, has_part(D, B)-1, has_part(D, E)-1, predicate(C, wait, D)-1]), [[specification, [s, [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-06-29-17-11-03', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 426, 'A man and a dog wait. He talks.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(E, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, talk, E)-2, has_part(D, B)-1, has_part(D, E)-1, predicate(C, wait, D)-1]), [[specification, [s, [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [talks]]]]], ['.']]], '2005-06-29-17-11-15', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 427, 'A man and a dog wait. It talks.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(E, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, talk, B)-2, has_part(D, B)-1, has_part(D, E)-1, predicate(C, wait, D)-1]), [[specification, [s, [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [talks]]]]], ['.']]], '2005-06-29-17-13-47', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 428, 'A man M and a dog D wait. They talk.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, wait, D)-1, has_part(D, B)-1, has_part(D, A)-1, predicate(E, talk, D)-2]), [[specification, [s, [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['M']]]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]], [appos_coord, [appos, [var, ['D']]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-08-26-19-28-30', blade17, '').
text_drs_eval(0, 429, 'A man M and the dog D wait. They talk.', drs([A, B, C, D, E], [object(D, na, countable, na, eq, 2)-1, object(B, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(C, wait, D)-1, has_part(D, B)-1, has_part(D, A)-1, predicate(E, talk, D)-2]), [[specification, [s, [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['M']]]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [dog]], [appos_coord, [appos, [var, ['D']]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-08-26-19-29-13', blade17, '').
text_drs_eval(0, 430, 'Each of some men talks. They walk.', drs([A, B], [predicate(B, walk, A)-2, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, talk, C)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [talks]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [walk]]]]], ['.']]], '2007-11-12-12-16-54', '130.60.155.177', '').
text_drs_eval(0, 431, 'Each of some men talks. The men walk.', drs([A, B], [object(A, man, countable, na, geq, 2)-1, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, talk, C)-1]), predicate(B, walk, A)-2]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [talks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [men]]]], [vp, [vbar, [v, [walk]]]]], ['.']]], '2005-07-06-16-44-15', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 432, 'John\'s dog barks.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, predicate(A, bark, B)-1, relation(B, of, C)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-06-30-14-50-18', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 433, 'There is a man. His dog barks.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(C, of, A)-2, predicate(B, bark, C)-2, object(C, dog, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [poss_spec, [poss_pn_coord, [posspn, [his]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-05-30-21-42-03', amadeus, '').
text_drs_eval(0, 434, 'There is a man a dog of who barks.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, relation(A, of, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2005-06-30-14-52-08', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 435, 'There is a man a dog of who barks. There is a man a dog of who eats. The man a dog of who barks waits.', drs([A, B, C, D, E, F, G], [object(D, dog, countable, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-2, object(C, dog, countable, na, eq, 1)-1, object(E, man, countable, na, eq, 1)-1, relation(C, of, E)-1, predicate(A, bark, C)-1, relation(D, of, B)-2, predicate(F, eat, D)-2, predicate(G, wait, E)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [eats]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-06-16-46-00', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 436, 'There is a man. There is a woman. His and her dog barks.', drs([], []), [], '2006-08-28-16-07-05', amadeus, '').
text_drs_eval(0, 437, 'There is a man. His dog barks. The dog is happy.', drs([A, B, C, D, E], [object(B, dog, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, relation(B, of, C)-2, predicate(A, bark, B)-2, property(D, happy, pos)-3, predicate(E, be, B, D)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-07-06-16-46-38', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 438, 'Somebody who eats drinks.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, drink, A)-1, predicate(C, eat, A)-1]), [[specification, [s, [nbar, [pn, [somebody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [eats]]]]]], [vp, [vbar, [v, [drinks]]]]], ['.']]], '2005-11-10-15-32-51', blade17, '').
text_drs_eval(0, 439, 'Something moves. It waits.', drs([A, B, C], [object(A, something, dom, na, na, na)-1, predicate(B, move, A)-1, predicate(C, wait, A)-2]), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [moves]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-10-15-33-16', blade17, '').
text_drs_eval(0, 440, 'Something moves.', drs([A, B], [object(A, something, dom, na, na, na)-1, predicate(B, move, A)-1]), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [moves]]]]], ['.']]], '2005-11-10-15-33-32', blade17, '').
text_drs_eval(0, 441, 'Something sees itself.', drs([A, B], [object(A, something, dom, na, na, na)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]], ['.']]], '2005-10-24-18-45-22', blade17, '').
text_drs_eval(0, 442, 'A dog of somebody barks.', drs([A, B, C], [object(B, somebody, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [somebody]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-12-01-16-48-29', blade17, '').
text_drs_eval(0, 443, 'A dog of somebody barks. He waits.', drs([A, B, C, D], [object(B, somebody, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1, predicate(D, wait, B)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [somebody]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-01-15-31-37', blade17, '').
text_drs_eval(0, 444, 'A dog of somebody barks. It waits.', drs([A, B, C, D], [object(B, somebody, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1, predicate(D, wait, A)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [somebody]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-01-15-32-57', blade17, '').
text_drs_eval(0, 445, 'Nobody sees herself.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, see, A, A)-1])])]), [[specification, [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [sees]], [np, [pn, [herself]]]]]], ['.']]], '2006-08-12-18-26-18', amadeus, '').
text_drs_eval(0, 446, 'A man sees everybody.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [everybody]]]]]], ['.']]], '2006-08-07-12-57-59', amadeus, '').
text_drs_eval(0, 447, 'A man sees everybody. He eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [object(C, somebody, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, A, C)-1]), predicate(B, eat, A)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [everybody]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-07-16-22-17', blade17, '').
text_drs_eval(0, 448, 'A man sees everybody who eat.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [eat]]]]]]]]], ['.']]], '2007-08-15-17-21-24', '130.60.155.177', '').
text_drs_eval(0, 449, 'Not everything sees itself.', drs([], [-drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B], [predicate(B, see, A, A)-1])])]), [[specification, [neg_s, [pneg, ['{not}']], [s, [np, [pn, [everything]]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]]], ['.']]], '2005-12-01-16-00-40', blade17, '').
text_drs_eval(0, 450, 'Everything barks at itself.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B], [predicate(B, bark, A)-1, modifier_pp(B, at, A)-1])]), [[specification, [s, [np, [pn, [everything]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [at]], [np, [pn, [itself]]]]]]], ['.']]], '2005-12-01-16-00-00', blade17, '').
text_drs_eval(0, 451, 'A man sees everybody and him.', drs([], []), [], '2006-08-15-19-27-32', amadeus, '').
text_drs_eval(0, 452, 'There is a man who owns a dog. There is a man who owns a cat. John sees the man. John sees the man who owns the dog.', drs([A, B, C, D, E, F, G, H, I], [object(E, cat, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-2, object(F, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-3, predicate(B, own, A, F)-1, predicate(G, own, C, E)-2, predicate(H, see, D, C)-3, predicate(I, see, D, A)-4]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]]]], ['.']]], '2005-11-29-20-43-31', blade17, '').
text_drs_eval(0, 453, 'John goes to Berlin.', drs([A, B, C], [object(C, 'John', named, na, eq, 1)-1, object(B, 'Berlin', named, na, eq, 1)-1, modifier_pp(A, to, B)-1, predicate(A, go, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [goes]]], [pp, [prep, [to]], [np, [pname, ['Berlin']]]]]]], ['.']]], '2005-07-02-17-00-56', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 454, 'John comes from Berlin.', drs([A, B, C], [object(C, 'John', named, na, eq, 1)-1, object(B, 'Berlin', named, na, eq, 1)-1, modifier_pp(A, from, B)-1, predicate(A, come, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [comes]]], [pp, [prep, [from]], [np, [pname, ['Berlin']]]]]]], ['.']]], '2005-07-02-17-01-31', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 455, 'John likes a town which he goes to.', drs([A, B, C, D], [object(A, town, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, go, B)-1, modifier_pp(C, to, A)-1, predicate(D, like, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [town]], [rel_cl, [comp, [which]], [np, [pn, [he]]], [vp, [vbar, [vbar, [v, [goes]]], [pp, [prep, [to]], [np, [[]]]]]]]]]]]], ['.']]], '2005-07-14-14-58-41', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 456, 'In which town does John live?', drs([], [question(drs([A, B], [query(A, which)-1/2, object(A, town, countable, na, eq, 1)-1/3, predicate(B, live, named('John'))-1/6, modifier_pp(B, in, A)-1/1]))]), [[sentence, [query, [question, [pp, [prep, 'In'], [np, [qdet, which], [nbar, [n, town]]]], does, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-14-05-45', '130.60.155.177', '').
text_drs_eval(0, 457, 'John comes from Berlin and goes to Paris.', drs([A, B, C, D, E], [object(E, 'John', named, na, eq, 1)-1, object(D, 'Berlin', named, na, eq, 1)-1, object(B, 'Paris', named, na, eq, 1)-1, modifier_pp(A, to, B)-1, predicate(A, go, E)-1, modifier_pp(C, from, D)-1, predicate(C, come, E)-1]), [[specification, [s, [np, [pname, ['John']]], [vp_coord, [vp, [vbar, [vbar, [v, [comes]]], [pp, [prep, [from]], [np, [pname, ['Berlin']]]]]], [coord, [and]], [vp, [vbar, [vbar, [v, [goes]]], [pp, [prep, [to]], [np, [pname, ['Paris']]]]]]]], ['.']]], '2005-07-02-17-07-57', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 458, 'Where does John live?', drs([], [question(drs([A], [predicate(A, live, named('John'))-1/4, query(A, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-14-07-41', '130.60.155.177', '').
text_drs_eval(0, 459, 'Where does John live in?', drs([], []), [], '2006-08-20-16-59-27', amadeus, '').
text_drs_eval(0, 460, 'From where does John come?', drs([], []), [], '2006-08-20-17-00-25', amadeus, '').
text_drs_eval(0, 461, 'Where does John come from?', drs([], []), [], '2006-08-20-17-01-06', amadeus, '').
text_drs_eval(0, 462, 'There is a man such that he waits.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, wait, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-07-02-18-13-17', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 463, 'There is a man such that the man sees himself.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, see, B, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]]], ['.']]], '2005-07-02-18-13-42', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 464, 'There is a man. There is a man such that the man sees him.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-2, predicate(B, see, A, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]], ['.']]], '2005-07-02-18-16-03', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 465, 'For each of the men a dog barks.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C, D], [predicate(D, bark, C)-1, object(C, dog, countable, na, eq, 1)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [the]], [nbar, [n, [men]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-11-12-12-17-35', '130.60.155.177', '').
text_drs_eval(0, 466, 'For each of the men a dog sees him.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C, D], [predicate(D, see, C, B)-1, object(C, dog, countable, na, eq, 1)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [the]], [nbar, [n, [men]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-12-12-18-00', '130.60.155.177', '').
text_drs_eval(0, 467, 'For each rich man a woman likes the rich man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, property(A, rich, pos)-1])=>drs([B, C], [object(C, woman, countable, na, eq, 1)-1, predicate(B, like, C, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [adj, [rich]], [nbar, [n, [man]]]]], [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [adj, [rich]], [nbar, [n, [man]]]]]]]]], ['.']]], '2005-07-02-18-52-08', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 468, 'For every rich man a woman likes the rich man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, property(A, rich, pos)-1])=>drs([B, C], [object(C, woman, countable, na, eq, 1)-1, predicate(B, like, C, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [adj, [rich]], [nbar, [n, [man]]]]], [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [adj, [rich]], [nbar, [n, [man]]]]]]]]], ['.']]], '2005-07-02-18-52-23', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 469, 'There are some big men. There are some small men. The big men are happy.', drs([A, B, C, D], [object(A, man, countable, na, geq, 2)-1, property(A, big, pos)-1, object(B, man, countable, na, geq, 2)-2, property(B, small, pos)-2, property(C, happy, pos)-3, predicate(D, be, A, C)-3]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [adj, [big]], [nbar, [n, [men]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [adj, [small]], [nbar, [n, [men]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [big]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2006-04-07-17-44-32', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 470, 'There are some big men. There are some small men. They wait.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, property(A, big, pos)-1, object(B, man, countable, na, geq, 2)-2, property(B, small, pos)-2, predicate(C, wait, B)-3]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [adj, [big]], [nbar, [n, [men]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [adj, [small]], [nbar, [n, [men]]]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-04-07-17-45-14', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 471, 'There are some men. For each of the men a dog barks.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-2])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-2, predicate(D, bark, C)-2])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [the]], [nbar, [n, [men]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-07-06-16-47-50', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 472, 'For each man a dog sees it.', drs([], []), [[specification, [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [pn, [it]]]]]]], ['.']]], '2005-08-26-14-37-40', blade17, '').
text_drs_eval(0, 473, 'A man\'s dog barks. The dog waits.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, wait, B)-2, predicate(C, bark, B)-1, relation(B, of, D)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-03-12-20-45', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 474, 'A big man\'s dog barks. The dog waits.', drs([A, B, C, D], [object(D, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(A, wait, B)-2, predicate(C, bark, B)-1, relation(B, of, D)-1, property(D, big, pos)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [adj, [big]], [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-03-12-39-58', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 475, 'There is a man. There is a dog. John beats his dog.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-2, relation(D, of, B)-3, object(D, dog, countable, na, eq, 1)-3, predicate(E, beat, A, D)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [posspn, [his]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-03-18-17-37-37', '130.60.155.177', '').
text_drs_eval(0, 476, 'John beats his own big dog and beats his own small dog. The big dog is sad.', drs([A, B, C, D, E, F, G], [object(D, dog, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, predicate(E, beat, B, A)-1, property(A, big, pos)-1, relation(D, of, B)-1, predicate(C, beat, B, D)-1, property(D, small, pos)-1, property(F, sad, pos)-2, predicate(G, be, A, F)-2]), [[specification, [s, [np, [pname, ['John']]], [vp_coord, [vp, [vbar, [v, [beats]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [adj, [big]], [nbar, [n, [dog]]]]]]], [coord, [and]], [vp, [vbar, [v, [beats]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [adj, [small]], [nbar, [n, [dog]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [big]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [sad]]]]]]], ['.']]], '2005-07-06-16-50-26', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 477, 'There is the man.', drs([], []), [], '2006-08-17-18-17-59', amadeus, '').
text_drs_eval(0, 478, 'The dog who sees the man barks.', drs([], []), [], '2005-08-30-19-04-21', blade17, '').
text_drs_eval(0, 479, 'There is a man. There is he.', drs([], []), [], '2006-05-24-19-09-07', amadeus, '').
text_drs_eval(0, 480, 'There is a man. There is he. There is he.', drs([], []), [], '2006-05-24-19-09-20', amadeus, '').
text_drs_eval(0, 481, 'There is a man. There are he and he.', drs([], []), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [pn, [he]]], [coord, [and]], [np, [pn, [he]]]]]]], '2007-11-02-19-27-05', '130.60.155.177', '').
text_drs_eval(0, 482, 'There is some laundry. It is clean.', drs([A, B, C], [object(A, laundry, mass, na, na, na)-1, property(B, clean, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-10-04-17-12-49', blade17, '').
text_drs_eval(0, 483, 'Each of some men who see themselves sees himself. /* Axiom :) */', drs([A, B], [object(A, man, countable, na, geq, 2)-1, predicate(B, see, A, A)-1, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, see, C, C)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [see]], [np, [pn, [themselves]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-07-06-16-52-22', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 484, 'There are 3 men.', drs([A], [object(A, man, countable, na, eq, 3)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]], ['.']]], '2006-04-07-17-10-00', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 485, 'There are 3 men. They talk.', drs([A, B], [object(A, man, countable, na, eq, 3)-1, predicate(B, talk, A)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2006-04-02-19-24-01', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 486, 'There are 3 men. The men talk.', drs([A, B], [object(B, man, countable, na, eq, 3)-1, predicate(A, talk, B)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [men]]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-07-13-13-11-59', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 487, 'There are 3 men. 3 men talk.', drs([A, B, C], [object(B, man, countable, na, eq, 3)-1, object(A, man, countable, na, eq, 3)-2, predicate(C, talk, A)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-07-12-19-13-02', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 488, 'There is a man A#.', drs([], []), [], '2005-07-11-15-55-18', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 489, 'There are 3 men Men-3. Men-3 talk.', drs([], []), [], '2008-07-09-15-25-32', '130.60.155.206', '').
text_drs_eval(0, 490, 'John waits. John does not sleep.', drs([A, B], [object(B, 'John', named, na, eq, 1)-1, -drs([C], [predicate(C, sleep, B)-2]), predicate(A, wait, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [sleep]]]]], ['.']]], '2005-07-05-11-12-12', blade17, '').
text_drs_eval(0, 491, 'There is a man. He sees himself.', drs([A, B], [object(B, man, countable, na, eq, 1)-1, predicate(A, see, B, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-07-05-11-14-03', blade17, '').
text_drs_eval(0, 492, 'If John waits then a man John sleeps.', drs([], []), [], '2005-08-31-20-22-53', blade17, '').
text_drs_eval(0, 493, 'If John waits then the man John sleeps.', drs([], []), [], '2005-08-31-20-23-16', blade17, '').
text_drs_eval(0, 494, 'Each of some men who own a dog owns a dog.', drs([A, B, C], [drs([D], [has_part(A, D)-1])=>drs([E, F], [predicate(F, own, D, E)-1, object(E, dog, countable, na, eq, 1)-1]), predicate(C, own, A, B)-1, object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, geq, 2)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [own]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-11-12-12-18-21', '130.60.155.177', '').
text_drs_eval(0, 495, 'Each of some men who own the dog owns the dog.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, object(C, man, countable, na, geq, 2)-1, predicate(A, own, C, B)-1, drs([D], [has_part(C, D)-1])=>drs([E], [predicate(E, own, D, B)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [own]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]], [vp, [vbar, [v, [owns]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-07-06-16-56-02', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 496, 'Each of some men who own the dog Muri owns Muri.', drs([], []), [], '2008-07-09-15-25-45', '130.60.155.206', '').
text_drs_eval(0, 497, 'There is a dog Muri. Each of some men who own Muri owns Muri.', drs([], []), [], '2008-07-09-15-26-00', '130.60.155.206', '').
text_drs_eval(0, 498, 'There is a dog. Each of some men who own the dog owns the dog.', drs([A, B, C], [drs([D], [has_part(B, D)-2])=>drs([E], [predicate(E, own, D, A)-2]), predicate(C, own, B, A)-2, object(B, man, countable, na, geq, 2)-2, object(A, dog, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [own]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]], [vp, [vbar, [v, [owns]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-11-12-12-18-42', '130.60.155.177', '').
text_drs_eval(0, 499, 'There is a man who sees a big dog. There is a man who sees a small dog. The man who sees a big dog waits.', drs([A, B, C, D, E, F, G], [object(G, man, countable, na, eq, 1)-1, object(E, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, object(F, dog, countable, na, eq, 1)-2, predicate(D, wait, G)-3, predicate(A, see, B, F)-2, property(F, small, pos)-2, predicate(C, see, G, E)-1, property(E, big, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [dog]]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [adj, [small]], [nbar, [n, [dog]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [dog]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-05-12-13-38', blade17, '').
text_drs_eval(0, 500, 'There are some men. Each of the men waits.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-2])=>drs([C], [predicate(C, wait, B)-2])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-06-16-58-20', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 501, 'Some groups of some men talk.', drs([A, B, C], [object(A, group, countable, na, geq, 2)-1, object(B, man, countable, na, geq, 2)-1, relation(A, of, B)-1, predicate(C, talk, A)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [groups]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [men]]]]]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2006-04-07-17-47-26', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 502, 'Some groups of some men see themselves.', drs([A, B, C], [object(A, group, countable, na, geq, 2)-1, object(B, man, countable, na, geq, 2)-1, relation(A, of, B)-1, predicate(C, see, A, A)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [groups]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [men]]]]]]], [vp, [vbar, [v, [see]], [np, [pn, [themselves]]]]]], ['.']]], '2006-04-07-17-48-07', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 503, 'Every group of some men waits.', drs([], [drs([A, B], [object(A, group, countable, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, relation(A, of, B)-1])=>drs([C], [predicate(C, wait, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [group]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [men]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-04-07-17-49-01', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 504, 'Each of no men talks.', drs([], []), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [no]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [talks]]]]], ['.']]], '2007-04-17-21-52-11', '130.60.155.177', '').
text_drs_eval(0, 505, 'Each of some men does not talk.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([], [-drs([C], [predicate(C, talk, B)-1])]), object(A, man, countable, na, geq, 2)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [vp, [aux, ['{does not}']], [vbar, [v, [talk]]]]], ['.']]], '2007-11-12-12-19-01', '130.60.155.177', '').
text_drs_eval(0, 506, 'A doctor sees himself/herself.', drs([A, B], [object(B, doctor, countable, na, eq, 1)-1, predicate(A, see, B, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [doctor]]]], [vp, [vbar, [v, [sees]], [np, [pn, ['himself/herself']]]]]], ['.']]], '2005-07-05-14-55-42', blade17, '').
text_drs_eval(0, 507, 'A doctor sees herself/himself.', drs([A, B], [object(A, doctor, countable, na, eq, 1)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [doctor]]]], [vp, [vbar, [v, [sees]], [np, [pn, ['herself/himself']]]]]], ['.']]], '2005-08-23-17-50-51', blade17, '').
text_drs_eval(0, 508, 'A thing sees himself/itself.', drs([], []), [], '2005-08-29-18-41-33', blade17, '').
text_drs_eval(0, 509, 'For each of some men a dog barks.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C, D], [predicate(D, bark, C)-1, object(C, dog, countable, na, eq, 1)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-11-12-12-19-17', '130.60.155.177', '').
text_drs_eval(0, 510, 'For each of some men a dog sees him.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C, D], [predicate(D, see, C, B)-1, object(C, dog, countable, na, eq, 1)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-12-12-19-30', '130.60.155.177', '').
text_drs_eval(0, 511, 'For each of John and Mary a dog sees him/her.', drs([A, B, C], [object(A, na, countable, na, eq, 2)-1, object(C, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([D], [has_part(A, D)-1])=>drs([E, F], [object(F, dog, countable, na, eq, 1)-1, predicate(E, see, F, D)-1]), has_part(A, B)-1, has_part(A, C)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [pn, ['him/her']]]]]]], ['.']]], '2005-07-05-15-53-51', blade17, '').
text_drs_eval(0, 512, 'A person sees himself.', drs([A, B], [object(B, person, countable, na, eq, 1)-1, predicate(A, see, B, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [person]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-07-05-16-11-01', blade17, '').
text_drs_eval(0, 513, 'A person sees herself.', drs([A, B], [object(B, person, countable, na, eq, 1)-1, predicate(A, see, B, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [person]]]], [vp, [vbar, [v, [sees]], [np, [pn, [herself]]]]]], ['.']]], '2005-07-05-16-11-08', blade17, '').
text_drs_eval(0, 514, 'For each of some men he waits.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, wait, B)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-11-12-12-19-40', '130.60.155.177', '').
text_drs_eval(0, 515, 'For each of the men he waits.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, wait, B)-1]), object(A, man, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [the]], [nbar, [n, [men]]]]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-11-12-12-19-51', '130.60.155.177', '').
text_drs_eval(0, 516, 'For each of a man and a woman a dog sees the man.', drs([A, B, C], [drs([D], [has_part(B, D)-1])=>drs([E, F], [object(F, dog, countable, na, eq, 1)-1, predicate(E, see, F, C)-1]), object(B, na, countable, na, eq, 2)-1, object(C, man, countable, na, eq, 1)-1, object(A, woman, countable, na, eq, 1)-1, has_part(B, A)-1, has_part(B, C)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [woman]]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']]], '2005-07-05-17-20-50', blade17, '').
text_drs_eval(0, 517, 'For each of a big man and a small man a dog sees the big man.', drs([A, B, C], [drs([D], [has_part(B, D)-1])=>drs([E, F], [object(F, dog, countable, na, eq, 1)-1, predicate(E, see, F, C)-1]), object(B, na, countable, na, eq, 2)-1, object(C, man, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, has_part(B, A)-1, has_part(B, C)-1, property(A, small, pos)-1, property(C, big, pos)-1]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np_coord, [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [man]]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [small]], [nbar, [n, [man]]]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [adj, [big]], [nbar, [n, [man]]]]]]]]], ['.']]], '2005-07-05-17-21-46', blade17, '').
text_drs_eval(0, 518, '5 men\'s dog barks.', drs([A, B, C], [object(A, man, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-04-07-17-33-31', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 519, '3 codes X and Y and Z are valid.', drs([A, B, C, D, E, F], [object(A, code, countable, na, eq, 3)-1, has_part(F, A)-1, property(B, valid, pos)-1, predicate(C, be, F, B)-1, object(D, something, dom, na, na, na)-1, has_part(F, D)-1, object(E, something, dom, na, na, na)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 3)-1]), [[specification, [s, [np_coord, [np, [nump, [num, 3]], [nbar, [n, codes], [appos, [var, 'X']]]], [coord, and], [np, [var, 'Y']], [coord, and], [np, [var, 'Z']]], [vp, [aux, are], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-10-10-45-12', '130.60.155.206', '').
text_drs_eval(0, 520, '2 men sees their own card.', drs([], []), [], '2005-08-18-18-33-50', blade17, '').
text_drs_eval(0, 521, 'If there is a man then there is more than 1 women.', drs([], []), [], '2005-08-17-19-24-04', blade17, '').
text_drs_eval(0, 522, 'Each of some men sees himself.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, see, B, B)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-07-06-15-43-14', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 523, 'Each of some men who see themselves sees himself.', drs([A, B], [object(A, man, countable, na, geq, 2)-1, predicate(B, see, A, A)-1, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, see, C, C)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [see]], [np, [pn, [themselves]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-07-06-15-43-52', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 524, 'A man has 2 kg of laundry.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, laundry, mass, kg, eq, 2)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]]]]], ['.']]], '2007-12-10-19-37-36', '130.60.155.177', '').
text_drs_eval(0, 525, 'A child Id1 of a child Id2 of a man Adam waits.', drs([], []), [], '2008-07-09-15-26-16', '130.60.155.206', '').
text_drs_eval(0, 526, 'There is a child of a man. The child waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, child, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, wait, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [child]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [child]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-18-18-34-20', blade17, '').
text_drs_eval(0, 527, 'The dog that sees the man barks.', drs([A, B, C, D], [object(C, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(A, see, C, B)-1, predicate(D, bark, C)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-07-07-16-49-11', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 528, 'The dog that sees the man barks. The dog eats. The man drinks.', drs([A, B, C, D, E, F], [object(E, dog, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, predicate(A, see, E, C)-1, predicate(B, drink, C)-3, predicate(D, eat, E)-2, predicate(F, bark, E)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [drinks]]]]], ['.']]], '2005-07-07-16-51-00', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 529, 'There is a man. Who hits him?', drs([A], [object(A, man, countable, na, eq, 1)-1/4, question(drs([B, C], [query(B, who)-2/1, predicate(C, hit, B, A)-2/2]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, hits], [np, [pn, him]]]]]], ?], '.']], '2009-05-13-14-14-14', '130.60.155.193', '').
text_drs_eval(0, 530, 'There is a man. Who hits himself?', drs([A], [object(A, man, countable, na, eq, 1)-1/4, question(drs([B, C], [query(B, who)-2/1, predicate(C, hit, B, B)-2/2]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, hits], [np, [pn, himself]]]]]], ?], '.']], '2009-05-13-14-14-15', '130.60.155.193', '').
text_drs_eval(0, 531, 'Who sees who?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, query(B, who)-1/3, predicate(C, see, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-14-14-17', '130.60.155.193', '').
text_drs_eval(0, 532, 'What sees itself?', drs([], [question(drs([A, B], [query(A, what)-1/1, predicate(B, see, A, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [vbar, [vcompl, [v, sees], [np, [pn, itself]]]]]], ?], '.']], '2009-05-13-14-14-18', '130.60.155.193', '').
text_drs_eval(0, 533, 'Mary sees herself. Who sees herself?', drs([A], [predicate(A, see, named('Mary'), named('Mary'))-1/2, question(drs([B, C], [query(B, who)-2/1, predicate(C, see, B, B)-2/2]))]), [[sentence, [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, sees], [np, [pn, herself]]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [pn, herself]]]]]], ?], '.']], '2009-05-13-14-14-20', '130.60.155.193', '').
text_drs_eval(0, 534, 'John\'s dog barks. The dog of John is happy.', drs([A, B, C, D, E], [predicate(E, be, B, D)-2, property(D, happy, pos)-2, predicate(C, bark, B)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2007-11-07-18-29-08', '130.60.204.23', '').
text_drs_eval(0, 535, 'John\'s dog eats. Mary\'s dog drinks. The dog of John waits.', drs([A, B, C, D, E, F, G], [predicate(G, wait, C)-3, predicate(F, drink, E)-2, object(E, dog, countable, na, eq, 1)-2, relation(E, of, B)-2, predicate(D, eat, C)-1, object(C, dog, countable, na, eq, 1)-1, relation(C, of, A)-1, object(B, 'Mary', named, na, eq, 1)-2, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [poss_np, [pname, ['Mary']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [drinks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-07-18-32-03', '130.60.204.23', '').
text_drs_eval(0, 536, 'A dog of a man eats. A dog of a woman drinks. The dog of a man waits.', drs([A, B, C, D, E, F, G], [object(D, woman, countable, na, eq, 1)-2, object(B, dog, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, object(E, dog, countable, na, eq, 1)-1, relation(E, of, C)-1, predicate(A, eat, E)-1, relation(B, of, D)-2, predicate(F, drink, B)-2, predicate(G, wait, E)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [vp, [vbar, [v, [drinks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-07-18-29-29', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 537, 'A dog of a man eats. A dog of a woman drinks. The dog of the man waits.', drs([A, B, C, D, E, F, G], [object(D, woman, countable, na, eq, 1)-2, object(B, dog, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, object(E, dog, countable, na, eq, 1)-1, relation(E, of, C)-1, predicate(A, eat, E)-1, relation(B, of, D)-2, predicate(F, drink, B)-2, predicate(G, wait, E)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [vp, [vbar, [v, [drinks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-29-20-46-14', blade17, '').
text_drs_eval(0, 538, 'A man\'s card sees itself.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, see, A, A)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [card]]]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]], ['.']]], '2005-07-08-12-31-28', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 539, 'A man\'s card sees him.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [poss_spec, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [card]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2006-08-22-12-17-40', amadeus, '').
text_drs_eval(0, 540, 'A man\'s dog barks. The woman\'s dog is green.', drs([A, B, C, D, E, F, G], [object(G, dog, countable, na, eq, 1)-1, object(E, man, countable, na, eq, 1)-1, object(F, dog, countable, na, eq, 1)-2, object(D, woman, countable, na, eq, 1)-2, relation(F, of, D)-2, relation(G, of, E)-1, predicate(A, bark, G)-1, property(B, green, pos)-2, predicate(C, be, F, B)-2]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [poss_np, [det, [the]], [nbar, [n, [woman]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2005-08-18-18-38-54', blade17, '').
text_drs_eval(0, 541, 'Somebody\'s dog barks.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [poss_np, [pn, [somebody]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-08-13-14-38-59', '130.60.155.177', '').
text_drs_eval(0, 542, 'Every ancestor of a man\'s father is the ancestor of the man.', drs([], [drs([A, B, C], [object(A, ancestor, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, father, countable, na, eq, 1)-1, relation(A, of, C)-1])=>drs([D, E], [predicate(D, be, A, E)-1, relation(E, of, B)-1, object(E, ancestor, countable, na, eq, 1)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [ancestor]], [pp, [prep, [of]], [np, [poss_np, [det, [a]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [father]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [ancestor]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]], ['.']]], '2007-11-20-14-48-45', '130.60.155.231', '').
text_drs_eval(0, 543, 'There is a man who sees John\'s brother. The man who sees the brother of John waits.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(C, of, A)-1, object(C, brother, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, wait, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [sees]], [np, [poss_np, [pname, ['John']], [gen_marker, ['\'s']]], [nbar, [n, [brother]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [brother]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-03-15-31-47', '130.60.155.177', '').
text_drs_eval(0, 544, 'There is a man who sees John\'s mother. The man who sees the mother of John waits.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(C, mother, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, relation(C, of, D)-1, predicate(B, see, A, C)-1, predicate(E, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [mother]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [mother]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-20-52-15', blade17, '').
text_drs_eval(0, 545, 'There is a man who sees a mother of John. The man who sees John\'s mother waits.', drs([A, B, C, D, E], [object(B, mother, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, predicate(D, see, C, B)-1, predicate(E, wait, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mother]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [mother]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-20-52-53', blade17, '').
text_drs_eval(0, 546, '2 girls lift 2 tables.', drs([A, B, C], [object(B, girl, countable, na, eq, 2)-1, object(A, table, countable, na, eq, 2)-1, predicate(C, lift, B, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]], [vp, [vbar, [v, [lift]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]]]], ['.']]], '2005-07-10-15-07-40', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 547, '2 girls lift each of 2 tables.', drs([A, B], [object(B, girl, countable, na, eq, 2)-1, object(A, table, countable, na, eq, 2)-1, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, lift, B, C)-1])]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]], [vp, [vbar, [v, [lift]], [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]]]]], ['.']]], '2005-07-10-15-10-18', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 548, 'Each of 2 girls lifts 2 tables.', drs([A], [object(A, girl, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, table, countable, na, eq, 2)-1, predicate(D, lift, B, C)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]]]], ['.']]], '2005-07-10-15-11-36', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 549, 'Each of 2 girls lifts each of 2 tables.', drs([A], [object(A, girl, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [object(C, table, countable, na, eq, 2)-1, drs([D], [has_part(C, D)-1])=>drs([E], [predicate(E, lift, B, D)-1])])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]]]]], ['.']]], '2005-07-10-15-13-28', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 550, 'There are 2 tables such that 2 girls lift them.', drs([A, B, C], [object(B, table, countable, na, eq, 2)-1, object(A, girl, countable, na, eq, 2)-1, predicate(C, lift, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]], [conj, ['{such that}']], [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]], [vp, [vbar, [v, [lift]], [np, [pn, [them]]]]]]], ['.']]], '2005-07-10-15-14-43', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 551, 'There are 2 tables such that each of 2 girls lifts them.', drs([A, B], [object(B, table, countable, na, eq, 2)-1, object(A, girl, countable, na, eq, 2)-1, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, lift, C, A)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]], [conj, ['{such that}']], [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [pn, [them]]]]]]], ['.']]], '2005-07-10-15-16-49', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 552, 'For each of 2 tables 2 girls lift it.', drs([A], [object(A, table, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, girl, countable, na, eq, 2)-1, predicate(D, lift, C, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]], [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]], [vp, [vbar, [v, [lift]], [np, [pn, [it]]]]]]], ['.']]], '2005-07-10-15-19-02', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 553, 'For each of 2 tables each of 2 girls lifts it.', drs([A], [object(A, table, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [object(C, girl, countable, na, eq, 2)-1, drs([D], [has_part(C, D)-1])=>drs([E], [predicate(E, lift, D, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]], [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [pn, [it]]]]]]], ['.']]], '2005-07-10-15-22-14', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 554, 'There are 2 girls and there are 2 tables such that each of the girls lifts each of the tables.', drs([A, B], [drs([C], [has_part(A, C)-1])=>drs([], [drs([D], [has_part(B, D)-1])=>drs([E], [predicate(E, lift, C, D)-1])]), object(B, table, countable, na, eq, 2)-1, object(A, girl, countable, na, eq, 2)-1]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]]], [coord, [and]], [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]], [conj, ['{such that}']], [s, [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [tables]]]]]]]]]], ['.']]], '2007-11-12-12-20-18', '130.60.155.177', '').
text_drs_eval(0, 555, 'There are 2 girls and there are 2 tables. Each of the girls lifts each of the tables.', drs([A, B], [drs([C], [has_part(A, C)-2])=>drs([], [drs([D], [has_part(B, D)-2])=>drs([E], [predicate(E, lift, C, D)-2])]), object(B, table, countable, na, eq, 2)-1, object(A, girl, countable, na, eq, 2)-1]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]]], [coord, [and]], [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [tables]]]]]]], ['.']], [specification, [s, [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [tables]]]]]]]], ['.']]], '2007-11-12-12-21-07', '130.60.155.177', '').
text_drs_eval(0, 556, 'Some men M1 and M2 and M3 drink.', drs([A, B, C, D, E], [object(A, man, countable, na, geq, 2)-1, has_part(E, A)-1, predicate(B, drink, E)-1, object(C, something, dom, na, na, na)-1, has_part(E, C)-1, object(D, something, dom, na, na, na)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 3)-1]), [[specification, [s, [np_coord, [np, [det, some], [nbar, [n, men], [appos, [var, 'M1']]]], [coord, and], [np, [var, 'M2']], [coord, and], [np, [var, 'M3']]], [vp, [vbar, [v, drink]]]], '.']], '2008-07-10-10-45-19', '130.60.155.206', '').
text_drs_eval(0, 557, 'There are a man and a woman.', drs([A, B, C], [object(B, na, countable, na, eq, 2)-1, object(C, man, countable, na, eq, 1)-1, object(A, woman, countable, na, eq, 1)-1, has_part(B, A)-1, has_part(B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], ['.']]], '2005-07-10-18-38-01', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 558, '2 codes X and Y are valid.', drs([A, B, C, D, E], [object(A, code, countable, na, eq, 2)-1, has_part(E, A)-1, property(B, valid, pos)-1, predicate(C, be, E, B)-1, object(D, something, dom, na, na, na)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, codes], [appos, [var, 'X']]]], [coord, and], [np, [var, 'Y']]], [vp, [aux, are], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-10-10-45-27', '130.60.155.206', '').
text_drs_eval(0, 559, 'There are 5 big men.', drs([A], [object(A, man, countable, na, eq, 5)-1, property(A, big, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [adj, [big]], [nbar, [n, [men]]]]]]], ['.']]], '2006-04-07-17-21-49', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 560, '2 men M1 and M2 drink. M1 talks.', drs([], []), [[specification, [s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['M1']]]]], [coord, [and]], [np, [var, ['M2']]]], [vp, [vbar, [v, [drink]]]]], ['.']], [specification, [s, [np, [var, ['M1']]], [vp, [vbar, [v, [talks]]]]], ['.']]], '2007-12-29-18-02-45', '130.60.204.10', '').
text_drs_eval(0, 561, '2 men M1 and M2 drink. M2 talks. They eat.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 2)-1, has_part(D, A)-1, predicate(B, drink, D)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, talk, C)-2, predicate(F, eat, D)-3]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'M1']]]], [coord, and], [np, [var, 'M2']]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [var, 'M2']], [vp, [vbar, [v, talks]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [vbar, [v, eat]]]], '.']], '2008-07-10-10-45-46', '130.60.155.206', '').
text_drs_eval(0, 562, '2 men ManGroup drink. They eat.', drs([], []), [], '2008-07-09-15-26-38', '130.60.155.206', '').
text_drs_eval(0, 563, '2 men ManGroup drink. ManGroup talk. They eat.', drs([], []), [], '2008-07-09-15-28-48', '130.60.155.206', '').
text_drs_eval(0, 564, '2 men ManGroup drink. ManGroup talks. They eat.', drs([], []), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['ManGroup']]]]], [vp, [vbar, [v, [drink]]]]], ['.']], [specification, [s, [np, [var, ['ManGroup']]], [vp, [vbar, [v, [talks]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [eat]]]]], ['.']]], '2007-12-29-18-03-52', '130.60.204.10', '').
text_drs_eval(0, 565, '2 men ManGroup drink. ManGroup talks. It eats.', drs([], []), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos_coord, [appos, [var, ['ManGroup']]]]]], [vp, [vbar, [v, [drink]]]]], ['.']], [specification, [s, [np, [np, [var, ['ManGroup']]]], [vp, [vbar, [v, [talks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-08-26-14-46-12', blade17, '').
text_drs_eval(0, 566, '2 men John and John eat.', drs([], []), [], '2005-08-31-21-06-11', blade17, '').
text_drs_eval(0, 567, 'There are 5 big men who are happy.', drs([A, B, C], [object(A, man, countable, na, eq, 5)-1, property(A, big, pos)-1, property(B, happy, pos)-1, predicate(C, be, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [adj, [big]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]]]]]]], ['.']]], '2006-04-07-17-32-40', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 568, 'There are 5 big men such that they are happy.', drs([A, B, C], [object(A, man, countable, na, eq, 5)-1, property(A, big, pos)-1, property(B, happy, pos)-1, predicate(C, be, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [adj, [big]], [nbar, [n, [men]]]]]], [conj, ['{such that}']], [s, [np, [pn, [they]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]]], ['.']]], '2006-04-07-17-55-32', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 569, '2 men M1 and M2 drink. The man M2 talks.', drs([], []), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'M1']]]], [coord, and], [np, [var, 'M2']]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'M2']]]], [vp, [vbar, [v, talks]]]], '.']], '2008-08-12-10-42-31', '84.74.167.232', '').
text_drs_eval(0, 570, 'There is a man who sees himself. There is a man who sees John. John watches the man who sees him. John watches the man who sees himself.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, B)-1, object(D, man, countable, na, eq, 1)-2, predicate(E, see, D, A)-2, predicate(F, watch, A, D)-3, predicate(G, watch, A, B)-4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pname, 'John']]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, him]]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]]], '.']], '2008-08-17-10-46-34', '84.74.167.232', '').
text_drs_eval(0, 571, 'There are some men. For each of them the card is valid.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-2])=>drs([C, D, E], [object(D, card, countable, na, eq, 1)-2, property(E, valid, pos)-2, predicate(C, be, D, E)-2])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{for each of}']], [np, [pn, [them]]]], [s, [np, [det, [the]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]], ['.']]], '2005-08-28-16-25-53', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 572, 'The card of which man the card of who is valid is valid?', drs([], [question(drs([A, B, C, D, E, F], [property(A, valid, pos)-1/13, predicate(B, be, C, A)-1/12, query(D, which)-1/4, property(E, valid, pos)-1/11, relation(C, of, D)-1/8, predicate(F, be, C, E)-1/10, object(D, man, countable, na, eq, 1)-1/5, object(C, card, countable, na, eq, 1)-1/7]))]), [[sentence, [query, [question, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-14-21', '130.60.155.193', '').
text_drs_eval(0, 573, 'There is a n:aaa. It barks.', drs([A, B], [object(A, aaa, countable, na, eq, 1)-1, predicate(B, bark, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [aaa]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-07-11-15-51-00', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 574, 'There are some n:aaa. They bark.', drs([A, B], [object(A, aaa, countable, na, geq, 2)-1, predicate(B, bark, A)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [aaa]]]]]], ['.']], [specification, [s, [np, [pn, [they]]], [vp, [vbar, [v, [bark]]]]], ['.']]], '2005-07-11-15-51-35', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 575, 'There is a n:aaa who waits. The n:aaa who waits barks.', drs([], []), [], '2005-08-30-19-05-47', blade17, '').
text_drs_eval(0, 576, 'A man who is hungry eats a pizza X. He is happy.', drs([A, B, C, D, E, F, G], [object(C, pizza, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, property(A, hungry, pos)-1, predicate(B, be, D, A)-1, predicate(E, eat, D, C)-1, property(F, happy, pos)-2, predicate(G, be, D, F)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [hungry]]]]]]]]], [vp, [vbar, [v, [eats]], [np, [det, [a]], [nbar, [n, [pizza]], [appos_coord, [appos, [var, ['X']]]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-08-26-19-37-38', blade17, '').
text_drs_eval(0, 577, 'There is a man or there is a dog who sees him or there is a cat who sees it.', drs([], []), [], '2005-08-30-19-06-04', blade17, '').
text_drs_eval(0, 578, 'There is a man or there is a dog who sees him or there is a cat who sees him.', drs([], []), [], '2005-08-30-19-08-29', blade17, '').
text_drs_eval(0, 579, 'There is a man or there is a dog who sees him or there is a cat who sees it and him.', drs([], []), [], '2005-11-25-20-11-35', blade17, '').
text_drs_eval(0, 580, 'A dog barks. Not everybody waits.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, -drs([], [drs([C], [object(C, somebody, countable, na, eq, 1)-2])=>drs([D], [predicate(D, wait, C)-2])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-12-01-17-26-51', blade17, '').
text_drs_eval(0, 581, 'A dog barks. Not every man waits.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, -drs([], [drs([C], [object(C, man, countable, na, eq, 1)-2])=>drs([D], [predicate(D, wait, C)-2])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, ['{not every}']], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-12-16-43-32', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 582, 'Not everybody waits. A dog barks.', drs([A, B], [-drs([], [drs([C], [object(C, somebody, countable, na, eq, 1)-1])=>drs([D], [predicate(D, wait, C)-1])]), object(A, dog, countable, na, eq, 1)-2, predicate(B, bark, A)-2]), [[specification, [neg_s, [pneg, ['{not}']], [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [waits]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-12-01-17-26-38', blade17, '').
text_drs_eval(0, 583, 'There is a man. A clerk enters every card of him.', drs([A, B], [object(A, clerk, countable, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, drs([C], [object(C, card, countable, na, eq, 1)-2, relation(C, of, B)-2])=>drs([D], [predicate(D, enter, A, C)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2005-07-12-17-29-55', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 584, 'There is a park. A dog barks in it.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-2, object(B, park, countable, na, eq, 1)-1, predicate(C, bark, A)-2, modifier_pp(C, in, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [park]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [in]], [np, [pn, [it]]]]]]], ['.']]], '2005-08-12-13-07-47', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 585, 'A man sees everybody who eats.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C], [predicate(B, eat, C)-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, A, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [eats]]]]]]]]], ['.']]], '2007-08-15-17-13-09', '130.60.155.177', '').
text_drs_eval(0, 586, 'Every man who waits eats.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C], [predicate(C, eat, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-07-12-17-39-33', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 587, 'Everybody who waits eats.', drs([], [drs([A, B], [object(B, somebody, countable, na, eq, 1)-1, predicate(A, wait, B)-1])=>drs([C], [predicate(C, eat, B)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-12-01-15-31-00', blade17, '').
text_drs_eval(0, 588, 'There is a man. He who waits eats.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.']], '2008-09-23-08-46-13', '130.60.155.206', '').
text_drs_eval(0, 589, 'A man sees himself and a dog.', drs([A, B, C, D], [object(D, na, countable, na, eq, 2)-1, object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, D)-1, has_part(D, B)-1, has_part(D, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pn, [himself]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2005-07-12-18-58-40', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 590, 'A man sees a dog and himself.', drs([A, B, C, D], [object(D, na, countable, na, eq, 2)-1, object(C, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(B, see, A, D)-1, has_part(D, C)-1, has_part(D, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [pn, [himself]]]]]]], ['.']]], '2005-07-14-11-52-23', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 591, 'There is a boy. A man sees him and a dog.', drs([A, B, C, D, E], [object(A, boy, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, has_part(E, A)-2, predicate(C, see, B, E)-2, object(D, dog, countable, na, eq, 1)-2, has_part(E, D)-2, object(E, na, countable, na, eq, 2)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, boy]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np_coord, [np, [pn, him]], [coord, and], [np, [det, a], [nbar, [n, dog]]]]]]], '.']], '2008-07-30-14-34-21', '130.60.155.177', '').
text_drs_eval(0, 592, 'There is a boy. A man sees himself and a dog.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-2, object(B, dog, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-2, object(D, boy, countable, na, eq, 1)-1, predicate(A, see, C, E)-2, has_part(E, C)-2, has_part(E, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [boy]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pn, [himself]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2005-07-12-19-01-34', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 593, 'A man sees a dog X. He waits.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, A)-1, predicate(D, wait, B)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [appos_coord, [appos, [var, ['X']]]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-19-37-57', blade17, '').
text_drs_eval(0, 594, 'There are some men. The men talk.', drs([A, B], [object(A, man, countable, na, geq, 2)-1, predicate(B, talk, A)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [men]]]], [vp, [vbar, [v, [talk]]]]], ['.']]], '2005-07-12-19-10-21', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 595, 'A set is a:located in itself.', drs([A, B, C], [object(A, set, countable, na, eq, 1)-1, property(B, located, pos)-1, predicate(C, be, A, B)-1, modifier_pp(C, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [set]]]], [vp, [vbar, [vbar, [v, [is]], [ap_coord, [ap, [adj, [located]]]]], [pp, [prep, [in]], [np, [pn, [itself]]]]]]], ['.']]], '2005-07-12-19-24-09', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 596, 'A set is in a set.', drs([A, B, C], [object(A, set, countable, na, eq, 1)-1, object(B, set, countable, na, eq, 1)-1, predicate(C, be, B)-1, modifier_pp(C, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [set]]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [set]]]]]]]], ['.']]], '2005-08-04-15-34-35', blade17, '').
text_drs_eval(0, 597, 'A set is in itself.', drs([A, B], [object(A, set, countable, na, eq, 1)-1, predicate(B, be, A)-1, modifier_pp(B, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [set]]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [pn, [itself]]]]]]], ['.']]], '2005-08-22-16-54-11', 'ifidyn125.ifi.unizh.ch', '').
text_drs_eval(0, 598, 'A set is a member in itself.', drs([A, B, C], [object(A, member, countable, na, eq, 1)-1, object(B, set, countable, na, eq, 1)-1, predicate(C, be, B, A)-1, modifier_pp(C, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [set]]]], [vp, [vbar, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [member]]]]], [pp, [prep, [in]], [np, [pn, [itself]]]]]]], ['.']]], '2005-07-12-19-29-19', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 599, 'A set exists in itself.', drs([A, B], [object(A, set, countable, na, eq, 1)-1, predicate(B, exist, A)-1, modifier_pp(B, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [set]]]], [vp, [vbar, [vbar, [v, [exists]]], [pp, [prep, [in]], [np, [pn, [itself]]]]]]], ['.']]], '2005-08-22-16-55-38', 'ifidyn125.ifi.unizh.ch', '').
text_drs_eval(0, 600, 'A table John waits.', drs([], []), [], '2005-08-31-20-23-33', blade17, '').
text_drs_eval(0, 601, 'John owns a park. A dog barks in it.', drs([A, B, C, D, E], [object(C, dog, countable, na, eq, 1)-2, object(D, park, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(B, own, A, D)-1, predicate(E, bark, C)-2, modifier_pp(E, in, D)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [park]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [in]], [np, [pn, [it]]]]]]], ['.']]], '2005-07-13-13-08-59', 'ifidyn231.ifi.unizh.ch', '').
text_drs_eval(0, 602, 'A dog barks. It is not the case that everybody waits.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, -drs([C, D], [predicate(C, be, A, D)-2, drs([E], [object(E, somebody, countable, na, eq, 1)-2])=>drs([F], [predicate(F, wait, E, D)-2]), object(D, case, countable, na, eq, 1)-2])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [every]], [nbar, [n, ['$body']]]], [vp, [vbar, [v, [waits]], [np, [[]]]]]]]]]]], ['.']]], '2007-12-14-17-02-30', '130.60.155.177', '').
text_drs_eval(0, 603, 'VisaCards wait.', drs([A, B], [object(B, 'VisaCard', named, na, geq, 2)-1, predicate(A, wait, B)-1]), [[specification, [s, [np, [pname, ['VisaCards']]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2005-07-13-18-15-36', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 604, 'Christmases are white.', drs([A, B, C], [object(A, 'Christmas', named, na, geq, 2)-1, property(B, white, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pname, ['Christmases']]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [white]]]]]]], ['.']]], '2005-07-13-18-18-41', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 605, 'Each of Christmases is white.', drs([], []), [], '2009-05-13-07-42-40', '130.60.155.193', '').
text_drs_eval(0, 606, 'Christmases are white. Some children like them.', drs([A, B, C, D, E], [object(D, 'Christmas', named, na, geq, 2)-1, property(A, white, pos)-1, predicate(B, be, D, A)-1, object(C, child, countable, na, geq, 2)-2, predicate(E, like, C, D)-2]), [[specification, [s, [np, [pname, ['Christmases']]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [white]]]]]]], ['.']], [specification, [s, [np, [det, [some]], [nbar, [n, [children]]]], [vp, [vbar, [v, [like]], [np, [pn, [them]]]]]], ['.']]], '2005-07-13-18-23-04', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 607, 'A person:xxx sees a masc:yyy and event:zzz him.', drs([], []), [], '2008-06-26-17-43-28', '130.60.155.206', '').
text_drs_eval(0, 608, 'A person:xxx sees a masc:yyy and event:zzz herself.', drs([], []), [], '2008-06-26-17-43-38', '130.60.155.206', '').
text_drs_eval(0, 609, 'A man talks about a day.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-1, predicate(C, talk, A)-1, modifier_pp(C, about, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [talks]]], [pp, [prep, [about]], [np, [det, [a]], [nbar, [n, [day]]]]]]]], ['.']]], '2006-04-07-18-41-45', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 610, 'A man talks during a day.', drs([A, B, C], [object(A, day, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, talk, B)-1, modifier_pp(C, during, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [talks]]], [pp, [prep, [during]], [np, [det, [a]], [nbar, [n, [day]]]]]]]], ['.']]], '2005-07-14-11-27-44', blade17, '').
text_drs_eval(0, 611, 'A man sees a boy and the girl.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1, object(D, boy, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(B, girl, countable, na, eq, 1)-1, predicate(A, see, C, E)-1, has_part(E, D)-1, has_part(E, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [boy]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [girl]]]]]]]], ['.']]], '2005-07-14-11-29-55', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 612, 'There is a bone. A man enters it and a card.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-2, object(B, card, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-2, object(D, bone, countable, na, eq, 1)-1, predicate(A, enter, C, E)-2, has_part(E, D)-2, has_part(E, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [bone]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [pn, [it]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [card]]]]]]]], ['.']]], '2005-07-14-11-32-31', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 613, 'There is a bone. A man enters the bone and a card.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-2, object(B, card, countable, na, eq, 1)-2, object(A, man, countable, na, eq, 1)-2, object(D, bone, countable, na, eq, 1)-1, predicate(C, enter, A, E)-2, has_part(E, D)-2, has_part(E, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [bone]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [the]], [nbar, [n, [bone]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [card]]]]]]]], ['.']]], '2005-07-14-11-33-03', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 614, 'A customer enters a card of himself.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, enter, B, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-07-14-11-49-22', '80-218-106-3.dclient.hispeed.ch', '').
text_drs_eval(0, 615, 'There is John. Mary sees him. He walks.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2006-08-15-21-00-12', amadeus, '').
text_drs_eval(0, 616, 'There is John. Peter sees him. He walks.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pname, ['John']]]]], ['.']], [specification, [s, [np, [np, [var, ['Peter']]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2005-08-26-14-33-33', blade17, '').
text_drs_eval(0, 617, 'A man hits his own dog. He is happy.', drs([A, B, C, D, E], [object(C, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, hit, C, B)-1, property(D, happy, pos)-2, predicate(E, be, C, D)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-08-22-10-07-08', blade17, '').
text_drs_eval(0, 618, 'A clerk enters a card of himself.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, enter, B, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-08-26-14-42-57', blade17, '').
text_drs_eval(0, 619, 'A clerk enters the card of himself.', drs([A, B, C], [object(C, clerk, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, enter, C, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-07-14-12-01-23', '80-218-106-3.dclient.hispeed.ch', '').
text_drs_eval(0, 620, 'A clerk enters a card of him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2005-08-26-14-42-44', blade17, '').
text_drs_eval(0, 621, 'There is a man. The man sees himself.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, see, A, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-07-14-12-03-08', '80-218-106-3.dclient.hispeed.ch', '').
text_drs_eval(0, 622, 'A machine reads a card that carries its own code.', drs([A, B, C, D, E], [object(A, card, countable, na, eq, 1)-1, object(D, machine, countable, na, eq, 1)-1, object(C, code, countable, na, eq, 1)-1, relation(C, of, A)-1, predicate(B, carry, A, C)-1, predicate(E, read, D, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [machine]]]], [vp, [vbar, [v, [reads]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [carries]], [np, [poss_pn_coord, [posspn, ['{its own}']]], [nbar, [n, [code]]]]]]]]]]]], ['.']]], '2005-08-26-19-39-11', blade17, '').
text_drs_eval(0, 623, 'A dog of a woman walks. A dog of a boy barks. The dog of the boy is happy.', drs([A, B, C, D, E, F, G, H], [object(D, boy, countable, na, eq, 1)-2, object(B, dog, countable, na, eq, 1)-2, object(C, woman, countable, na, eq, 1)-1, object(E, dog, countable, na, eq, 1)-1, relation(E, of, C)-1, predicate(A, walk, E)-1, relation(B, of, D)-2, predicate(F, bark, B)-2, property(G, happy, pos)-3, predicate(H, be, B, G)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [vp, [vbar, [v, [walks]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [boy]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [boy]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-08-18-18-46-36', blade17, '').
text_drs_eval(0, 624, 'A dog of a boy barks. The boy waits.', drs([A, B, C, D], [object(C, boy, countable, na, eq, 1)-1, object(D, dog, countable, na, eq, 1)-1, relation(D, of, C)-1, predicate(A, bark, D)-1, predicate(B, wait, C)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [boy]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [boy]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-07-14-13-35-56', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 625, 'A man lives in a town.', drs([A, B, C], [object(A, town, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, live, B)-1, modifier_pp(C, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [lives]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [town]]]]]]]], ['.']]], '2005-07-14-14-11-33', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 626, 'A man lives in a town. Where does the man live?', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, town, countable, na, eq, 1)-1/6, predicate(C, live, A)-1/3, modifier_pp(C, in, B)-1/4, question(drs([D], [predicate(D, live, A)-2/5, query(D, where)-2/1]))]), [[sentence, [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, lives]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, town]]]]]]]], '.'], '.'], [sentence, [query, [question, [qpn, where], does, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-14-14-23', '130.60.155.193', '').
text_drs_eval(0, 627, 'Where does the man live?', drs([], [question(drs([A, B], [predicate(A, live, B)-1/5, query(A, where)-1/1, object(B, man, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-14-14-25', '130.60.155.193', '').
text_drs_eval(0, 628, 'Where does the man live? Who lives in the town?', drs([], [question(drs([A, B], [predicate(A, live, B)-1/5, query(A, where)-1/1, object(B, man, countable, na, eq, 1)-1/4])), question(drs([C, D, E], [query(C, who)-2/1, predicate(D, live, C)-2/2, modifier_pp(D, in, E)-2/3, object(E, town, countable, na, eq, 1)-2/5]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, live]]]]], ?], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, lives]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, town]]]]]]]], ?], '.']], '2009-05-13-14-14-26', '130.60.155.193', '').
text_drs_eval(0, 629, 'A man lives in a town. Where does the man live? Who lives in the town?', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, town, countable, na, eq, 1)-1/6, predicate(C, live, A)-1/3, modifier_pp(C, in, B)-1/4, question(drs([D], [predicate(D, live, A)-2/5, query(D, where)-2/1])), question(drs([E, F], [query(E, who)-3/1, predicate(F, live, E)-3/2, modifier_pp(F, in, B)-3/3]))]), [[sentence, [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, lives]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, town]]]]]]]], '.'], '.'], [sentence, [query, [question, [qpn, where], does, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, live]]]]], ?], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, lives]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, town]]]]]]]], ?], '.']], '2009-05-13-14-14-28', '130.60.155.193', '').
text_drs_eval(0, 630, 'A girl of a boy waits. The girl eats.', drs([A, B, C, D], [object(A, boy, countable, na, eq, 1)-1, object(B, girl, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, wait, B)-1, predicate(D, eat, B)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [girl]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [boy]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [girl]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-08-18-18-47-24', blade17, '').
text_drs_eval(0, 631, 'There is John. Bill sees him. He walks.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], ['.']], [specification, [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2006-08-15-21-00-26', amadeus, '').
text_drs_eval(0, 632, 'There is a man a dog of who barks. The dog eats.', drs([A, B, C, D], [object(C, dog, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, relation(C, of, D)-1, predicate(A, bark, C)-1, predicate(B, eat, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-07-14-16-19-29', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 633, 'There is a man a dog of who barks. The man eats.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1, predicate(D, eat, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-08-18-18-48-50', blade17, '').
text_drs_eval(0, 634, 'Some men\'s car is fast.', drs([A, B, C, D], [object(A, car, countable, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, relation(A, of, B)-1, property(C, fast, pos)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [poss_np, [det, [some]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [car]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]], ['.']]], '2005-07-14-18-42-33', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 635, 'There is a donkey of a wife\'s brother.', drs([A, B, C], [object(B, brother, countable, na, eq, 1)-1, object(C, wife, countable, na, eq, 1)-1, object(A, donkey, countable, na, eq, 1)-1, relation(B, of, C)-1, relation(A, of, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [poss_np, [det, [a]], [nbar, [n, [wife]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [brother]]]]]]]]], ['.']]], '2005-07-14-18-46-59', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 636, 'There is a donkey of the wife\'s brother.', drs([A, B, C], [object(A, donkey, countable, na, eq, 1)-1, relation(B, of, C)-1, object(B, brother, countable, na, eq, 1)-1, relation(A, of, B)-1, object(C, wife, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [poss_spec, [poss_np, [det, [the]], [nbar, [n, [wife]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [brother]]]]]]]]], ['.']]], '2006-08-22-11-43-36', amadeus, '').
text_drs_eval(0, 637, 'A big hungry dog barks.', drs([], []), [], '2005-08-29-18-43-10', blade17, '').
text_drs_eval(0, 638, 'John is a rich customer. His wealth is enormous. He is in his office.', drs([A, B, C, D, E, F, G, H], [object(H, customer, countable, na, eq, 1)-1, object(G, office, countable, na, eq, 1)-3, object(D, wealth, mass, na, na, na)-2, object(E, 'John', named, na, eq, 1)-1, property(H, rich, pos)-1, predicate(A, be, E, H)-1, relation(D, of, H)-2, property(B, enormous, pos)-2, predicate(C, be, D, B)-2, relation(G, of, E)-3, predicate(F, be, H)-3, modifier_pp(F, in, G)-3]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [adj, [rich]], [nbar, [n, [customer]]]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [wealth]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [enormous]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [office]]]]]]]], ['.']]], '2005-10-04-17-13-58', blade17, '').
text_drs_eval(0, 639, 'John is a rich customer. His wealth is enormous. He is in his own office.', drs([A, B, C, D, E, F, G, H], [object(H, customer, countable, na, eq, 1)-1, object(G, office, countable, na, eq, 1)-3, object(D, wealth, mass, na, na, na)-2, object(E, 'John', named, na, eq, 1)-1, property(H, rich, pos)-1, predicate(A, be, E, H)-1, relation(D, of, H)-2, property(B, enormous, pos)-2, predicate(C, be, D, B)-2, relation(G, of, H)-3, predicate(F, be, H)-3, modifier_pp(F, in, G)-3]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [adj, [rich]], [nbar, [n, [customer]]]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [wealth]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [enormous]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [office]]]]]]]], ['.']]], '2005-10-04-17-14-12', blade17, '').
text_drs_eval(0, 640, 'John is not a customer. He is happy.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, -drs([D, E], [object(D, customer, countable, na, eq, 1)-1, predicate(E, be, A, D)-1]), property(B, happy, pos)-2, predicate(C, be, A, B)-2]), [[specification, [s, [np, [pname, ['John']]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [customer]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-07-20-16-43-06', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 641, 'A man is not a customer. He is happy.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, customer, countable, na, eq, 1)-1, predicate(E, be, A, D)-1]), property(B, happy, pos)-2, predicate(C, be, A, B)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [customer]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-07-20-16-43-29', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 642, 'A man is a clerk. His dog barks.', drs([A, B, C, D, E], [object(A, clerk, countable, na, eq, 1)-1, object(E, man, countable, na, eq, 1)-1, object(D, dog, countable, na, eq, 1)-2, predicate(B, be, E, A)-1, relation(D, of, A)-2, predicate(C, bark, D)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [clerk]]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-07-20-16-49-25', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 643, 'A man is a clerk. His own dog barks.', drs([], []), [], '2005-08-18-18-52-32', blade17, '').
text_drs_eval(0, 644, 'A customer gives a card to a clerk.', drs([A, B, C, D], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(C, clerk, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [clerk]]]]]]]], ['.']]], '2006-08-14-18-43-31', amadeus, '').
text_drs_eval(0, 645, 'A customer gives a clerk a card.', drs([A, B, C, D], [object(A, customer, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(D, give, A, C, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [clerk]]]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2006-08-14-18-44-11', amadeus, '').
text_drs_eval(0, 646, 'For every code there is a clerk such that he enters it.', drs([], [drs([A], [object(A, code, countable, na, eq, 1)-1])=>drs([B, C], [object(B, clerk, countable, na, eq, 1)-1, predicate(C, enter, B, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [code]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [clerk]]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [enters]], [np, [pn, [it]]]]]]]], ['.']]], '2005-07-20-16-58-52', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 647, 'For every code a clerk enters it.', drs([], [drs([A], [object(A, code, countable, na, eq, 1)-1])=>drs([B, C], [object(B, clerk, countable, na, eq, 1)-1, predicate(C, enter, B, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [code]]]], [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [pn, [it]]]]]]], ['.']]], '2005-07-20-16-59-28', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 648, 'Some water is not drinkable.', drs([A], [object(A, water, mass, na, na, na)-1, -drs([B, C], [property(B, drinkable, pos)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, [some]], [nbar, [n, [water]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [drinkable]]]]]]], ['.']]], '2005-10-04-17-14-40', blade17, '').
text_drs_eval(0, 649, 'A man enters a card that carries a code and opens an account.', drs([A, B, C, D, E, F, G], [object(E, account, countable, na, eq, 1)-1, object(A, code, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, object(F, man, countable, na, eq, 1)-1, predicate(C, carry, B, A)-1, predicate(D, enter, F, B)-1, predicate(G, open, F, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [carries]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [opens]], [np, [det, [an]], [nbar, [n, [account]]]]]]]], ['.']]], '2005-07-20-17-01-28', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 650, 'A man who enters a card manually types a code.', drs([A, B, C, D, E], [object(C, code, countable, na, eq, 1)-1, object(D, card, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(B, enter, A, D)-1, modifier_adv(B, manually, pos)-1, predicate(E, type, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]], [adv, [manually]]]]]]], [vp, [vbar, [v, [types]], [np, [det, [a]], [nbar, [n, [code]]]]]]], ['.']]], '2005-07-20-17-02-23', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 651, 'A man sees every dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-07-20-17-04-33', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 652, 'Every man sees a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-07-20-17-04-51', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 653, 'A laundry of John collapses.', drs([A, B, C], [object(A, laundry, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, collapse, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [laundry]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [collapses]]]]], ['.']]], '2005-07-20-17-10-05', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 654, 'There is a man. His laundry smells.', drs([A, B, C], [object(C, man, countable, na, eq, 1)-1, object(B, laundry, countable, na, eq, 1)-2, relation(B, of, C)-2, predicate(A, smell, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [smells]]]]], ['.']]], '2005-08-26-19-39-33', blade17, '').
text_drs_eval(0, 655, 'There is a man a laundry of who collapses.', drs([A, B, C], [object(A, laundry, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, collapse, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [laundry]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [collapses]]]]]]]]], ['.']]], '2005-07-20-17-12-11', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 656, 'John is a customer. He inserts a card that belongs to himself and types a code X. Bill sees X. He inserts his own card and types the code.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]], '.']], '2008-10-06-13-23-16', '130.60.155.206', '').
text_drs_eval(0, 657, 'John takes his own card and gets some money for himself.', drs([A, B, C, D, E], [object(C, money, mass, na, na, na)-1, object(A, card, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, predicate(D, take, B, A)-1, predicate(E, get, B, C)-1, modifier_pp(E, for, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp_coord, [vp, [vbar, [v, [takes]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [card]]]]]], [coord, [and]], [vp, [vbar, [vbar, [v, [gets]], [np, [det, [some]], [nbar, [n, [money]]]]], [pp, [prep, [for]], [np, [pn, [himself]]]]]]]], ['.']]], '2005-10-04-17-14-50', blade17, '').
text_drs_eval(0, 658, 'A man visits a town ZÃ¼rich.', drs([], []), [], '2007-12-29-17-43-34', '130.60.204.10', '').
text_drs_eval(0, 659, 'A man who is richer than John waits.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, property(C, rich, comp_than, A)-1, predicate(D, be, B, C)-1, predicate(E, wait, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [richer]], [conj, [than]], [np, [pname, ['John']]]]|F]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-05-09-12-12-21', '130.60.156.229', '').
text_drs_eval(0, 660, 'There is a dog. /* # with comment without comment */ There is a man.', drs([A, B], [object(A, man, countable, na, eq, 1)-2, object(B, dog, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']]], '2005-08-11-21-06-44', blade17, '').
text_drs_eval(0, 661, 'There is a dog. /* # with comment (line break) without comment */ There is a man.', drs([A, B], [object(A, man, countable, na, eq, 1)-2, object(B, dog, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']]], '2005-08-11-21-07-59', blade17, '').
text_drs_eval(0, 662, 'There is the man\'s dog and cat.', drs([], []), [], '2005-08-18-18-57-41', blade17, '').
text_drs_eval(0, 663, 'A man waits carefully manually.', drs([], []), [], '2005-08-10-12-09-47', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 664, 'A man carefully waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, modifier_adv(B, carefully, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [adv, [carefully]], [vbar, [v, [waits]]]]]], ['.']]], '2005-07-22-10-28-58', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 665, 'A man carefully manually waits.', drs([], []), [], '2005-08-22-10-05-17', blade17, '').
text_drs_eval(0, 666, 'A man gives a bone to a dog manually carefully.', drs([], []), [], '2005-08-10-12-11-02', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 667, 'A clerk enters a card of every customer.', drs([A, B, C], [object(A, clerk, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, drs([D], [object(D, customer, countable, na, eq, 1)-1])=>drs([], [relation(B, of, D)-1]), predicate(C, enter, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [customer]]]]]]]]]], ['.']]], '2006-04-20-12-10-13', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 668, 'A clerk enters every customer\'s card.', drs([A], [object(A, clerk, countable, na, eq, 1)-1, drs([B, C], [object(B, customer, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, card, countable, na, eq, 1)-1])=>drs([D], [predicate(D, enter, A, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [poss_np, [det, [every]], [nbar, [n, [customer]]], [gen_marker, ['\'s']]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-20-17-44-34', '130.60.155.231', '').
text_drs_eval(0, 669, 'A n:xxx\'s dog barks.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, xxx, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [n, [xxx]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-07-22-10-51-24', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 670, 'The customer enters a card and a numeric personal code. If it is not valid then SM rejects the card.', drs([], []), [], '2006-08-15-15-13-06', amadeus, '').
text_drs_eval(0, 671, 'The customer enters a card and a numeric personal code.', drs([], []), [], '2006-08-15-15-14-04', amadeus, '').
text_drs_eval(0, 672, 'Who enters a card?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, object(B, card, countable, na, eq, 1)-1/4, predicate(C, enter, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-14-14-29', '130.60.155.193', '').
text_drs_eval(0, 673, 'A man John gives his own wife Mary a big and red apple.', drs([], []), [], '2005-08-31-20-23-59', blade17, '').
text_drs_eval(0, 674, 'John owns some services that deliver some pizzas.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(C, service, countable, na, geq, 2)-1, object(B, pizza, countable, na, geq, 2)-1, predicate(D, deliver, C, B)-1, predicate(E, own, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [det, [some]], [nbar, [n, [services]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [deliver]], [np, [det, [some]], [nbar, [n, [pizzas]]]]]]]]]]]], ['.']]], '2005-07-22-13-40-14', blade17, '').
text_drs_eval(0, 675, 'John owns some services each of which delivers some pizzas.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, service, countable, na, geq, 2)-1, drs([D], [has_part(B, D)-1])=>drs([E, F], [object(E, pizza, countable, na, geq, 2)-1, predicate(F, deliver, D, E)-1]), predicate(C, own, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [det, [some]], [nbar, [n, [services]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [which]]]], [vp, [vbar, [v, [delivers]], [np, [det, [some]], [nbar, [n, [pizzas]]]]]]]]]]]], ['.']]], '2007-11-20-11-30-19', '130.60.155.231', '').
text_drs_eval(0, 676, 'John waits in a bank. He is happy.', drs([A, B, C, D, E], [object(A, bank, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, wait, B)-1, modifier_pp(C, in, A)-1, property(D, happy, pos)-2, predicate(E, be, B, D)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-07-22-14-37-59', blade17, '').
text_drs_eval(0, 677, '1 man\'s dog barks.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1]), [[specification, [s, [np, [poss_np, [numberp, [gen_quant, [[]]], [number, [1]]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-07-22-14-55-55', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 678, 'A customer waits patiently.', drs([A, B], [object(A, customer, countable, na, eq, 1)-1, predicate(B, wait, A)-1, modifier_adv(B, patiently, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [vbar, [v, [waits]]], [adv, [patiently]]]]], ['.']]], '2005-07-22-14-58-23', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 679, 'How does John enter a card?', drs([], [question(drs([A, B], [object(A, card, countable, na, eq, 1)-1/6, predicate(B, enter, named('John'), A)-1/4, query(B, how)-1/1]))]), [[sentence, [query, [question, [qpn, how], does, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-14-14-31', '130.60.155.193', '').
text_drs_eval(0, 680, 'The waters are deep.', drs([A, B, C], [property(A, deep, pos)-1, predicate(B, be, C, A)-1, object(C, water, countable, na, geq, 2)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [waters]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [deep]]]]]]], ['.']]], '2006-04-07-17-34-04', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 681, 'A customer enters a card or drops it. He is angry.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, drs([D, E], [object(D, card, countable, na, eq, 1)-1, predicate(E, enter, A, D)-1])v drs([F], [predicate(F, drop, A, D)-1]), property(B, angry, pos)-2, predicate(C, be, A, B)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]], [coord, [or]], [vp, [vbar, [v, [drops]], [np, [pn, [it]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [angry]]]]]]], ['.']]], '2005-08-22-17-01-55', 'ifidyn125.ifi.unizh.ch', '').
text_drs_eval(0, 682, 'A customer enters a card or he drops it. He is angry.', drs([], []), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drops]], [np, [pn, [it]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [angry]]]]]]], ['.']]], '2006-04-20-12-11-02', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 683, 'A customer enters a card or he drops it. The customer is angry.', drs([A, B, C], [object(B, customer, countable, na, eq, 1)-2, drs([D, E, F], [object(D, card, countable, na, eq, 1)-1, object(E, customer, countable, na, eq, 1)-1, predicate(F, enter, E, D)-1])v drs([G], [predicate(G, drop, E, D)-1]), property(C, angry, pos)-2, predicate(A, be, B, C)-2]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drops]], [np, [pn, [it]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [angry]]]]]]], ['.']]], '2005-07-22-15-16-05', 'ifidyn134.ifi.unizh.ch', '').
text_drs_eval(0, 684, 'If a customer has a card C then the customer enters C.', drs([], [drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, predicate(C, have, B, A)-1])=>drs([D], [predicate(D, enter, B, A)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [card]], [appos_coord, [appos, [var, ['C']]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [np, [var, ['C']]]]]]]], ['.']]], '2005-08-26-19-39-56', blade17, '').
text_drs_eval(0, 685, 'If a customer has a card C then he enters C.', drs([], [drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, predicate(C, have, B, A)-1])=>drs([D], [predicate(D, enter, B, A)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [card]], [appos_coord, [appos, [var, ['C']]]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [enters]], [np, [np, [var, ['C']]]]]]]], ['.']]], '2005-08-26-19-40-17', blade17, '').
text_drs_eval(0, 686, 'p:Kaarel waits.', drs([A, B], [object(A, 'Kaarel', named, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [pname, ['Kaarel']]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-20-22-00-20', '130.60.155.177', '').
text_drs_eval(0, 687, 'Is there a dog?', drs([], [question(drs([A], [object(A, dog, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, a], [nbar, [n, dog]]]]], ?], '.']], '2009-05-13-14-14-32', '130.60.155.193', '').
text_drs_eval(0, 688, 'John gives Bill Mary.', drs([A, B, C, D], [object(C, 'Mary', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(D, give, A, C, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [gives]], [np, [pname, ['Bill']]], [np, [pname, ['Mary']]]]]], ['.']]], '2006-08-14-18-44-27', amadeus, '').
text_drs_eval(0, 689, 'John gives Mary to Bill.', drs([A, B, C, D], [object(C, 'Bill', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(D, give, A, B, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [gives]], [np, [pname, ['Mary']]], [pp, [prep, [to]], [np, [pname, ['Bill']]]]]]], ['.']]], '2006-08-14-18-44-43', amadeus, '').
text_drs_eval(0, 690, 'There is a man. The man "John" waits.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']]|A], '2007-04-10-15-42-39', '130.60.155.177', '').
text_drs_eval(0, 691, 'There is a red and blue dog. The red dog barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, property(A, red, pos)-1, property(A, blue, pos)-1, predicate(B, bark, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj_coord, [adj, [red]], [coord, [and]], [adj, [blue]]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [red]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-08-02-18-37-15', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 692, 'A dog of who eats a bone?', drs([], [question(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, object(C, bone, countable, na, eq, 1)-1/7, predicate(D, eat, A, C)-1/5]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [vbar, [vcompl, [v, eats], [np, [det, a], [nbar, [n, bone]]]]]]], ?], '.']], '2009-05-13-14-14-34', '130.60.155.193', '').
text_drs_eval(0, 693, 'The dog of who eats a bone?', drs([], [question(drs([A, B, C, D], [object(A, bone, countable, na, eq, 1)-1/7, predicate(B, eat, C, A)-1/5, relation(C, of, D)-1/3, query(D, who)-1/4, object(C, dog, countable, na, eq, 1)-1/2]))]), [[sentence, [query, [question, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [vbar, [vcompl, [v, eats], [np, [det, a], [nbar, [n, bone]]]]]]], ?], '.']], '2009-05-13-14-14-35', '130.60.155.193', '').
text_drs_eval(0, 694, 'A man a dog of who eats a bone waits.', drs([A, B, C, D, E], [object(B, bone, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, relation(C, of, A)-1, predicate(D, eat, C, B)-1, predicate(E, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [eats]], [np, [det, [a]], [nbar, [n, [bone]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-02-17-23-04', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 695, 'If a man walks then he talks quickly.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1])=>drs([C], [predicate(C, talk, A)-1, modifier_adv(C, quickly, pos)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [walks]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [vbar, [v, [talks]]], [adv, [quickly]]]]]], ['.']]], '2005-08-03-16-59-52', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 696, 'If a man walks quickly then he talks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1, modifier_adv(B, quickly, pos)-1])=>drs([C], [predicate(C, talk, A)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [walks]]], [adv, [quickly]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [talks]]]]]], ['.']]], '2005-08-03-17-01-52', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 697, 'If a man walks quickly then he talks quickly.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1, modifier_adv(B, quickly, pos)-1])=>drs([C], [predicate(C, talk, A)-1, modifier_adv(C, quickly, pos)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [walks]]], [adv, [quickly]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [vbar, [v, [talks]]], [adv, [quickly]]]]]], ['.']]], '2005-08-03-17-02-13', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 698, 'A man enters all laundry.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, laundry, mass, na, na, na)-1])=>drs([C], [predicate(C, enter, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [det, [all]], [nbar, [n, [laundry]]]]]]], ['.']]], '2005-10-04-17-15-54', blade17, '').
text_drs_eval(0, 699, 'p:p v:v.', drs([A, B], [object(A, p, named, na, eq, 1)-1, predicate(B, v, A)-1]), [[specification, [s, [np, [pname, [p]]], [vp, [vbar, [v, [v]]]]], ['.']]], '2007-08-20-22-00-34', '130.60.155.177', '').
text_drs_eval(0, 700, 'A man is rich and famous.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, property(B, rich, pos)-1, property(B, famous, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]], [coord, [and]], [ap_coord, [ap, [adj, [famous]]]]]]]], ['.']]], '2005-08-08-12-46-37', blade17, '').
text_drs_eval(0, 701, 'A dog is not a cat.', drs([A], [object(A, dog, countable, na, eq, 1)-1, -drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2005-08-08-20-44-23', blade17, '').
text_drs_eval(0, 702, 'John vaguely sees a big dog that barks in the garden of his own brother.', drs([], []), [], '2008-10-06-13-23-02', '130.60.155.206', '').
text_drs_eval(0, 703, 'John vaguely sees a big dog. The dog barks in the garden of the brother of John.', drs([A, B, C, D, E, F], [object(E, dog, countable, na, eq, 1)-1, object(C, brother, countable, na, eq, 1)-2, object(A, garden, countable, na, eq, 1)-2, object(B, 'John', named, na, eq, 1)-1, relation(A, of, C)-2, relation(C, of, B)-2, property(E, big, pos)-1, predicate(D, see, B, E)-1, modifier_adv(D, vaguely, pos)-1, predicate(F, bark, E)-2, modifier_pp(F, in, A)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [adv, [vaguely]], [vbar, [v, [sees]], [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [dog]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [garden]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [brother]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]]]]]], ['.']]], '2005-08-09-18-02-44', blade17, '').
text_drs_eval(0, 704, 'Who is in the park in the town?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/1, predicate(B, be, A)-1/2, modifier_pp(B, in, C)-1/3, object(C, park, countable, na, eq, 1)-1/5, modifier_pp(B, in, D)-1/6, object(D, town, countable, na, eq, 1)-1/8]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [pp, [prep, in], [np, [det, the], [nbar, [n, park]]]]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, town]]]]]]]], ?], '.']], '2009-05-13-14-14-37', '130.60.155.193', '').
text_drs_eval(0, 705, 'There is not a man.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2005-08-26-14-41-39', blade17, '').
text_drs_eval(0, 706, 'There is not some laundry.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [some]], [nbar, [n, [laundry]]]]]]], ['.']]], '2005-08-26-14-41-17', blade17, '').
text_drs_eval(0, 707, 'There is no man.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]]]]]], ['.']]], '2005-08-09-22-07-07', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 708, 'A man Kaarel works extremely and fast.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['Kaarel']]]]]], [vp, [vbar, [vbar, [v, [works]]], [adv_coord, [adv, [extremely]], [coord, [and]], [adv, [fast]]]]]], ['.']]], '2006-08-12-22-38-45', amadeus, '').
text_drs_eval(0, 709, 'A man waits carefully and manually.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, modifier_adv(B, manually, pos)-1, modifier_adv(B, carefully, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [adv, [carefully]], [coord, [and]], [adv, [manually]]]]], ['.']]], '2005-08-10-12-11-55', 'ifidyn186.ifi.unizh.ch', '').
text_drs_eval(0, 710, 'A man gives a bone to a dog manually and carefully.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, bone, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1, modifier_adv(D, carefully, pos)-1, modifier_adv(D, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [bone]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [adv_coord, [adv, [manually]], [coord, [and]], [adv, [carefully]]]]]], ['.']]], '2006-08-14-18-51-43', amadeus, '').
text_drs_eval(0, 711, 'A man carefully and manually waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, modifier_adv(B, manually, pos)-1, modifier_adv(B, carefully, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [adv_coord, [adv, [carefully]], [coord, [and]], [adv, [manually]]], [vbar, [v, [waits]]]]]], ['.']]], '2005-08-22-10-04-54', blade17, '').
text_drs_eval(0, 712, 'There are a dog and a cat.', drs([A, B, C], [object(C, na, countable, na, eq, 2)-1, object(B, cat, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, has_part(C, A)-1, has_part(C, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2005-08-11-21-12-53', blade17, '').
text_drs_eval(0, 713, 'There is a dog and a cat.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2005-08-26-14-40-48', blade17, '').
text_drs_eval(0, 714, 'For every body who waits there is a clerk.', drs([], []), [], '2005-08-30-19-11-11', blade17, '').
text_drs_eval(0, 715, 'For everybody who waits there is a clerk.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C], [object(C, clerk, countable, na, eq, 1)-1])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, ['$body']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [clerk]]]]]]]], '2007-10-17-15-13-05', '130.60.155.177', '').
text_drs_eval(0, 716, 'There is a customer. The customer enters a card or he drops it. He is angry.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, drs([D, E], [object(D, card, countable, na, eq, 1)-2, predicate(E, enter, A, D)-2])v drs([F], [predicate(F, drop, A, D)-2]), property(B, angry, pos)-3, predicate(C, be, A, B)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [customer]]]]]], ['.']], [specification, [s_coord, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [drops]], [np, [pn, [it]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [angry]]]]]]], ['.']]], '2005-08-12-13-33-36', blade17, '').
text_drs_eval(0, 717, 'There is a customer. The customer enters a card or drops it. He is angry.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, drs([D, E], [object(D, card, countable, na, eq, 1)-2, predicate(E, enter, A, D)-2])v drs([F], [predicate(F, drop, A, D)-2]), property(B, angry, pos)-3, predicate(C, be, A, B)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [customer]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]], [coord, [or]], [vp, [vbar, [v, [drops]], [np, [pn, [it]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [angry]]]]]]], ['.']]], '2005-08-12-13-34-28', blade17, '').
text_drs_eval(0, 718, 'For everybody there is a dog.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [object(B, dog, countable, na, eq, 1)-1])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, ['$body']]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], '2007-10-17-15-14-51', '130.60.155.177', '').
text_drs_eval(0, 719, 'There is some n:laundry.', drs([A], [object(A, laundry, mass, na, na, na)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']]], '2007-04-10-16-09-30', '130.60.155.177', '').
text_drs_eval(0, 720, '2 kg of laundry waits.', drs([A, B], [object(A, laundry, mass, kg, eq, 2)-1, predicate(B, wait, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-25-12-15-35', '130.60.206.10', '').
text_drs_eval(0, 721, 'A man wait.', drs([], []), [], '2005-08-16-16-14-13', blade17, '').
text_drs_eval(0, 722, '2 men waits.', drs([], []), [], '2005-08-16-16-13-54', blade17, '').
text_drs_eval(0, 723, 'A man manually is happy.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, property(B, happy, pos)-1/5, predicate(C, be, A, B)-1/4, modifier_adv(C, manually, pos)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, manually]], [aux, is], [ap_coord, [ap, [adj, happy]]]]], '.']], '2009-05-19-17-21-10', '130.60.155.193', '').
text_drs_eval(0, 724, 'A man very is happy.', drs([], []), [], '2005-08-31-21-52-39', blade17, '').
text_drs_eval(0, 725, 'There is a dog X. A man\'s X barks.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']]|A], '2007-06-12-10-02-41', '130.60.156.66', '').
text_drs_eval(0, 726, 'There is a dog X. X of a man barks.', drs([], []), [], '2006-08-17-15-40-58', amadeus, '').
text_drs_eval(0, 727, 'There is 1 kg of laundry.', drs([A], [object(A, laundry, mass, kg, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [measurement_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]]]], ['.']]], '2007-12-10-19-37-48', '130.60.155.177', '').
text_drs_eval(0, 728, 'Some men are happy.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, property(B, happy, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-08-15-14-29-42', blade17, '').
text_drs_eval(0, 729, 'Some men is happy.', drs([], []), [], '2005-08-16-16-13-17', blade17, '').
text_drs_eval(0, 730, 'There is some men.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np, [det, [some]], [nbar, [n, [men]]]]]]], ['.']]], '2005-08-26-14-32-46', blade17, '').
text_drs_eval(0, 731, 'John\'s laundry waits.', drs([A, B, C], [object(B, laundry, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, wait, B)-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-20-25-47', blade17, '').
text_drs_eval(0, 732, 'A man runs almost.', drs([], []), [], '2005-08-31-21-51-55', blade17, '').
text_drs_eval(0, 733, 'He who eats drinks.', drs([], []), [], '2005-08-15-19-19-55', blade17, '').
text_drs_eval(0, 734, 'A dog of some men runs.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, geq, 2)-1, relation(B, of, A)-1, predicate(C, run, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [men]]]]]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2005-08-16-11-50-03', blade17, '').
text_drs_eval(0, 735, 'A dog of some men who run barks.', drs([A, B, C, D], [object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, geq, 2)-1, predicate(C, run, A)-1, relation(B, of, A)-1, predicate(D, bark, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [run]]]]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-11-10-15-17-46', blade17, '').
text_drs_eval(0, 736, 'A dog of some men who runs barks.', drs([], []), [], '2005-11-10-15-17-19', blade17, '').
text_drs_eval(0, 737, 'Some men\'s dog runs.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, relation(A, of, B)-1, predicate(C, run, A)-1]), [[specification, [s, [np, [poss_np, [det, [some]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2005-08-16-11-58-06', blade17, '').
text_drs_eval(0, 738, 'Some men\'s dog who runs barks.', drs([], []), [], '2005-08-30-19-12-06', blade17, '').
text_drs_eval(0, 739, 'Some men\'s dog who run barks.', drs([], []), [], '2005-08-16-11-59-17', blade17, '').
text_drs_eval(0, 740, 'A dog who runs barks.', drs([], []), [], '2005-08-30-19-13-36', blade17, '').
text_drs_eval(0, 741, 'A dog who run barks.', drs([], []), [], '2005-08-16-12-32-16', blade17, '').
text_drs_eval(0, 742, 'Is there a man John?', drs([], []), [], '2005-09-01-19-45-01', blade17, '').
text_drs_eval(0, 743, 'There is a man or there is a woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([B], [object(B, woman, countable, na, eq, 1)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]], ['.']]], '2005-08-16-13-30-36', blade17, '').
text_drs_eval(0, 744, 'Is there a man or is there a woman?', drs([], []), [], '2005-08-29-18-44-06', blade17, '').
text_drs_eval(0, 745, 'There is a n:laundry.', drs([A], [object(A, laundry, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [laundry]]]]]], ['.']]], '2005-08-16-16-15-50', blade17, '').
text_drs_eval(0, 746, 'A man works in a bank in a morning.', drs([A, B, C, D], [object(B, bank, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1, modifier_pp(D, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [works]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]]]]], ['.']]], '2005-08-17-11-53-57', blade17, '').
text_drs_eval(0, 747, 'A man works in a bank and in a morning.', drs([], []), [], '2005-08-17-11-54-12', blade17, '').
text_drs_eval(0, 748, 'A man works in a bank manually.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, work, B)-1, modifier_adv(C, manually, pos)-1, modifier_pp(C, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [works]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]], [adv, [manually]]]]], ['.']]], '2005-08-17-11-54-33', blade17, '').
text_drs_eval(0, 749, 'A man works manually in a bank.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, work, B)-1, modifier_pp(C, in, A)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [works]]], [adv, [manually]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-08-17-11-54-56', blade17, '').
text_drs_eval(0, 750, 'A man works manually in a bank quickly.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, work, B)-1, modifier_adv(C, quickly, pos)-1, modifier_pp(C, in, A)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [works]]], [adv, [manually]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]], [adv, [quickly]]]]], ['.']]], '2005-08-17-11-55-28', blade17, '').
text_drs_eval(0, 751, 'A man works manually and quickly in a bank.', drs([A, B, C], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, work, B)-1, modifier_pp(C, in, A)-1, modifier_adv(C, quickly, pos)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [works]]], [adv, [manually]], [coord, [and]], [adv, [quickly]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]], ['.']]], '2005-08-17-11-55-59', blade17, '').
text_drs_eval(0, 752, 'A man works manually quickly in a bank.', drs([], []), [], '2005-08-17-11-56-14', blade17, '').
text_drs_eval(0, 753, 'A man works in a bank manually quickly.', drs([], []), [], '2005-08-17-11-56-51', blade17, '').
text_drs_eval(0, 754, 'A man works in a bank manually in a morning.', drs([A, B, C, D], [object(B, bank, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1, modifier_adv(D, manually, pos)-1, modifier_pp(D, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [works]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]], [adv, [manually]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]]]]], ['.']]], '2005-08-17-11-57-40', blade17, '').
text_drs_eval(0, 755, 'A man gives a boy his own card.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, boy, countable, na, eq, 1)-1, relation(D, of, A)-1, predicate(C, give, A, D, B)-1, object(D, card, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [boy]]]], [np, [poss_spec, [poss_pn_coord, [posspn, ['{his own}']]]], [nbar, [n, [card]]]]]]], ['.']]], '2006-08-14-18-52-23', amadeus, '').
text_drs_eval(0, 756, 'His own card waits.', drs([], []), [], '2005-08-17-20-38-41', blade17, '').
text_drs_eval(0, 757, 'Not more than 5 men wait.', drs([], []), [], '2008-08-19-19-56-50', '130.60.155.177', '').
text_drs_eval(0, 758, 'Not less than 5 men wait.', drs([], []), [], '2008-08-19-19-56-59', '130.60.155.177', '').
text_drs_eval(0, 759, 'There is a cat. It sees itself.', drs([A, B], [object(A, cat, countable, na, eq, 1)-1, predicate(B, see, A, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]], ['.']]], '2005-08-17-17-38-51', blade17, '').
text_drs_eval(0, 760, 'There is a cat. A dog sees it.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-2, object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [pn, [it]]]]]], ['.']]], '2005-08-17-17-39-13', blade17, '').
text_drs_eval(0, 761, 'Every man waits-for some women who are happy or who are sad.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, woman, countable, na, geq, 2)-1, drs([D, E], [property(D, happy, pos)-1, predicate(E, be, B, D)-1])v drs([F, G], [property(F, sad, pos)-1, predicate(G, be, B, F)-1]), predicate(C, 'wait-for', A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, ['waits-for']], [np, [det, [some]], [nbar, [n, [women]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [sad]]]]]]]]]]]]], ['.']]], '2007-05-09-12-12-30', '130.60.156.229', '').
text_drs_eval(0, 762, 'If there is a man then there are more than 1 women.', drs([], []), [], '2007-04-13-14-50-19', '130.60.155.177', '').
text_drs_eval(0, 763, 'Is there no laundry?', drs([], [question(drs([], [-drs([A], [object(A, laundry, countable, na, eq, 1)-1/4])]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, no], [nbar, [n, laundry]]]]], ?], '.']], '2009-05-13-14-14-38', '130.60.155.193', '').
text_drs_eval(0, 764, 'Everybody a dog of who barks waits.', drs([], [drs([A, B, C], [object(C, somebody, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, bark, B)-1])=>drs([D], [predicate(D, wait, C)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-07-16-10-23', blade17, '').
text_drs_eval(0, 765, 'Are there Augusts?', drs([], []), [[query, [question, [topic, [quant, ['{are there}']], [np, [np, [var, ['Augusts']]]]]], [?]]], '2006-08-15-21-00-41', amadeus, '').
text_drs_eval(0, 766, 'A laundry sees its own dog.', drs([A, B, C], [object(C, laundry, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, see, C, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [sees]], [np, [poss_pn_coord, [posspn, ['{its own}']]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-08-18-15-01-54', blade17, '').
text_drs_eval(0, 767, 'Some laundry sees its own dog.', drs([A, B, C], [object(C, laundry, mass, na, na, na)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, see, C, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [sees]], [np, [poss_pn_coord, [posspn, ['{its own}']]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-10-04-17-15-25', blade17, '').
text_drs_eval(0, 768, 'There is John. John walks.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2006-08-15-21-01-38', amadeus, '').
text_drs_eval(0, 769, 'Some laundry are clean.', drs([], []), [], '2005-08-18-15-38-03', blade17, '').
text_drs_eval(0, 770, 'A man sees 2 signs "Go!" and "Stop".', drs([], []), [], '2007-04-10-15-43-14', '130.60.155.177', '').
text_drs_eval(0, 771, 'A man sees 3 signs "Go!" and "Stop".', drs([], []), [], '2007-04-10-15-22-57', '130.60.155.177', '').
text_drs_eval(0, 772, 'Where does a man quickly run?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, run, A)-1/6, modifier_adv(B, quickly, pos)-1/5, query(B, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vmod, [adv, quickly]], [vbar, [v, run]]]]], ?], '.']], '2009-05-13-14-14-40', '130.60.155.193', '').
text_drs_eval(0, 773, 'Where does a man run quickly?', drs([], []), [], '2006-08-20-17-08-37', amadeus, '').
text_drs_eval(0, 774, 'A card of a man sees him.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2005-08-18-18-36-46', blade17, '').
text_drs_eval(0, 775, 'There are the man\'s dog and cat.', drs([], []), [], '2006-05-24-19-13-35', amadeus, '').
text_drs_eval(0, 776, 'A man runs. There is the man.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [man]]]]]]], ['.']]], '2006-05-24-19-09-46', amadeus, '').
text_drs_eval(0, 777, 'where does a man run?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, run, A)-1/5, query(B, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, run]]]]], ?], '.']], '2009-05-13-14-14-42', '130.60.155.193', '').
text_drs_eval(0, 778, 'Everything runs.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B], [predicate(B, run, A)-1])]), [[specification, [s, [np, [pn, [everything]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2005-10-31-12-05-30', blade17, '').
text_drs_eval(0, 779, 'A dog of a man and of a woman waits.', drs([], []), [], '2007-06-12-10-04-18', '130.60.156.66', '').
text_drs_eval(0, 780, 'John\'s Mary waits.', drs([], []), [], '2007-06-12-10-04-28', '130.60.156.66', '').
text_drs_eval(0, 781, 'Mary of John waits.', drs([], []), [], '2007-06-12-10-04-35', '130.60.156.66', '').
text_drs_eval(0, 782, 'If every man runs then a dog barks.', drs([], [drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, run, A)-1])])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [runs]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-08-21-16-06-37', blade17, '').
text_drs_eval(0, 783, 'If if there is a man then he runs then a dog barks.', drs([], [drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, run, A)-1])])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, [if], [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [runs]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-08-21-16-07-14', blade17, '').
text_drs_eval(0, 784, 'There is a man such that he walks.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]]], ['.']]], '2005-11-11-20-52-52', blade17, '').
text_drs_eval(0, 785, 'There is a man A. A is happy.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, property(B, happy, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['A']]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2005-08-28-16-12-05', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 786, 'Where does a man run?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, run, A)-1/5, query(B, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, run]]]]], ?], '.']], '2009-05-13-14-14-43', '130.60.155.193', '').
text_drs_eval(0, 787, 'A man of the man waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(A, of, A)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-22-19-17-35', blade17, '').
text_drs_eval(0, 788, 'If a man runs, and walks or eats then a dog barks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, run, A)-1, drs([C], [predicate(C, walk, A)-1])v drs([D], [predicate(D, eat, A)-1])])=>drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [runs]]]], [coord, ['{, and}']], [vp_coord, [vp, [vbar, [v, [walks]]]], [coord, [or]], [vp, [vbar, [v, [eats]]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-08-23-12-48-09', blade17, '').
text_drs_eval(0, 789, 'If a man does not walk then a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B], [predicate(B, walk, A)-1])])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [walk]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-08-23-14-32-46', blade17, '').
text_drs_eval(0, 790, 'A man waits in a bank which likes him.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, bank, countable, na, eq, 1)-1, predicate(C, like, B, A)-1, predicate(D, wait, A)-1, modifier_pp(D, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [likes]], [np, [pn, [him]]]]]]]]]]]], ['.']]], '2006-08-20-17-10-30', amadeus, '').
text_drs_eval(0, 791, 'A man waits in a bank which likes himself.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]], [pp, [prep, in], [np, [det, a], [nbar, [n, bank], [rel_cl, [np, [relpn, which]], [vp, [vbar, [v, likes], [np, [pn, himself]]]]]]]]]]], '.']], '2008-07-30-14-45-08', '130.60.155.177', '').
text_drs_eval(0, 792, 'A man X walks. A man X talks.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [walks]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [talks]]]]], ['.']]], '2005-11-07-15-57-03', blade17, '').
text_drs_eval(0, 793, 'There is a box.', drs([A], [object(A, box, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [box]]]]]], ['.']]], '2005-08-25-17-33-34', blade17, '').
text_drs_eval(0, 794, 'a man gives a dog a card in his house.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [dog]]]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [house]]]]]]]], ['.']]], '2007-11-22-18-06-43', '84.74.90.129', '').
text_drs_eval(0, 795, 'a man gives a dog a card in him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [dog]]]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-18-06-28', '84.74.90.129', '').
text_drs_eval(0, 796, 'a man gives his dog a card.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [posspn, [his]], [nbar, [n, [dog]]]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-18-06-17', '84.74.90.129', '').
text_drs_eval(0, 797, 'a man gives a card to his dog.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [posspn, [his]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-11-22-18-06-04', '84.74.90.129', '').
text_drs_eval(0, 798, 'a man gives him a card .', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [pn, [him]]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2005-08-25-22-18-36', '217-162-134-182.dclient.hispeed.ch', '').
text_drs_eval(0, 799, 'a man gives a card to him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-18-05-32', '84.74.90.129', '').
text_drs_eval(0, 800, 'a man gives a dog him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [dog]]]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-18-04-55', '84.74.90.129', '').
text_drs_eval(0, 801, 'a man gives him to a dog.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [pn, [him]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-11-22-18-04-41', '84.74.90.129', '').
text_drs_eval(0, 802, 'a man sees a card in his house.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [house]]]]]]]], ['.']]], '2007-11-22-18-03-51', '84.74.90.129', '').
text_drs_eval(0, 803, 'a man sees a card in him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-18-03-38', '84.74.90.129', '').
text_drs_eval(0, 804, 'a man sees his card .', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [card]]]]]]], ['.']]], '2005-08-25-22-19-23', '217-162-134-182.dclient.hispeed.ch', '').
text_drs_eval(0, 805, 'a man sees him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-18-03-06', '84.74.90.129', '').
text_drs_eval(0, 806, 'a man waits in his house.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [house]]]]]]]], ['.']]], '2007-11-22-18-02-56', '84.74.90.129', '').
text_drs_eval(0, 807, 'a man waits in him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-18-02-43', '84.74.90.129', '').
text_drs_eval(0, 808, 'A man X waits. X sleeps.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, sleep, A)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-25-22-20-41', '217-162-134-182.dclient.hispeed.ch', '').
text_drs_eval(0, 809, 'A dog of its own man barks.', drs([], []), [], '2008-10-23-15-00-51', '130.60.155.206', '').
text_drs_eval(1, 810, 'There is a woman. Her man of a dog waits.', drs([A, B, C, D], [object(D, woman, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-2, object(C, dog, countable, na, eq, 1)-2, relation(A, of, C)-2, relation(A, of, D)-2, predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [her]]], [nbar, [n, [man]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-08-26-17-58-23', blade17, '2 relations attaching to the same referent. possesive pronouns can not be replaced by an of-construction. This can not be paraphrased.').
text_drs_eval(0, 811, 'A dog X of a woman eats. The dog X of a man drinks.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, dog], [appos, [var, 'X']], [pp, [prep, of], [np, [det, a], [nbar, [n, woman]]]]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [appos, [var, 'X']], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [vbar, [v, drinks]]]], '.']], '2008-08-15-20-25-13', '130.60.204.15', '').
text_drs_eval(0, 812, 'A man sees a cat and a dog and a mouse.', drs([A, B, C, D, E, F], [object(F, na, countable, na, eq, 3)-1, object(C, mouse, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, predicate(E, see, D, F)-1, has_part(F, B)-1, has_part(F, A)-1, has_part(F, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [cat]]]], [coord, [and]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]]], ['.']]], '2005-08-26-18-59-29', blade17, '').
text_drs_eval(0, 813, 'Somebody waits. He sleeps.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, sleep, A)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-12-01-15-27-21', blade17, '').
text_drs_eval(0, 814, 'Something waits. He sleeps.', drs([], []), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-27-18-16-56', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 815, 'It is not the case that there is some water.', drs([], []), [], '2007-12-14-17-02-42', '130.60.155.177', '').
text_drs_eval(0, 816, 'There is no water.', drs([], [-drs([A], [object(A, water, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [water]]]]]], ['.']]], '2005-08-27-18-17-22', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 817, 'Somebody waits. It sleeps.', drs([], []), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-27-18-18-10', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 818, 'Something waits. It sleeps.', drs([A, B, C], [object(A, something, dom, na, na, na)-1, predicate(B, wait, A)-1, predicate(C, sleep, A)-2]), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-12-01-15-27-41', blade17, '').
text_drs_eval(0, 819, 'John watches a man who sees himself.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, B)-1, predicate(D, watch, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]]], '.']], '2008-08-17-10-45-13', '84.74.167.232', '').
text_drs_eval(0, 820, 'John beats the donkey of his wife.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [the]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [wife]]]]]]]]]], ['.']]], '2005-11-10-15-20-04', blade17, '').
text_drs_eval(0, 821, 'John beats his own donkey.', drs([A, B, C], [object(B, donkey, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, beat, C, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [donkey]]]]]]], ['.']]], '2005-08-28-09-59-36', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 822, 'John beats the donkey of himself.', drs([A, B, C], [object(B, donkey, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, beat, C, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [the]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-08-28-10-00-12', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 823, 'John beats a donkey of himself.', drs([A, B, C], [object(A, donkey, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, beat, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [a]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-08-28-10-00-54', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 824, 'John beats his donkey.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [donkey]]]]]]], ['.']]], '2005-08-28-12-57-58', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 825, 'John beats a donkey of him.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [a]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2005-08-28-12-57-48', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 826, 'John beats the donkey of him.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [the]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2005-10-31-14-48-14', blade17, '').
text_drs_eval(0, 827, 'John beats the donkey of his own wife.', drs([A, B, C, D], [object(C, wife, countable, na, eq, 1)-1, object(A, donkey, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, C)-1, relation(C, of, B)-1, predicate(D, beat, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [the]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [wife]]]]]]]]]], ['.']]], '2005-11-10-15-19-55', blade17, '').
text_drs_eval(0, 828, 'John beats a donkey of a wife of himself.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, donkey, countable, na, eq, 1)-1, object(C, wife, countable, na, eq, 1)-1, relation(C, of, A)-1, relation(B, of, C)-1, predicate(D, beat, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [a]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [wife]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]]]]], ['.']]], '2006-08-22-12-22-30', amadeus, '').
text_drs_eval(0, 829, 'John beats a donkey of a wife of him.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [a]], [nbar, [n, [donkey]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [wife]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]]]]], ['.']]], '2006-08-22-12-22-09', amadeus, '').
text_drs_eval(0, 830, 'A man has 2 kg of laundries.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, laundry, countable, kg, eq, 2)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundries]]]]]]]]], ['.']]], '2007-12-10-19-38-04', '130.60.155.177', '').
text_drs_eval(0, 831, 'John sees some water of himself.', drs([A, B, C], [object(A, water, mass, na, na, na)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [some]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-10-04-17-17-42', blade17, '').
text_drs_eval(0, 832, 'John sees a water of himself.', drs([A, B, C], [object(A, water, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-08-28-13-19-04', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 833, 'John sees his own water.', drs([A, B, C], [object(B, water, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, see, C, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [water]]]]]]], ['.']]], '2005-08-28-13-19-10', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 834, 'John sees a water.', drs([A, B, C], [object(A, water, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [water]]]]]]], ['.']]], '2005-08-28-13-19-37', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 835, 'John sees some water.', drs([A, B, C], [object(A, water, mass, na, na, na)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [some]], [nbar, [n, [water]]]]]]], ['.']]], '2005-10-04-17-18-12', blade17, '').
text_drs_eval(0, 836, 'John sees the water.', drs([A, B, C], [object(B, water, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, predicate(A, see, C, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [water]]]]]]], ['.']]], '2005-08-28-13-20-08', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 837, 'John does not see a water.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([B, C], [object(B, water, countable, na, eq, 1)-1, predicate(C, see, A, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [water]]]]]]], ['.']]], '2005-08-28-13-21-27', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 838, 'John sees no water.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, water, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [no]], [nbar, [n, [water]]]]]]], ['.']]], '2006-08-12-18-27-47', amadeus, '').
text_drs_eval(0, 839, 'John does not see some water.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([B, C], [object(B, water, mass, na, na, na)-1, predicate(C, see, A, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [see]], [np, [det, [some]], [nbar, [n, [water]]]]]]], ['.']]], '2005-09-01-15-19-22', blade17, '').
text_drs_eval(0, 840, 'A man waits. A man wait.', drs([], []), [], '2005-08-28-13-30-01', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 841, 'A dog of a man of a house barks.', drs([A, B, C, D], [object(B, house, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, relation(C, of, B)-1, relation(A, of, C)-1, predicate(D, bark, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [house]]]]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-08-28-16-02-55', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 842, 'A man gives a cat. The cat gives a bone to a dog.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, predicate(C, give, A, B)-1, object(D, bone, countable, na, eq, 1)-2, object(E, dog, countable, na, eq, 1)-2, predicate(F, give, B, D, E)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [bone]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-08-14-18-52-54', amadeus, '').
text_drs_eval(0, 843, 'A man gives a cat to a dog. The cat gives a bone.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1, object(E, bone, countable, na, eq, 1)-2, predicate(F, give, B, E)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [cat]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [bone]]]]]]], ['.']]], '2006-08-14-18-53-17', amadeus, '').
text_drs_eval(0, 844, 'If there is a man then there are more than 2 women.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [object(B, woman, countable, na, greater, 2)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, ['{more than}']], [number, [2]]], [nbar, [n, [women]]]]]]], ['.']]], '2005-08-28-16-23-47', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 845, 'A man runs in the park manually and quickly.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, run, A)-1, modifier_pp(B, in, C)-1, modifier_adv(B, manually, pos)-1, modifier_adv(B, quickly, pos)-1, object(C, park, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [park]]]]], [adv_coord, [adv, [manually]], [coord, [and]], [adv, [quickly]]]]]], ['.']]], '2007-07-04-13-35-57', '130.60.206.45', '').
text_drs_eval(0, 846, 'A dog is good and bad.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, property(B, good, pos)-1, property(B, bad, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]], [coord, [and]], [ap_coord, [ap, [adj, [bad]]]]]]]], ['.']]], '2005-08-28-19-38-49', blade17, '').
text_drs_eval(0, 847, 'A dog is good and interested-in a bone.', drs([], []), [], '2007-05-04-17-27-29', '130.60.156.229', '').
text_drs_eval(0, 848, 'A dog is good and interested-in a bone and bad.', drs([], []), [], '2007-05-04-18-37-55', '130.60.155.177', '').
text_drs_eval(0, 849, 'if there is a man then there are 2 women.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [object(B, woman, countable, na, eq, 2)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [women]]]]]]], ['.']]], '2005-08-28-21-44-01', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 850, 'There is some laundry. There is a dog. It is clean.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-2, object(B, laundry, mass, na, na, na)-1, property(C, clean, pos)-3, predicate(D, be, A, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-09-01-15-20-31', blade17, '').
text_drs_eval(0, 851, 'There is some laundry. It sees itself.', drs([A, B], [object(A, laundry, mass, na, na, na)-1, predicate(B, see, A, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]], ['.']]], '2005-09-01-15-20-52', blade17, '').
text_drs_eval(0, 852, 'There is some laundry. It sees its own dog.', drs([A, B, C], [object(C, laundry, mass, na, na, na)-1, object(B, dog, countable, na, eq, 1)-2, relation(B, of, C)-2, predicate(A, see, C, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [laundry]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [sees]], [np, [poss_pn_coord, [posspn, ['{its own}']]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-10-04-17-19-33', blade17, '').
text_drs_eval(0, 853, 'Some laundry which sees itself is clean.', drs([A, B, C, D], [object(A, laundry, mass, na, na, na)-1, predicate(B, see, A, A)-1, property(C, clean, pos)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [laundry]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2005-09-01-15-17-08', blade17, '').
text_drs_eval(0, 854, 'Each of 2 girls lifts them.', drs([A], [object(A, girl, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, lift, B, A)-1])]), [[specification, [s, [np, [quant, 'each of'], [np, [nump, [num, 2]], [nbar, [n, girls]]]], [vp, [vbar, [v, lifts], [np, [pn, them]]]]], '.']], '2008-08-12-16-22-26', '130.60.155.208', '').
text_drs_eval(0, 855, 'Each of 2 girls lifts themselves.', drs([], []), [[specification, [s, [np, [quant, 'each of'], [np, [nump, [num, 2]], [nbar, [n, girls]]]], [vp, [vbar, [v, lifts], [np, [pn, themselves]]]]], '.']], '2008-08-12-16-22-46', '130.60.155.208', '').
text_drs_eval(0, 856, 'A man is interested-in every dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [property(C, 'interested-in', pos, B)-1, predicate(D, be, A, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [det, [every]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-12-47', '130.60.156.229', '').
text_drs_eval(0, 857, 'A man is interested-in every dog that barks.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])=>drs([D, E], [property(D, 'interested-in', pos, B)-1, predicate(E, be, A, D)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]|F]]]], ['.']]], '2007-05-09-12-12-54', '130.60.156.229', '').
text_drs_eval(0, 858, 'A man is interested-in no dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C, D], [property(C, 'interested-in', pos, B)-1, predicate(D, be, A, C)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [det, [no]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-12-59', '130.60.156.229', '').
text_drs_eval(0, 859, 'A man is interested-in not every dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [property(C, 'interested-in', pos, B)-1, predicate(D, be, A, C)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [det, ['{not every}']], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-13-05', '130.60.156.229', '').
text_drs_eval(0, 860, 'A bank which a man enters is good.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, bank, countable, na, eq, 1)-1, predicate(C, enter, A, B)-1, property(D, good, pos)-1, predicate(E, be, B, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [bank]], [rel_cl, [comp, [which]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [enters]], [np, [[]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [good]]]]]]], ['.']]], '2005-08-30-18-06-45', blade17, '').
text_drs_eval(0, 861, 'Which bank which a man enters is good?', drs([], [question(drs([A, B, C, D, E], [query(A, which)-1/1, object(A, bank, countable, na, eq, 1)-1/2, object(B, man, countable, na, eq, 1)-1/5, predicate(C, enter, B, A)-1/6, property(D, good, pos)-1/8, predicate(E, be, A, D)-1/7]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, bank], [rel_cl, [np, [relpn, which]], [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enters]]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, good]]]]]]], ?], '.']], '2009-05-13-14-14-44', '130.60.155.193', '').
text_drs_eval(0, 862, 'What which is good does a man enter?', drs([], []), [], '2008-09-23-08-46-22', '130.60.155.206', '').
text_drs_eval(0, 863, 'A card a code of who a man enters is valid.', drs([], []), [], '2007-11-20-11-30-32', '130.60.155.231', '').
text_drs_eval(0, 864, 'The customer Mr-Miller inserts a card A.', drs([], []), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]], [appos_coord, [appos, [var, ['Mr-Miller']]]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]], [appos_coord, [appos, [var, ['A']]]]]]]]], ['.']]], '2006-08-15-15-14-48', amadeus, '').
text_drs_eval(0, 865, 'The dog which sees the man barks.', drs([A, B, C, D], [object(C, man, countable, na, eq, 1)-1, object(D, dog, countable, na, eq, 1)-1, predicate(B, see, D, C)-1, predicate(A, bark, D)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-08-30-19-04-48', blade17, '').
text_drs_eval(0, 866, 'There is a n:aaa which waits. The n:aaa which waits barks.', drs([A, B, C], [object(A, aaa, countable, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, bark, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [aaa]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [aaa]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [waits]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-08-30-19-05-42', blade17, '').
text_drs_eval(0, 867, 'There is a man or there is a dog which sees him or there is a cat which sees it.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, B)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [sees]], [np, [pn, [it]]]]]]]]]]]], ['.']]], '2005-08-30-19-07-38', blade17, '').
text_drs_eval(0, 868, 'There is a man or there is a dog which sees him or there is a cat which sees him.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, A)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]]]]]]], ['.']]], '2005-08-30-19-09-22', blade17, '').
text_drs_eval(0, 869, 'For every body which waits there is a clerk.', drs([], [drs([A, B], [object(A, body, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C], [object(C, clerk, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [body]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [waits]]]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [clerk]]]]]]], ['.']]], '2005-08-30-19-11-44', blade17, '').
text_drs_eval(0, 870, 'Some men\'s dog which runs barks.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, relation(A, of, B)-1, predicate(C, run, A)-1, predicate(D, bark, A)-1]), [[specification, [s, [np, [poss_np, [det, [some]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [runs]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-08-30-19-13-18', blade17, '').
text_drs_eval(0, 871, 'A dog which runs barks.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, predicate(B, run, A)-1, predicate(C, bark, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [runs]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-08-30-19-13-57', blade17, '').
text_drs_eval(0, 872, 'A man John waits. John is happy.', drs([], []), [], '2005-08-31-21-08-28', blade17, '').
text_drs_eval(0, 873, '2 men X and X eat.', drs([], []), [[s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['X']]]]], [coord, [and]], [np, [var, ['X']]]], [vp, [vbar, [v, [eat]]]]]], '2007-11-02-19-27-54', '130.60.155.177', '').
text_drs_eval(0, 874, 'A laundry washes some laundry. It is clean. Some water sees a water. It is cold.', drs([A, B, C, D, E, F, G, H, I, J], [object(F, water, countable, na, eq, 1)-3, object(D, water, mass, na, na, na)-3, object(E, laundry, mass, na, na, na)-1, object(G, laundry, countable, na, eq, 1)-1, predicate(A, wash, G, E)-1, property(B, clean, pos)-2, predicate(C, be, E, B)-2, predicate(H, see, D, F)-3, property(I, cold, pos)-4, predicate(J, be, F, I)-4]), [[specification, [s, [np, [det, [a]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [washes]], [np, [det, [some]], [nbar, [n, [laundry]]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']], [specification, [s, [np, [det, [some]], [nbar, [n, [water]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [water]]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [cold]]]]]]], ['.']]], '2005-09-01-15-13-49', blade17, '').
text_drs_eval(0, 875, 'A card who is tired sleeps.', drs([], []), [], '2005-08-31-10-35-36', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 876, 'A card which is tired sleeps.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(B, tired, pos)-1, predicate(C, be, A, B)-1, predicate(D, sleep, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [tired]]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-31-10-35-42', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 877, 'A card that is tired sleeps.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(B, tired, pos)-1, predicate(C, be, A, B)-1, predicate(D, sleep, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [tired]]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-31-10-35-51', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 878, 'A man that is tired sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, property(B, tired, pos)-1, predicate(C, be, A, B)-1, predicate(D, sleep, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [tired]]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-31-10-36-00', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 879, 'A man which is tired sleeps.', drs([], []), [], '2005-08-31-10-36-09', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 880, 'A man who is tired sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, property(B, tired, pos)-1, predicate(C, be, A, B)-1, predicate(D, sleep, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [tired]]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-31-10-36-16', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 881, 'A man who is tired sleeps', drs([], []), [], '2005-08-31-10-36-29', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 882, 'A man who is John sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, be, A, B)-1, predicate(D, sleep, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [pname, ['John']]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-08-31-10-37-16', '217-162-130-102.dclient.hispeed.ch', '').
text_drs_eval(0, 883, 'John who is a man sleeps.', drs([A, B, C, D], [object(B, man, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, predicate(A, sleep, C)-1, predicate(D, be, C, B)-1]), [[specification, [s, [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2005-09-01-14-30-31', blade17, '').
text_drs_eval(0, 884, '2 men X and John wait.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 2)-1, predicate(C, wait, D)-1, has_part(D, B)-1, has_part(D, A)-1, object(D, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['X']]]]], [coord, [and]], [np, [pname, ['John']]]], [vp, [vbar, [v, [wait]]]]]], '2007-10-17-16-43-23', '130.60.155.177', '').
text_drs_eval(0, 885, 'John wait.', drs([], []), [[specification, [s, [np, [np, [var, ['John']]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-04-20-12-18-46', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 886, '2 men John and X wait.', drs([], []), [], '2005-08-31-19-58-14', blade17, '').
text_drs_eval(0, 887, 'Christmases wait.', drs([A, B], [object(A, 'Christmas', named, na, geq, 2)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [pname, ['Christmases']]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2005-08-31-20-15-07', blade17, '').
text_drs_eval(0, 888, 'Some men Christmases wait.', drs([], []), [], '2005-08-31-20-15-29', blade17, '').
text_drs_eval(0, 889, 'There is a man X. A man Y brings him his pencil and his own computer.', drs([A, B, C, D, E, F], [object(F, na, countable, na, eq, 2)-2, object(D, man, countable, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, computer, countable, na, eq, 1)-2, object(A, pencil, countable, na, eq, 1)-2, relation(A, of, B)-2, predicate(E, bring, D, F, B)-2, relation(C, of, D)-2, has_part(F, A)-2, has_part(F, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['Y']]]]]], [vp, [vbar, [v, [brings]], [np, [pn, [him]]], [np_coord, [np, [poss_pn_coord, [posspn, [his]]], [nbar, [n, [pencil]]]], [coord, [and]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [computer]]]]]]]], ['.']]], '2005-08-31-20-18-59', blade17, '').
text_drs_eval(0, 890, 'A man runs there.', drs([], []), [], '2005-09-01-14-29-33', blade17, '').
text_drs_eval(0, 891, 'Is there a man X?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'is there'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], ?], '.']], '2009-05-13-14-16-20', '130.60.155.193', '').
text_drs_eval(0, 892, 'A man X gives his own wife Y a big and red apple.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(D, of, A)-1, object(B, apple, countable, na, eq, 1)-1, property(B, big, pos)-1, property(B, red, pos)-1, predicate(C, give, A, B, D)-1, object(D, wife, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [gives]], [np, [poss_spec, [poss_pn_coord, [posspn, ['{his own}']]]], [nbar, [n, [wife]], [appos_coord, [appos, [var, ['Y']]]]]], [np, [det, [a]], [nbar, [adj_coord, [adj, [big]], [coord, [and]], [adj, [red]]], [nbar, [n, [apple]]]]]]]], ['.']]], '2006-08-14-18-53-51', amadeus, '').
text_drs_eval(0, 893, 'If John waits then the man X sleeps.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])=>drs([C, D], [object(C, man, countable, na, eq, 1)-1, predicate(D, sleep, C)-1])]), [[specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-08-31-20-28-38', blade17, '').
text_drs_eval(0, 894, 'If John waits then a man X sleeps.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])=>drs([C, D], [object(C, man, countable, na, eq, 1)-1, predicate(D, sleep, C)-1])]), [[specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-08-31-20-28-55', blade17, '').
text_drs_eval(0, 895, 'The man X walks. The woman X talks.', drs([], []), [[specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, walks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, woman], [appos, [var, 'X']]]], [vp, [vbar, [v, talks]]]], '.']], '2008-08-15-20-26-29', '130.60.204.15', '').
text_drs_eval(0, 896, 'If a man X waits then he sleeps.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C], [predicate(C, sleep, A)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2005-08-31-20-30-08', blade17, '').
text_drs_eval(0, 897, 'A man does not like a man X.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]]], ['.']]], '2005-08-31-20-31-16', blade17, '').
text_drs_eval(0, 898, 'A man X gives his own wife Y a unknownword.', drs([], []), [], '2006-04-20-12-19-29', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 899, 'A man X gives an apple to a woman Y. Y accepts the apple and eats it. She is happy and he has no apples.', drs([A, B, C, D, E, F, G, H], [object(A, man, countable, na, eq, 1)-1, object(B, apple, countable, na, eq, 1)-1, object(C, woman, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1, predicate(E, accept, C, B)-2, predicate(F, eat, C, B)-2, property(G, happy, pos)-3, predicate(H, be, C, G)-3, drs([I], [object(I, apple, countable, na, eq, 1)-3])=>drs([], [-drs([J], [predicate(J, have, A, I)-3])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [apple]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [woman]], [appos_coord, [appos, [var, ['Y']]]]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['Y']]]], [vp_coord, [vp, [vbar, [v, [accepts]], [np, [det, [the]], [nbar, [n, [apple]]]]]], [coord, [and]], [vp, [vbar, [v, [eats]], [np, [pn, [it]]]]]]], ['.']], [specification, [s_coord, [s, [np, [pn, [she]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [has]], [np, [det, [no]], [nbar, [n, [apples]]]]]]]], ['.']]], '2007-07-18-14-38-39', '130.60.155.177', '').
text_drs_eval(0, 900, 'John gives an apple to Mary. Mary accepts the apple and eats it. She is happy and he has no apples.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, give, A, C, B)-1, predicate(E, accept, B, C)-2, predicate(F, eat, B, C)-2, property(G, happy, pos)-3, predicate(H, be, B, G)-3, drs([I], [object(I, apple, countable, na, eq, 1)-3])=>drs([], [-drs([J], [predicate(J, have, A, I)-3])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [apple]]]], [pp, [prep, [to]], [np, [pname, ['Mary']]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp_coord, [vp, [vbar, [v, [accepts]], [np, [det, [the]], [nbar, [n, [apple]]]]]], [coord, [and]], [vp, [vbar, [v, [eats]], [np, [pn, [it]]]]]]], ['.']], [specification, [s_coord, [s, [np, [pn, [she]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [has]], [np, [det, [no]], [nbar, [n, [apples]]]]]]]], ['.']]], '2007-07-18-14-38-57', '130.60.155.177', '').
text_drs_eval(0, 901, 'A man runs easily.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, easily, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [easily]]]]], ['.']]], '2005-08-31-21-53-10', blade17, '').
text_drs_eval(0, 902, 'There is a man X. X who runs is happy.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.']], '2008-09-23-08-46-33', '130.60.155.206', '').
text_drs_eval(0, 903, 'John which runs eats.', drs([], []), [], '2005-09-01-14-36-35', blade17, '').
text_drs_eval(0, 904, 'There is a man X. X which runs is happy.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.']], '2008-09-23-11-32-57', '130.60.155.206', '').
text_drs_eval(0, 905, 'John who run eats.', drs([], []), [], '2005-09-01-14-38-00', blade17, '').
text_drs_eval(0, 906, 'There is a dog which a man hits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, hit, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [which]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [[]]]]]]]]]], ['.']]], '2005-09-01-14-40-03', blade17, '').
text_drs_eval(0, 907, 'There is a dog X. X which a man hits barks.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [appos, [var, 'X']]]]]], '.']], '2008-09-23-08-46-43', '130.60.155.206', '').
text_drs_eval(0, 908, 'There is a dog X. X which sees a man barks.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [appos, [var, 'X']]]]]], '.']], '2008-09-23-08-46-52', '130.60.155.206', '').
text_drs_eval(0, 909, 'John\'s car are fast.', drs([], []), [], '2005-09-01-19-49-06', blade17, '').
text_drs_eval(0, 910, 'John who is a clerk waits.', drs([A, B, C, D], [object(B, clerk, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-1, predicate(A, wait, C)-1, predicate(D, be, C, B)-1]), [[specification, [s, [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [clerk]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-09-01-19-50-17', blade17, '').
text_drs_eval(0, 911, 'John who is the clerk waits.', drs([A, B, C, D], [object(C, clerk, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, predicate(A, wait, D)-1, predicate(B, be, D, C)-1]), [[specification, [s, [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [clerk]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-09-01-19-50-41', blade17, '').
text_drs_eval(0, 912, 'There is a clerk X. X the card of who a customer steals is angry.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, clerk], [appos, [var, 'X']]]]]], '.']], '2008-09-23-08-47-03', '130.60.155.206', '').
text_drs_eval(0, 913, 'There are at most 2 men X and Y and Z.', drs([A, B, C, D], [[has_part(D, A)-1, object(A, man, countable, na, leq, 2)-1], object(B, something, dom, na, na, na)-1, has_part(D, B)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 3)-1]), [[specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [var, 'Y']], [coord, and], [np, [var, 'Z']]]]], '.']], '2009-03-02-11-27-44', '130.60.155.206', '').
text_drs_eval(0, 914, 'There is John. A man brings him his pencil and brings him his own computer.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [brings]], [np, [pn, [him]]], [np, [poss_spec, [poss_pn_coord, [posspn, [his]]]], [nbar, [n, [pencil]]]]]], [coord, [and]], [vp, [vbar, [v, [brings]], [np, [pn, [him]]], [np, [poss_spec, [poss_pn_coord, [posspn, ['{his own}']]]], [nbar, [n, [computer]]]]]]]], ['.']]], '2006-08-15-21-01-52', amadeus, '').
text_drs_eval(0, 915, 'A man waits in a bank with John.', drs([A, B, C, D], [object(B, bank, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(D, wait, C)-1, modifier_pp(D, with, A)-1, modifier_pp(D, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]], [pp, [prep, [with]], [np, [pname, ['John']]]]]]], ['.']]], '2005-09-02-13-26-59', blade17, '').
text_drs_eval(0, 916, 'Every customer enters every card.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, card, countable, na, eq, 1)-1])=>drs([C], [predicate(C, enter, A, B)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]]]]]]], ['.']]], '2005-09-02-16-28-10', blade17, '').
text_drs_eval(0, 917, 'Every customer enters every card or enters every code.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1])=>drs([], [drs([], [drs([B], [object(B, card, countable, na, eq, 1)-1])=>drs([C], [predicate(C, enter, A, B)-1])])v drs([], [drs([D], [object(D, code, countable, na, eq, 1)-1])=>drs([E], [predicate(E, enter, A, D)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]]]]]], [coord, [or]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-09-02-16-30-31', blade17, '').
text_drs_eval(0, 918, 'It is not the case that no man does not wait.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [no]], [nbar, [n, [man]]]], [vp, [aux, ['{does not}']], [vbar, [v, [wait]], [np, [[]]]]]]]]]]], ['.']]], '2007-12-14-17-03-01', '130.60.155.177', '').
text_drs_eval(0, 919, 'A customer enters every card and enters every code.', drs([A], [object(A, customer, countable, na, eq, 1)-1, drs([B], [object(B, card, countable, na, eq, 1)-1])=>drs([C], [predicate(C, enter, A, B)-1]), drs([D], [object(D, code, countable, na, eq, 1)-1])=>drs([E], [predicate(E, enter, A, D)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp_coord, [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]]]]]], [coord, [and]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [code]]]]]]]], ['.']]], '2005-09-02-17-09-33', blade17, '').
text_drs_eval(0, 920, 'It is not the case that a man waits and a dog barks.', drs([], []), [[specification, [s_coord, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]], [np, [[]]]]]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-12-14-17-03-25', '130.60.155.177', '').
text_drs_eval(0, 921, 'It is not the case that there is a man and a dog barks.', drs([], []), [], '2007-12-14-17-03-48', '130.60.155.177', '').
text_drs_eval(0, 922, 'It is not the case that a man who waits or who eats runs and sleeps.', drs([], []), [[specification, [s, [np, [pn, [it]]], [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2007-12-14-17-04-07', '130.60.155.177', '').
text_drs_eval(0, 923, 'It is not the case that a man who waits or who eats runs or sleeps.', drs([], []), [[specification, [s, [np, [pn, [it]]], [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2007-12-14-17-04-39', '130.60.155.177', '').
text_drs_eval(0, 924, 'It is not the case that a man who waits or who eats runs or sleeps and barks.', drs([], []), [[specification, [s, [np, [pn, [it]]], [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]], [coord, [or]], [vp_coord, [vp, [vbar, [v, [sleeps]]]], [coord, [and]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2007-12-14-17-05-09', '130.60.155.177', '').
text_drs_eval(0, 925, 'It is not the case that a man who waits or who eats runs or sleeps ,and barks.', drs([], []), [[specification, [s, [np, [pn, [it]]], [vp_coord, [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]], [coord, ['{, and}']], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-12-14-17-05-53', '130.60.155.177', '').
text_drs_eval(0, 926, 'For every dog if it barks then it does not sleep.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, bark, A)-1])=>drs([], [-drs([C], [predicate(C, sleep, A)-1])])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [dog]]]], [cond_s, [if], [s, [np, [pn, [it]]], [vp, [vbar, [v, [barks]]]]], [then], [s, [np, [pn, [it]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [sleep]]]]]]], ['.']]], '2005-09-30-17-16-45', blade17, '').
text_drs_eval(0, 927, 'There is a dog ,and there is a man or there is a woman ,and there is a cat.', drs([A, B], [object(A, cat, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])v drs([D], [object(D, woman, countable, na, eq, 1)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, ['{, and}']], [s_coord, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [coord, ['{, and}']], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2005-10-01-20-54-24', blade17, '').
text_drs_eval(0, 928, 'It is not the case that there is a dog ,and there is a man or there is a woman ,and there is a cat.', drs([], []), [], '2007-12-14-17-06-18', '130.60.155.177', '').
text_drs_eval(0, 929, 'It is not the case that there is a dog. There is a man or there is a woman ,and it is not the case that there is a cat.', drs([], []), [], '2007-12-15-19-55-00', '130.60.155.177', '').
text_drs_eval(0, 930, 'It is not the case that there is a dog ,and there is a man or there is a woman ,and it is not the case that there is a cat.', drs([], []), [], '2007-12-15-19-59-40', '130.60.155.177', '').
text_drs_eval(0, 931, 'It is not the case that a man sleeps or waits.', drs([], []), [[specification, [s, [np, [pn, [it]]], [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]], [np, [[]]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-12-15-20-00-13', '130.60.155.177', '').
text_drs_eval(0, 932, 'It is not the case that there is a man and the man sleeps or the man waits.', drs([], []), [], '2007-12-15-20-00-45', '130.60.155.177', '').
text_drs_eval(0, 933, 'It is not the case that there is a man ,and the man sleeps or the man waits.', drs([], []), [], '2007-12-15-20-03-45', '130.60.155.177', '').
text_drs_eval(0, 934, 'It is not the case that there is a dog and it is not the case that there is a cat.', drs([], []), [], '2007-12-15-20-09-31', '130.60.155.177', '').
text_drs_eval(0, 935, 'It is not the case that there is a dog. It is not the case that there is a cat.', drs([], []), [], '2007-12-15-20-09-57', '130.60.155.177', '').
text_drs_eval(0, 936, 'A dog does not bark or a cat does not sleep.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1, -drs([B], [predicate(B, bark, A)-1])])v drs([C], [object(C, cat, countable, na, eq, 1)-1, -drs([D], [predicate(D, sleep, C)-1])])]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [bark]]]]], [coord, [or]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [sleep]]]]]], ['.']]], '2005-10-01-22-02-35', blade17, '').
text_drs_eval(0, 937, 'Somebody sees himself.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-10-24-18-44-58', blade17, '').
text_drs_eval(0, 938, 'Somebody gives him him.', drs([], []), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [him]]], [np, [pn, [him]]]]]], ['.']]], '2005-10-02-19-26-59', blade17, '').
text_drs_eval(0, 939, 'Somebody gives him himself.', drs([], []), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [him]]], [np, [pn, [himself]]]]]], ['.']]], '2005-10-02-19-28-01', blade17, '').
text_drs_eval(0, 940, 'There is somebody. Somebody gives him himself.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-2, predicate(C, give, B, B, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [somebody]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [him]]], [np, [pn, [himself]]]]]], ['.']]], '2006-08-14-18-56-25', amadeus, '').
text_drs_eval(0, 941, 'Somebody gives somebody himself/herself.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, predicate(C, give, A, A, B)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [somebody]]], [np, [pn, ['himself/herself']]]]]], ['.']]], '2006-08-14-18-56-55', amadeus, '').
text_drs_eval(0, 942, 'Somebody gives himself him.', drs([], []), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [himself]]], [np, [pn, [him]]]]]], ['.']]], '2005-10-02-19-31-26', blade17, '').
text_drs_eval(0, 943, 'There is somebody. Somebody gives himself him.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-2, predicate(C, give, B, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [somebody]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [himself]]], [np, [pn, [him]]]]]], ['.']]], '2006-08-14-18-57-20', amadeus, '').
text_drs_eval(0, 944, 'Somebody gives himself himself.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, give, A, A, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [gives]], [np, [pn, [himself]]], [np, [pn, [himself]]]]]], ['.']]], '2006-08-14-18-57-42', amadeus, '').
text_drs_eval(0, 945, 'Somebody sees his own dog.', drs([A, B, C], [object(C, somebody, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, see, C, B)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-12-07-13-10-22', blade17, '').
text_drs_eval(0, 946, 'Somebody sees a dog of himself.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-12-07-13-11-25', blade17, '').
text_drs_eval(0, 947, 'There is somebody. A dog of him barks.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-2, object(B, somebody, countable, na, eq, 1)-1, relation(A, of, B)-2, predicate(C, bark, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [somebody]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [him]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-11-07-16-21-14', blade17, '').
text_drs_eval(0, 948, 'Somebody waits. He sees a dog of himself.', drs([A, B, C, D], [object(B, dog, countable, na, eq, 1)-2, object(C, somebody, countable, na, eq, 1)-1, predicate(A, wait, C)-1, relation(B, of, C)-2, predicate(D, see, C, B)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-12-07-13-14-22', blade17, '').
text_drs_eval(0, 949, 'Somebody waits. Somebody sees a dog of himself.', drs([A, B, C, D, E], [object(C, dog, countable, na, eq, 1)-2, object(B, somebody, countable, na, eq, 1)-2, object(A, somebody, countable, na, eq, 1)-1, predicate(D, wait, A)-1, relation(C, of, B)-2, predicate(E, see, B, C)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [himself]]]]]]]]], ['.']]], '2005-12-07-13-14-07', blade17, '').
text_drs_eval(0, 950, 'Somebody waits. Somebody sees a dog of him.', drs([A, B, C, D, E], [object(C, dog, countable, na, eq, 1)-2, object(B, somebody, countable, na, eq, 1)-2, object(A, somebody, countable, na, eq, 1)-1, predicate(D, wait, A)-1, relation(C, of, A)-2, predicate(E, see, B, C)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2005-12-07-13-14-50', blade17, '').
text_drs_eval(0, 951, 'Somebody waits. He sees himself.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, see, A, A)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-11-07-16-12-46', blade17, '').
text_drs_eval(0, 952, 'Somebody waits. Somebody sees him.', drs([A, B, C, D], [object(C, somebody, countable, na, eq, 1)-2, object(B, somebody, countable, na, eq, 1)-1, predicate(A, wait, B)-1, predicate(D, see, C, B)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2005-11-07-16-13-09', blade17, '').
text_drs_eval(0, 953, 'Somebody waits. Somebody sees himself.', drs([A, B, C, D], [object(C, somebody, countable, na, eq, 1)-2, object(B, somebody, countable, na, eq, 1)-1, predicate(A, wait, B)-1, predicate(D, see, C, C)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2005-12-01-15-45-26', blade17, '').
text_drs_eval(0, 954, 'Somebody is interested-in himself.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, property(B, 'interested-in', pos, A)-1, predicate(C, be, A, B)-1]), [[specification, [s, [nbar, [pn, [somebody]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [pn, [himself]]]]|D]]]], ['.']]], '2007-05-09-12-13-12', '130.60.156.229', '').
text_drs_eval(0, 955, 'Somebody is interested-in him.', drs([], []), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [pn, [him]]]]]]]], ['.']]], '2005-10-31-12-11-09', blade17, '').
text_drs_eval(0, 956, 'Somebody waits in himself.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-1, modifier_pp(B, in, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [pn, [himself]]]]]]], ['.']]], '2005-12-07-13-15-06', blade17, '').
text_drs_eval(0, 957, 'Somebody waits in him.', drs([], []), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [pn, [him]]]]]]], ['.']]], '2005-10-03-13-23-33', blade17, '').
text_drs_eval(0, 958, 'There is somebody. Somebody waits in him.', drs([A, B, C], [object(B, somebody, countable, na, eq, 1)-2, object(A, somebody, countable, na, eq, 1)-1, predicate(C, wait, B)-2, modifier_pp(C, in, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [somebody]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [pn, [him]]]]]]], ['.']]], '2005-12-01-15-47-12', blade17, '').
text_drs_eval(0, 959, 'Somebody runs. Somebody waits in him.', drs([A, B, C, D], [object(C, somebody, countable, na, eq, 1)-2, object(B, somebody, countable, na, eq, 1)-1, predicate(A, run, B)-1, predicate(D, wait, C)-2, modifier_pp(D, in, B)-2]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [pn, [him]]]]]]], ['.']]], '2005-12-07-13-17-38', blade17, '').
text_drs_eval(0, 960, 'Somebody is big and small.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, property(B, big, pos)-1, property(B, small, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [big]]], [coord, [and]], [ap_coord, [ap, [adj, [small]]]]]]]], ['.']]], '2005-12-01-15-41-22', blade17, '').
text_drs_eval(0, 961, 'Somebody is interested-in a dog and interested-in a cat.', drs([], []), [], '2007-05-04-17-27-40', '130.60.156.229', '').
text_drs_eval(0, 962, 'Somebody is himself.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, be, A, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [is]], [nbar, [pn, [himself]]]]]], ['.']]], '2005-12-01-15-46-01', blade17, '').
text_drs_eval(0, 963, 'A man is himself.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, be, A, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [nbar, [pn, [himself]]]]]], ['.']]], '2005-10-03-18-36-36', blade17, '').
text_drs_eval(0, 964, 'There is a dog. A man sees the dog of it.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, predicate(C, see, B, D)-2, relation(D, of, D)-2, object(D, dog, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [pn, it]]]]]]]], '.']], '2008-10-23-14-54-51', '130.60.155.177', '').
text_drs_eval(0, 965, 'It is not the case that a man waits and that a dog barks.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl_coord, [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]], [np, [[]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]], [np, [[]]]]]]]]]]]], ['.']]], '2007-12-15-20-10-18', '130.60.155.177', '').
text_drs_eval(0, 966, 'It is not the case that there is a man and that a dog barks.', drs([], []), [], '2007-12-15-20-10-38', '130.60.155.177', '').
text_drs_eval(0, 967, 'It is not the case that there is a dog ,and that there is a man or there is a woman ,and there is a cat.', drs([], []), [], '2007-12-15-20-11-01', '130.60.155.177', '').
text_drs_eval(0, 968, 'It is not the case that there is a dog ,and that there is a man or that there is a woman ,and there is a cat.', drs([], []), [], '2007-12-14-17-07-08', '130.60.155.177', '').
text_drs_eval(0, 969, 'It is not the case that there is a dog ,and that there is a man or that there is a woman ,and that there is a cat.', drs([], []), [], '2007-12-14-17-07-44', '130.60.155.177', '').
text_drs_eval(0, 970, 'It is not the case that there is a dog A. There is a man C or there is a woman E. It is not the case that there is a cat G.', drs([], []), [], '2007-12-14-17-08-51', '130.60.155.177', '').
text_drs_eval(0, 971, 'A man does not sleep or does not wait.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([], [-drs([B], [predicate(B, sleep, A)-1])])v drs([], [-drs([C], [predicate(C, wait, A)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [sleep]]]], [coord, [or]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [wait]]]]]], ['.']]], '2005-10-03-20-00-15', blade17, '').
text_drs_eval(0, 972, 'It is not the case that there is a man ,and that the man sleeps or that the man waits.', drs([], []), [], '2007-12-14-17-11-09', '130.60.155.177', '').
text_drs_eval(0, 973, 'It is not the case that there is a dog and that it is not the case that there is a cat.', drs([], []), [], '2007-12-14-17-11-35', '130.60.155.177', '').
text_drs_eval(0, 974, 'If there is something that barks then it is a dog.', drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1, predicate(B, bark, A)-1])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, be, A, C)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [something]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]], [then], [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2005-12-01-15-40-57', blade17, '').
text_drs_eval(0, 975, 'A dog that a man sees in a park barks.', drs([A, B, C, D, E], [object(B, park, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, predicate(D, see, C, A)-1, modifier_pp(D, in, B)-1, predicate(E, bark, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [sees]], [np, [[]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-10-05-13-40-04', blade17, '').
text_drs_eval(0, 976, 'A dog that a man sees quickly barks.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, modifier_adv(C, quickly, pos)-1, predicate(D, bark, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [sees]], [np, [[]]]], [adv, [quickly]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-10-05-13-42-23', blade17, '').
text_drs_eval(0, 977, 'It is not the case that a man runs. He walks.', drs([], []), [[specification, [neg_s, [sneg, ['{it is not the case}']], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [runs]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2005-10-05-16-02-09', blade17, '').
text_drs_eval(0, 978, 'It is not the case that John runs. He walks.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [pname, ['John']]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2007-12-14-17-12-09', '130.60.155.177', '').
text_drs_eval(0, 979, 'A man gives a dog a bone and gives a cat a cake.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, bone, countable, na, eq, 1)-1, predicate(D, give, A, C, B)-1, object(E, cat, countable, na, eq, 1)-1, object(F, cake, countable, na, eq, 1)-1, predicate(G, give, A, F, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [dog]]]], [np, [det, [a]], [nbar, [n, [bone]]]]]], [coord, [and]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [cat]]]], [np, [det, [a]], [nbar, [n, [cake]]]]]]]], ['.']]], '2006-08-14-18-58-30', amadeus, '').
text_drs_eval(0, 980, 'A man gives a bone to a dog and gives a cake to a cat.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, object(B, bone, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1, object(E, cake, countable, na, eq, 1)-1, object(F, cat, countable, na, eq, 1)-1, predicate(G, give, A, E, F)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [bone]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [cake]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2006-08-14-18-59-26', amadeus, '').
text_drs_eval(0, 981, 'A man waits not.', drs([], []), [], '2005-10-10-17-19-40', blade17, '').
text_drs_eval(0, 982, 'Somebody is himself/herself.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, be, A, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [vbar, [v, [is]], [np, [pn, ['himself/herself']]]]]], ['.']]], '2006-08-14-20-21-34', amadeus, '').
text_drs_eval(0, 983, 'There is a long zip code ZC.', drs([], []), [], '2006-08-15-15-10-56', amadeus, '').
text_drs_eval(0, 984, 'There is an empty string " ".', drs([], []), [], '2007-04-10-15-43-26', '130.60.155.177', '').
text_drs_eval(0, 985, 'There are 2 kg of apples. The apples are red.', drs([A, B, C], [object(A, apple, countable, kg, eq, 2)-1, property(B, red, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [measure_spec, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]]]]], [nbar, [n, [apples]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [apples]]]], [vp, [aux, [are], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']]], '2008-02-16-21-03-25', '130.60.155.177', '').
text_drs_eval(0, 986, 'There are 2 kg of apples "Golden" of John.', drs([], []), [], '2007-04-10-15-43-42', '130.60.155.177', '').
text_drs_eval(0, 987, 'There is 1 kg of dirty laundry.', drs([A], [object(A, laundry, mass, kg, eq, 1)-1, property(A, dirty, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [measurement_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [dirty]], [nbar, [n, [laundry]]]]]]]]], ['.']]], '2007-12-10-19-38-13', '130.60.155.177', '').
text_drs_eval(0, 988, 'There are more than 2 kg of dirty laundry.', drs([A], [object(A, laundry, mass, kg, greater, 2)-1, property(A, dirty, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measure_np, [numberp, [gen_quant, ['{more than}']], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [dirty]], [nbar, [n, [laundry]]]]]]]]], ['.']]], '2007-12-18-12-30-10', '130.60.155.231', '').
text_drs_eval(0, 989, 'There is a long zip code " 90210 ".', drs([], []), [], '2007-01-09-20-05-52', '130.60.155.211', '').
text_drs_eval(0, 990, 'There is a card such that a clerk enters the card of every customer.', drs([A, B, C, D], [drs([E], [object(E, customer, countable, na, eq, 1)-1])=>drs([], [relation(C, of, E)-1]), object(A, clerk, countable, na, eq, 1)-1, object(D, card, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, predicate(B, enter, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]], [conj, ['{such that}']], [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [customer]]]]]]]]]]], ['.']]], '2005-10-31-14-55-17', blade17, '').
text_drs_eval(0, 991, 'There is a card. If there is a man then there is the card of the man.', drs([], []), [], '2006-05-24-19-10-15', amadeus, '').
text_drs_eval(0, 992, 'There is a card of every man.', drs([A], [object(A, card, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([], [relation(A, of, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [man]]]]]]]]], ['.']]], '2006-04-20-12-23-46', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 993, 'A dog of every man waits.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([], [relation(A, of, C)-1]), predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-04-20-12-22-01', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 994, 'Every man\'s dog waits.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-20-17-44-48', '130.60.155.231', '').
text_drs_eval(0, 995, 'For every book a database lists its title.', drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D], [object(D, database, countable, na, eq, 1)-1, object(C, title, countable, na, eq, 1)-1, relation(C, of, A)-1, predicate(B, list, D, C)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [book]]]], [s, [np, [det, [a]], [nbar, [n, [database]]]], [vp, [vbar, [v, [lists]], [np, [poss_pn_coord, [posspn, [its]]], [nbar, [n, [title]]]]]]]], ['.']]], '2005-10-10-15-53-27', blade17, '').
text_drs_eval(0, 996, 'A database lists for every book its title.', drs([], []), [], '2005-10-31-14-56-06', blade17, '').
text_drs_eval(0, 997, 'For every book a database lists its title and lists its code.', drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(B, database, countable, na, eq, 1)-1, relation(C, of, A)-1, object(C, title, countable, na, eq, 1)-1, predicate(D, list, B, C)-1, relation(E, of, C)-1, object(E, code, countable, na, eq, 1)-1, predicate(F, list, B, E)-1])]), [[specification, [top_s, [topic, [quant, for], [np, [det, every], [nbar, [n, book]]]], [s, [np, [det, a], [nbar, [n, database]]], [vp_coord, [vp, [vbar, [v, lists], [np, [posspn, its], [nbar, [n, title]]]]], [coord, and], [vp, [vbar, [v, lists], [np, [posspn, its], [nbar, [n, code]]]]]]]], '.']], '2008-10-23-14-55-26', '130.60.155.177', '').
text_drs_eval(0, 998, 'For every book a database lists the title of the book and lists the code of the book.', drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(C, database, countable, na, eq, 1)-1, object(E, code, countable, na, eq, 1)-1, object(B, title, countable, na, eq, 1)-1, relation(B, of, A)-1, relation(E, of, A)-1, predicate(F, list, C, B)-1, predicate(D, list, C, E)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [book]]]], [s, [np, [det, [a]], [nbar, [n, [database]]]], [vp_coord, [vp, [vbar, [v, [lists]], [np, [det, [the]], [nbar, [n, [title]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [book]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [lists]], [np, [det, [the]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [book]]]]]]]]]]]], ['.']]], '2005-10-10-16-45-45', blade17, '').
text_drs_eval(0, 999, 'There is a man such that he waits and the dog of who sleeps.', drs([], []), [], '2007-11-06-18-04-37', '130.60.155.177', '').
text_drs_eval(0, 1000, 'There is no dog that bites every man.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([C], [predicate(C, bite, A, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [bites]], [np, [det, [every]], [nbar, [n, [man]]]]]]]]]]], ['.']]], '2005-10-10-20-05-47', blade17, '').
text_drs_eval(0, 1001, 'For every book the book has a title and the book has a code.', drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(C, code, countable, na, eq, 1)-1, object(D, title, countable, na, eq, 1)-1, predicate(B, have, A, D)-1, predicate(E, have, A, C)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [book]]]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [title]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]], ['.']]], '2005-10-11-12-34-09', blade17, '').
text_drs_eval(0, 1002, 'Not for every book the book has a title and the book has a code.', drs([], [-drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(C, code, countable, na, eq, 1)-1, object(D, title, countable, na, eq, 1)-1, predicate(B, have, A, D)-1, predicate(E, have, A, C)-1])])]), [[specification, [neg_s, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [book]]]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [title]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]], ['.']]], '2005-10-11-12-36-16', blade17, '').
text_drs_eval(0, 1003, 'It is not the case that for every book the book has a title and the book has a code.', drs([], []), [], '2007-12-14-17-12-37', '130.60.155.177', '').
text_drs_eval(0, 1004, 'It is not the case that if there is a book then the book has a title and the book has a code.', drs([], []), [], '2007-12-14-17-13-02', '130.60.155.177', '').
text_drs_eval(0, 1005, 'A ball is blue.', drs([A, B, C], [object(A, ball, countable, na, eq, 1)-1, property(B, blue, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [ball]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [blue]]]]]]], ['.']]], '2005-10-11-20-15-41', blade17, '').
text_drs_eval(0, 1006, 'There is a man. If there is the man then a dog barks.', drs([], []), [], '2006-05-24-19-21-05', amadeus, '').
text_drs_eval(0, 1007, 'A man\'s every dog barks.', drs([], []), [], '2007-12-23-11-59-16', '130.60.204.35', '').
text_drs_eval(0, 1008, 'There is a man such that every dog of the man barks.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1])=>drs([C], [predicate(C, bark, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [det, [every]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-10-11-21-16-04', blade17, '').
text_drs_eval(0, 1009, 'Every dog of a man barks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1])=>drs([C], [predicate(C, bark, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-10-11-21-16-52', blade17, '').
text_drs_eval(0, 1010, 'For every man every dog of him barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1])=>drs([C], [predicate(C, bark, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [man]]]], [s, [np, [det, [every]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [him]]]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-10-11-21-18-30', blade17, '').
text_drs_eval(0, 1011, 'Every dog of every man barks.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([], [relation(A, of, B)-1])])=>drs([C], [predicate(C, bark, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-12-20-13-19-58', '130.60.155.231', '').
text_drs_eval(0, 1012, 'For every dog of every man the dog barks.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([], [relation(A, of, B)-1])])=>drs([C], [predicate(C, bark, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for}']], [np, [det, [every]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [man]]]]]]]], [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-12-20-13-24-23', '130.60.155.231', '').
text_drs_eval(0, 1013, 'There is a dog of every man.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([], [relation(A, of, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [man]]]]]]]]], ['.']]], '2006-04-20-12-33-50', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1014, 'John is a friend of Mary.', drs([A, B, C, D], [object(B, friend, countable, na, eq, 1)-1, object(C, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, relation(B, of, C)-1, predicate(D, be, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [friend]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]]]], ['.']]], '2005-11-16-13-07-44', blade17, '').
text_drs_eval(0, 1015, 'For every customer John assigns a personal code to the customer.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, customer, countable, na, eq, 1)-1])=>drs([C, D], [object(C, code, countable, na, eq, 1)-1, property(C, personal, pos)-1, predicate(D, assign, A, C, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [customer]]]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [assigns]], [np, [det, [a]], [nbar, [adj, [personal]], [nbar, [n, [code]]]]], [pp, [prep, [to]], [np, [det, [the]], [nbar, [n, [customer]]]]]]]]], ['.']]], '2007-02-22-15-41-08', '130.60.155.211', '').
text_drs_eval(0, 1016, 'John blahblah.', drs([], []), [], '2005-11-16-13-04-50', blade17, '').
text_drs_eval(0, 1017, 'A man waits only.', drs([], []), [], '2007-12-20-13-22-11', '130.60.155.231', '').
text_drs_eval(0, 1018, 'A man v:waits_waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, waits_waits, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits_waits]]]]], ['.']]], '2005-10-12-20-43-15', blade17, '').
text_drs_eval(0, 1019, 'A card of a man which is valid is green.', drs([], []), [], '2007-08-08-11-08-11', '130.60.155.231', '').
text_drs_eval(0, 1020, 'Not each dog barks.', drs([], [-drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B], [predicate(B, bark, A)-1])])]), [[specification, [s, [np, [det, ['{not each}']], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2005-10-13-16-09-31', blade17, '').
text_drs_eval(0, 1021, 'Not all laundry waits.', drs([], [-drs([], [drs([A], [object(A, laundry, mass, na, na, na)-1])=>drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [np, [det, ['{not all}']], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-10-13-16-10-12', blade17, '').
text_drs_eval(0, 1022, 'Not for each man a dog barks.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])]), [[specification, [neg_pronoun, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for each}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2005-10-13-16-11-01', blade17, '').
text_drs_eval(0, 1023, 'Not for each of some men a dog barks.', drs([], [-drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])])]), [[specification, [top_s, [topic, [neg, [not]], [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2008-01-04-14-38-18', '130.60.204.113', '').
text_drs_eval(0, 1024, 'For all laundry a dog barks.', drs([], [drs([A], [object(A, laundry, mass, na, na, na)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [laundry]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2005-10-13-16-17-27', blade17, '').
text_drs_eval(0, 1025, 'Not for all laundry a dog barks.', drs([], [-drs([], [drs([A], [object(A, laundry, mass, na, na, na)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])]), [[specification, [neg_pronoun, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [laundry]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2005-10-13-16-17-50', blade17, '').
text_drs_eval(0, 1026, 'A dog sees each of some men.', drs([A, B], [object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, geq, 2)-1, drs([C], [has_part(A, C)-1])=>drs([D], [predicate(D, see, B, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]]]]], ['.']]], '2005-10-13-16-22-43', blade17, '').
text_drs_eval(0, 1027, 'A man sees no dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [no]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-12-18-33-31', amadeus, '').
text_drs_eval(0, 1028, 'A man sees not every dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, ['{not every}']], [nbar, [n, [dog]]]]]]], ['.']]], '2006-04-07-18-52-58', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1029, 'There is a n:man who waits.', drs([], []), [], '2005-10-28-14-44-21', blade17, '').
text_drs_eval(0, 1030, 'A man waits in every bank.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, bank, countable, na, eq, 1)-1])=>drs([C], [predicate(C, wait, A)-1, modifier_pp(C, in, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [every]], [nbar, [n, [bank]]]]]]]], ['.']]], '2006-01-03-10-27-55', 'catv-5665202b.catv.broadband.hu', '').
text_drs_eval(0, 1031, 'There is a dog that barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2005-10-18-16-19-01', blade17, '').
text_drs_eval(0, 1032, 'A doctor waits. She is tired. He is happy.', drs([], []), [], '2005-10-18-20-32-31', '217-162-130-61.dclient.hispeed.ch', '').
text_drs_eval(0, 1033, 'A doctor waits. He is happy.She is tired.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [doctor]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']], [specification, [s, [np, [pn, [she]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [tired]]]]]]], ['.']]], '2005-10-18-20-29-36', '217-162-130-61.dclient.hispeed.ch', '').
text_drs_eval(0, 1034, 'who waits? what waits?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, wait, A)-1/2])), question(drs([C, D], [query(C, what)-2/1, predicate(D, wait, C)-2/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.'], [sentence, [query, [question, [np, [qpn, what]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-14-47', '130.60.155.193', '').
text_drs_eval(0, 1035, 'A service is quick usually.', drs([A, B, C], [object(A, service, countable, na, eq, 1)-1/2, property(B, quick, pos)-1/4, predicate(C, be, A, B)-1/3, modifier_adv(C, usually, pos)-1/5]), [[specification, [s, [np, [det, a], [nbar, [n, service]]], [vp, [aux, is], [ap_coord, [ap, [adj, quick]]], [vmod, [adv, usually]]]], '.']], '2009-05-19-17-21-17', '130.60.155.193', '').
text_drs_eval(0, 1036, 'There is a dog "".', drs([], []), [], '2007-04-10-15-44-13', '130.60.155.177', '').
text_drs_eval(0, 1037, 'Which code is there?', drs([], [question(drs([A], [query(A, which)-1/1, object(A, code, countable, na, eq, 1)-1/2]))]), [[sentence, [query, [question, [topic, [np, [qdet, which], [nbar, [n, code]]], [quant, 'is there']]], ?], '.']], '2009-05-13-14-14-49', '130.60.155.193', '').
text_drs_eval(0, 1038, 'A man sees himself who eats.', drs([], []), [], '2008-09-23-08-47-50', '130.60.155.206', '').
text_drs_eval(0, 1039, 'A card of who is valid?', drs([], [question(drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, property(C, valid, pos)-1/6, predicate(D, be, A, C)-1/5]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-14-50', '130.60.155.193', '').
text_drs_eval(0, 1040, 'A code of a card of who is valid?', drs([], [question(drs([A, B, C, D, E], [object(A, code, countable, na, eq, 1)-1/2, object(B, card, countable, na, eq, 1)-1/5, query(C, who)-1/7, relation(B, of, C)-1/6, relation(A, of, B)-1/3, property(D, valid, pos)-1/9, predicate(E, be, A, D)-1/8]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [qpn, who]]]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-14-51', '130.60.155.193', '').
text_drs_eval(0, 1041, 'A card of somebody is valid. A card of who is valid?', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, object(B, somebody, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, property(C, valid, pos)-1/7, predicate(D, be, A, C)-1/6, question(drs([E, F, G, H], [object(E, card, countable, na, eq, 1)-2/2, query(F, who)-2/4, relation(E, of, F)-2/3, property(G, valid, pos)-2/6, predicate(H, be, E, G)-2/5]))]), [[sentence, [specification, [s, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [pn, somebody]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], '.'], '.'], [sentence, [query, [question, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-14-14-52', '130.60.155.193', '').
text_drs_eval(0, 1042, 'A screen of what blinks?', drs([], [question(drs([A, B, C], [object(A, screen, countable, na, eq, 1)-1/2, query(B, what)-1/4, relation(A, of, B)-1/3, predicate(C, blink, A)-1/5]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, screen], [pp, [prep, of], [np, [qpn, what]]]]], [vp, [vbar, [vbar, [v, blinks]]]]], ?], '.']], '2009-05-13-14-14-53', '130.60.155.193', '').
text_drs_eval(0, 1043, 'A doctor sees her/his own dog.', drs([A, B, C], [object(A, doctor, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [doctor]]]], [vp, [vbar, [v, [sees]], [np, [posspn, ['his/her own']], [nbar, [n, [dog]]]]]]], ['.']]], '2008-01-11-13-18-27', '130.60.155.231', '').
text_drs_eval(0, 1044, 'John is richer than Mary and smarter than Bill.', drs([], []), [], '2007-05-04-17-27-55', '130.60.156.229', '').
text_drs_eval(0, 1045, 'John is interested-in Mary and fond-of Bill.', drs([], []), [], '2007-05-04-17-28-04', '130.60.156.229', '').
text_drs_eval(0, 1046, 'A customer is manually.', drs([], []), [], '2005-10-28-13-43-55', blade17, '').
text_drs_eval(0, 1047, 'A customer is.', drs([], []), [], '2005-10-28-13-44-10', blade17, '').
text_drs_eval(0, 1048, 'There is a man who sees a dog that sees a cat.', drs([A, B, C, D, E], [object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(D, see, C, B)-1, predicate(E, see, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]]]], ['.']]], '2005-10-28-14-32-45', blade17, '').
text_drs_eval(0, 1049, 'There is a man who sees a dog that sees a cat. The man who sees a dog that sees a cat waits.', drs([A, B, C, D, E, F], [object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1, predicate(D, see, C, B)-1, predicate(E, see, A, C)-1, predicate(F, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-10-28-14-34-49', blade17, '').
text_drs_eval(0, 1050, 'There is a man who sees every dog that sees a cat.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C, D], [object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, see, C, B)-1])=>drs([E], [predicate(E, see, A, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]]]], ['.']]], '2005-10-28-14-36-54', blade17, '').
text_drs_eval(0, 1051, 'There is a man who sees every dog that sees a cat. The man who sees every dog that sees a cat waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C, D, E], [object(C, cat, countable, na, eq, 1)-1, object(D, dog, countable, na, eq, 1)-1, predicate(E, see, D, C)-1])=>drs([F], [predicate(F, see, A, D)-1]), predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-10-15-25-15', blade17, '').
text_drs_eval(0, 1052, 'There is a man who sees every dog. The man who sees every dog waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [object(C, dog, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, A, C)-1]), predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-10-15-10-51', blade17, '').
text_drs_eval(0, 1053, 'There is a n:man that waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2005-10-28-14-43-56', blade17, '').
text_drs_eval(0, 1054, 'John is rich and richer than Mary.', drs([], []), [], '2007-05-04-17-28-15', '130.60.156.229', '').
text_drs_eval(0, 1055, 'John is interested and interested-in Mary.', drs([], []), [], '2007-05-04-17-28-23', '130.60.156.229', '').
text_drs_eval(0, 1056, 'There are 2 signs "Go!" and "Stop!".', drs([], []), [], '2007-04-10-15-44-36', '130.60.155.177', '').
text_drs_eval(0, 1057, 'There are 1000000000000000000000000000000 men.', drs([A], [object(A, man, countable, na, eq, 1000000000000000000000000000000)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [1000000000000000000000000000000]]], [nbar, [n, [men]]]]]], ['.']]], '2007-08-20-16-34-15', '130.60.155.177', '').
text_drs_eval(0, 1058, 'A man waits in a bank which likes itself.', drs([A, B, C, D], [object(A, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, like, A, A)-1, predicate(D, wait, B)-1, modifier_pp(D, in, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [waits]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [likes]], [np, [pn, [itself]]]]]]]]]]]], ['.']]], '2005-10-31-12-08-54', blade17, '').
text_drs_eval(0, 1059, 'There is a card such that a clerk enters a card of every customer.', drs([A, B, C, D], [object(B, card, countable, na, eq, 1)-1, object(C, clerk, countable, na, eq, 1)-1, object(A, card, countable, na, eq, 1)-1, drs([E], [object(E, customer, countable, na, eq, 1)-1])=>drs([], [relation(B, of, E)-1]), predicate(D, enter, C, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]], [conj, ['{such that}']], [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [customer]]]]]]]]]]], ['.']]], '2005-10-31-14-54-57', blade17, '').
text_drs_eval(0, 1060, 'A man waits or takes John\'s rook. If John moves his own queen then there is a dog.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, drs([C], [predicate(C, wait, A)-1])v drs([D, E], [object(D, rook, countable, na, eq, 1)-1, predicate(E, take, A, D)-1, relation(D, of, B)-1]), drs([F, G], [object(F, queen, countable, na, eq, 1)-2, relation(F, of, B)-2, predicate(G, move, B, F)-2])=>drs([H], [object(H, dog, countable, na, eq, 1)-2])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [waits]]]], [coord, [or]], [vp, [vbar, [v, [takes]], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [rook]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [moves]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [queen]]]]]]], [then], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-12-07-13-35-42', blade17, '').
text_drs_eval(0, 1061, 'John takes a queen Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, queen, countable, na, eq, 1)-1, predicate(D, take, A, B, C)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, takes], [np, [det, a], [nbar, [n, queen]]], [np, [pname, 'Mary']]]]], '.']], '2008-07-18-16-51-41', '130.60.155.206', '').
text_drs_eval(0, 1062, 'If an element is a member of a tail of a list then the element is a member of the list.', drs([], [drs([A, B, C, D, E], [object(A, element, countable, na, eq, 1)-1, object(B, member, countable, na, eq, 1)-1, object(C, tail, countable, na, eq, 1)-1, object(D, list, countable, na, eq, 1)-1, relation(C, of, D)-1, relation(B, of, C)-1, predicate(E, be, A, B)-1])=>drs([F, G], [object(F, member, countable, na, eq, 1)-1, relation(F, of, D)-1, predicate(G, be, A, F)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [element]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [member]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [tail]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [list]]]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [element]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [member]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [list]]]]]]]]]]], ['.']]], '2006-04-20-12-39-20', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1063, 'Every dog barks or a cat sleeps.', drs([], [drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B], [predicate(B, bark, A)-1])])v drs([C, D], [object(C, cat, countable, na, eq, 1)-1, predicate(D, sleep, C)-1])]), [[specification, [s_coord, [s, [np, [det, every], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], [coord, or], [s, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [v, sleeps]]]]], '.']], '2008-08-19-19-01-51', '130.60.155.177', '').
text_drs_eval(0, 1064, 'if there is a dog A then the dog A barks, or a cat D sleeps .', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, bark, A)-1])v drs([C, D], [object(C, cat, countable, na, eq, 1)-1, predicate(D, sleep, C)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [appos, [var, ['A']]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [dog]], [appos, [var, ['A']]]]], [vp, [vbar, [v, [barks]]]]], [coord, ['{, or}']], [s, [np, [det, [a]], [nbar, [n, [cat]], [appos, [var, ['D']]]]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2007-12-23-11-59-44', '130.60.204.35', '').
text_drs_eval(0, 1065, 'It is not the case that there is a man and that there is a dog or that there is a cat.', drs([], []), [], '2007-12-14-17-13-23', '130.60.155.177', '').
text_drs_eval(0, 1066, 'It is not the case that there is a man and that there is a dog or there is a cat.', drs([], []), [], '2007-12-14-17-13-40', '130.60.155.177', '').
text_drs_eval(0, 1067, 'It is not the case that there is a man ,and that there is a dog or there is a cat.', drs([], []), [], '2007-12-23-12-00-02', '130.60.204.35', '').
text_drs_eval(0, 1068, 'It is not the case that there is a man ,and there is a dog or there is a cat.', drs([], []), [], '2007-12-14-17-14-36', '130.60.155.177', '').
text_drs_eval(0, 1069, 'There is a man who sees no dog. The man who sees no dog waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [object(C, dog, countable, na, eq, 1)-1])=>drs([], [-drs([D], [predicate(D, see, A, C)-1])]), predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [no]], [nbar, [n, [dog]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [no]], [nbar, [n, [dog]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-35-33', amadeus, '').
text_drs_eval(0, 1070, 'There is a man who sees a dog or who sees a cat. The man who sees a dog or who sees a cat waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, see, A, C)-1])v drs([E, F], [object(E, cat, countable, na, eq, 1)-1, predicate(F, see, A, E)-1]), predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-11-10-15-12-00', blade17, '').
text_drs_eval(0, 1071, 'John likes a dog and a cat.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1, object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, object(D, 'John', named, na, eq, 1)-1, predicate(A, like, D, E)-1, has_part(E, C)-1, has_part(E, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2005-11-11-19-59-21', blade17, '').
text_drs_eval(0, 1072, 'John likes a dog ,and a cat.', drs([], []), [], '2005-11-11-19-59-42', blade17, '').
text_drs_eval(0, 1073, 'There is no man who has a dog and who likes it.', drs([], [-drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, have, B, A)-1, predicate(D, like, B, A)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [likes]], [np, [pn, [it]]]]]]]]]]], ['.']]], '2005-11-11-20-51-59', blade17, '').
text_drs_eval(0, 1074, 'There is no man and he walks.', drs([], []), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]]], ['.']]], '2005-11-11-20-53-40', blade17, '').
text_drs_eval(0, 1075, 'There is no man such that he walks.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]]], ['.']]], '2005-11-11-20-53-49', blade17, '').
text_drs_eval(0, 1076, 'There is no man who walks.', drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]]]], ['.']]], '2005-11-11-20-54-14', blade17, '').
text_drs_eval(0, 1077, 'Every man likes himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, like, A, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [pn, [himself]]]]]], ['.']]], '2005-11-15-18-53-40', blade17, '').
text_drs_eval(0, 1078, 'There is a man who walks and who talks. The man who talks eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1, predicate(C, talk, A)-1, predicate(D, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-15-18-53-10', blade17, '').
text_drs_eval(0, 1079, 'There is a man who walks or who talks. The man who talks eats.', drs([A, B, C, D], [object(C, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, predicate(D, talk, B)-2, drs([E], [predicate(E, walk, C)-1])v drs([F], [predicate(F, talk, C)-1]), predicate(A, eat, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-15-19-00-51', blade17, '').
text_drs_eval(0, 1080, 'There is a man who walks or who talks. The man who walks or who talks eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [predicate(C, walk, A)-1])v drs([D], [predicate(D, talk, A)-1]), predicate(B, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-12-40-00', blade17, '').
text_drs_eval(0, 1081, 'There is a man who walks and who talks. The man who walks and who talks eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1, predicate(C, talk, A)-1, predicate(D, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-12-40-30', blade17, '').
text_drs_eval(0, 1082, 'There is a man who walks and who talks. The man who talks and who walks eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, walk, A)-1, predicate(C, talk, A)-1, predicate(D, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-12-41-40', blade17, '').
text_drs_eval(0, 1083, 'There is a man who walks or who talks. The man who talks or who walks eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [predicate(C, walk, A)-1])v drs([D], [predicate(D, talk, A)-1]), predicate(B, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-15-18-08-22', blade17, '').
text_drs_eval(0, 1084, 'John likes a dog ,and a cat and a rat and a mouse see a cheese.', drs([A, B, C, D, E, F, G, H, I], [object(A, 'John', named, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, object(D, cat, countable, na, eq, 1)-1, object(E, cheese, countable, na, eq, 1)-1, predicate(F, see, I, E)-1, object(G, rat, countable, na, eq, 1)-1, object(H, mouse, countable, na, eq, 1)-1, has_part(I, D)-1, has_part(I, G)-1, has_part(I, H)-1, object(I, na, countable, na, eq, 3)-1]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, ['{, and}']], [s, [np_coord, [np, [det, [a]], [nbar, [n, [cat]]]], [coord, [and]], [np_coord, [np, [det, [a]], [nbar, [n, [rat]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [mouse]]]]]], [vp, [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [cheese]]]]]]]], ['.']]], '2007-08-14-20-18-45', '130.60.155.177', '').
text_drs_eval(0, 1085, 'John likes a dog and a cat ,and a rat and a mouse see a cheese.', drs([A, B, C, D, E, F, G, H, I, J], [object(A, 'John', named, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, E)-1, object(D, cat, countable, na, eq, 1)-1, has_part(E, B)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1, object(F, rat, countable, na, eq, 1)-1, object(G, cheese, countable, na, eq, 1)-1, predicate(H, see, J, G)-1, object(I, mouse, countable, na, eq, 1)-1, has_part(J, F)-1, has_part(J, I)-1, object(J, na, countable, na, eq, 2)-1]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], [coord, ['{, and}']], [s, [np_coord, [np, [det, [a]], [nbar, [n, [rat]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [mouse]]]]], [vp, [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [cheese]]]]]]]], ['.']]], '2007-08-14-20-19-00', '130.60.155.177', '').
text_drs_eval(0, 1086, 'There is a man who waits silently and patiently. The man who waits silently eats.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, modifier_adv(B, patiently, pos)-1, modifier_adv(B, silently, pos)-1, predicate(C, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [waits]]], [adv_coord, [adv, [silently]], [coord, [and]], [adv, [patiently]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [waits]]], [adv, [silently]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-18-00-12', blade17, '').
text_drs_eval(0, 1087, 'There is a man who every dog sees. The man who every dog sees eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [object(C, dog, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, C, A)-1]), predicate(B, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [every]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [every]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-18-15-08', blade17, '').
text_drs_eval(0, 1088, 'There is a man who is rich and famous. The man who is rich eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, property(B, rich, pos)-1, property(B, famous, pos)-1, predicate(C, be, A, B)-1, predicate(D, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]], [coord, [and]], [ap_coord, [ap, [adj, [famous]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-18-39-17', blade17, '').
text_drs_eval(0, 1089, 'There is a man who is rich and famous. The man who is famous and rich eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, property(B, rich, pos)-1, property(B, famous, pos)-1, predicate(C, be, A, B)-1, predicate(D, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]], [coord, [and]], [ap_coord, [ap, [adj, [famous]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [famous]]], [coord, [and]], [ap_coord, [ap, [adj, [rich]]]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-14-18-40-06', blade17, '').
text_drs_eval(0, 1090, 'A man who waits walks and eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, walk, A)-1, predicate(D, eat, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]], [vp_coord, [vp, [vbar, [v, [walks]]]], [coord, [and]], [vp, [vbar, [v, [eats]]]]]], ['.']]], '2005-11-15-17-43-50', blade17, '').
text_drs_eval(0, 1091, 'A man who waits walks and eats and sleeps.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, walk, A)-1, predicate(D, eat, A)-1, predicate(E, sleep, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]], [vp_coord, [vp, [vbar, [v, [walks]]]], [coord, [and]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [and]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2005-11-15-17-44-15', blade17, '').
text_drs_eval(0, 1092, 'There is a man who walks or who talks or who sleeps. The man who talks or who walks or who sleeps eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [predicate(C, walk, A)-1])v drs([], [drs([D], [predicate(D, talk, A)-1])v drs([E], [predicate(E, sleep, A)-1])]), predicate(B, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sleeps]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sleeps]]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-15-19-10-54', blade17, '').
text_drs_eval(0, 1093, 'There is a man who walks or who talks ,and who sleeps. The man who talks or who walks ,and who sleeps eats.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, drs([D], [predicate(D, walk, A)-1])v drs([E], [predicate(E, talk, A)-1]), predicate(B, sleep, A)-1, predicate(C, eat, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]]], [coord, ['{, and}']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sleeps]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [talks]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [walks]]]]]], [coord, ['{, and}']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sleeps]]]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2005-11-15-19-13-12', blade17, '').
text_drs_eval(0, 1094, 'John serves a meal to a customer.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, meal, countable, na, eq, 1)-1, object(C, customer, countable, na, eq, 1)-1, predicate(D, serve, A, B, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [serves]], [np, [det, [a]], [nbar, [n, [meal]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [customer]]]]]]]], ['.']]], '2006-08-14-19-00-11', amadeus, '').
text_drs_eval(0, 1095, 'John serves a customer a meal.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, object(C, meal, countable, na, eq, 1)-1, predicate(D, serve, A, C, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [serves]], [np, [det, [a]], [nbar, [n, [customer]]]], [np, [det, [a]], [nbar, [n, [meal]]]]]]], ['.']]], '2006-08-14-19-00-32', amadeus, '').
text_drs_eval(0, 1096, 'There is a man. Every dog sees him and hears him.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-2])=>drs([C, D], [predicate(C, see, B, A)-2, predicate(D, hear, B, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [dog]]]], [vp_coord, [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]], [coord, [and]], [vp, [vbar, [v, [hears]], [np, [pn, [him]]]]]]], ['.']]], '2005-11-16-17-04-02', blade17, '').
text_drs_eval(0, 1097, 'A man who sees a dog and who walks.', drs([], []), [], '2006-08-17-08-58-56', amadeus, '').
text_drs_eval(0, 1098, 'There is a man who does not see every dog that he sees. The man who sees a dog and who does not see the dog waits.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([F, G], [object(F, dog, countable, na, eq, 1)-1, predicate(G, see, A, F)-1])=>drs([H], [predicate(H, see, A, F)-1])]), predicate(B, wait, C)-2, -drs([I, J], [predicate(J, see, C, I)-2, object(I, dog, countable, na, eq, 1)-2]), predicate(E, see, C, D)-2, object(D, dog, countable, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, see], [np, [det, every], [nbar, [n, dog], [rel_cl, [comp, that], [np, [pn, he]], [vp, [vbar, [v, sees]]]]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, dog]]]]]], [coord, and], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, see], [np, [det, the], [nbar, [n, dog]]]]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-12-16-28-42', '130.60.155.208', '').
text_drs_eval(0, 1099, 'There is a man who sees a dog and who the dog does not see.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, A)-1, -drs([D], [predicate(D, see, A, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [rel_cl, [comp, [who]], [np, [det, [the]], [nbar, [n, [dog]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [see]], [np, [[]]]]]]]]]]], ['.']]], '2005-11-16-17-56-13', blade17, '').
text_drs_eval(0, 1100, 'The man looks-at the men, and they v:look-back-at him.', drs([A, B, C, D], [predicate(A, 'look-at', C, B)-1, object(C, man, countable, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, predicate(D, 'look-back-at', B, C)-1]), [[specification, [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, ['looks-at']], [np, [det, [the]], [nbar, [n, [men]]]]]]], [coord, ['{, and}']], [s, [np, [pn, [they]]], [vp, [vbar, [v, ['look-back-at']], [np, [pn, [him]]]]]]], ['.']]], '2007-05-07-16-40-48', '130.60.156.229', '').
text_drs_eval(0, 1101, 'It is not the case that John likes a dog ,and that a cat and a rat and a mouse see a cheese ,or that a man waits.', drs([], []), [], '2007-12-14-17-15-00', '130.60.155.177', '').
text_drs_eval(0, 1102, 'There is a ball of a girl which is blue. There is a ball which is red. John sees the ball which is blue. Mary sees the girl\'s ball.', drs([], []), [], '2007-08-08-11-08-27', '130.60.155.231', '').
text_drs_eval(0, 1103, 'Every airline buys 2 aircraft.', drs([], [drs([A], [object(A, airline, countable, na, eq, 1)-1])=>drs([B, C], [object(B, aircraft, countable, na, eq, 2)-1, predicate(C, buy, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [airline]]]], [vp, [vbar, [v, [buys]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [aircraft]]]]]]], ['.']]], '2005-11-25-20-19-46', blade17, '').
text_drs_eval(0, 1104, 'Something is green.', drs([A, B, C], [object(A, something, dom, na, na, na)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pn, [something]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], ['.']]], '2005-11-23-11-24-42', blade17, '').
text_drs_eval(0, 1105, 'There is a man. There is a dog. If there is he then there is it.', drs([], []), [], '2006-05-24-19-23-07', amadeus, '').
text_drs_eval(0, 1106, 'A man sees a boy and every girl.', drs([], []), [], '2005-11-25-12-41-16', blade17, '').
text_drs_eval(0, 1107, 'A man sees every boy and a girl.', drs([], []), [], '2006-08-15-19-30-44', amadeus, '').
text_drs_eval(0, 1108, 'A man sees everybody and a dog.', drs([], []), [], '2006-08-15-19-31-05', amadeus, '').
text_drs_eval(0, 1109, 'A man sees a dog and everybody.', drs([], []), [], '2005-11-25-12-42-49', blade17, '').
text_drs_eval(0, 1110, 'A man sees his own dog and his own cat.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1, object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(D, dog, countable, na, eq, 1)-1, relation(D, of, A)-1, predicate(C, see, A, E)-1, relation(B, of, A)-1, has_part(E, D)-1, has_part(E, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [dog]]]], [coord, [and]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [cat]]]]]]]], ['.']]], '2005-11-25-12-47-51', blade17, '').
text_drs_eval(0, 1111, 'There is somebody such that he eats.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, eat, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [somebody]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [eats]]]]]], ['.']]], '2005-11-25-14-55-48', blade17, '').
text_drs_eval(0, 1112, 'There is a man such that he eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [eats]]]]]], ['.']]], '2005-11-25-14-55-53', blade17, '').
text_drs_eval(0, 1113, 'There is everybody such that he eats.', drs([], []), [], '2005-11-25-14-56-22', blade17, '').
text_drs_eval(0, 1114, 'A man sees somebody and a dog.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1, object(B, dog, countable, na, eq, 1)-1, object(D, somebody, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, predicate(A, see, C, E)-1, has_part(E, D)-1, has_part(E, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pn, [somebody]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2005-11-25-15-01-46', blade17, '').
text_drs_eval(0, 1115, 'A man sees a dog and the cat.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1, object(D, dog, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, predicate(A, see, C, E)-1, has_part(E, D)-1, has_part(E, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [cat]]]]]]]], ['.']]], '2005-11-25-15-02-16', blade17, '').
text_drs_eval(0, 1116, 'A man sees a dog and somebody.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1, object(C, somebody, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, predicate(A, see, D, E)-1, has_part(E, B)-1, has_part(E, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [pn, [somebody]]]]]]], ['.']]], '2005-11-25-15-02-28', blade17, '').
text_drs_eval(0, 1117, 'There is a dog. There is a man who sees the dog.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-2, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]]], ['.']]], '2005-11-25-19-06-03', blade17, '').
text_drs_eval(0, 1118, 'A man dances.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, dance, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [dances]]]]], ['.']]], '2007-06-12-10-27-53', '130.60.156.66', '').
text_drs_eval(0, 1119, 'There is a man or there is a dog that sees him or there is a cat that sees itself and him.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])v drs([D, E, F], [object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, F)-1, has_part(F, D)-1, has_part(F, A)-1, object(F, na, countable, na, eq, 2)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pn, [itself]]], [coord, [and]], [np, [pn, [him]]]]]]]]]]]]], ['.']]], '2007-11-20-11-52-52', '130.60.155.231', '').
text_drs_eval(0, 1120, 'There is a man or there is a dog that sees him or there is a cat that sees it and him.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])v drs([D, E, F], [object(D, cat, countable, na, eq, 1)-1, has_part(F, B)-1, predicate(E, see, D, F)-1, has_part(F, A)-1, object(F, na, countable, na, eq, 2)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [pn, him]]]]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np_coord, [np, [pn, it]], [coord, and], [np, [pn, him]]]]]]]]]]], '.']], '2008-08-18-20-04-22', '130.60.206.84', '').
text_drs_eval(0, 1121, 'A man sees a dog and the dog.', drs([], []), [[s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]], '2007-11-02-19-28-30', '130.60.155.177', '').
text_drs_eval(0, 1122, 'No man and a dog wait.', drs([], []), [], '2005-11-28-15-44-48', blade17, '').
text_drs_eval(0, 1123, 'A man and no dog wait.', drs([], []), [], '2005-11-28-15-45-07', blade17, '').
text_drs_eval(0, 1124, 'It is not the case that John runs. John walks.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [pname, ['John']]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2007-12-14-17-15-50', '130.60.155.177', '').
text_drs_eval(0, 1125, 'A customer enters a card. If it is not valid then SM rejects the card.', drs([A, B, C, D], [object(B, card, countable, na, eq, 1)-1, object(C, customer, countable, na, eq, 1)-1, object(A, 'SimpleMat', named, na, eq, 1)-2, predicate(D, enter, C, B)-1, drs([], [-drs([E, F], [property(E, valid, pos)-2, predicate(F, be, B, E)-2])])=>drs([G], [predicate(G, reject, A, B)-2])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [pname, ['SimpleMat']]], [vp, [vbar, [v, [rejects]], [np, [det, [the]], [nbar, [n, [card]]]]]]]], ['.']]], '2005-12-01-12-54-24', blade17, '').
text_drs_eval(0, 1126, 'Somebody is big and small and waits.', drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1, property(B, big, pos)-1, property(B, small, pos)-1, predicate(C, be, A, B)-1, predicate(D, wait, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [big]]], [coord, [and]], [ap_coord, [ap, [adj, [small]]]]]]], [coord, [and]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-12-01-15-42-43', blade17, '').
text_drs_eval(0, 1127, 'Somebody is big and eats and waits.', drs([A, B, C, D, E], [object(A, somebody, countable, na, eq, 1)-1, property(B, big, pos)-1, predicate(C, be, A, B)-1, predicate(D, eat, A)-1, predicate(E, wait, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [big]]]]]], [coord, [and]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [and]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2005-12-01-15-44-21', blade17, '').
text_drs_eval(0, 1128, 'Every man sees John. He waits.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, C, A)-1]), predicate(B, wait, A)-2]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pname, ['John']]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-01-20-06-50', blade17, '').
text_drs_eval(0, 1129, 'John runs or he eats. He waits.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, drs([C], [predicate(C, run, A)-1])v drs([D], [predicate(D, eat, A)-1]), predicate(B, wait, A)-2]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [runs]]]]], [coord, [or]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [eats]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-01-20-06-13', blade17, '').
text_drs_eval(0, 1130, 'Not every man sees John. John waits.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, -drs([], [drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, C, A)-1])]), predicate(B, wait, A)-2]), [[specification, [s, [np, [det, ['{not every}']], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pname, ['John']]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-07-13-02-21', blade17, '').
text_drs_eval(0, 1131, 'Not every man sees John. He waits.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, -drs([], [drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, C, A)-1])]), predicate(B, wait, A)-2]), [[specification, [s, [np, [det, ['{not every}']], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pname, ['John']]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-01-20-07-46', blade17, '').
text_drs_eval(0, 1132, 'It is not the case that John walks. He runs.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [pname, ['John']]], [vp, [vbar, [v, [walks]], [np, [[]]]]]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2007-12-14-17-16-09', '130.60.155.177', '').
text_drs_eval(0, 1133, '5 rich men wait.', drs([A, B], [object(A, man, countable, na, eq, 5)-1, property(A, rich, pos)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [adj, [rich]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-04-07-18-59-54', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1134, 'John walks. It is not the case that John runs.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [walks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [pname, ['John']]], [vp, [vbar, [v, [runs]], [np, [[]]]]]]]]]]], ['.']]], '2007-12-14-17-16-24', '130.60.155.177', '').
text_drs_eval(0, 1135, 'Each of 2 girls lifts herself.', drs([A], [object(A, girl, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, lift, B, B)-1])]), [[specification, [s, [np, [quant, 'each of'], [np, [nump, [num, 2]], [nbar, [n, girls]]]], [vp, [vbar, [v, lifts], [np, [pn, herself]]]]], '.']], '2008-08-12-16-22-29', '130.60.155.208', '').
text_drs_eval(0, 1136, 'Each of 2 girls lifts itself.', drs([], []), [[specification, [s, [np, [quant, 'each of'], [np, [nump, [num, 2]], [nbar, [n, girls]]]], [vp, [vbar, [v, lifts], [np, [pn, itself]]]]], '.']], '2008-08-13-11-07-12', '130.60.155.206', '').
text_drs_eval(0, 1137, 'John inserts his own card. Bill inserts his own card.', drs([A, B, C, D, E, F], [object(B, 'Bill', named, na, eq, 1)-2, object(A, 'John', named, na, eq, 1)-1, relation(C, of, A)-1, object(C, card, countable, na, eq, 1)-1, predicate(D, insert, A, C)-1, relation(E, of, B)-2, object(E, card, countable, na, eq, 1)-2, predicate(F, insert, B, E)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [inserts]], [np, [posspn, ['{his own}']], [nbar, [n, [card]]]]]]], ['.']], [specification, [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [inserts]], [np, [posspn, ['{his own}']], [nbar, [n, [card]]]]]]], ['.']]], '2007-03-18-17-45-06', '130.60.155.177', '').
text_drs_eval(0, 1138, 'If there is John then there is Mary.', drs([], []), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]], [then], [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['Mary']]]]]]], ['.']]], '2006-08-15-21-02-55', amadeus, '').
text_drs_eval(0, 1139, 'If there are a dog and a cat then a man waits.', drs([], [drs([A, B, C], [object(C, na, countable, na, eq, 2)-1, object(B, cat, countable, na, eq, 1)-1, object(A, dog, countable, na, eq, 1)-1, has_part(C, A)-1, has_part(C, B)-1])=>drs([D, E], [object(D, man, countable, na, eq, 1)-1, predicate(E, wait, D)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2005-12-10-22-52-59', blade17, '').
text_drs_eval(0, 1140, 'There is a man who he sees.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]], ['.']]], '2006-08-12-22-45-28', amadeus, '').
text_drs_eval(0, 1141, 'John is taller than Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [pname, ['Mary']]]]|E]]]], ['.']]], '2007-05-09-12-13-18', '130.60.156.229', '').
text_drs_eval(0, 1142, 'A man has 2 kg of green apples.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, apple, countable, kg, eq, 2)-1, property(B, green, pos)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [green]], [nbar, [n, [apples]]]]]]]]]], ['.']]], '2007-12-10-19-38-49', '130.60.155.177', '').
text_drs_eval(0, 1143, 'A man has 2 kg of dirty water.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, water, mass, kg, eq, 2)-1, property(B, dirty, pos)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [dirty]], [nbar, [n, [water]]]]]]]]]], ['.']]], '2007-12-10-19-39-04', '130.60.155.177', '').
text_drs_eval(0, 1144, 'It is not the case that there are 2 kg of dirty laundry.', drs([], []), [], '2007-12-14-17-16-40', '130.60.155.177', '').
text_drs_eval(0, 1145, 'There are more than 2 kg of laundry.', drs([A], [object(A, laundry, mass, kg, greater, 2)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measure_np, [numberp, [gen_quant, ['{more than}']], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]]]], ['.']]], '2007-12-18-12-31-26', '130.60.155.231', '').
text_drs_eval(0, 1146, 'Less than 2 women wait.', drs([A, B], [[predicate(B, wait, A)-1, object(A, woman, countable, na, less, 2)-1]]), [[specification, [s, [np, [nump, [genqu, 'less than'], 2], [nbar, [n, women]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2009-03-02-11-28-07', '130.60.155.206', '').
text_drs_eval(0, 1147, 'Each of some men sees every dog.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([], [drs([C], [object(C, dog, countable, na, eq, 1)-1])=>drs([D], [predicate(D, see, B, C)-1])])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-12-12-12-55-20', blade17, '').
text_drs_eval(0, 1148, 'For each of some men he likes every dog.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([], [drs([C], [object(C, dog, countable, na, eq, 1)-1])=>drs([D], [predicate(D, like, B, C)-1])])]), [[specification, [top_s, [topic, [quant, 'for each of'], [np, [det, some], [nbar, [n, men]]]], [s, [np, [pn, he]], [vp, [vbar, [v, likes], [np, [det, every], [nbar, [n, dog]]]]]]], '.']], '2008-10-22-16-54-08', '130.60.155.177', '').
text_drs_eval(0, 1149, 'For each of some men the man likes every dog.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [drs([D], [object(D, dog, countable, na, eq, 1)-1])=>drs([E], [predicate(E, like, C, D)-1]), object(C, man, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, 'for each of'], [np, [det, some], [nbar, [n, men]]]], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, likes], [np, [det, every], [nbar, [n, dog]]]]]]], '.']], '2008-10-22-16-53-14', '130.60.155.177', '').
text_drs_eval(0, 1150, 'Each of 2 girls lifts herself and sees a dog.', drs([A], [object(A, girl, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D, E], [object(C, dog, countable, na, eq, 1)-1, predicate(D, lift, B, B)-1, predicate(E, see, B, C)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]], [vp_coord, [vp, [vbar, [v, [lifts]], [np, [pn, [herself]]]]], [coord, [and]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2005-12-13-11-22-17', blade17, '').
text_drs_eval(0, 1151, 'It is not the case that there are 1 men.', drs([], []), [], '2007-04-13-14-54-39', '130.60.155.177', '').
text_drs_eval(0, 1152, 'It is not the case that there is a man or there is a dog.', drs([], []), [], '2007-12-14-17-16-54', '130.60.155.177', '').
text_drs_eval(0, 1153, 'It is not the case that there is a man or that there is a dog.', drs([], []), [], '2007-12-14-17-17-12', '130.60.155.177', '').
text_drs_eval(0, 1154, 'There is a man "A" who runs. There is a man "A" who walks. The man "A" who runs is happy.', drs([], []), [], '2007-04-10-15-44-53', '130.60.155.177', '').
text_drs_eval(0, 1155, 'A man "A" waits. A man "A" sleeps.', drs([], []), [], '2007-04-10-15-45-08', '130.60.155.177', '').
text_drs_eval(0, 1156, 'There is a man. His dog eats. There is a woman. Her dog drinks.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, dog, countable, na, eq, 1)-2, predicate(C, eat, B)-2, object(D, woman, countable, na, eq, 1)-3, relation(E, of, D)-4, object(E, dog, countable, na, eq, 1)-4, predicate(F, drink, E)-4]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]], ['.']], [specification, [s, [np, [posspn, [her]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [drinks]]]]], ['.']]], '2007-03-18-17-45-51', '130.60.155.177', '').
text_drs_eval(0, 1157, 'The man whose dog eats waits.', drs([A, B, C, D], [object(C, dog, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, predicate(A, wait, D)-1, predicate(B, eat, C)-1, relation(C, of, D)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2005-12-24-15-46-18', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 1158, 'There is a man whose dog waits.', drs([A, B, C], [object(B, dog, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(A, wait, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2005-12-24-15-46-55', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 1159, 'A girl sees every man whose dog waits.', drs([A], [object(A, girl, countable, na, eq, 1)-1, drs([B, C, D], [object(C, dog, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, relation(C, of, D)-1, predicate(B, wait, C)-1])=>drs([E], [predicate(E, see, A, D)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [girl]]]], [vp, [vbar, [v, [sees]], [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]]]]]]], ['.']]], '2005-12-24-15-48-53', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 1160, 'A dog of who waits?', drs([], [question(drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, predicate(C, wait, A)-1/5]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-14-55', '130.60.155.193', '').
text_drs_eval(0, 1161, 'Whose dog waits?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, dog, countable, na, eq, 1)-1/2, predicate(C, wait, B)-1/3]))]), [[sentence, [query, [question, [np, [qdet, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-14-56', '130.60.155.193', '').
text_drs_eval(0, 1162, 'A girl whose mouse smiles sees a dog.', drs([A, B, C, D, E], [object(C, dog, countable, na, eq, 1)-1, object(A, mouse, countable, na, eq, 1)-1, object(B, girl, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(D, smile, A)-1, predicate(E, see, B, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [girl]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [mouse]]]], [vp, [vbar, [v, [smiles]]]]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-12-24-15-59-43', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 1163, 'A girl whose cat whose mouse smiles eats sees a dog.', drs([A, B, C, D, E, F, G], [object(E, dog, countable, na, eq, 1)-1, object(C, mouse, countable, na, eq, 1)-1, object(F, cat, countable, na, eq, 1)-1, object(A, girl, countable, na, eq, 1)-1, relation(F, of, A)-1, predicate(D, eat, F)-1, predicate(B, smile, C)-1, relation(C, of, F)-1, predicate(G, see, A, E)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [girl]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [cat]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [mouse]]]], [vp, [vbar, [v, [smiles]]]]]]], [vp, [vbar, [v, [eats]]]]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2005-12-24-16-00-50', 'ip87.cab62.mus.starman.ee', '').
text_drs_eval(0, 1164, 'A girl whose cat a mouse of who smiles eats waits.', drs([], []), [], '2007-11-20-11-28-16', '130.60.155.231', '').
text_drs_eval(0, 1165, 'A man waits in every bank in every morning.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, drs([B], [object(B, bank, countable, na, eq, 1)-1/6])=>drs([], [drs([C], [object(C, morning, countable, na, eq, 1)-1/9])=>drs([D], [predicate(D, wait, A)-1/3, modifier_pp(D, in, C)-1/7, modifier_pp(D, in, B)-1/4])])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, bank]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]]]], '.']], '2009-04-02-16-09-33', '130.60.155.206', '').
text_drs_eval(0, 1166, 'Every man waits in every bank in every morning.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, bank, countable, na, eq, 1)-1/6])=>drs([], [drs([C], [object(C, morning, countable, na, eq, 1)-1/9])=>drs([D], [predicate(D, wait, A)-1/3, modifier_pp(D, in, C)-1/7, modifier_pp(D, in, B)-1/4])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, bank]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]]]], '.']], '2009-04-02-16-09-45', '130.60.155.206', '').
text_drs_eval(0, 1167, 'Each of some men a dog of who barks waits.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, drs([D], [has_part(A, D)-1])=>drs([E], [predicate(E, wait, D)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-15-19-16-18', '130.60.155.177', '').
text_drs_eval(0, 1168, 'Each of some men whose dog barks waits.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, drs([D], [has_part(A, D)-1])=>drs([E], [predicate(E, wait, D)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-15-19-16-58', '130.60.155.177', '').
text_drs_eval(0, 1169, 'There are some men each of who waits.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [who]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2007-11-20-11-30-55', '130.60.155.231', '').
text_drs_eval(0, 1170, 'There are some men who wait.', drs([A, B], [object(A, man, countable, na, geq, 2)-1, predicate(B, wait, A)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [wait]]]]]]]]], ['.']]], '2006-01-05-18-08-25', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1171, 'There are some men a dog of who barks.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2008-01-02-15-41-15', '130.60.206.59', '').
text_drs_eval(0, 1172, 'There are some men whose dog barks.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [posspn, [whose]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2008-01-02-15-41-35', '130.60.206.59', '').
text_drs_eval(0, 1173, 'There are some men each of whose dog barks.', drs([], []), [], '2008-01-02-16-17-48', '130.60.206.8', '').
text_drs_eval(0, 1174, 'There are some men each of a dog of who barks.', drs([], []), [], '2007-12-20-13-26-02', '130.60.155.231', '').
text_drs_eval(0, 1175, 'There are some men a dog of each of who barks.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, object(B, dog, countable, na, eq, 1)-1, drs([D], [has_part(A, D)-1])=>drs([], [relation(B, of, D)-1]), predicate(C, bark, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2007-12-31-10-00-27', '130.60.204.31', '').
text_drs_eval(0, 1176, 'A man\'s dog barks. He is happy.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, property(D, happy, pos)-2, predicate(E, be, A, D)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2006-08-21-18-24-53', amadeus, '').
text_drs_eval(0, 1177, '\'A man waits. It is happy.\'', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2006-01-17-17-46-08', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1178, 'A man waits. It is happy.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2006-01-17-17-50-41', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1179, 'p:Kaarel\'s dog barks.', drs([A, B, C], [object(A, 'Kaarel', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [poss_np, [pname, ['Kaarel']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-08-20-22-00-50', '130.60.155.177', '').
text_drs_eval(0, 1180, 'There are 3 men. Each of them wait.', drs([], []), [], '2006-05-24-18-25-24', amadeus, '').
text_drs_eval(0, 1181, 'There are 3 men. Each of the men wait.', drs([], []), [], '2006-05-24-18-26-22', amadeus, '').
text_drs_eval(0, 1182, 'Each of 3 men sees each of 2 dogs.', drs([A], [drs([B], [has_part(A, B)-1])=>drs([C], [drs([D], [has_part(C, D)-1])=>drs([E], [predicate(E, see, B, D)-1]), object(C, dog, countable, na, eq, 2)-1]), object(A, man, countable, na, eq, 3)-1]), [[specification, [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [sees]], [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [dogs]]]]]]]], ['.']]], '2007-11-12-12-23-54', '130.60.155.177', '').
text_drs_eval(0, 1183, 'Everybody who is a person and who is a female is a woman.', drs([], [drs([A, B, C, D, E], [object(E, somebody, countable, na, eq, 1)-1, object(A, female, countable, na, eq, 1)-1, object(B, person, countable, na, eq, 1)-1, predicate(D, be, E, B)-1, predicate(C, be, E, A)-1])=>drs([F, G], [object(F, woman, countable, na, eq, 1)-1, predicate(G, be, E, F)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [person]]]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [female]]]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], ['.']]], '2006-01-23-13-17-18', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1184, 'Each of some girls lifts her own table.', drs([A], [object(A, girl, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, table, countable, na, eq, 1)-1, relation(C, of, B)-1, predicate(D, lift, B, C)-1])]), [[specification, [s, [np, [quant, ['{each of}']], [np, [det, [some]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [poss_pn_coord, [posspn, ['{her own}']]], [nbar, [n, [table]]]]]]], ['.']]], '2006-01-24-17-04-13', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1185, 'Everybody who likes Mary she loves.', drs([], []), [], '2006-02-02-12-46-37', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1186, 'Every man likes more than 2 dogs and likes less than 4 dogs.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, dog, countable, na, greater, 2)-1, predicate(C, like, A, B)-1, [predicate(E, like, A, D)-1, object(D, dog, countable, na, less, 4)-1]])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp_coord, [vp, [vbar, [vcompl, [v, likes], [np, [nump, [genqu, 'more than'], 2], [nbar, [n, dogs]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, likes], [np, [nump, [genqu, 'less than'], 4], [nbar, [n, dogs]]]]]]]], '.']], '2009-03-02-11-28-29', '130.60.155.206', '').
text_drs_eval(0, 1187, 'If there is a man then he is not a woman or is not a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([], [-drs([B, C], [object(B, woman, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])])v drs([], [-drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s, [np, [pn, [he]]], [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [woman]]]]]], [coord, [or]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]], ['.']]], '2006-02-06-21-01-57', 'ifidyn223.ifi.unizh.ch', '').
text_drs_eval(0, 1188, 'If there is no man then he waits.', drs([], []), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2006-04-10-12-52-19', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1189, 'At least 1 man waits.', drs([A, B], [object(A, man, countable, na, geq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, ['{at least}']], [number, [1]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-30-18-04-02', '130.60.155.177', '').
text_drs_eval(0, 1190, 'At most 1 man waits.', drs([A, B], [[predicate(B, wait, A)-1, object(A, man, countable, na, leq, 1)-1]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 1], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-03-02-11-28-40', '130.60.155.206', '').
text_drs_eval(0, 1191, 'More than 1 man waits.', drs([A, B], [object(A, man, countable, na, greater, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, ['{more than}']], [number, [1]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-30-18-04-24', '130.60.155.177', '').
text_drs_eval(0, 1192, 'Less than 1 man waits.', drs([A, B], [[predicate(B, wait, A)-1, object(A, man, countable, na, less, 1)-1]]), [[specification, [s, [np, [nump, [genqu, 'less than'], 1], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-03-02-11-28-49', '130.60.155.206', '').
text_drs_eval(0, 1193, 'There are 3 kg of apples. Each of the apples is red.', drs([A], [object(A, apple, countable, kg, eq, 3)-1, drs([B], [has_part(A, B)-2])=>drs([C, D], [property(C, red, pos)-2, predicate(D, be, B, C)-2])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [measure_spec, [numberp, [gen_quant, [[]]], [number, [3]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]]]]], [nbar, [n, [apples]]]]]], ['.']], [specification, [s, [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [apples]]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [red]]]]]]], ['.']]], '2008-02-16-21-04-10', '130.60.155.177', '').
text_drs_eval(0, 1194, 'John likes Mary\'s sister who is not John.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, relation(C, of, B)-1, object(C, sister, countable, na, eq, 1)-1, -drs([E], [predicate(E, be, C, A)-1]), predicate(D, like, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [poss_spec, [poss_np, [pname, ['Mary']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [sister]], [rel_cl, [comp, [who]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [pname, ['John']]]]]]]]]]], ['.']]], '2006-08-22-11-47-16', amadeus, '').
text_drs_eval(0, 1195, 'There is Mary\'s sister. Mary is richer than her own sister.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, sister, countable, na, eq, 1)-1, relation(C, of, A)-2, object(C, sister, countable, na, eq, 1)-2, property(D, rich, comp_than, C)-2, predicate(E, be, A, D)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pname, ['Mary']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [sister]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [richer]], [conj, [than]], [np, [posspn, ['{her own}']], [nbar, [n, [sister]]]]]|F]]]], ['.']]], '2007-05-09-12-13-23', '130.60.156.229', '').
text_drs_eval(0, 1196, '10 kg of laundry is on the table.', drs([A, B, C], [object(A, laundry, mass, kg, eq, 10)-1, predicate(B, be, A)-1, modifier_pp(B, on, C)-1, object(C, table, countable, na, eq, 1)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [10]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]], [vp, [vbar, [v, [is]], [pp, [prep, [on]], [np, [det, [the]], [nbar, [n, [table]]]]]]]], ['.']]], '2007-12-25-12-16-40', '130.60.206.10', '').
text_drs_eval(0, 1197, '10 kg of laundry are on the table.', drs([A, B, C], [object(A, laundry, mass, kg, eq, 10)-1, predicate(B, be, A)-1, modifier_pp(B, on, C)-1, object(C, table, countable, na, eq, 1)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [10]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]], [vp, [vbar, [v, [are]], [pp, [prep, [on]], [np, [det, [the]], [nbar, [n, [table]]]]]]]], ['.']]], '2007-12-25-12-16-51', '130.60.206.10', '').
text_drs_eval(0, 1198, 'Every man who feeds a dog waits. Every man feeds a dog and waits.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, feed, A, B)-1])=>drs([D], [predicate(D, wait, A)-1]), drs([E], [object(E, man, countable, na, eq, 1)-2])=>drs([F, G, H], [object(F, dog, countable, na, eq, 1)-2, predicate(G, feed, E, F)-2, predicate(H, wait, E)-2])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [feeds]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [feeds]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [and]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2006-04-07-19-05-57', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1199, 'Every man does not feed a dog and wait.', drs([], []), [], '2006-05-24-18-29-43', amadeus, '').
text_drs_eval(0, 1200, 'Everybody sees at most 1 things.', drs([], []), [], '2007-04-13-14-50-31', '130.60.155.177', '').
text_drs_eval(0, 1201, 'Everybody sees 1 things.', drs([], []), [], '2006-05-24-18-30-22', amadeus, '').
text_drs_eval(0, 1202, 'A man is not no dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, be, A, B)-1])])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [no]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-12-18-36-55', amadeus, '').
text_drs_eval(0, 1203, 'Everybody sees at least 1 man.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C], [object(B, man, countable, na, geq, 1)-1, predicate(C, see, A, B)-1])]), [[specification, [s, [nbar, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, ['{at least}']], [number, [1]]], [nbar, [n, [man]]]]]]], ['.']]], '2007-05-02-20-20-14', '130.60.155.177', '').
text_drs_eval(0, 1204, 'A man comes in a day A1. A boy reads in the day A2 that follows A1. The book is red in the day that follows A2.', drs([A, B, C, D, E, F, G, H, I, J, K, L], [object(A, man, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-1, predicate(C, come, A)-1, modifier_pp(C, in, B)-1, object(D, boy, countable, na, eq, 1)-2, predicate(E, read, D)-2, modifier_pp(E, in, F)-2, predicate(G, follow, F, B)-2, object(F, day, countable, na, eq, 1)-2, property(H, red, pos)-3, predicate(I, be, L, H)-3, modifier_pp(I, in, J)-3, object(L, book, countable, na, eq, 1)-3, predicate(K, follow, J, F)-3, object(J, day, countable, na, eq, 1)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, comes]], [pp, [prep, in], [np, [det, a], [nbar, [n, day], [appos, [var, 'A1']]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, boy]]], [vp, [vbar, [vbar, [v, reads]], [pp, [prep, in], [np, [det, the], [nbar, [n, day], [appos, [var, 'A2']], [rel_cl, [comp, that], [vp, [vbar, [v, follows], [np, [var, 'A1']]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, book]]], [vp, [aux, is], [vbar, [vbar, [ap_coord, [ap, [adj, red]]]], [pp, [prep, in], [np, [det, the], [nbar, [n, day], [rel_cl, [comp, that], [vp, [vbar, [v, follows], [np, [var, 'A2']]]]]]]]]]], '.']], '2008-08-18-20-06-36', '130.60.206.84', '').
text_drs_eval(0, 1205, 'John\'s 2 kg of apples wait.', drs([], []), [], '2006-05-24-18-31-43', amadeus, '').
text_drs_eval(0, 1206, '2 kg of apples of John wait.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, apple, countable, kg, eq, 2)-1, relation(B, of, A)-1, predicate(C, wait, B)-1]), [[specification, [s, [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-12-10-19-39-33', '130.60.155.177', '').
text_drs_eval(0, 1207, 'If there is a carnivore then everybody that it eats is an animal.', drs([], [drs([A], [object(A, carnivore, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [object(C, somebody, countable, na, eq, 1)-1, predicate(B, eat, A, C)-1])=>drs([D, E], [object(D, animal, countable, na, eq, 1)-1, predicate(E, be, C, D)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [carnivore]]]]]], [then], [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [that]], [np, [pn, [it]]], [vp, [vbar, [v, [eats]], [np, [[]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [animal]]]]]]]], ['.']]], '2006-03-21-09-19-48', 'kalju.kongress.mwn.de', '').
text_drs_eval(0, 1208, 'If there is a carnivore then everything that it eats is a meat.', drs([], [drs([A], [object(A, carnivore, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [predicate(B, eat, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D, E], [object(D, meat, countable, na, eq, 1)-1, predicate(E, be, C, D)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [carnivore]]]]]], [then], [s, [nbar, [pn, [everything]], [rel_cl, [comp, [that]], [np, [pn, [it]]], [vp, [vbar, [v, [eats]], [np, [[]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [meat]]]]]]]], ['.']]], '2006-08-12-18-57-48', amadeus, '').
text_drs_eval(0, 1209, 'If there is a thing that does not eat something that is not a meat then the thing is a carnivore.', drs([], [drs([A], [object(A, thing, countable, na, eq, 1)-1, -drs([B, C], [object(B, something, dom, na, na, na)-1, predicate(C, eat, A, B)-1, -drs([D, E], [object(D, meat, countable, na, eq, 1)-1, predicate(E, be, B, D)-1])])])=>drs([F, G], [object(F, carnivore, countable, na, eq, 1)-1, predicate(G, be, A, F)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [thing]], [rel_cl, [comp, [that]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [eat]], [nbar, [pn, [something]], [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [meat]]]]]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [thing]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [carnivore]]]]]]]], ['.']]], '2006-03-27-18-52-41', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1210, 'Everything is a cat and everything is a dog.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, be, A, B)-1]), drs([D], [object(D, something, dom, na, na, na)-1])=>drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, be, D, E)-1])]), [[specification, [s_coord, [s, [np, [pn, [everything]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, [and]], [s, [np, [pn, [everything]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-03-27-19-01-44', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1211, 'There is a cat and everything is a dog.', drs([A], [object(A, cat, countable, na, eq, 1)-1, drs([B], [object(B, something, dom, na, na, na)-1])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]], [coord, [and]], [s, [np, [pn, [everything]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-08-14-20-16-02', amadeus, '').
text_drs_eval(0, 1212, 'If there is a thing and everything that it eats is a meat then it is a carnivore.', drs([], [drs([A], [object(A, thing, countable, na, eq, 1)-1, drs([B, C], [predicate(B, eat, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D, E], [object(D, meat, countable, na, eq, 1)-1, predicate(E, be, C, D)-1])])=>drs([F, G], [object(F, carnivore, countable, na, eq, 1)-1, predicate(G, be, A, F)-1])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [thing]]]]]], [coord, [and]], [s, [nbar, [pn, [everything]], [rel_cl, [comp, [that]], [np, [pn, [it]]], [vp, [vbar, [v, [eats]], [np, [[]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [meat]]]]]]]], [then], [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [carnivore]]]]]]]], ['.']]], '2006-08-14-20-18-19', amadeus, '').
text_drs_eval(0, 1213, '2 men wait.', drs([A, B], [object(A, man, countable, na, eq, 2)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-03-29-11-24-07', '217-162-25-170.dclient.hispeed.ch', '').
text_drs_eval(0, 1214, 'There are less than 2 kg of milk. There are less than 2 men.', drs([A, B], [[object(A, milk, mass, kg, less, 2)-1], [object(B, man, countable, na, less, 2)-2]]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [meas_spec, [nump, [genqu, 'less than'], 2], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, milk]]]]], '.'], [specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [genqu, 'less than'], 2], [nbar, [n, men]]]]], '.']], '2009-03-02-11-29-02', '130.60.155.206', '').
text_drs_eval(0, 1215, 'There are 1 kg of water and 2 kg of apples.', drs([A, B, C], [object(A, water, mass, kg, eq, 1)-1, has_part(C, A)-1, object(B, apple, countable, kg, eq, 2)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np_coord, [measure_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [water]]]]]], [coord, [and]], [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]]]]], ['.']]], '2007-12-25-13-04-30', '130.60.206.10', '').
text_drs_eval(0, 1216, 'There is a man A who sees A. There is a man who sees John. John watches the man who sees him. John watches the man who sees A.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, B)-1, object(D, man, countable, na, eq, 1)-2, predicate(E, see, D, A)-2, predicate(F, watch, A, D)-3, predicate(G, watch, A, B)-4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'A']], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [var, 'A']]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pname, 'John']]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, him]]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [var, 'A']]]]]]]]]], '.']], '2008-08-15-20-33-51', '130.60.204.15', '').
text_drs_eval(0, 1217, 'There is a man who owns a dog. There is a man who owns a cat. John sees the man who owns the dog.', drs([A, B, C, D, E, F, G, H], [predicate(H, see, A, B)-3, predicate(G, own, E, F)-2, object(F, cat, countable, na, eq, 1)-2, object(E, man, countable, na, eq, 1)-2, predicate(D, own, B, C)-1, object(C, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]]]], ['.']]], '2007-11-11-11-47-38', '130.60.204.22', '').
text_drs_eval(0, 1218, 'Everybody sees John and Mary.', drs([A, B], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, drs([C], [object(C, somebody, countable, na, eq, 1)-1])=>drs([D, E], [object(E, na, countable, na, eq, 2)-1, predicate(D, see, C, E)-1, has_part(E, B)-1, has_part(E, A)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]]]]], ['.']]], '2006-04-07-12-18-09', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1219, 'For all clean laundry a dog barks.', drs([], [drs([A], [object(A, laundry, mass, na, na, na)-1, property(A, clean, pos)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [adj, [clean]], [nbar, [n, [laundry]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2006-04-07-12-58-27', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1220, 'John enters every card which is his card.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, card, countable, na, eq, 1)-1, relation(C, of, A)-1, object(C, card, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])=>drs([E], [predicate(E, enter, A, B)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, enters], [np, [det, every], [nbar, [n, card], [rel_cl, [np, [relpn, which]], [vp, [aux, is], [vbar, [np, [posspn, his], [nbar, [n, card]]]]]]]]]]], '.']], '2008-10-23-14-58-57', '130.60.155.206', '').
text_drs_eval(0, 1221, 'John enters every card which carries his code.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, card, countable, na, eq, 1)-1, relation(C, of, A)-1, object(C, code, countable, na, eq, 1)-1, predicate(D, carry, B, C)-1])=>drs([E], [predicate(E, enter, A, B)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, enters], [np, [det, every], [nbar, [n, card], [rel_cl, [np, [relpn, which]], [vp, [vbar, [v, carries], [np, [posspn, his], [nbar, [n, code]]]]]]]]]]], '.']], '2008-10-23-14-59-17', '130.60.155.206', '').
text_drs_eval(0, 1222, 'John enters every card which carries its code.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [carries]], [np, [poss_pn_coord, [posspn, [its]]], [nbar, [n, [code]]]]]]]]]]]], ['.']]], '2006-04-10-12-55-41', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1223, 'John enters every card which carries its own code.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, card, countable, na, eq, 1)-1, relation(D, of, B)-1, predicate(C, carry, B, D)-1, object(D, code, countable, na, eq, 1)-1])=>drs([E], [predicate(E, enter, A, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [carries]], [np, [poss_pn_coord, [posspn, ['{its own}']]], [nbar, [n, [code]]]]]]]]]]]], ['.']]], '2006-04-10-12-56-10', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1224, 'John enters every card which carries his own code.', drs([], []), [], '2008-10-23-14-59-21', '130.60.155.206', '').
text_drs_eval(0, 1225, 'John enters every card which is its card.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [np, [poss_pn_coord, [posspn, [its]]], [nbar, [n, [card]]]]]]]]]]]], ['.']]], '2006-04-10-12-57-09', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1226, 'John enters every card which is its own card.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, card, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, card, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])=>drs([E], [predicate(E, enter, A, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [enters]], [np, [det, [every]], [nbar, [n, [card]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [np, [posspn, ['{its own}']], [nbar, [n, [card]]]]]]]]]]]], ['.']]], '2007-03-18-17-34-29', '130.60.155.177', '').
text_drs_eval(0, 1227, 'John vaguely sees a big dog that barks in the garden of its own brother.', drs([A, B, C, D, E, F], [modifier_adv(F, vaguely, pos)-1, predicate(F, see, A, B)-1, object(D, garden, countable, na, eq, 1)-1, relation(E, of, B)-1, object(E, brother, countable, na, eq, 1)-1, relation(D, of, E)-1, modifier_pp(C, in, D)-1, predicate(C, bark, B)-1, property(B, big, pos)-1, object(B, dog, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [adv, [vaguely]], [vbar, [v, [sees]], [np, [det, [a]], [nbar, [adj, [big]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [garden]], [pp, [prep, [of]], [np, [posspn, ['{its own}']], [nbar, [n, [brother]]]]]]]]]]]]]]]]]], ['.']]], '2007-11-13-15-05-59', '130.60.155.161', '').
text_drs_eval(0, 1228, 'There is a carnivore "<".', drs([], []), [], '2007-11-06-17-33-03', '130.60.155.177', '').
text_drs_eval(0, 1229, 'There is a carnivore "&".', drs([], []), [], '2007-04-10-15-45-47', '130.60.155.177', '').
text_drs_eval(0, 1230, 'If there is a man such that he waits then he is happy.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C, D], [property(C, happy, pos)-1, predicate(D, be, A, C)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]]], ['.']]], '2006-04-13-14-58-48', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1231, 'If there is an animal such that everything that the animal eats is a meat then the animal is a carnivore.', drs([], [drs([A], [object(A, animal, countable, na, eq, 1)-1, drs([B, C], [predicate(B, eat, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D, E], [object(D, meat, countable, na, eq, 1)-1, predicate(E, be, C, D)-1])])=>drs([F, G], [object(F, carnivore, countable, na, eq, 1)-1, predicate(G, be, A, F)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [animal]]]]], [conj, ['{such that}']], [s, [nbar, [pn, [everything]], [rel_cl, [comp, [that]], [np, [det, [the]], [nbar, [n, [animal]]]], [vp, [vbar, [v, [eats]], [np, [[]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [meat]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [animal]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [carnivore]]]]]]]], ['.']]], '2006-04-13-15-22-46', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1232, 'There is a cat such that everything is a dog.', drs([A], [object(A, cat, countable, na, eq, 1)-1, drs([B], [object(B, something, dom, na, na, na)-1])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]], [conj, ['{such that}']], [s, [np, [pn, [everything]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-04-13-15-24-27', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1233, 'John feeds his own dogs.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(C, of, A)-1, predicate(B, feed, A, C)-1, object(C, dog, countable, na, geq, 2)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [feeds]], [np, [poss_pn_coord, [posspn, ['{his own}']]], [nbar, [n, [dogs]]]]]]], ['.']]], '2006-04-19-14-42-02', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1234, 'There is a bank. A code is not in the bank.', drs([A, B], [object(A, bank, countable, na, eq, 1)-1, object(B, code, countable, na, eq, 1)-2, -drs([C], [predicate(C, be, B)-2, modifier_pp(C, in, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [bank]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [code]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [bank]]]]]]]], ['.']]], '2006-04-19-15-04-03', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1235, 'If there is a man then a dog of the man waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, wait, B)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2006-04-20-12-23-19', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1236, 'There is a girl\'s ball which is blue.', drs([A, B, C, D], [object(A, girl, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, ball, countable, na, eq, 1)-1, property(C, blue, pos)-1, predicate(D, be, B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [det, [a]], [nbar, [n, [girl]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [ball]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [blue]]]]]]]]]]], ['.']]], '2006-04-20-12-45-18', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1237, 'John sees a girl\'s ball which is blue.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, girl, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, ball, countable, na, eq, 1)-1, property(D, blue, pos)-1, predicate(E, be, C, D)-1, predicate(F, see, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [poss_np, [det, [a]], [nbar, [n, [girl]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [ball]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [blue]]]]]]]]]]]], ['.']]], '2006-04-20-12-46-20', 'ifidyn175.ifi.unizh.ch', '').
text_drs_eval(0, 1238, 'There is a ball of a girl. Mary sees the girl\'s ball.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-2, object(B, ball, countable, na, eq, 1)-1, object(C, girl, countable, na, eq, 1)-1, relation(B, of, C)-1, relation(D, of, C)-2, object(D, ball, countable, na, eq, 1)-2, predicate(E, see, A, D)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [ball]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [girl]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sees]], [np, [poss_spec, [poss_np, [det, [the]], [nbar, [n, [girl]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [ball]]]]]]], ['.']]], '2006-08-22-11-48-21', amadeus, '').
text_drs_eval(0, 1239, 'There is a man who sees John and Mary. The man who sees John and Mary waits.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, predicate(D, see, C, E)-1, has_part(E, A)-1, has_part(E, B)-1, object(E, na, countable, na, eq, 2)-1, predicate(F, wait, C)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]]]]]]]]], [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]]]]]]], [vp, [vbar, [v, [waits]]]]]], '2007-09-26-17-02-01', '130.60.155.177', '').
text_drs_eval(0, 1240, 'There is a man who sees John and Mary. The man who sees Mary and John waits.', drs([A, B, C, D, E, F], [predicate(F, wait, C)-2, object(E, na, countable, na, eq, 2)-1, has_part(E, B)-1, has_part(E, A)-1, predicate(D, see, C, E)-1, object(C, man, countable, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['Mary']]], [coord, [and]], [np, [pname, ['John']]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-10-17-21-59', '84.74.160.172', '').
text_drs_eval(0, 1241, 'There is a man who sees John and Mary. The man who sees Mary and Bill waits.', drs([A, B, C, D, E, F, G, H, I, J], [has_part(F, A)-1, has_part(F, B)-1, has_part(J, B)-2, has_part(J, C)-2, predicate(G, wait, H)-2, predicate(E, see, D, F)-1, predicate(I, see, H, J)-2, object(D, man, countable, na, eq, 1)-1, object(F, na, countable, na, eq, 2)-1, object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(H, man, countable, na, eq, 1)-2, object(J, na, countable, na, eq, 2)-2, object(C, 'Bill', named, na, eq, 1)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]]]]]]]]], [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['Mary']]], [coord, [and]], [np, [pname, ['Bill']]]]]]]]], [vp, [vbar, [v, [waits]]]]]], '2007-11-05-11-03-25', '130.60.155.231', '').
text_drs_eval(1, 1242, 'There are some data. John sees the data.', drs([A, B, C], [object(A, data, countable, na, geq, 2)-1/4, object(C, data, countable, na, eq, 1)-2/4, predicate(B, see, named('John'), C)-2/2]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [det, some], [nbar, [n, data]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, data]]]]]]], '.']], '2009-11-23-17-26-16', '84.74.142.247', 'Original comment: Plural \'data\' is not resolved. New comment: This is a lexical problem of "data". Resolving a singular countable NP to a plural countable NP would also allow to derive "the man" from "some men" which is certainly wrong. Further comment: replacing "there are" by "there is" gives "some data" a mass noun interpretation, and the anaphoric reference is resolved.').
text_drs_eval(0, 1243, 'There is a company that John awaits a delivery from.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, company, countable, na, eq, 1)-1, object(C, delivery, countable, na, eq, 1)-1, predicate(D, await, A, C)-1, modifier_pp(D, from, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [company]], [rel_cl, [comp, [that]], [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [awaits]], [np, [det, [a]], [nbar, [n, [delivery]]]]], [pp, [prep, [from]], [np, [[]]]]]]]]]]], ['.']]], '2007-12-18-11-10-09', '130.60.155.231', '').
text_drs_eval(0, 1244, 'There is a company from which John awaits a delivery.', drs([], []), [], '2007-11-20-11-28-28', '130.60.155.231', '').
text_drs_eval(0, 1245, 'John\'s dog barks. John\'s dog barks.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, relation(D, of, A)-2, object(D, dog, countable, na, eq, 1)-2, predicate(E, bark, D)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-22-11-48-55', amadeus, '').
text_drs_eval(0, 1246, 'It is possible that a man waits.', drs([], [can(drs([A, B], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, wait, A)-1/7]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-10-01', '89.206.64.27', '').
text_drs_eval(0, 1247, 'It is necessary that a man waits.', drs([], [must(drs([A, B], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, wait, A)-1/7]))]), [[specification, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-10-09', '89.206.64.27', '').
text_drs_eval(0, 1248, 'It is possible that a man waits and that a dog barks.', drs([], [can(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, wait, A)-1/7, object(C, dog, countable, na, eq, 1)-1/11, predicate(D, bark, C)-1/12]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s_coord, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], [coord, and], [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]], '.']], '2010-10-27-09-10-16', '89.206.64.27', '').
text_drs_eval(0, 1249, 'It is necessary that a man waits and that a dog barks.', drs([], [must(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, wait, A)-1/7, object(C, dog, countable, na, eq, 1)-1/11, predicate(D, bark, C)-1/12]))]), [[specification, [s, [necessity, 'it is necessary'], [cp, that, [s_coord, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], [coord, and], [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]], '.']], '2010-10-27-09-10-22', '89.206.64.27', '').
text_drs_eval(0, 1250, 'It is necessary that a man waits and a dog barks.', drs([A, B], [must(drs([C, D], [object(C, man, countable, na, eq, 1)-1/6, predicate(D, wait, C)-1/7])), object(A, dog, countable, na, eq, 1)-1/10, predicate(B, bark, A)-1/11]), [[specification, [s_coord, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]], [coord, and], [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]], '.']], '2010-10-27-09-10-27', '89.206.64.27', '').
text_drs_eval(0, 1251, 'It is possible that a man waits and a dog barks.', drs([A, B], [can(drs([C, D], [object(C, man, countable, na, eq, 1)-1/6, predicate(D, wait, C)-1/7])), object(A, dog, countable, na, eq, 1)-1/10, predicate(B, bark, A)-1/11]), [[specification, [s_coord, [s, [poss, 'it is possible'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]], [coord, and], [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]], '.']], '2010-10-27-09-10-32', '89.206.64.27', '').
text_drs_eval(0, 1252, 'If a man eats then necessarily he does not sleep.', drs([], []), [], '2006-07-25-15-38-04', amadeus, '').
text_drs_eval(0, 1253, 'A man "A" waits. The man sleeps.', drs([], []), [], '2007-04-10-15-45-26', '130.60.155.177', '').
text_drs_eval(0, 1254, 'A man "A" waits. The man "A" sleeps.', drs([], []), [], '2007-04-10-15-45-36', '130.60.155.177', '').
text_drs_eval(0, 1255, 'There are 3 men. Each of them waits.', drs([A], [drs([B], [has_part(A, B)-2])=>drs([C], [predicate(C, wait, B)-2]), object(A, man, countable, na, eq, 3)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [quant, ['{each of}']], [np, [pn, [them]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-12-12-24-11', '130.60.155.177', '').
text_drs_eval(0, 1256, 'There are 3 men. Each of the men waits.', drs([A], [drs([B], [has_part(A, B)-2])=>drs([C], [predicate(C, wait, B)-2]), object(A, man, countable, na, eq, 3)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-12-12-24-24', '130.60.155.177', '').
text_drs_eval(0, 1257, 'There are a man\'s dog and cat.', drs([], []), [], '2006-08-28-21-11-32', amadeus, '').
text_drs_eval(0, 1258, 'There is a man. There is the man\'s dog.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-2, relation(B, of, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [det, [the]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]]], ['.']]], '2006-05-30-20-36-12', amadeus, '').
text_drs_eval(0, 1259, 'There is Mary\'s sister.', drs([A, B], [object(A, 'Mary', named, na, eq, 1)-1, object(B, sister, countable, na, eq, 1)-1, relation(B, of, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pname, ['Mary']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [sister]]]]]], ['.']]], '2006-05-30-20-35-04', amadeus, '').
text_drs_eval(0, 1260, 'There are the man and the dog.', drs([], []), [], '2008-01-03-16-27-54', '130.60.206.88', '').
text_drs_eval(0, 1261, 'There are a man and the dog.', drs([], []), [], '2008-01-03-16-28-05', '130.60.206.88', '').
text_drs_eval(0, 1262, 'There is John or there is Mary.', drs([], []), [], '2006-08-17-15-36-18', amadeus, '').
text_drs_eval(0, 1263, 'It is necessary that there is John.', drs([], []), [], '2006-08-17-15-36-41', amadeus, '').
text_drs_eval(0, 1264, 'There is a man. There is a card of him.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-2, relation(B, of, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]], ['.']]], '2006-05-30-12-55-23', amadeus, '').
text_drs_eval(0, 1265, 'A customer and a clerk\'s contract is green.', drs([], []), [], '2006-08-28-16-07-22', amadeus, '').
text_drs_eval(0, 1266, 'A contract of a customer and a clerk is green.', drs([A, B, C, D, E, F], [object(A, contract, countable, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, relation(A, of, D)-1, object(C, clerk, countable, na, eq, 1)-1, has_part(D, B)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, property(E, green, pos)-1, predicate(F, be, A, E)-1]), [[s, [np, [det, [a]], [nbar, [n, [contract]], [pp, [prep, [of]], [np_coord, [np, [det, [a]], [nbar, [n, [customer]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [clerk]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]]], '2007-09-26-17-03-32', '130.60.155.177', '').
text_drs_eval(0, 1267, 'A contract of a customer and a clerk are green.', drs([A, B, C, D, E, F], [object(A, contract, countable, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, relation(A, of, B)-1, property(C, green, pos)-1, predicate(D, be, F, C)-1, object(E, clerk, countable, na, eq, 1)-1, has_part(F, A)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [det, [a]], [nbar, [n, [contract]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [customer]]]]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [clerk]]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [green]]]]]]]], '2007-09-26-17-04-27', '130.60.155.177', '').
text_drs_eval(0, 1268, 'Some contracts of a customer and a clerk are green.', drs([A, B, C, D, E, F], [object(A, contract, countable, na, geq, 2)-1, object(B, customer, countable, na, eq, 1)-1, has_part(D, B)-1, relation(A, of, D)-1, object(C, clerk, countable, na, eq, 1)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, property(E, green, pos)-1, predicate(F, be, A, E)-1]), [[specification, [s, [np, [det, some], [nbar, [n, contracts], [pp, [prep, of], [np_coord, [np, [det, a], [nbar, [n, customer]]], [coord, and], [np, [det, a], [nbar, [n, clerk]]]]]]], [vp, [aux, are], [vbar, [ap_coord, [ap, [adj, green]]]]]], '.']], '2008-10-06-14-47-27', '130.60.155.206', '').
text_drs_eval(0, 1269, 'Is there the card?', drs([], []), [], '2006-05-30-20-33-58', amadeus, '').
text_drs_eval(0, 1270, 'There is a man. There is a man. There is the man\'s dog.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, object(C, dog, countable, na, eq, 1)-3, relation(C, of, B)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [det, [the]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]]], ['.']]], '2006-05-30-20-36-40', amadeus, '').
text_drs_eval(0, 1271, 'There are a man\'s dogs.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, geq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dogs]]]]]], ['.']]], '2006-05-30-20-40-05', amadeus, '').
text_drs_eval(0, 1272, 'John and Mary\'s dog barks.', drs([], []), [], '2006-08-28-16-08-14', amadeus, '').
text_drs_eval(0, 1273, 'There are the man and a dog.', drs([], []), [], '2008-01-03-16-28-15', '130.60.206.88', '').
text_drs_eval(0, 1274, 'There is John\'s dog. The dog barks.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-05-30-21-08-45', amadeus, '').
text_drs_eval(0, 1275, 'There is a man. There is his dog that barks.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, predicate(C, bark, B)-2, object(B, dog, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_spec, [poss_pn_coord, [posspn, [his]]]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2006-05-30-21-45-48', amadeus, '').
text_drs_eval(0, 1276, 'There is the man and the man\'s dog.', drs([], []), [], '2006-08-28-21-10-47', amadeus, '').
text_drs_eval(0, 1277, 'There is a man and the man\'s dog.', drs([], []), [], '2006-08-28-21-10-29', amadeus, '').
text_drs_eval(0, 1278, 'There are a man and the man\'s dog.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, has_part(C, A)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1]), [[top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [poss_np, [det, [the]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]]]]], '2007-09-26-17-05-02', '130.60.155.177', '').
text_drs_eval(0, 1279, 'A man can wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, can(drs([B], [predicate(B, wait, A)-1/4]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-10-45', '89.206.64.27', '').
text_drs_eval(0, 1280, 'A man must wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, must(drs([B], [predicate(B, wait, A)-1/4]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-10-51', '89.206.64.27', '').
text_drs_eval(0, 1281, 'Can a man wait?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/3, can(drs([B], [predicate(B, wait, A)-1/4]))]))]), [[query, [question, can, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, wait]]]]], ?]], '2010-10-27-09-10-56', '89.206.64.27', '').
text_drs_eval(0, 1282, 'Must a man wait?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/3, must(drs([B], [predicate(B, wait, A)-1/4]))]))]), [[query, [question, must, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, wait]]]]], ?]], '2010-10-27-09-11-01', '89.206.64.27', '').
text_drs_eval(0, 1283, 'Everybody can see something.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [can(drs([B, C], [object(B, something, dom, na, na, na)-1/6, predicate(C, see, A, B)-1/4]))])]), [[specification, [s, [np, [pn, everybody]], [vp, [aux, can], [vbar, [vcompl, [v, see], [np, [pn, something]]]]]], '.']], '2010-10-27-09-11-06', '89.206.64.27', '').
text_drs_eval(0, 1284, 'If there is somebody then it is possible that he/she sees something.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/5])=>drs([], [can(drs([B, C], [object(B, something, dom, na, na, na)-1/16, predicate(C, see, A, B)-1/14]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [pn, somebody]]]], then, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pn, 'he/she']], [vp, [vbar, [vcompl, [v, sees], [np, [pn, something]]]]]]]]], '.']], '2010-10-27-09-11-18', '89.206.64.27', '').
text_drs_eval(0, 1285, 'It is possible that a man can wait.', drs([], [can(drs([A], [object(A, man, countable, na, eq, 1)-1/6, can(drs([B], [predicate(B, wait, A)-1/8]))]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]]]], '.']], '2010-10-27-09-38-22', '89.206.64.27', '').
text_drs_eval(0, 1286, 'Some laundry can wait.', drs([A], [object(A, laundry, mass, na, na, na)-1/2, can(drs([B], [predicate(B, wait, A)-1/4]))]), [[specification, [s, [np, [det, some], [nbar, [n, laundry]]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-11-28', '89.206.64.27', '').
text_drs_eval(0, 1287, 'Some men can wait.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, can(drs([B], [predicate(B, wait, A)-1/4]))]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-11-33', '89.206.64.27', '').
text_drs_eval(0, 1288, 'Some men can see themselves.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, can(drs([B], [predicate(B, see, A, A)-1/4]))]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, can], [vbar, [vcompl, [v, see], [np, [pn, themselves]]]]]], '.']], '2010-10-27-09-11-38', '89.206.64.27', '').
text_drs_eval(0, 1289, 'A man can see a dog in a park.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, can(drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1/6, object(C, park, countable, na, eq, 1)-1/9, predicate(D, see, A, B)-1/4, modifier_pp(D, in, C)-1/7]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, dog]]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]]]]], '.']], '2010-10-27-09-11-43', '89.206.64.27', '').
text_drs_eval(0, 1290, 'A man can see a dog that barks.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, can(drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1/6, predicate(C, bark, B)-1/8, predicate(D, see, A, B)-1/4]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, barks]]]]]]]]]]], '.']], '2010-10-27-09-11-50', '89.206.64.27', '').
text_drs_eval(0, 1291, 'A man can see a dog that barks in a park.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, can(drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1/6, object(C, park, countable, na, eq, 1)-1/11, predicate(D, bark, B)-1/8, modifier_pp(D, in, C)-1/9, predicate(E, see, A, B)-1/4]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, barks]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]]]]]]]]]]], '.']], '2010-10-27-09-11-56', '89.206.64.27', '').
text_drs_eval(0, 1292, 'John hates a man who can see him.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, can(drs([C], [predicate(C, see, A, named('John'))-1/7])), predicate(B, hate, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vcompl, [v, see], [np, [pn, him]]]]]]]]]]]], '.']], '2010-10-27-09-12-01', '89.206.64.27', '').
text_drs_eval(0, 1293, 'John hates a man who John can see.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, can(drs([C], [predicate(C, see, named('John'), A)-1/8])), predicate(B, hate, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [np, [pname, 'John']], [vp, [aux, can], [vbar, [vcompl, [v, see]]]]]]]]]]], '.']], '2010-10-27-09-12-07', '89.206.64.27', '').
text_drs_eval(0, 1294, 'John sees exactly 2 men.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, [predicate(C, see, A, B)-1, object(B, man, countable, na, exactly, 2)-1]]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [nump, [genqu, exactly], 2], [nbar, [n, men]]]]]]], '.']], '2009-03-02-11-29-13', '130.60.155.206', '').
text_drs_eval(0, 1295, 'It is impossible that a man waits.', drs([], []), [], '2006-07-15-17-42-11', amadeus, '').
text_drs_eval(0, 1296, 'It is not possible that a man waits.', drs([], [-drs([], [can(drs([A, B], [object(A, man, countable, na, eq, 1)-1/7, predicate(B, wait, A)-1/8]))])]), [[specification, [s, [impossibility, 'it is not possible'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-12-17', '89.206.64.27', '').
text_drs_eval(0, 1297, 'Possibly a man waits.', drs([], []), [], '2006-07-25-15-30-04', amadeus, '').
text_drs_eval(0, 1298, 'For every thing which knows something it knows it.', drs([], [drs([A, B, C], [object(A, thing, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, know, A, B)-1])=>drs([D], [predicate(D, know, B, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [thing]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [knows]], [np, [pn, [something]]]]]]]], [s, [np, [pn, [it]]], [vp, [vbar, [v, [knows]], [np, [pn, [it]]]]]]], ['.']]], '2006-06-06-17-42-32', amadeus, '').
text_drs_eval(0, 1299, 'For everything which knows something it knows it.', drs([], [drs([A, B, C], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, predicate(C, know, A, B)-1])=>drs([D], [predicate(D, know, B, A)-1])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, ['$thing']], [rel_cl, [comp, [which]], [vp, [vbar, [v, [knows]], [np, [det, [a]], [nbar, [n, ['$thing']]]]]]]]], [s, [np, [pn, [it]]], [vp, [vbar, [v, [knows]], [np, [pn, [it]]]]]]]], '2007-10-17-15-19-56', '130.60.155.177', '').
text_drs_eval(0, 1300, 'Somebody X waits.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-16-28-03', amadeus, '').
text_drs_eval(0, 1301, 'Somebody of John waits.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, predicate(C, wait, B)-1, relation(B, of, A)-1]), [[specification, [s, [nbar, [pn, [somebody]], [pp, [prep, [of]], [np, [pname, ['John']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-16-29-00', amadeus, '').
text_drs_eval(0, 1302, 'Every dog that sees a cat that sees a rat X sees X.', drs([], [drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, rat, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])=>drs([F], [predicate(F, see, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]], [appos_coord, [appos, [var, ['X']]]]]]]]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['X']]]]]]], ['.']]], '2007-08-14-20-19-45', '130.60.155.177', '').
text_drs_eval(0, 1303, 'Every dog that sees a cat that sees a rat sees the rat.', drs([], [drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, rat, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])=>drs([F], [predicate(F, see, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [rat]]]]]]], ['.']]], '2007-08-14-20-19-57', '130.60.155.177', '').
text_drs_eval(0, 1304, 'Every dog that sees a cat that sees a rat sees it.', drs([], [drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, rat, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])=>drs([F], [predicate(F, see, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [pn, [it]]]]]], ['.']]], '2007-08-15-15-15-56', '130.60.155.177', '').
text_drs_eval(0, 1305, 'Every dog that sees a cat that sees something sees it.', drs([], [drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, something, dom, na, na, na)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])=>drs([F], [predicate(F, see, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [pn, [something]]]]]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [pn, [it]]]]]], ['.']]], '2006-06-07-17-03-39', amadeus, '').
text_drs_eval(0, 1306, 'Every dog that sees a cat that sees a rat sees itself.', drs([], [drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, rat, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])=>drs([F], [predicate(F, see, A, A)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, rat]]]]]]]]]]]]], [vp, [vbar, [v, sees], [np, [pn, itself]]]]], '.']], '2008-07-30-01-11-56', '130.60.204.7', '').
text_drs_eval(0, 1307, 'If there is somebody A and A loves somebody B then A likes B.', drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, predicate(C, love, A, B)-1])=>drs([D], [predicate(D, like, A, B)-1])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['A']]]]]]], [coord, [and]], [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [loves]], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['B']]]]]]]]], [then], [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [likes]], [np, [np, [var, ['B']]]]]]]], ['.']]], '2006-06-07-17-16-12', amadeus, '').
text_drs_eval(0, 1308, 'There is something X.', drs([A], [object(A, something, dom, na, na, na)-1]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X']]]]], '.']], '2008-07-12-21-01-01', '77.57.2.2', '').
text_drs_eval(0, 1309, 'Everybody X waits.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [predicate(B, wait, A)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-19-41-49', amadeus, '').
text_drs_eval(0, 1310, 'Everything X waits.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B], [predicate(B, wait, A)-1])]), [[specification, [s, [nbar, [pn, [everything]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-19-42-03', amadeus, '').
text_drs_eval(0, 1311, 'Nobody X waits.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [nbar, [pn, [nobody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-38-39', amadeus, '').
text_drs_eval(0, 1312, 'Nothing X waits.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([], [-drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [nbar, [pn, [nothing]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-38-50', amadeus, '').
text_drs_eval(0, 1313, 'Everybody of John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [relation(B, of, A)-1, object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [pp, [prep, [of]], [np, [pname, ['John']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-19-43-03', amadeus, '').
text_drs_eval(0, 1314, 'Everything of John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [relation(B, of, A)-1, object(B, something, dom, na, na, na)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [s, [nbar, [pn, [everything]], [pp, [prep, [of]], [np, [pname, ['John']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-19-43-17', amadeus, '').
text_drs_eval(0, 1315, 'Nobody of John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [relation(B, of, A)-1, object(B, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, wait, B)-1])])]), [[specification, [s, [nbar, [pn, [nobody]], [pp, [prep, [of]], [np, [pname, ['John']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-39-16', amadeus, '').
text_drs_eval(0, 1316, 'Nothing of John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [relation(B, of, A)-1, object(B, something, dom, na, na, na)-1])=>drs([], [-drs([C], [predicate(C, wait, B)-1])])]), [[specification, [s, [nbar, [pn, [nothing]], [pp, [prep, [of]], [np, [pname, ['John']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-39-31', amadeus, '').
text_drs_eval(0, 1317, 'Everybody X of John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [relation(B, of, A)-1, object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [appos_coord, [appos, [var, ['X']]]], [pp, [prep, [of]], [np, [pname, ['John']]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-07-19-44-44', amadeus, '').
text_drs_eval(0, 1318, 'Everybody X sees X.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [predicate(B, see, A, A)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['X']]]]]]], ['.']]], '2006-06-07-19-45-00', amadeus, '').
text_drs_eval(0, 1319, 'Nobody X sees X.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, see, A, A)-1])])]), [[specification, [s, [nbar, [pn, [nobody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['X']]]]]]], ['.']]], '2006-08-12-18-39-52', amadeus, '').
text_drs_eval(0, 1320, 'If there is somebody A then A sees A.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [predicate(B, see, A, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['A']]]]]]], [then], [s, [np, [np, [var, ['A']]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['A']]]]]]]], ['.']]], '2006-06-07-20-59-37', amadeus, '').
text_drs_eval(0, 1321, 'There is a dog that nobody likes.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, like, B, A)-1])])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [np, [pn, [nobody]]], [vp, [vbar, [v, [likes]], [np, [[]]]]]]]]]], ['.']]], '2006-08-12-18-40-21', amadeus, '').
text_drs_eval(0, 1322, 'John owns something X of Mary which is expensive.', drs([], []), [], '2007-08-08-11-08-37', '130.60.155.231', '').
text_drs_eval(0, 1323, 'Everything X of John which is valid contains a description of X.', drs([], []), [], '2007-08-08-11-08-44', '130.60.155.231', '').
text_drs_eval(0, 1324, 'Nobody X of the group who is a manager has a customer who knows X.', drs([], []), [], '2007-08-08-11-08-51', '130.60.155.231', '').
text_drs_eval(0, 1325, 'A customer of a man who is rich waits.', drs([A, B, C, D, E], [object(A, customer, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, property(C, rich, pos)-1, predicate(D, be, B, C)-1, relation(A, of, B)-1, predicate(E, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-06-09-15-51-06', amadeus, '').
text_drs_eval(0, 1326, 'A customer of John who is rich waits.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, relation(B, of, A)-1, property(C, rich, pos)-1, predicate(D, be, A, C)-1, predicate(E, wait, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [customer]], [pp, [prep, [of]], [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-08-11-10-31', '130.60.155.231', '').
text_drs_eval(0, 1327, 'There is a man that sees a dog that sees a cat.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]]]]], ['.']]], '2006-06-16-15-53-42', amadeus, '').
text_drs_eval(0, 1328, 'There is a man that sees a dog that a cat sees.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, see, C, B)-1, predicate(E, see, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]]]]]]], ['.']]], '2006-06-16-15-54-25', amadeus, '').
text_drs_eval(0, 1329, 'There is a man that sees a dog and that sees a cat.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, see, A, D)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']]], '2006-06-16-15-54-39', amadeus, '').
text_drs_eval(0, 1330, 'There is a man that sees a dog and that a cat sees.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]]], ['.']]], '2006-06-16-15-55-34', amadeus, '').
text_drs_eval(0, 1331, 'There is a man that sees a cat and that a cat sees.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]]], ['.']]], '2006-06-16-15-56-09', amadeus, '').
text_drs_eval(0, 1332, 'There is a man that sees a cat and that the cat sees.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, predicate(D, see, B, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [np, [det, [the]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]]], ['.']]], '2006-06-16-15-57-15', amadeus, '').
text_drs_eval(0, 1333, 'Everybody who somebody is taller than waits.', drs([], []), [], '2007-12-20-13-28-23', '130.60.155.231', '').
text_drs_eval(0, 1334, 'No man who a woman sees waits.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])=>drs([], [-drs([D], [predicate(D, wait, A)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-12-18-42-42', amadeus, '').
text_drs_eval(0, 1335, 'No man a woman sees.', drs([], []), [], '2006-06-23-12-28-23', amadeus, '').
text_drs_eval(0, 1336, 'No man a woman is.', drs([], []), [], '2006-06-23-12-28-27', amadeus, '').
text_drs_eval(0, 1337, 'Every goal that a referee counts is a point.', drs([], [drs([A, B, C], [object(A, goal, countable, na, eq, 1)-1, object(B, referee, countable, na, eq, 1)-1, predicate(C, count, B, A)-1])=>drs([D, E], [object(D, point, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [goal]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, [referee]]]], [vp, [vbar, [v, [counts]], [np, [[]]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [point]]]]]]], ['.']]], '2006-06-23-12-36-22', amadeus, '').
text_drs_eval(0, 1338, 'Everybody who lives-at a place that he/she works-at is a home-worker.', drs([], []), [], '2006-06-26-17-47-32', amadeus, '').
text_drs_eval(0, 1339, 'Everybody sees John who waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([C, D], [predicate(C, see, B, A)-1, predicate(D, wait, A)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2006-07-25-15-43-54', amadeus, '').
text_drs_eval(0, 1340, 'Every man sees John who hears the man.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([C, D], [predicate(C, see, B, A)-1, predicate(D, hear, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [hears]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]], ['.']]], '2006-07-25-15-44-45', amadeus, '').
text_drs_eval(0, 1341, 'If somebody lives-at a place and he/she works-at the place then he/she is a home-worker.', drs([], []), [], '2006-06-26-17-48-07', amadeus, '').
text_drs_eval(0, 1342, 'If somebody lives-at a place and works-at the place then he/she is a home-worker.', drs([], []), [], '2006-06-26-17-48-45', amadeus, '').
text_drs_eval(0, 1343, 'There is a man who sees some women.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, geq, 2)-1, predicate(C, see, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [some]], [nbar, [n, [women]]]]]]]]]]], ['.']]], '2006-06-24-18-10-31', amadeus, '').
text_drs_eval(0, 1344, 'There is a man who some women see.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, geq, 2)-1, predicate(C, see, B, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [some]], [nbar, [n, [women]]]], [vp, [vbar, [v, [see]], [np, [[]]]]]]]]]], ['.']]], '2006-06-24-18-10-50', amadeus, '').
text_drs_eval(0, 1345, 'Every goal is something that at most 1 persons score.', drs([], []), [], '2007-04-13-14-51-03', '130.60.155.177', '').
text_drs_eval(0, 1346, 'Everybody who lives-at a place that he/she works-at is a n:home-worker.', drs([], [drs([A, B, C, D], [object(A, place, countable, na, eq, 1)-1, predicate(B, 'work-at', D, A)-1, predicate(C, 'live-at', D, A)-1, object(D, somebody, countable, na, eq, 1)-1])=>drs([E, F], [object(E, 'home-worker', countable, na, eq, 1)-1, predicate(F, be, D, E)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, ['lives-at']], [np, [det, [a]], [nbar, [n, [place]], [rel_cl, [comp, [that]], [np, [pn, ['he/she']]], [vp, [vbar, [v, ['works-at']], [np, [[]]]]]]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['home-worker']]]]]]], ['.']]], '2007-05-07-16-41-11', '130.60.156.229', '').
text_drs_eval(0, 1347, 'If somebody lives-at a place and he/she works-at the place then he/she is a n:home-worker.', drs([], [drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1, object(B, place, countable, na, eq, 1)-1, predicate(C, 'live-at', A, B)-1, predicate(D, 'work-at', A, B)-1])=>drs([E, F], [object(E, 'home-worker', countable, na, eq, 1)-1, predicate(F, be, A, E)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [nbar, [pn, [somebody]]], [vp, [vbar, [v, ['lives-at']], [np, [det, [a]], [nbar, [n, [place]]]]]]], [coord, [and]], [s, [np, [pn, ['he/she']]], [vp, [vbar, [v, ['works-at']], [np, [det, [the]], [nbar, [n, [place]]]]]]]], [then], [s, [np, [pn, ['he/she']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['home-worker']]]]]]]], ['.']]], '2007-05-07-16-41-19', '130.60.156.229', '').
text_drs_eval(0, 1348, 'If somebody lives-at a place and works-at the place then he/she is a n:home-worker.', drs([], [drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1, object(B, place, countable, na, eq, 1)-1, predicate(C, 'live-at', A, B)-1, predicate(D, 'work-at', A, B)-1])=>drs([E, F], [object(E, 'home-worker', countable, na, eq, 1)-1, predicate(F, be, A, E)-1])]), [[specification, [cond_s, [if], [s, [nbar, [pn, [somebody]]], [vp_coord, [vp, [vbar, [v, ['lives-at']], [np, [det, [a]], [nbar, [n, [place]]]]]], [coord, [and]], [vp, [vbar, [v, ['works-at']], [np, [det, [the]], [nbar, [n, [place]]]]]]]], [then], [s, [np, [pn, ['he/she']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['home-worker']]]]]]]], ['.']]], '2007-05-07-16-41-27', '130.60.156.229', '').
text_drs_eval(0, 1349, 'If a thing X likes a thing Y and Y likes a thing Z then X likes Z.', drs([], [drs([A, B, C, D, E], [object(A, thing, countable, na, eq, 1)-1, object(B, thing, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, object(D, thing, countable, na, eq, 1)-1, predicate(E, like, B, D)-1])=>drs([F], [predicate(F, like, A, D)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [det, [a]], [nbar, [n, [thing]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [thing]], [appos_coord, [appos, [var, ['Y']]]]]]]]], [coord, [and]], [s, [np, [np, [var, ['Y']]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [thing]], [appos_coord, [appos, [var, ['Z']]]]]]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [likes]], [np, [np, [var, ['Z']]]]]]]], ['.']]], '2006-07-06-21-30-38', amadeus, '').
text_drs_eval(0, 1350, 'If something X likes something Y and Y likes something Z then X likes Z.', drs([], [drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, predicate(C, like, A, B)-1, object(D, something, dom, na, na, na)-1, predicate(E, like, B, D)-1])=>drs([F], [predicate(F, like, A, D)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [nbar, [pn, [something]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [likes]], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['Y']]]]]]]], [coord, [and]], [s, [np, [np, [var, ['Y']]]], [vp, [vbar, [v, [likes]], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['Z']]]]]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [likes]], [np, [np, [var, ['Z']]]]]]]], ['.']]], '2006-08-14-20-14-12', amadeus, '').
text_drs_eval(0, 1351, 'Everything that v:affiliatedWith something that v:affiliatedWith something v:affiliatedWith it.', drs([], [drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1, predicate(B, affiliatedWith, E, A)-1, object(C, something, dom, na, na, na)-1, predicate(D, affiliatedWith, A, C)-1, object(E, something, dom, na, na, na)-1])=>drs([F], [predicate(F, affiliatedWith, E, C)-1])]), [[specification, [s, [nbar, [pn, [everything]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [affiliatedWith]], [nbar, [pn, [something]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [affiliatedWith]], [np, [pn, [something]]]]]]]]]]], [vp, [vbar, [v, [affiliatedWith]], [np, [pn, [it]]]]]], ['.']]], '2006-08-29-14-19-50', amadeus, '').
text_drs_eval(0, 1352, 'There is nobody.', drs([], [-drs([A], [object(A, somebody, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [pn, [nobody]]]]], ['.']]], '2006-07-07-21-17-00', amadeus, '').
text_drs_eval(0, 1353, 'Every man whose age is an integer is a manager.', drs([], [drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, age, countable, na, eq, 1)-1, relation(B, of, A)-1, object(C, integer, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])=>drs([E, F], [object(E, manager, countable, na, eq, 1)-1, predicate(F, be, A, E)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [integer]]]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [manager]]]]]]], ['.']]], '2007-05-02-20-20-42', '130.60.155.177', '').
text_drs_eval(0, 1354, 'Every man\'s age is an integer.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1])=>drs([C, D], [object(C, integer, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [integer]]]]]]], ['.']]], '2007-11-20-17-49-20', '130.60.155.231', '').
text_drs_eval(0, 1355, 'Everybody whose dog barks waits.', drs([], [drs([A, B, C], [relation(B, of, C)-1, predicate(A, bark, B)-1, object(B, dog, countable, na, eq, 1)-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([D], [predicate(D, wait, C)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [np, [poss_spec, [poss_pn_coord, [posspn, [whose]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-07-13-16-53-32', amadeus, '').
text_drs_eval(0, 1356, 'Every man\'s dog is an animal.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [object(C, animal, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [animal]]]]]]], ['.']]], '2007-11-20-17-49-36', '130.60.155.231', '').
text_drs_eval(0, 1357, 'Who who a dog sees waits?', drs([], []), [], '2008-09-23-08-48-00', '130.60.155.206', '').
text_drs_eval(0, 1358, 'It is not necessary that John waits.', drs([], [-drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/7]))])]), [[specification, [s, [unnecessity, 'it is not necessary'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-12-28', '89.206.64.27', '').
text_drs_eval(0, 1359, 'It is unnecessary that John waits.', drs([], []), [], '2006-07-16-22-28-57', amadeus, '').
text_drs_eval(0, 1360, 'John knows that Mary waits.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, know, A, D)-1, D:drs([E], [predicate(E, wait, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [that, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2006-07-14-21-41-36', amadeus, '').
text_drs_eval(0, 1361, 'John knows that Mary does not wait.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, know, A, D)-1, D:drs([], [-drs([E], [predicate(E, wait, B)-1])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [that, [that], [s, [np, [pname, ['Mary']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [wait]]]]]]]]], ['.']]], '2006-07-15-16-55-36', amadeus, '').
text_drs_eval(0, 1362, 'John knows something.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [np, [det, [a]], [nbar, [n, ['$thing']]]]]]], ['.']]], '2007-12-20-13-28-56', '130.60.155.231', '').
text_drs_eval(0, 1363, 'John knows that Mary sees him.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, know, A, D)-1, D:drs([E], [predicate(E, see, B, A)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [that, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]]]]]], ['.']]], '2006-07-15-17-19-07', amadeus, '').
text_drs_eval(0, 1364, 'John wisely knows that Mary waits.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/5, predicate(C, know, A, D)-1/3, modifier_adv(C, wisely, pos)-1/2, D:drs([E], [predicate(E, wait, B)-1/6])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, wisely], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, waits]]]]]]]]], '.']], '2009-04-02-15-22-43', '130.60.155.206', '').
text_drs_eval(0, 1365, 'John knows wisely that Mary waits.', drs([], []), [], '2009-04-02-13-13-05', '130.60.155.206', '').
text_drs_eval(0, 1366, 'There is a man that waits and that likes a dog.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, like, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]]], ['.']]], '2006-07-15-18-39-59', amadeus, '').
text_drs_eval(0, 1367, 'John\'s rich brother waits.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, C)-1, property(C, rich, pos)-1, object(C, brother, countable, na, eq, 1)-1, relation(C, of, A)-1]), [[specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [adj, [rich]], [nbar, [n, [brother]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-07-15-19-14-06', amadeus, '').
text_drs_eval(0, 1368, 'John does not know that Mary sleeps.', drs([A, B], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, -drs([C, D], [predicate(C, know, A, D)-1, D:drs([E], [predicate(E, sleep, B)-1])])]), [[specification, [s, [np, [pname, ['John']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [know]], [that, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]]]], ['.']]], '2006-07-16-18-41-38', amadeus, '').
text_drs_eval(0, 1369, 'John sees that a dog barks. It is happy.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [that, [that], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2006-07-16-18-42-07', amadeus, '').
text_drs_eval(0, 1370, 'Does John see that a dog barks?', drs([], [question(drs([A, B], [predicate(A, see, named('John'), B)-1/3, B:drs([C, D], [object(C, dog, countable, na, eq, 1)-1/6, predicate(D, bark, C)-1/7])]))]), [[sentence, [query, [question, does, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]], ?], '.']], '2009-05-13-14-10-12', '130.60.155.193', '').
text_drs_eval(0, 1371, 'Can John run?', drs([], [question(drs([], [can(drs([A], [predicate(A, run, named('John'))-1/3]))]))]), [[query, [question, can, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, run]]]]], ?]], '2010-10-27-09-12-38', '89.206.64.27', '').
text_drs_eval(0, 1372, 'Must John run?', drs([], [question(drs([], [must(drs([A], [predicate(A, run, named('John'))-1/3]))]))]), [[query, [question, must, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, run]]]]], ?]], '2010-10-27-09-12-43', '89.206.64.27', '').
text_drs_eval(0, 1373, 'Has to John run?', drs([], []), [], '2007-06-12-10-37-14', '130.60.156.66', '').
text_drs_eval(0, 1374, 'A man has to wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, must(drs([B], [predicate(B, wait, A)-1/5]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, 'has to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-12-53', '89.206.64.27', '').
text_drs_eval(0, 1375, 'Some men have to wait.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, must(drs([B], [predicate(B, wait, A)-1/5]))]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, 'have to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-12-59', '89.206.64.27', '').
text_drs_eval(0, 1376, 'Some men has to wait.', drs([], []), [], '2006-07-16-19-16-13', amadeus, '').
text_drs_eval(0, 1377, 'A man have to wait.', drs([], []), [], '2006-07-16-19-16-23', amadeus, '').
text_drs_eval(0, 1378, 'A man does not quickly wait.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B], [predicate(B, wait, A)-1, modifier_adv(B, quickly, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [adv, [quickly]], [vbar, [v, [wait]]]]]], ['.']]], '2006-07-16-19-39-01', amadeus, '').
text_drs_eval(0, 1379, 'A man must quickly wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, must(drs([B], [modifier_adv(B, quickly, pos)-1/4, predicate(B, wait, A)-1/5]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, must], [vbar, [vmod, [adv, quickly]], [vbar, [v, wait]]]]], '.']], '2010-10-27-09-13-08', '89.206.64.27', '').
text_drs_eval(0, 1380, 'A man can\'t wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B], [predicate(B, wait, A)-1/5]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-13-13', '89.206.64.27', '').
text_drs_eval(0, 1381, 'A man can not wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B], [predicate(B, wait, A)-1/5]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-13-19', '89.206.64.27', '').
text_drs_eval(0, 1382, 'A man cannot wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B], [predicate(B, wait, A)-1/5]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-13-26', '89.206.64.27', '').
text_drs_eval(0, 1383, 'Some men can\'t wait.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, -drs([], [can(drs([B], [predicate(B, wait, A)-1/5]))])]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-13-31', '89.206.64.27', '').
text_drs_eval(0, 1384, 'A man does not have to wait.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [must(drs([B], [predicate(B, wait, A)-1/7]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, 'not have to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-13-37', '89.206.64.27', '').
text_drs_eval(0, 1385, 'Some men does not have to wait.', drs([], []), [], '2006-07-16-20-23-20', amadeus, '').
text_drs_eval(0, 1386, 'Some men do not have to wait.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, -drs([], [must(drs([B], [predicate(B, wait, A)-1/7]))])]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, do, 'not have to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-18-45', '89.206.64.27', '').
text_drs_eval(0, 1387, 'John knows that Mary sleeps quickly quickly.', drs([], []), [], '2006-08-03-19-16-53', amadeus, '').
text_drs_eval(0, 1388, 'John knows that Mary sleeps and he knows that Bill waits.', drs([A, B, C, D, E, F, G], [object(C, 'Bill', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(D, know, A, E)-1, E:drs([H], [predicate(H, sleep, B)-1]), predicate(F, know, A, G)-1, G:drs([I], [predicate(I, wait, C)-1])]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [comp, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [knows]], [comp, [that], [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [waits]]]]]]]]]], ['.']]], '2006-07-25-16-31-42', amadeus, '').
text_drs_eval(0, 1389, 'John wants that he flies.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, want, A, C)-1, C:drs([D], [predicate(D, fly, A)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [wants]], [that, [that], [s, [np, [pn, [he]]], [vp, [vbar, [v, [flies]]]]]]]]], ['.']]], '2006-07-16-22-26-00', amadeus, '').
text_drs_eval(0, 1390, 'John knows quickly that Mary sleeps.', drs([], []), [], '2009-04-02-13-13-11', '130.60.155.206', '').
text_drs_eval(0, 1391, 'John knows quickly that Mary sleeps quickly.', drs([], []), [], '2009-04-02-13-13-18', '130.60.155.206', '').
text_drs_eval(0, 1392, 'John quickly knows that Mary sleeps quickly.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/5, predicate(C, know, A, D)-1/3, modifier_adv(C, quickly, pos)-1/2, D:drs([E], [predicate(E, sleep, B)-1/6, modifier_adv(E, quickly, pos)-1/7])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, quickly], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]], [vmod, [adv, quickly]]]]]]]]], '.']], '2009-04-02-15-23-04', '130.60.155.206', '').
text_drs_eval(0, 1393, 'John knows that Mary sleeps quickly.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, know, A, D)-1, D:drs([E], [predicate(E, sleep, B)-1, modifier_adv(E, quickly, pos)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [that, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [vbar, [v, [sleeps]]], [adv, [quickly]]]]]]]]], ['.']]], '2006-07-16-22-27-35', amadeus, '').
text_drs_eval(0, 1394, 'John tells Mary that he wants to fly.', drs([], []), [], '2007-12-04-19-19-51', '130.60.155.177', '').
text_drs_eval(0, 1395, 'John belives that Mary has a book.', drs([], []), [], '2006-07-20-13-51-42', amadeus, '').
text_drs_eval(0, 1396, 'Every customer believes that John does not wait.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, customer, countable, na, eq, 1)-1])=>drs([C, D], [predicate(C, believe, B, D)-1, D:drs([], [-drs([E], [predicate(E, wait, A)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [believes]], [that, [that], [s, [np, [pname, ['John']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [wait]]]]]]]]], ['.']]], '2006-07-16-22-28-30', amadeus, '').
text_drs_eval(0, 1397, 'Every customer believes that John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, customer, countable, na, eq, 1)-1])=>drs([C, D], [predicate(C, believe, B, D)-1, D:drs([E], [predicate(E, wait, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [believes]], [that, [that], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2006-07-16-22-28-35', amadeus, '').
text_drs_eval(0, 1398, 'It is possible that every customer waits.', drs([], [can(drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/6])=>drs([B], [predicate(B, wait, A)-1/7])]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [det, every], [nbar, [n, customer]]], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-18-51', '89.206.64.27', '').
text_drs_eval(0, 1399, 'Every customer can wait.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/2])=>drs([], [can(drs([B], [predicate(B, wait, A)-1/4]))])]), [[specification, [s, [np, [det, every], [nbar, [n, customer]]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-18-55', '89.206.64.27', '').
text_drs_eval(0, 1400, 'Necessarily John waits.', drs([], []), [], '2006-07-16-22-28-50', amadeus, '').
text_drs_eval(0, 1401, 'It is necessary that John waits.', drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/6]))]), [[specification, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-19-04', '89.206.64.27', '').
text_drs_eval(0, 1402, 'Possibly John waits.', drs([], []), [], '2006-07-16-22-29-09', amadeus, '').
text_drs_eval(0, 1403, 'It is impossible that John waits.', drs([], []), [], '2006-07-16-22-29-15', amadeus, '').
text_drs_eval(0, 1404, 'It is not possible that John waits.', drs([], [-drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/7]))])]), [[specification, [s, [impossibility, 'it is not possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-19-10', '89.206.64.27', '').
text_drs_eval(0, 1405, 'It is possible that John waits.', drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/6]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-19-23', '89.206.64.27', '').
text_drs_eval(0, 1406, 'John does not have to wait.', drs([], [-drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/6]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'not have to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-19-21', '89.206.64.27', '').
text_drs_eval(0, 1407, 'John has to wait.', drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/4]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, 'has to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-19-30', '89.206.64.27', '').
text_drs_eval(0, 1408, 'John must not wait.', drs([], []), [], '2006-07-16-22-29-41', amadeus, '').
text_drs_eval(0, 1409, 'John must wait.', drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/3]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-19-34', '89.206.64.27', '').
text_drs_eval(0, 1410, 'John can\'t wait.', drs([], [-drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-19-40', '89.206.64.27', '').
text_drs_eval(0, 1411, 'John cannot wait.', drs([], [-drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-19-47', '89.206.64.27', '').
text_drs_eval(0, 1412, 'John can wait.', drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/3]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-19-52', '89.206.64.27', '').
text_drs_eval(0, 1413, 'John says that there is a card.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, say, A, C)-1, C:drs([D], [object(D, card, countable, na, eq, 1)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [says]], [that, [that], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]]]]]], ['.']]], '2006-07-16-22-30-17', amadeus, '').
text_drs_eval(0, 1414, 'John believes that there is a card.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, believe, A, C)-1, C:drs([D], [object(D, card, countable, na, eq, 1)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [believes]], [that, [that], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]]]]]], ['.']]], '2006-07-16-22-30-20', amadeus, '').
text_drs_eval(0, 1415, 'John believes that Mary sleeps.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, believe, A, D)-1, D:drs([E], [predicate(E, sleep, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [believes]], [that, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]]]], ['.']]], '2006-07-16-22-30-26', amadeus, '').
text_drs_eval(0, 1416, 'It is not provable that John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, ~drs([B], [predicate(B, wait, A)-1])]), [[specification, [modality, [naf, ['{it is not provable that}']], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2006-07-18-13-55-45', amadeus, '').
text_drs_eval(0, 1417, 'It is not provable that John waits and Mary sleeps.', drs([A, B, C], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, ~drs([D], [predicate(D, wait, A)-1]), predicate(C, sleep, B)-1]), [[specification, [s_coord, [modality, [naf, ['{it is not provable}']], [comp, [that], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]]]], [coord, [and]], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2006-07-25-15-29-13', amadeus, '').
text_drs_eval(0, 1418, 'If a customer does not transmit some money and it is not provable that he does not transmit the money then the bank assumes that he transmits the money.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1, -drs([B, C], [object(B, money, mass, na, na, na)-1, predicate(C, transmit, A, B)-1]), ~drs([], [-drs([D, E], [predicate(D, transmit, A, E)-1, object(E, money, countable, na, eq, 1)-1])])])=>drs([F, G, H], [predicate(F, assume, H, G)-1, G:drs([I, J], [predicate(I, transmit, A, J)-1, object(J, money, countable, na, eq, 1)-1]), object(H, bank, countable, na, eq, 1)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [det, [a]], [nbar, [n, [customer]]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [transmit]], [np, [det, [some]], [nbar, [n, [money]]]]]]], [coord, [and]], [modality, [naf, ['{it is not provable that}']], [s, [np, [pn, [he]]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [v, [transmit]], [np, [det, [the]], [nbar, [n, [money]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [bank]]]], [vp, [vbar, [v, [assumes]], [that, [that], [s, [np, [pn, [he]]], [vp, [vbar, [v, [transmits]], [np, [det, [the]], [nbar, [n, [money]]]]]]]]]]]], ['.']]], '2006-07-18-14-57-57', amadeus, '').
text_drs_eval(0, 1419, 'Which dog of which man sleeps?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, dog, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, man, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, predicate(C, sleep, A)-1/6]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, dog], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man]]]]]], [vp, [vbar, [vbar, [v, sleeps]]]]], ?], '.']], '2009-05-13-14-10-19', '130.60.155.193', '').
text_drs_eval(0, 1420, 'John does not quickly run.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([B], [predicate(B, run, A)-1, modifier_adv(B, quickly, pos)-1])]), [[specification, [s, [np, [pname, ['John']]], [neg_vp, [aux, [does]], [neg, [not]], [vbar, [adv, [quickly]], [vbar, [v, [run]]]]]], ['.']]], '2006-07-20-14-33-42', amadeus, '').
text_drs_eval(0, 1421, 'A man does not is seen by a dog.', drs([], []), [], '2006-07-20-19-46-46', amadeus, '').
text_drs_eval(0, 1422, 'A man seen by a dog.', drs([], []), [], '2006-07-20-19-47-08', amadeus, '').
text_drs_eval(0, 1423, 'A book is written by a man.', drs([A, B, C], [object(A, book, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2006-07-20-20-29-17', amadeus, '').
text_drs_eval(0, 1424, 'Some books are written by a man.', drs([A, B, C], [object(A, book, countable, na, geq, 2)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [books]]]], [vp, [aux, [are]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2006-07-20-20-30-07', amadeus, '').
text_drs_eval(0, 1425, 'A book is not written by a man.', drs([A], [object(A, book, countable, na, eq, 1)-1, -drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [neg_vp, [aux, [is]], [neg, [not]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2006-07-20-20-30-32', amadeus, '').
text_drs_eval(0, 1426, 'Some books are not written by a man.', drs([A], [object(A, book, countable, na, geq, 2)-1, -drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1])]), [[specification, [s, [np, [det, [some]], [nbar, [n, [books]]]], [neg_vp, [aux, [are]], [neg, [not]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2006-07-20-20-30-53', amadeus, '').
text_drs_eval(0, 1427, 'A book written by a man.', drs([], []), [], '2006-07-20-21-38-49', amadeus, '').
text_drs_eval(0, 1428, 'A book is quickly written by a man.', drs([A, B, C], [object(A, book, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1, modifier_adv(C, quickly, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [adv, [quickly]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-07-20-20-31-41', amadeus, '').
text_drs_eval(0, 1429, 'A book is not quickly written by a man.', drs([A], [object(A, book, countable, na, eq, 1)-1, -drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1, modifier_adv(C, quickly, pos)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [neg_vp, [aux, [is]], [neg, [not]], [vbar, [adv, [quickly]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-07-20-20-32-05', amadeus, '').
text_drs_eval(0, 1430, 'Some books are quickly written by a man.', drs([A, B, C], [object(A, book, countable, na, geq, 2)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1, modifier_adv(C, quickly, pos)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [books]]]], [vp, [aux, [are]], [vbar, [adv, [quickly]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-07-20-20-32-30', amadeus, '').
text_drs_eval(0, 1431, 'Some books are not quickly written by a man.', drs([A], [object(A, book, countable, na, geq, 2)-1, -drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, write, B, A)-1, modifier_adv(C, quickly, pos)-1])]), [[specification, [s, [np, [det, [some]], [nbar, [n, [books]]]], [neg_vp, [aux, [are]], [neg, [not]], [vbar, [adv, [quickly]], [vbar, [v, [written]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-07-20-20-32-44', amadeus, '').
text_drs_eval(0, 1432, 'A book written by a man quickly.', drs([], []), [], '2006-07-20-21-40-54', amadeus, '').
text_drs_eval(0, 1433, 'A best car wins.', drs([A, B], [object(A, car, countable, na, eq, 1)-1, property(A, good, sup)-1, predicate(B, win, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [best]], [nbar, [n, [car]]]]], [vp, [vbar, [v, [wins]]]]], ['.']]], '2007-06-12-10-37-59', '130.60.156.66', '').
text_drs_eval(0, 1434, 'Does a book written by a man?', drs([], []), [], '2006-07-20-21-39-05', amadeus, '').
text_drs_eval(0, 1435, 'John is permitted that a dog barks.', drs([], []), [], '2006-07-20-21-39-27', amadeus, '').
text_drs_eval(0, 1436, 'What is written by a man?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, object(B, man, countable, na, eq, 1)-1/6, predicate(C, write, B, A)-1/3]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [v, written], by, [np, [det, a], [nbar, [n, man]]]]]]], ?], '.']], '2009-05-13-14-10-20', '130.60.155.193', '').
text_drs_eval(0, 1437, 'Is a book written by a man?', drs([], [question(drs([A, B, C], [object(A, book, countable, na, eq, 1)-1/3, object(B, man, countable, na, eq, 1)-1/7, predicate(C, write, B, A)-1/4]))]), [[sentence, [query, [question, is, [np, [det, a], [nbar, [n, book]]], [vp, [vbar, [vcompl, [v, written], by, [np, [det, a], [nbar, [n, man]]]]]]], ?], '.']], '2009-05-13-14-10-21', '130.60.155.193', '').
text_drs_eval(0, 1438, 'Is a car blue?', drs([], [question(drs([A, B, C], [object(A, car, countable, na, eq, 1)-1/3, property(B, blue, pos)-1/4, predicate(C, be, A, B)-1/1]))]), [[sentence, [query, [question, is, [np, [det, a], [nbar, [n, car]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, blue]]]]]]], ?], '.']], '2009-05-13-14-10-22', '130.60.155.193', '').
text_drs_eval(0, 1439, 'There is John who Mary is seen by.', drs([], []), [], '2007-01-22-16-14-51', '130.60.155.211', '').
text_drs_eval(0, 1440, 'Everything that is written by somebody is a book or is a paper.', drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, write, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([], [drs([D, E], [object(D, book, countable, na, eq, 1)-1, predicate(E, be, C, D)-1])v drs([F, G], [object(F, paper, countable, na, eq, 1)-1, predicate(G, be, C, F)-1])])]), [[specification, [s, [nbar, [pn, [everything]], [rel_cl, [comp, [that]], [vp, [aux, [is]], [vbar, [v, [written]], [np, [pn, [somebody]]]]]]], [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [book]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [paper]]]]]]]], ['.']]], '2006-07-20-21-47-54', amadeus, '').
text_drs_eval(0, 1441, 'John is liked by himself.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, like, A, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [aux, [is]], [vbar, [v, [liked]], [np, [pn, [himself]]]]]], ['.']]], '2006-08-12-19-14-36', amadeus, '').
text_drs_eval(0, 1442, 'John is liked by him.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [aux, [is]], [vbar, [v, [liked]], [np, [pn, [him]]]]]], ['.']]], '2006-08-12-19-14-54', amadeus, '').
text_drs_eval(0, 1443, 'Which card is seen by John?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, card, countable, na, eq, 1)-1/2, predicate(B, see, named('John'), A)-1/4]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vcompl, [v, seen], by, [np, [pname, 'John']]]]]], ?], '.']], '2009-05-13-14-10-23', '130.60.155.193', '').
text_drs_eval(0, 1444, 'Is a code is entered by a customer?', drs([], []), [], '2006-07-21-18-41-54', amadeus, '').
text_drs_eval(0, 1445, 'does a code is entered by a customer?', drs([], []), [], '2006-07-21-18-41-57', amadeus, '').
text_drs_eval(0, 1446, 'Where does a customer enter a card?', drs([], [question(drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, predicate(C, enter, A, B)-1/5, query(C, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-14-10-24', '130.60.155.193', '').
text_drs_eval(0, 1447, 'Where is a card entered by a customer?', drs([], [question(drs([A, B, C], [object(A, card, countable, na, eq, 1)-1/4, object(B, customer, countable, na, eq, 1)-1/8, predicate(C, enter, B, A)-1/5, query(C, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], is, [np, [det, a], [nbar, [n, card]]], [vp, [vbar, [vcompl, [v, entered], by, [np, [det, a], [nbar, [n, customer]]]]]]], ?], '.']], '2009-05-13-14-10-25', '130.60.155.193', '').
text_drs_eval(0, 1448, 'Who does not wait?', drs([], [question(drs([A], [query(A, who)-1/1, -drs([B], [predicate(B, wait, A)-1/4])]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-14-10-26', '130.60.155.193', '').
text_drs_eval(0, 1449, 'It is not possible that John flies.', drs([], [-drs([], [can(drs([A], [predicate(A, fly, named('John'))-1/7]))])]), [[specification, [s, [impossibility, 'it is not possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, flies]]]]]]], '.']], '2010-10-27-09-20-02', '89.206.64.27', '').
text_drs_eval(0, 1450, 'It is possible that John flies.', drs([], [can(drs([A], [predicate(A, fly, named('John'))-1/6]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, flies]]]]]]], '.']], '2010-10-27-09-20-07', '89.206.64.27', '').
text_drs_eval(0, 1451, 'John can not fly.', drs([], [-drs([], [can(drs([A], [predicate(A, fly, named('John'))-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, not], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-12', '89.206.64.27', '').
text_drs_eval(0, 1452, 'John can\'t fly.', drs([], [-drs([], [can(drs([A], [predicate(A, fly, named('John'))-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, not], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-16', '89.206.64.27', '').
text_drs_eval(0, 1453, 'John cannot fly.', drs([], [-drs([], [can(drs([A], [predicate(A, fly, named('John'))-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, not], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-28', '89.206.64.27', '').
text_drs_eval(0, 1454, 'John can fly.', drs([], [can(drs([A], [predicate(A, fly, named('John'))-1/3]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-33', '89.206.64.27', '').
text_drs_eval(0, 1455, 'John believes that he can fly.', drs([A, B], [predicate(A, believe, named('John'), B)-1/2, B:drs([], [can(drs([C], [predicate(C, fly, named('John'))-1/6]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, can], [vbar, [vbar, [v, fly]]]]]]]]], '.']], '2010-10-27-09-20-39', '89.206.64.27', '').
text_drs_eval(0, 1456, 'John believes that he must fly.', drs([A, B], [predicate(A, believe, named('John'), B)-1/2, B:drs([], [must(drs([C], [predicate(C, fly, named('John'))-1/6]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, must], [vbar, [vbar, [v, fly]]]]]]]]], '.']], '2010-10-27-09-20-45', '89.206.64.27', '').
text_drs_eval(0, 1457, 'John must fly.', drs([], [must(drs([A], [predicate(A, fly, named('John'))-1/3]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, must], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-49', '89.206.64.27', '').
text_drs_eval(0, 1458, 'John has to fly.', drs([], [must(drs([A], [predicate(A, fly, named('John'))-1/4]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, 'has to'], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-53', '89.206.64.27', '').
text_drs_eval(0, 1459, 'John does not have to fly.', drs([], [-drs([], [must(drs([A], [predicate(A, fly, named('John'))-1/6]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'not have to'], [vbar, [vbar, [v, fly]]]]], '.']], '2010-10-27-09-20-59', '89.206.64.27', '').
text_drs_eval(0, 1460, 'It is necessary that John flies.', drs([], [must(drs([A], [predicate(A, fly, named('John'))-1/6]))]), [[specification, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, flies]]]]]]], '.']], '2010-10-27-09-21-05', '89.206.64.27', '').
text_drs_eval(0, 1461, 'It is not necessary that John flies.', drs([], [-drs([], [must(drs([A], [predicate(A, fly, named('John'))-1/7]))])]), [[specification, [s, [unnecessity, 'it is not necessary'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, flies]]]]]]], '.']], '2010-10-27-09-21-11', '89.206.64.27', '').
text_drs_eval(0, 1462, 'It is unnecessary that John flies.', drs([], []), [], '2006-07-23-14-41-03', amadeus, '').
text_drs_eval(0, 1463, 'It is impossible that John flies.', drs([], []), [], '2006-07-23-14-41-17', amadeus, '').
text_drs_eval(0, 1464, 'It is not provable that John flies.', drs([A], [object(A, 'John', named, na, eq, 1)-1, ~drs([B], [predicate(B, fly, A)-1])]), [[specification, [modality, [naf, ['{it is not provable that}']], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [flies]]]]]], ['.']]], '2006-07-23-14-42-09', amadeus, '').
text_drs_eval(0, 1465, 'It is not the case that it is not provable that John flies.', drs([], []), [], '2007-12-14-17-17-31', '130.60.155.177', '').
text_drs_eval(0, 1466, 'John sees Mary. Mary is seen by John.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, see, A, B)-1, predicate(D, see, A, B)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [pname, ['Mary']]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [seen]], [np, [pname, ['John']]]]]], ['.']]], '2006-07-23-14-43-15', amadeus, '').
text_drs_eval(0, 1467, 'John does not have to be seen by Mary.', drs([], [-drs([], [must(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/7]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'not have to be'], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-21', '89.206.64.27', '').
text_drs_eval(0, 1468, 'John has to be seen by Mary.', drs([], [must(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/5]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, 'has to be'], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-27', '89.206.64.27', '').
text_drs_eval(0, 1469, 'John must be seen by Mary.', drs([], [must(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/4]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, must, be], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-32', '89.206.64.27', '').
text_drs_eval(0, 1470, 'John can be seen by Mary.', drs([], [can(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/4]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, be], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-37', '89.206.64.27', '').
text_drs_eval(0, 1471, 'John cannot be seen by Mary.', drs([], [-drs([], [can(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/5]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, 'not be'], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-43', '89.206.64.27', '').
text_drs_eval(0, 1472, 'John can not be seen by Mary.', drs([], [-drs([], [can(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/5]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, 'not be'], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-48', '89.206.64.27', '').
text_drs_eval(0, 1473, 'John can\'t be seen by Mary.', drs([], [-drs([], [can(drs([A], [predicate(A, see, named('Mary'), named('John'))-1/5]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, 'not be'], [vbar, [vcompl, [v, seen], by, [np, [pname, 'Mary']]]]]], '.']], '2010-10-27-09-21-54', '89.206.64.27', '').
text_drs_eval(0, 1474, 'Nobody believes that he does not have to be seen by everybody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [predicate(B, believe, A, C)-1/3, C:drs([], [-drs([], [must(drs([], [drs([D], [object(D, somebody, countable, na, eq, 1)-1/14])=>drs([E], [predicate(E, see, D, A)-1/11])]))])])])])]), [[specification, [s, [np, [pn, nobody]], [vp, [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, does, 'not have to be'], [vbar, [vcompl, [v, seen], by, [np, [pn, everybody]]]]]]]]]], '.']], '2010-10-27-09-21-59', '89.206.64.27', '').
text_drs_eval(0, 1475, 'Nobody believes that he has to be seen by everybody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [predicate(B, believe, A, C)-1/3, C:drs([], [must(drs([], [drs([D], [object(D, somebody, countable, na, eq, 1)-1/12])=>drs([E], [predicate(E, see, D, A)-1/9])]))])])])]), [[specification, [s, [np, [pn, nobody]], [vp, [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, 'has to be'], [vbar, [vcompl, [v, seen], by, [np, [pn, everybody]]]]]]]]]], '.']], '2010-10-27-09-22-06', '89.206.64.27', '').
text_drs_eval(0, 1476, 'Nobody believes that he must be seen by everybody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [predicate(B, believe, A, C)-1/3, C:drs([], [must(drs([], [drs([D], [object(D, somebody, countable, na, eq, 1)-1/11])=>drs([E], [predicate(E, see, D, A)-1/8])]))])])])]), [[specification, [s, [np, [pn, nobody]], [vp, [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, must, be], [vbar, [vcompl, [v, seen], by, [np, [pn, everybody]]]]]]]]]], '.']], '2010-10-27-09-22-13', '89.206.64.27', '').
text_drs_eval(0, 1477, 'Nobody believes that he can be seen by everybody.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [predicate(B, believe, A, C)-1/3, C:drs([], [can(drs([], [drs([D], [object(D, somebody, countable, na, eq, 1)-1/11])=>drs([E], [predicate(E, see, D, A)-1/8])]))])])])]), [[specification, [s, [np, [pn, nobody]], [vp, [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, can, be], [vbar, [vcompl, [v, seen], by, [np, [pn, everybody]]]]]]]]]], '.']], '2010-10-27-09-22-18', '89.206.64.27', '').
text_drs_eval(0, 1478, 'John does wait. John waits.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, A)-1, predicate(C, wait, A)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [aux, [does]], [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-07-23-14-49-20', amadeus, '').
text_drs_eval(0, 1479, 'It is possible that a card is valid.', drs([], [can(drs([A, B, C], [object(A, card, countable, na, eq, 1)-1/6, property(B, valid, pos)-1/8, predicate(C, be, A, B)-1/7]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]]], '.']], '2010-10-27-09-22-31', '89.206.64.27', '').
text_drs_eval(0, 1480, 'There is a dog. It of a man waits.', drs([], []), [], '2006-07-23-15-42-28', amadeus, '').
text_drs_eval(0, 1481, 'Everything a dog of which barks waits.', drs([], [drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, relation(A, of, C)-1, predicate(B, bark, A)-1, object(C, something, dom, na, na, na)-1])=>drs([D], [predicate(D, wait, C)-1])]), [[specification, [s, [nbar, [pn, [everything]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [vp, [vbar, [v, [barks]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-07-23-19-54-16', amadeus, '').
text_drs_eval(0, 1482, 'It is not the case that everybody waits.', drs([], []), [[specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [every]], [nbar, [n, ['$body']]]], [vp, [vbar, [v, [waits]], [np, [[]]]]]]]]]]], ['.']]], '2007-12-14-17-17-53', '130.60.155.177', '').
text_drs_eval(0, 1483, 'It is not provable that John waits and that Mary sleeps.', drs([A, B], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, ~drs([C, D], [predicate(C, wait, A)-1, predicate(D, sleep, B)-1])]), [[specification, [modality, [naf, ['{it is not provable}']], [comp, [that], [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], [coord, [and]], [comp, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]]]], ['.']]], '2006-07-25-15-30-56', amadeus, '').
text_drs_eval(0, 1484, 'It is not provable that John waits or that Mary sleeps.', drs([A, B], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, ~drs([], [drs([C], [predicate(C, wait, A)-1])v drs([D], [predicate(D, sleep, B)-1])])]), [[specification, [modality, [naf, ['{it is not provable}']], [s_coord, [comp, [that], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]]], [coord, [or]], [comp, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]]], ['.']]], '2006-07-25-15-31-11', amadeus, '').
text_drs_eval(0, 1485, 'It is necessary that John waits or that Mary sleeps.', drs([], [must(drs([], [drs([A], [predicate(A, wait, named('John'))-1/6])v drs([B], [predicate(B, sleep, named('Mary'))-1/10])]))]), [[specification, [s, [necessity, 'it is necessary'], [s_coord, [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]], [coord, or], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]], '.']], '2010-10-27-09-22-36', '89.206.64.27', '').
text_drs_eval(0, 1486, 'It is necessary that John waits and that Mary sleeps.', drs([], [must(drs([A, B], [predicate(A, wait, named('John'))-1/6, predicate(B, sleep, named('Mary'))-1/10]))]), [[specification, [s, [necessity, 'it is necessary'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], [coord, and], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2010-10-27-09-22-41', '89.206.64.27', '').
text_drs_eval(0, 1487, 'It is not necessary that John waits and that Mary sleeps.', drs([], [-drs([], [must(drs([A, B], [predicate(A, wait, named('John'))-1/7, predicate(B, sleep, named('Mary'))-1/11]))])]), [[specification, [s, [unnecessity, 'it is not necessary'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], [coord, and], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2010-10-27-09-22-45', '89.206.64.27', '').
text_drs_eval(0, 1488, 'It is not the case that it is necessary that John waits and that Mary sleeps.', drs([], []), [], '2007-12-14-17-18-10', '130.60.155.177', '').
text_drs_eval(0, 1489, 'It is possible that John waits and that Mary sleeps.', drs([], [can(drs([A, B], [predicate(A, wait, named('John'))-1/6, predicate(B, sleep, named('Mary'))-1/10]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], [coord, and], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2010-10-27-09-22-51', '89.206.64.27', '').
text_drs_eval(0, 1490, 'It is possible that John waits and Mary sleeps.', drs([A], [can(drs([B], [predicate(B, wait, named('John'))-1/6])), predicate(A, sleep, named('Mary'))-1/9]), [[specification, [s_coord, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], [coord, and], [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]], '.']], '2010-10-27-09-22-56', '89.206.64.27', '').
text_drs_eval(0, 1491, 'It is not possible that John waits and Mary sleeps.', drs([A], [-drs([], [can(drs([B], [predicate(B, wait, named('John'))-1/7]))]), predicate(A, sleep, named('Mary'))-1/10]), [[specification, [s_coord, [s, [impossibility, 'it is not possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], [coord, and], [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]], '.']], '2010-10-27-09-23-01', '89.206.64.27', '').
text_drs_eval(0, 1492, 'A man knows that a dog barks and that a cat eats a cake.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, know, A, C)-1, C:drs([D, E, F, G, H], [object(D, dog, countable, na, eq, 1)-1, predicate(E, bark, D)-1, object(F, cat, countable, na, eq, 1)-1, object(G, cake, countable, na, eq, 1)-1, predicate(H, eat, F, G)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [comp, [that], [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [eats]], [np, [det, [a]], [nbar, [n, [cake]]]]]]]]]]]]], ['.']]], '2006-07-25-16-32-31', amadeus, '').
text_drs_eval(0, 1493, 'A man knows that a dog barks and a cat eats a cake.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, predicate(B, know, A, C)-1, C:drs([G, H], [object(G, dog, countable, na, eq, 1)-1, predicate(H, bark, G)-1]), object(D, cat, countable, na, eq, 1)-1, object(E, cake, countable, na, eq, 1)-1, predicate(F, eat, D, E)-1]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [eats]], [np, [det, [a]], [nbar, [n, [cake]]]]]]]], ['.']]], '2006-07-25-16-41-43', amadeus, '').
text_drs_eval(0, 1494, 'Not for every man a dog barks.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])]), [[specification, [neg_s, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2006-07-25-16-09-11', amadeus, '').
text_drs_eval(0, 1495, 'Not for every man that a dog barks.', drs([], []), [], '2007-08-15-15-31-55', '130.60.155.177', '').
text_drs_eval(0, 1496, 'Not somebody waits.', drs([], []), [], '2007-08-08-09-57-43', '130.60.155.231', '').
text_drs_eval(0, 1497, 'Not every man waits.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, wait, A)-1])])]), [[specification, [s, [np, [det, ['{not every}']], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-07-25-16-14-49', amadeus, '').
text_drs_eval(0, 1498, 'A man does not know that a dog barks and that a cat eats a cake.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B, C], [predicate(B, know, A, C)-1, C:drs([D, E, F, G, H], [object(D, dog, countable, na, eq, 1)-1, predicate(E, bark, D)-1, object(F, cat, countable, na, eq, 1)-1, object(G, cake, countable, na, eq, 1)-1, predicate(H, eat, F, G)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, ['{does not}']], [vbar, [v, [know]], [comp, [that], [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [eats]], [np, [det, [a]], [nbar, [n, [cake]]]]]]]]]]]]], ['.']]], '2006-07-25-16-33-00', amadeus, '').
text_drs_eval(0, 1499, 'John believes that Mary sleeps and he waits.', drs([A, B, C, D, E], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, believe, A, D)-1, D:drs([F], [predicate(F, sleep, B)-1]), predicate(E, wait, A)-1]), [[specification, [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [believes]], [comp, [that], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2006-07-25-16-41-15', amadeus, '').
text_drs_eval(0, 1500, 'John believes that Mary sleeps and waits.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, believe, A, D)-1, D:drs([E, F], [predicate(E, sleep, B)-1, predicate(F, wait, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [believes]], [comp, [that], [s, [np, [pname, ['Mary']]], [vp_coord, [vp, [vbar, [v, [sleeps]]]], [coord, [and]], [vp, [vbar, [v, [waits]]]]]]]]]], ['.']]], '2006-07-25-16-41-22', amadeus, '').
text_drs_eval(0, 1501, 'A man does not know that a dog barks and a cat eats a cake.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, -drs([E, F], [predicate(E, know, A, F)-1, F:drs([G, H], [object(G, dog, countable, na, eq, 1)-1, predicate(H, bark, G)-1])]), object(B, cat, countable, na, eq, 1)-1, object(C, cake, countable, na, eq, 1)-1, predicate(D, eat, B, C)-1]), [[specification, [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, ['{does not}']], [vbar, [v, [know]], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [eats]], [np, [det, [a]], [nbar, [n, [cake]]]]]]]], ['.']]], '2006-07-25-16-42-14', amadeus, '').
text_drs_eval(0, 1502, 'A man can be rich.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, can(drs([B, C], [property(B, rich, pos)-1/5, predicate(C, be, A, B)-1/3]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, be], [ap_coord, [ap, [adj, rich]]]]], '.']], '2010-10-27-09-23-11', '89.206.64.27', '').
text_drs_eval(0, 1503, 'A man must be rich.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, must(drs([B, C], [property(B, rich, pos)-1/5, predicate(C, be, A, B)-1/3]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, must, be], [ap_coord, [ap, [adj, rich]]]]], '.']], '2010-10-27-09-23-17', '89.206.64.27', '').
text_drs_eval(0, 1504, 'A man can\'t be rich.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B, C], [property(B, rich, pos)-1/6, predicate(C, be, A, B)-1/3]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, 'not be'], [ap_coord, [ap, [adj, rich]]]]], '.']], '2010-10-27-09-23-23', '89.206.64.27', '').
text_drs_eval(0, 1505, 'A man does not have to be rich.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [must(drs([B, C], [property(B, rich, pos)-1/8, predicate(C, be, A, B)-1/3]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, 'not have to be'], [ap_coord, [ap, [adj, rich]]]]], '.']], '2010-10-27-09-23-28', '89.206.64.27', '').
text_drs_eval(0, 1506, 'Some men does not have to be rich.', drs([], []), [], '2006-07-26-13-56-03', amadeus, '').
text_drs_eval(0, 1507, 'Some men do not have to be rich.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, -drs([], [must(drs([B, C], [property(B, rich, pos)-1/8, predicate(C, be, A, B)-1/3]))])]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, do, 'not have to be'], [ap_coord, [ap, [adj, rich]]]]], '.']], '2010-10-27-09-23-35', '89.206.64.27', '').
text_drs_eval(0, 1508, 'Something "Go!" waits.', drs([], []), [], '2007-04-10-15-46-43', '130.60.155.177', '').
text_drs_eval(0, 1509, 'Some sand "Go!" waits.', drs([], []), [], '2007-04-10-15-46-52', '130.60.155.177', '').
text_drs_eval(0, 1510, 'If somebody X is a person and X is a female then X is a woman.', drs([], [drs([A, B, C, D, E], [object(A, somebody, countable, na, eq, 1)-1, object(B, person, countable, na, eq, 1)-1, predicate(C, be, A, B)-1, object(D, female, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])=>drs([F, G], [object(F, woman, countable, na, eq, 1)-1, predicate(G, be, A, F)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [person]]]]]]], [coord, [and]], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [female]]]]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [woman]]]]]]]], ['.']]], '2006-08-14-19-45-34', amadeus, '').
text_drs_eval(0, 1511, 'Somebody and something wait.', drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, wait, D)-1, object(C, something, dom, na, na, na)-1, has_part(D, A)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [pn, [somebody]]], [coord, [and]], [np, [pn, [something]]]], [vp, [vbar, [v, [wait]]]]]], '2007-09-26-17-06-37', '130.60.155.177', '').
text_drs_eval(0, 1512, 'Everybody "Go!" of John waits.', drs([], []), [], '2007-04-10-15-47-00', '130.60.155.177', '').
text_drs_eval(0, 1513, 'A man is a dog and a cat.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, has_part(E, B)-1, predicate(C, be, A, E)-1, object(D, cat, countable, na, eq, 1)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2007-12-23-12-02-09', '130.60.204.35', '').
text_drs_eval(0, 1514, 'A man can give a woman an apple.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, can(drs([B, C, D], [object(B, woman, countable, na, eq, 1)-1/6, object(C, apple, countable, na, eq, 1)-1/8, predicate(D, give, A, C, B)-1/4]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, give], [np, [det, a], [nbar, [n, woman]]], [np, [det, an], [nbar, [n, apple]]]]]]], '.']], '2010-10-27-09-23-41', '89.206.64.27', '').
text_drs_eval(0, 1515, 'A man can\'t give a woman an apple.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B, C, D], [object(B, woman, countable, na, eq, 1)-1/7, object(C, apple, countable, na, eq, 1)-1/9, predicate(D, give, A, C, B)-1/5]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vcompl, [v, give], [np, [det, a], [nbar, [n, woman]]], [np, [det, an], [nbar, [n, apple]]]]]]], '.']], '2010-10-27-09-23-47', '89.206.64.27', '').
text_drs_eval(0, 1516, 'There is a man who can eat. The man who can eat drinks.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, can(drs([C], [predicate(C, eat, A)-1/7])), predicate(B, drink, A)-2/6]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, eat]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, eat]]]]]]], [vp, [vbar, [vbar, [v, drinks]]]]], '.']], '2010-10-27-09-23-53', '89.206.64.27', '').
text_drs_eval(0, 1517, 'There is a man who does not have to eat. The man who does not have to eat drinks.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, -drs([], [must(drs([C], [predicate(C, eat, A)-1/10]))]), predicate(B, drink, A)-2/9]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, 'not have to'], [vbar, [vbar, [v, eat]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, 'not have to'], [vbar, [vbar, [v, eat]]]]]]], [vp, [vbar, [vbar, [v, drinks]]]]], '.']], '2010-10-27-09-24-00', '89.206.64.27', '').
text_drs_eval(0, 1518, 'There is a man who knows that a dog barks. The man who knows that a dog barks waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, know, A, C)-1, C:drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1]), predicate(D, wait, A)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, knows], [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, knows], [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-17-10-50-21', '84.74.167.232', '').
text_drs_eval(0, 1519, 'Does a man enter no card manually?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/3, drs([B], [object(B, card, countable, na, eq, 1)-1/6])=>drs([], [-drs([C], [predicate(C, enter, A, B)-1/4, modifier_adv(C, manually, pos)-1/7])])]))]), [[sentence, [query, [question, does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, no], [nbar, [n, card]]]], [vmod, [adv, manually]]]]], ?], '.']], '2009-05-13-14-10-28', '130.60.155.193', '').
text_drs_eval(0, 1520, 'Does a man enter every card manually?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/3, drs([B], [object(B, card, countable, na, eq, 1)-1/6])=>drs([C], [predicate(C, enter, A, B)-1/4, modifier_adv(C, manually, pos)-1/7])]))]), [[sentence, [query, [question, does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, every], [nbar, [n, card]]]], [vmod, [adv, manually]]]]], ?], '.']], '2009-05-13-14-10-29', '130.60.155.193', '').
text_drs_eval(0, 1521, 'Where does a man enter no card?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4, drs([B], [object(B, card, countable, na, eq, 1)-1/7])=>drs([], [-drs([C], [predicate(C, enter, A, B)-1/5, query(C, where)-1/1])])]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, no], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-14-10-30', '130.60.155.193', '').
text_drs_eval(0, 1522, 'Where does a man enter every card?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4, drs([B], [object(B, card, countable, na, eq, 1)-1/7])=>drs([C], [predicate(C, enter, A, B)-1/5, query(C, where)-1/1])]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, every], [nbar, [n, card]]]]]]], ?], '.']], '2009-05-13-14-10-31', '130.60.155.193', '').
text_drs_eval(0, 1523, 'A man runs manually and quickly manually and quickly.', drs([], []), [], '2006-07-27-18-43-22', amadeus, '').
text_drs_eval(0, 1524, 'A man runs fast.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [fast]]]]], ['.']]], '2006-07-27-19-09-17', amadeus, '').
text_drs_eval(0, 1525, 'A man runs in a park.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, run, A)-1, modifier_pp(C, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]]]]], ['.']]], '2006-07-27-19-09-32', amadeus, '').
text_drs_eval(0, 1526, 'A man runs fast and quickly.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, quickly, pos)-1, modifier_adv(B, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv_coord, [adv, [fast]], [coord, [and]], [adv, [quickly]]]]]], ['.']]], '2006-07-27-19-09-54', amadeus, '').
text_drs_eval(0, 1527, 'A man runs in a park in a morning.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, morning, countable, na, eq, 1)-1, object(C, park, countable, na, eq, 1)-1, predicate(D, run, A)-1, modifier_pp(D, in, B)-1, modifier_pp(D, in, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]]]]], ['.']]], '2006-07-27-19-10-10', amadeus, '').
text_drs_eval(0, 1528, 'A man runs fast in a park.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, run, A)-1, modifier_pp(C, in, B)-1, modifier_adv(C, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [fast]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]]]]], ['.']]], '2006-07-27-19-10-34', amadeus, '').
text_drs_eval(0, 1529, 'A man runs fast and quickly and manually.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, manually, pos)-1, modifier_adv(B, quickly, pos)-1, modifier_adv(B, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv_coord, [adv, [fast]], [coord, [and]], [adv_coord, [adv, [quickly]], [coord, [and]], [adv, [manually]]]]]]], ['.']]], '2006-07-27-19-11-29', amadeus, '').
text_drs_eval(0, 1530, 'A man runs in a park in a morning in a hurry.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, hurry, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, object(D, park, countable, na, eq, 1)-1, predicate(E, run, A)-1, modifier_pp(E, in, B)-1, modifier_pp(E, in, C)-1, modifier_pp(E, in, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [hurry]]]]]]]], ['.']]], '2006-07-27-19-12-03', amadeus, '').
text_drs_eval(0, 1531, 'A man runs fast in a morning in a hurry.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, hurry, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, predicate(D, run, A)-1, modifier_pp(D, in, B)-1, modifier_pp(D, in, C)-1, modifier_adv(D, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [fast]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [hurry]]]]]]]], ['.']]], '2006-07-27-19-12-28', amadeus, '').
text_drs_eval(0, 1532, 'A man runs in a park fast in a hurry.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, hurry, countable, na, eq, 1)-1, object(C, park, countable, na, eq, 1)-1, predicate(D, run, A)-1, modifier_pp(D, in, B)-1, modifier_adv(D, fast, pos)-1, modifier_pp(D, in, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [adv, [fast]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [hurry]]]]]]]], ['.']]], '2006-07-27-19-12-50', amadeus, '').
text_drs_eval(0, 1533, 'A man runs in a park in a morning fast.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, morning, countable, na, eq, 1)-1, object(C, park, countable, na, eq, 1)-1, predicate(D, run, A)-1, modifier_adv(D, fast, pos)-1, modifier_pp(D, in, B)-1, modifier_pp(D, in, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]], [adv, [fast]]]]], ['.']]], '2006-07-27-19-13-29', amadeus, '').
text_drs_eval(0, 1534, 'A man runs fast and quickly in a park.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, run, A)-1, modifier_pp(C, in, B)-1, modifier_adv(C, quickly, pos)-1, modifier_adv(C, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv_coord, [adv, [fast]], [coord, [and]], [adv, [quickly]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]]]]], ['.']]], '2006-07-27-19-13-54', amadeus, '').
text_drs_eval(0, 1535, 'A man runs fast in a park manually.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, run, A)-1, modifier_adv(C, manually, pos)-1, modifier_pp(C, in, B)-1, modifier_adv(C, fast, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [fast]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [adv, [manually]]]]], ['.']]], '2006-07-27-19-14-33', amadeus, '').
text_drs_eval(0, 1536, 'A man runs in a park fast and manually.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, run, A)-1, modifier_pp(C, in, B)-1, modifier_adv(C, fast, pos)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [runs]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [adv_coord, [adv, [fast]], [coord, [and]], [adv, [manually]]]]]], ['.']]], '2007-07-04-13-36-03', '130.60.206.45', '').
text_drs_eval(0, 1537, 'There is a card of John that is correct.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, relation(B, of, A)-1, property(C, correct, pos)-1, predicate(D, be, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pname, ['John']], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]]]]]]]], ['.']]], '2007-08-08-11-10-57', '130.60.155.231', '').
text_drs_eval(0, 1538, 'There is a case of some beer. It is not the case.', drs([A, B], [object(A, case, countable, na, eq, 1)-1, object(B, beer, mass, na, na, na)-1, relation(A, of, B)-1, -drs([C], [predicate(C, be, B, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [case]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [beer]]]]]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]]]]]]], ['.']]], '2006-08-01-18-33-59', amadeus, '').
text_drs_eval(0, 1539, 'It is false that a man waits.', drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2006-08-02-13-40-02', amadeus, '').
text_drs_eval(0, 1540, 'It is not true that a man waits.', drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [comp, [that], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2006-08-02-13-40-16', amadeus, '').
text_drs_eval(0, 1541, 'Every man that is not liked by a woman that owns a dog sees a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B, C, D, E], [object(B, woman, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, predicate(E, like, B, A)-1])])=>drs([F, G], [object(F, cat, countable, na, eq, 1)-1, predicate(G, see, A, F)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [aux, ['{is not}']], [vbar, [v, [liked]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2006-08-10-19-51-22', amadeus, '').
text_drs_eval(0, 1542, 'It is possible that it is false that a dog sees a cat.', drs([], [can(drs([], [-drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1/10, object(B, cat, countable, na, eq, 1)-1/13, predicate(C, see, A, B)-1/11])]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [neg, 'it is false'], [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat]]]]]]]]]]], '.']], '2010-10-27-09-24-06', '89.206.64.27', '').
text_drs_eval(0, 1543, 'Every man who must hate a dog can own a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2, must(drs([B, C], [object(B, dog, countable, na, eq, 1)-1/7, predicate(C, hate, A, B)-1/5]))])=>drs([], [can(drs([D, E], [object(D, cat, countable, na, eq, 1)-1/11, predicate(E, own, A, D)-1/9]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, must], [vbar, [vcompl, [v, hate], [np, [det, a], [nbar, [n, dog]]]]]]]]], [vp, [aux, can], [vbar, [vcompl, [v, own], [np, [det, a], [nbar, [n, cat]]]]]]], '.']], '2010-10-27-09-24-11', '89.206.64.27', '').
text_drs_eval(0, 1544, 'If a man must own a dog then the man can own an animal.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/3, must(drs([B, C], [object(B, dog, countable, na, eq, 1)-1/7, predicate(C, own, A, B)-1/5]))])=>drs([], [can(drs([D, E], [object(D, animal, countable, na, eq, 1)-1/14, predicate(E, own, A, D)-1/12]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, must], [vbar, [vcompl, [v, own], [np, [det, a], [nbar, [n, dog]]]]]]], then, [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, own], [np, [det, an], [nbar, [n, animal]]]]]]]], '.']], '2010-10-27-09-24-16', '89.206.64.27', '').
text_drs_eval(0, 1545, 'It is false _that_ a man waits.', drs([], []), [], '2009-04-02-13-13-24', '130.60.155.206', '').
text_drs_eval(0, 1546, 'John knows _that_ Mary sleeps.', drs([], []), [], '2009-04-02-13-13-29', '130.60.155.206', '').
text_drs_eval(0, 1547, 'John knows proposition P _that_ Mary sleeps.', drs([], []), [], '2006-08-12-18-46-00', amadeus, '').
text_drs_eval(0, 1548, 'John knows proposition P _that_ Mary sleeps. P holds.', drs([], []), [], '2006-08-12-18-46-09', amadeus, '').
text_drs_eval(0, 1549, 'John knows Proposition P _that_ Mary sleeps.', drs([], []), [], '2006-08-12-18-46-27', amadeus, '').
text_drs_eval(0, 1550, 'How does a man sell a visa card?', drs([], []), [], '2006-08-15-15-15-15', amadeus, '').
text_drs_eval(0, 1551, 'John knows Proposition P quickly that Mary sleeps.', drs([], []), [], '2006-08-12-18-47-00', amadeus, '').
text_drs_eval(0, 1552, 'John knows Proposition P that Mary sleeps.', drs([], []), [], '2006-08-14-20-10-59', amadeus, '').
text_drs_eval(0, 1553, 'John wisely knows Proposition P in the morning that Mary sleeps. P holds in the evening.', drs([], []), [], '2006-08-12-18-47-35', amadeus, '').
text_drs_eval(0, 1554, 'John sees in the morning _that_ Mary sleeps.', drs([], []), [], '2009-04-02-13-13-35', '130.60.155.206', '').
text_drs_eval(0, 1555, 'John sees in the morning that Mary sleeps.', drs([A, B, C, D, E], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, see, A)-1, modifier_pp(C, in, D)-1, predicate(E, sleep, B, D)-1, object(D, morning, countable, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [sees]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [morning]], [rel_cl, [comp, [that]], [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]], [np, [[]]]]]]]]]]]], ['.']]], '2006-08-04-10-31-41', amadeus, '').
text_drs_eval(0, 1556, 'John wisely knows Proposition P in the park _that_ Mary sleeps.', drs([], []), [], '2006-08-12-18-47-50', amadeus, '').
text_drs_eval(0, 1557, 'John knows in the park that Mary sleeps.', drs([A, B, C, D, E], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, know, A)-1, modifier_pp(C, in, D)-1, predicate(E, sleep, B, D)-1, object(D, park, countable, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [knows]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [park]], [rel_cl, [comp, [that]], [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]], [np, [[]]]]]]]]]]]], ['.']]], '2006-08-04-10-33-12', amadeus, '').
text_drs_eval(0, 1558, 'John wisely knows Proposition P in the park that Mary sleeps.', drs([], []), [], '2006-08-14-20-10-31', amadeus, '').
text_drs_eval(0, 1559, 'John is a customer of someone who is important.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, customer, countable, na, eq, 1)-1, object(C, somebody, countable, na, eq, 1)-1, relation(B, of, C)-1, property(D, important, pos)-1, predicate(E, be, C, D)-1, predicate(F, be, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [customer]], [pp, [prep, [of]], [nbar, [pn, [someone]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [important]]]]]]]]]]]]]], ['.']]], '2007-08-08-11-11-20', '130.60.155.231', '').
text_drs_eval(0, 1560, 'Someone is a brother of a man X and X waits.', drs([A, B, C, D, E], [object(A, somebody, countable, na, eq, 1)-1, object(B, brother, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, relation(B, of, C)-1, predicate(D, be, A, B)-1, predicate(E, wait, C)-1]), [[specification, [s_coord, [s, [np, [pn, [someone]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [brother]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]]]]]], [coord, [and]], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2006-08-20-17-26-06', amadeus, '').
text_drs_eval(0, 1561, 'A dog is more active than a cat.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, property(C, active, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['more active']], [conj, [than]], [np, [det, [a]], [nbar, [n, [cat]]]]]|E]]]], ['.']]], '2007-05-09-12-13-31', '130.60.156.229', '').
text_drs_eval(0, 1562, 'A man is more interested-in a cat.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, property(C, 'interested-in', comp, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more, 'interested-in']], [np, [det, [a]], [nbar, [n, [cat]]]]]|E]]]], ['.']]], '2007-06-12-10-42-14', '130.60.156.66', '').
text_drs_eval(0, 1563, 'A man is more interested-in a cat than a dog.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, property(D, 'interested-in', B, comp_than, subj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more, 'interested-in']], [np, [det, [a]], [nbar, [n, [cat]]]], [than], [np, [det, [a]], [nbar, [n, [dog]]]]]|F]]]], ['.']]], '2007-06-12-10-42-25', '130.60.156.66', '').
text_drs_eval(0, 1564, 'A man is more interested-in a cat than in a dog.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, property(D, 'interested-in', B, comp_than, obj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more, 'interested-in']], [np, [det, [a]], [nbar, [n, [cat]]]], [than], [in], [np, [det, [a]], [nbar, [n, [dog]]]]]|F]]]], ['.']]], '2007-06-12-10-42-36', '130.60.156.66', '').
text_drs_eval(0, 1565, 'A car runs more speedily than a bike.', drs([], []), [], '2007-06-12-10-43-10', '130.60.156.66', '').
text_drs_eval(0, 1566, 'A car runs more speedily.', drs([A, B], [object(A, car, countable, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, speedily, comp)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [car]]]], [vp, [vbar, [vbar, [v, [runs]]], [adv, [more, speedily]]]]], ['.']]], '2007-06-12-10-43-21', '130.60.156.66', '').
text_drs_eval(0, 1567, 'A dog is more good than a cat.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, property(C, good, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more, good]], [conj, [than]], [np, [det, [a]], [nbar, [n, [cat]]]]]|E]]]], ['.']]], '2007-06-12-10-43-31', '130.60.156.66', '').
text_drs_eval(0, 1568, 'A dog is better than a cat.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, property(C, good, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [better]], [conj, [than]], [np, [det, [a]], [nbar, [n, [cat]]]]]|E]]]], ['.']]], '2007-05-09-12-13-36', '130.60.156.229', '').
text_drs_eval(0, 1569, 'John is more clever than Bill.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, property(C, clever, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['more clever']], [conj, [than]], [np, [pname, ['Bill']]]]|E]]]], ['.']]], '2007-05-09-12-13-44', '130.60.156.229', '').
text_drs_eval(0, 1570, 'John is cleverer than Bill.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, property(C, clever, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [cleverer]], [conj, [than]], [np, [pname, ['Bill']]]]|E]]]], ['.']]], '2007-05-09-12-13-50', '130.60.156.229', '').
text_drs_eval(0, 1571, 'It is false.', drs([], []), [[specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [false]]]]]]], ['.']]], '2006-08-14-20-09-38', amadeus, '').
text_drs_eval(0, 1572, 'There is proposition P that a dog barks.', drs([], []), [[specification, [prop, [quant, ['{there is}']], [p, [proposition]], 'P', [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2006-08-12-18-48-19', amadeus, '').
text_drs_eval(0, 1573, 'There is P _that_ a dog barks.', drs([], []), [], '2006-08-22-11-51-32', amadeus, '').
text_drs_eval(0, 1574, 'There is Proposition P _that_ a dog barks. A man knows P.', drs([], []), [[specification, [prop, [quant, ['{there is}']], [p, [proposition]], 'P', [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [np, [np, [var, ['P']]]]]]], ['.']]], '2006-08-20-15-33-26', amadeus, '').
text_drs_eval(0, 1575, 'Every man who loves a woman who loves the man owns a car.', drs([], [drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(C, love, B, A)-1, predicate(D, love, A, B)-1])=>drs([E, F], [object(E, car, countable, na, eq, 1)-1, predicate(F, own, A, E)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [loves]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [loves]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]], ['.']]], '2006-08-04-22-39-04', amadeus, '').
text_drs_eval(0, 1576, 'Everybody who is not an animal is not a dog.', drs([], [drs([A], [-drs([B, C], [object(B, animal, countable, na, eq, 1)-1, predicate(C, be, A, B)-1]), object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [animal]]]]]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-05-17-57-59', amadeus, '').
text_drs_eval(0, 1577, 'Everything that is not a cat can be a dog.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1/2, -drs([B, C], [object(B, cat, countable, na, eq, 1)-1/7, predicate(C, be, A, B)-1/4])])=>drs([], [can(drs([D, E], [object(D, dog, countable, na, eq, 1)-1/11, predicate(E, be, A, D)-1/8]))])]), [[specification, [s, [np, [pn, everything], [rel_cl, [comp, that], [vp, [aux, is, not], [np, [det, a], [nbar, [n, cat]]]]]], [vp, [aux, can, be], [np, [det, a], [nbar, [n, dog]]]]], '.']], '2010-10-27-09-24-22', '89.206.64.27', '').
text_drs_eval(0, 1578, 'Every man who is not liked by a woman who owns a dog sees a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B, C, D, E], [object(B, woman, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, predicate(E, like, B, A)-1])])=>drs([F, G], [object(F, cat, countable, na, eq, 1)-1, predicate(G, see, A, F)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [aux, ['{is not}']], [vbar, [v, [liked]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2006-08-05-21-00-51', amadeus, '').
text_drs_eval(0, 1579, 'There is a man X. It is false that there is X.', drs([], []), [], '2006-08-20-17-23-38', amadeus, '').
text_drs_eval(0, 1580, 'There is a man X. It is false that there is the man.', drs([], []), [], '2006-08-05-21-08-39', amadeus, '').
text_drs_eval(0, 1581, 'There is a man X. It is false that there is a man.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B], [object(B, man, countable, na, eq, 1)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']], [specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-08-05-21-09-02', amadeus, '').
text_drs_eval(0, 1582, 'There is a man X. It is false that there is the man X.', drs([], []), [], '2006-08-17-18-18-58', amadeus, '').
text_drs_eval(0, 1583, 'A cat is feared by every mouse.', drs([A], [object(A, cat, countable, na, eq, 1)-1, drs([B], [object(B, mouse, countable, na, eq, 1)-1])=>drs([C], [predicate(C, fear, B, A)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [aux, [is]], [vbar, [v, [feared]], [np, [det, [every]], [nbar, [n, [mouse]]]]]]], ['.']]], '2006-08-07-12-12-03', amadeus, '').
text_drs_eval(0, 1584, 'Every man is not no dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, be, A, B)-1])])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [no]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-12-18-49-04', amadeus, '').
text_drs_eval(0, 1585, 'If there is a man then it is false that he owns a dog that does not bark.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, -drs([D], [predicate(D, bark, B)-1]), predicate(C, own, A, B)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [pn, [he]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [aux, ['{does not}']], [vbar, [v, [bark]]]]]]]]]]]]], ['.']]], '2006-08-12-22-16-04', amadeus, '').
text_drs_eval(0, 1586, 'Everybody does not know a dog that likes a cat.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, like, B, C)-1, predicate(E, know, A, B)-1])])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [aux, ['{does not}']], [vbar, [v, [know]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']]], '2006-08-07-15-41-10', amadeus, '').
text_drs_eval(0, 1587, 'Everybody who waits does not know a dog that likes a cat.', drs([], [drs([A, B], [predicate(A, wait, B)-1, object(B, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([C, D, E, F], [object(C, dog, countable, na, eq, 1)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, like, C, D)-1, predicate(F, know, B, C)-1])])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]], [vp, [aux, ['{does not}']], [vbar, [v, [know]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']]], '2006-08-07-15-42-26', amadeus, '').
text_drs_eval(0, 1588, 'Everybody does not know a dog that is liked by a cat.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, like, C, B)-1, predicate(E, know, A, B)-1])])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [aux, ['{does not}']], [vbar, [v, [know]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [aux, [is]], [vbar, [v, [liked]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']]], '2006-08-07-15-42-56', amadeus, '').
text_drs_eval(0, 1589, 'Everybody who somebody likes owns a dog.', drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, like, A, C)-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, own, C, D)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [np, [pn, [somebody]]], [vp, [vbar, [v, [likes]], [np, [[]]]]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-07-16-22-31', amadeus, '').
text_drs_eval(0, 1590, 'Everything that somebody likes is owned by somebody else.', drs([], []), [[specification, [s, [nbar, [pn, [everything]], [rel_cl, [comp, [that]], [np, [pn, [somebody]]], [vp, [vbar, [v, [likes]], [np, [[]]]]]]], [vp, [aux, [is]], [vbar, [v, [owned]], [np, [pn, [somebody]]]]]], ['.']]], '2006-08-12-18-49-38', amadeus, '').
text_drs_eval(0, 1591, 'John\'s age is 30.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1, predicate(C, be, B, int(30))-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [30]]]]]], ['.']]], '2007-09-01-16-54-44', '130.60.155.177', '').
text_drs_eval(0, 1592, 'A code is 1234.', drs([A, B], [object(A, code, countable, na, eq, 1)-1, predicate(B, be, A, int(1234))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [code]]]], [vp, [vbar, [v, [is]], [np, [int, [1234]]]]]], ['.']]], '2007-09-01-16-54-55', '130.60.155.177', '').
text_drs_eval(0, 1593, 'A text is "abcdef".', drs([A, B], [object(A, text, countable, na, eq, 1)-1, predicate(B, be, A, string(abcdef))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [text]]]], [vp, [vbar, [v, [is]], [np, [string, [abcdef]]]]]], ['.']]], '2007-09-01-16-35-06', '130.60.155.177', '').
text_drs_eval(0, 1594, '1234 is a code.', drs([A, B], [object(A, code, countable, na, eq, 1)-1, predicate(B, be, int(1234), A)-1]), [[specification, [s, [np, [int, [1234]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [code]]]]]]], ['.']]], '2007-09-01-16-58-18', '130.60.155.177', '').
text_drs_eval(0, 1595, 'Everybody A sees A who waits.', drs([], []), [], '2008-09-23-08-48-09', '130.60.155.206', '').
text_drs_eval(0, 1596, 'Everybody whose age is 31 is a grown-up.', drs([], [drs([A, B, C], [object(A, age, countable, na, eq, 1)-1, relation(A, of, C)-1, predicate(B, be, A, int(31))-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([D, E], [object(D, 'grown-up', countable, na, eq, 1)-1, predicate(E, be, C, D)-1])]), [[specification, [s, [np, [pn, [everybody]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['grown-up']]]]]]], ['.']]], '2007-09-01-16-58-41', '130.60.155.177', '').
text_drs_eval(0, 1597, 'Everybody whose age is 20 can drink some wine in Paris.', drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1/2, object(B, age, countable, na, eq, 1)-1/4, relation(B, of, A)-1/3, predicate(C, be, B, int(20))-1/5])=>drs([], [can(drs([D, E], [object(D, wine, mass, na, na, na)-1/10, predicate(E, drink, A, D)-1/8, modifier_pp(E, in, named('Paris'))-1/11]))])]), [[specification, [s, [np, [pn, everybody], [rel_cl, [np, [posspn, whose], [nbar, [n, age]]], [vp, [aux, is], [np, [int, 20]]]]], [vp, [aux, can], [vbar, [vcompl, [v, drink], [np, [det, some], [nbar, [n, wine]]]], [vmod, [pp, [prep, in], [np, [pname, 'Paris']]]]]]], '.']], '2010-10-27-09-24-32', '89.206.64.27', '').
text_drs_eval(0, 1598, 'If there is a man then a dog barks and bites the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, bite, B, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp_coord, [vp, [vbar, [v, [barks]]]], [coord, [and]], [vp, [vbar, [v, [bites]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], ['.']]], '2006-08-07-21-49-34', amadeus, '').
text_drs_eval(0, 1599, 'If there is a man then a dog that hates a cat barks and bites the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, hate, B, C)-1, predicate(E, bark, B)-1, predicate(F, bite, B, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], [vp_coord, [vp, [vbar, [v, [barks]]]], [coord, [and]], [vp, [vbar, [v, [bites]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], ['.']]], '2006-08-07-21-51-30', amadeus, '').
text_drs_eval(0, 1600, 'Every man that sleeps can be bitten by a dog that is known by a cat that drinks a milk and that is hated by the dog .', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, sleep, A)-1/4])=>drs([], [can(drs([C, D, E, F, G, H, I], [object(C, dog, countable, na, eq, 1)-1/10, object(D, cat, countable, na, eq, 1)-1/16, object(E, milk, countable, na, eq, 1)-1/20, predicate(F, drink, D, E)-1/18, predicate(G, hate, C, D)-1/24, predicate(H, know, D, C)-1/13, predicate(I, bite, C, A)-1/7]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, sleeps]]]]]]], [vp, [aux, can, be], [vbar, [vcompl, [v, bitten], by, [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, known], by, [np, [det, a], [nbar, [n, cat], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, drinks], [np, [det, a], [nbar, [n, milk]]]]]]], [coord, and], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, hated], by, [np, [det, the], [nbar, [n, dog]]]]]]]]]]]]]]]]]]]], '.']], '2010-10-27-09-24-38', '89.206.64.27', '').
text_drs_eval(0, 1601, 'The book is given by Mary.', drs([A, B, C], [object(A, 'Mary', named, na, eq, 1)-1, predicate(B, give, A, C)-1, object(C, book, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [given]], [np, [pname, ['Mary']]]]]], ['.']]], '2006-08-08-09-15-53', amadeus, '').
text_drs_eval(0, 1602, 'The book is given John by Mary.', drs([A, B, C, D], [object(B, 'Mary', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(C, give, B, A, D)-1, object(D, book, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [given]], [np, [pname, ['John']]], [by, [by]], [np, [pname, ['Mary']]]]]], ['.']]], '2006-08-14-20-00-34', amadeus, '').
text_drs_eval(0, 1603, 'The book is given by Mary to John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1, predicate(C, give, A, D)-1, modifier_pp(C, to, B)-1, object(D, book, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [vbar, [v, [given]], [by, [by]], [np, [pname, ['Mary']]]], [pp, [prep, [to]], [np, [pname, ['John']]]]]]], ['.']]], '2006-08-14-20-01-59', amadeus, '').
text_drs_eval(0, 1604, 'Every man can be bitten by a dog that hates a cat that likes the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [can(drs([B, C, D, E, F], [object(B, dog, countable, na, eq, 1)-1/8, object(C, cat, countable, na, eq, 1)-1/12, predicate(D, like, C, A)-1/14, predicate(E, hate, B, C)-1/10, predicate(F, bite, B, A)-1/5]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, can, be], [vbar, [vcompl, [v, bitten], by, [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, man]]]]]]]]]]]]]]]]]]], '.']], '2010-10-27-09-24-56', '89.206.64.27', '').
text_drs_eval(0, 1605, 'Every man who waits is not bitten by a dog that hates a cat that likes the man.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([], [-drs([C, D, E, F, G], [object(C, dog, countable, na, eq, 1)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, like, D, A)-1, predicate(F, hate, C, D)-1, predicate(G, bite, C, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]], [vp, [aux, ['{is not}']], [vbar, [v, [bitten]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]]]]]]]], ['.']]], '2006-08-08-18-53-42', amadeus, '').
text_drs_eval(0, 1606, 'If there are 2 men then they wait.', drs([], [drs([A], [object(A, man, countable, na, eq, 2)-1])=>drs([B], [predicate(B, wait, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]]]]]], [then], [s, [np, [pn, [they]]], [vp, [vbar, [v, [wait]]]]]], ['.']]], '2006-08-08-22-22-43', amadeus, '').
text_drs_eval(0, 1607, 'It is true that a dog barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1]), [[specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2006-08-09-14-48-26', amadeus, '').
text_drs_eval(0, 1608, 'It is not false that a dog barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1]), [[specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2006-08-09-14-48-47', amadeus, '').
text_drs_eval(0, 1609, 'All water runs.', drs([], [drs([A], [object(A, water, mass, na, na, na)-1])=>drs([B], [predicate(B, run, A)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [water]]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2006-08-09-16-03-49', amadeus, '').
text_drs_eval(0, 1610, 'All sand needs some water.', drs([], [drs([A], [object(A, sand, mass, na, na, na)-1])=>drs([B, C], [object(B, water, mass, na, na, na)-1, predicate(C, need, A, B)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [sand]]]], [vp, [vbar, [v, [needs]], [np, [det, [some]], [nbar, [n, [water]]]]]]], ['.']]], '2006-08-09-16-29-19', amadeus, '').
text_drs_eval(0, 1611, 'For no man a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{for no}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-08-15-16-00-50', '130.60.155.177', '').
text_drs_eval(0, 1612, 'No man is liked by a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, B, A)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [aux, [is]], [vbar, [v, [liked]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-10-12-03-46', amadeus, '').
text_drs_eval(0, 1613, 'Every man who waits is seen by himself.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C], [predicate(C, see, A, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]], [vp, [aux, [is]], [vbar, [v, [seen]], [np, [pn, [himself]]]]]], ['.']]], '2006-08-10-12-16-01', amadeus, '').
text_drs_eval(0, 1614, 'Every man likes himself and feeds a cat that sees the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [predicate(B, like, A, A)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, see, C, A)-1, predicate(E, feed, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [pn, [himself]]]]], [coord, [and]], [vp, [vbar, [v, [feeds]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]]]], ['.']]], '2006-08-10-12-38-02', amadeus, '').
text_drs_eval(0, 1615, 'Every man feeds a cat that sees the man and likes a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, B, A)-1, predicate(D, feed, A, B)-1, object(E, dog, countable, na, eq, 1)-1, predicate(F, like, A, E)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [feeds]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-08-10-12-38-52', amadeus, '').
text_drs_eval(0, 1616, 'Every man feeds a cat that sees the man and likes himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, B, A)-1, predicate(D, feed, A, B)-1, predicate(E, like, A, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [feeds]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [likes]], [np, [pn, [himself]]]]]]], ['.']]], '2007-01-22-13-25-46', '130.60.155.211', '').
text_drs_eval(0, 1617, 'Every man feeds a cat that sees the man and likes the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, B, A)-1, predicate(D, feed, A, B)-1, predicate(E, like, A, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [feeds]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-08-10-12-40-50', amadeus, '').
text_drs_eval(0, 1618, 'Every man X sees the man that waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D], [predicate(B, see, A, C)-1, predicate(D, wait, C)-1, object(C, man, countable, na, eq, 1)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]]], ['.']]], '2006-08-14-20-02-53', amadeus, '').
text_drs_eval(0, 1619, 'Every man X sees the man X that waits.', drs([], []), [[specification, [s, [np, [det, every], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [appos, [var, 'X']], [rel_cl, [comp, that], [vp, [vbar, [v, waits]]]]]]]]], '.']], '2008-08-15-20-25-36', '130.60.204.15', '').
text_drs_eval(0, 1620, 'Every man X sees X that waits.', drs([], []), [], '2008-09-23-08-48-18', '130.60.155.206', '').
text_drs_eval(0, 1621, 'If there is a man then the man sees a dog and the dog sees a cat and the cat sees the dog and the dog sees a rat and the rat sees a mouse.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G, H, I, J], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, see, B, D)-1, predicate(F, see, D, B)-1, object(G, rat, countable, na, eq, 1)-1, predicate(H, see, B, G)-1, object(I, mouse, countable, na, eq, 1)-1, predicate(J, see, G, I)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, [and]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], [coord, [and]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [rat]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]]]]]], ['.']]], '2007-08-14-20-21-51', '130.60.155.177', '').
text_drs_eval(0, 1622, 'Every man sees a dog X that sees a cat that sees X that sees a rat that sees a mouse.', drs([], []), [], '2008-09-23-08-48-29', '130.60.155.206', '').
text_drs_eval(0, 1623, 'If there is a man then the man sees a rat that sees a mouse and a cat sees the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G], [object(B, rat, countable, na, eq, 1)-1, object(C, mouse, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1, object(F, cat, countable, na, eq, 1)-1, predicate(G, see, F, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], ['.']]], '2007-08-14-20-22-42', '130.60.155.177', '').
text_drs_eval(0, 1624, 'Every man sees a cat that sees the man and sees a rat that sees a mouse.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G, H], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, B, A)-1, predicate(D, see, A, B)-1, object(E, rat, countable, na, eq, 1)-1, object(F, mouse, countable, na, eq, 1)-1, predicate(G, see, E, F)-1, predicate(H, see, A, E)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]]]]]]], ['.']]], '2007-08-14-20-23-05', '130.60.155.177', '').
text_drs_eval(0, 1625, 'Nobody knows nothing.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, something, dom, na, na, na)-1])=>drs([], [-drs([C], [predicate(C, know, A, B)-1])])])])]), [[specification, [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [knows]], [np, [pn, [nothing]]]]]], ['.']]], '2006-08-10-16-56-28', amadeus, '').
text_drs_eval(0, 1626, 'If there is a man then there is a dog and there is a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [and]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-08-10-20-26-05', amadeus, '').
text_drs_eval(0, 1627, 'If there is a dog then the dog barks and it is false that there is a cat.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B], [predicate(B, bark, A)-1, -drs([C], [object(C, cat, countable, na, eq, 1)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]], ['.']]], '2006-08-10-20-44-37', amadeus, '').
text_drs_eval(0, 1628, 'Every man likes a dog and hates a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [and]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-08-11-13-09-03', amadeus, '').
text_drs_eval(0, 1629, 'Every man likes a dog or hates a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-08-11-13-12-00', amadeus, '').
text_drs_eval(0, 1630, 'Every man does not like a dog or hates a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-08-11-13-12-21', amadeus, '').
text_drs_eval(0, 1631, 'Every man likes a dog or does not hate a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])v drs([], [-drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [aux, ['{does not}']], [vbar, [v, [hate]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-08-11-13-12-41', amadeus, '').
text_drs_eval(0, 1632, 'Every man does not like a dog or does not hate a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])])v drs([], [-drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [aux, ['{does not}']], [vbar, [v, [hate]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-08-11-13-13-04', amadeus, '').
text_drs_eval(0, 1633, 'Every man does not like a dog or hate a cat.', drs([], []), [], '2006-08-11-13-13-19', amadeus, '').
text_drs_eval(0, 1634, 'There is a man who waits. The man who also sleeps.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]|A], '2007-12-20-13-29-27', '130.60.155.231', '').
text_drs_eval(0, 1635, 'Every man who does not like a dog or who hates a cat waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])])=>drs([F], [predicate(F, wait, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-11-14-42-27', amadeus, '').
text_drs_eval(0, 1636, 'Every man who eats or who drinks waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, eat, A)-1])v drs([C], [predicate(C, drink, A)-1])])=>drs([D], [predicate(D, wait, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [drinks]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-11-14-44-43', amadeus, '').
text_drs_eval(0, 1637, 'Every man eats or drinks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, eat, A)-1])v drs([C], [predicate(C, drink, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [or]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2006-08-11-14-44-46', amadeus, '').
text_drs_eval(0, 1638, 'Every man does not eat or drinks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([], [-drs([B], [predicate(B, eat, A)-1])])v drs([C], [predicate(C, drink, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [aux, ['{does not}']], [vbar, [v, [eat]]]], [coord, [or]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2006-08-11-14-45-30', amadeus, '').
text_drs_eval(0, 1639, 'Every man eats or does not drink.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, eat, A)-1])v drs([], [-drs([C], [predicate(C, drink, A)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [or]], [vp, [aux, ['{does not}']], [vbar, [v, [drink]]]]]], ['.']]], '2006-08-11-14-45-40', amadeus, '').
text_drs_eval(0, 1640, 'Every man who eats or who does not drink waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, eat, A)-1])v drs([], [-drs([C], [predicate(C, drink, A)-1])])])=>drs([D], [predicate(D, wait, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [aux, ['{does not}']], [vbar, [v, [drink]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-11-14-46-10', amadeus, '').
text_drs_eval(0, 1641, 'Every man who does not eat or who drinks waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, drs([], [-drs([B], [predicate(B, eat, A)-1])])v drs([C], [predicate(C, drink, A)-1])])=>drs([D], [predicate(D, wait, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [aux, ['{does not}']], [vbar, [v, [eat]]]]], [coord, [or]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [drinks]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-11-14-46-43', amadeus, '').
text_drs_eval(0, 1642, 'No man eats or drinks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [predicate(B, eat, A)-1])v drs([C], [predicate(C, drink, A)-1])])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [or]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2006-08-11-14-51-13', amadeus, '').
text_drs_eval(0, 1643, 'A man It waits. A woman The sleeps. A child IF walks.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['It']]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [woman]], [appos_coord, [appos, [var, ['The']]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [child]], [appos_coord, [appos, [var, ['IF']]]]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2006-08-14-20-07-42', amadeus, '').
text_drs_eval(0, 1644, 'Every man works and eats or sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [predicate(B, work, A)-1, predicate(C, eat, A)-1])v drs([D], [predicate(D, sleep, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [works]]]], [coord, [and]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2006-08-12-16-11-20', amadeus, '').
text_drs_eval(0, 1645, 'Every man works, and eats or sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, work, A)-1, drs([C], [predicate(C, eat, A)-1])v drs([D], [predicate(D, sleep, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [works]]]], [coord, ['{, and}']], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2006-08-12-16-11-48', amadeus, '').
text_drs_eval(0, 1646, 'Every man knows a cat that eats or that sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1, drs([D], [predicate(D, eat, B)-1])v drs([E], [predicate(E, sleep, B)-1]), predicate(C, know, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]]]]]]]], ['.']]], '2006-08-12-22-14-13', amadeus, '').
text_drs_eval(0, 1647, '2 men X and Y program a n:parser Z the sentences of which nobody understands.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 2)-1, has_part(F, A)-1, object(B, parser, countable, na, eq, 1)-1, drs([G], [object(G, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([H], [predicate(H, understand, G, C)-1])]), predicate(D, program, F, B)-1, object(E, something, dom, na, na, na)-1, relation(C, of, B)-1, object(C, sentence, countable, na, geq, 2)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [var, 'Y']]], [vp, [vbar, [v, program], [np, [det, a], [nbar, [n, parser], [appos, [var, 'Z']], [rel_cl, [np, [det, the], [nbar, [n, sentences], [pp, [prep, of], [np, [relpn, which]]]]], [np, [pn, nobody]], [vp, [vbar, [v, understands]]]]]]]]], '.']], '2008-07-10-10-46-11', '130.60.155.206', '').
text_drs_eval(0, 1648, 'Some men X and Y program a n:parser Z the sentences of which nobody understands.', drs([A, B, C, D, E, F], [object(A, man, countable, na, geq, 2)-1, has_part(F, A)-1, object(B, parser, countable, na, eq, 1)-1, drs([G], [object(G, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([H], [predicate(H, understand, G, C)-1])]), predicate(D, program, F, B)-1, object(E, something, dom, na, na, na)-1, relation(C, of, B)-1, object(C, sentence, countable, na, geq, 2)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [det, some], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [var, 'Y']]], [vp, [vbar, [v, program], [np, [det, a], [nbar, [n, parser], [appos, [var, 'Z']], [rel_cl, [np, [det, the], [nbar, [n, sentences], [pp, [prep, of], [np, [relpn, which]]]]], [np, [pn, nobody]], [vp, [vbar, [v, understands]]]]]]]]], '.']], '2008-07-10-10-46-19', '130.60.155.206', '').
text_drs_eval(0, 1649, 'Every man works or eats or sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, work, A)-1])v drs([], [drs([C], [predicate(C, eat, A)-1])v drs([D], [predicate(D, sleep, A)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [works]]]], [coord, [or]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2006-08-12-22-10-05', amadeus, '').
text_drs_eval(0, 1650, 'Every man works or eats, or sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([], [drs([B], [predicate(B, work, A)-1])v drs([C], [predicate(C, eat, A)-1])])v drs([D], [predicate(D, sleep, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [works]]]], [coord, [or]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, or}']], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2006-08-12-22-10-31', amadeus, '').
text_drs_eval(0, 1651, 'Every dog X hates a cat that X hates.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B, C, D], [object(B, cat, countable, na, eq, 1)-1, predicate(C, hate, A, B)-1, predicate(D, hate, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [np, [np, [var, ['X']]]], [vp, [vbar, [v, [hates]], [np, [[]]]]]]]]]]], ['.']]], '2006-08-13-16-04-14', amadeus, '').
text_drs_eval(0, 1652, 'Mary waits. John gives a book to her.', drs([A, B, C, D, E], [object(B, 'John', named, na, eq, 1)-2, object(A, 'Mary', named, na, eq, 1)-1, predicate(C, wait, A)-1, object(D, book, countable, na, eq, 1)-2, predicate(E, give, B, D, A)-2]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [book]]]], [pp, [prep, [to]], [np, [pn, [her]]]]]]], ['.']]], '2006-08-14-19-03-17', amadeus, '').
text_drs_eval(0, 1653, 'Mary waits. John gives a book to she.', drs([], []), [], '2006-08-13-17-55-48', amadeus, '').
text_drs_eval(0, 1654, 'A book is given to Mary by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1, object(C, book, countable, na, eq, 1)-1, predicate(D, give, B, C, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [given]], [pp, [prep, [to]], [np, [pname, ['Mary']]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-22-42', amadeus, '').
text_drs_eval(0, 1655, 'Mary waits. A book is given to her by John.', drs([A, B, C, D, E], [object(B, 'John', named, na, eq, 1)-2, object(A, 'Mary', named, na, eq, 1)-1, predicate(C, wait, A)-1, object(D, book, countable, na, eq, 1)-2, predicate(E, give, B, D, A)-2]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [given]], [pp, [prep, [to]], [np, [pn, [her]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-25-41', amadeus, '').
text_drs_eval(0, 1656, 'Mary waits. John waits. A book is given to her by him.', drs([A, B, C, D, E, F], [object(B, 'John', named, na, eq, 1)-2, object(A, 'Mary', named, na, eq, 1)-1, predicate(C, wait, A)-1, predicate(D, wait, B)-2, object(E, book, countable, na, eq, 1)-3, predicate(F, give, B, E, A)-3]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [given]], [pp, [prep, [to]], [np, [pn, [her]]]], [by, [by]], [np, [pn, [him]]]]]], ['.']]], '2006-08-13-18-27-02', amadeus, '').
text_drs_eval(0, 1657, 'Mary waits. John waits. What is given to her by him?', drs([A, B], [predicate(A, wait, named('Mary'))-1/2, predicate(B, wait, named('John'))-2/2, question(drs([C, D], [query(C, what)-3/1, predicate(D, give, named('John'), C, named('Mary'))-3/3]))]), [[sentence, [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], '.'], [sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [v, given], to, [np, [pn, her]], by, [np, [pn, him]]]]]], ?], '.']], '2009-05-13-14-10-32', '130.60.155.193', '').
text_drs_eval(0, 1658, 'Mary is sent a book by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1, object(C, book, countable, na, eq, 1)-1, predicate(D, send, B, C, A)-1]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [sent]], [np, [det, [a]], [nbar, [n, [book]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-40-30', amadeus, '').
text_drs_eval(0, 1659, 'There is a book. Mary is sent it by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-2, object(A, 'Mary', named, na, eq, 1)-2, object(C, book, countable, na, eq, 1)-1, predicate(D, send, B, C, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [book]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [sent]], [np, [pn, [it]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-40-59', amadeus, '').
text_drs_eval(0, 1660, 'There is a book. Mary is sent to it by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-2, object(A, 'Mary', named, na, eq, 1)-2, object(C, book, countable, na, eq, 1)-1, predicate(D, send, B, A, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [book]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [sent]], [pp, [prep, [to]], [np, [pn, [it]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-47-28', amadeus, '').
text_drs_eval(0, 1661, 'Some men are sent a book by John.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, object(C, book, countable, na, eq, 1)-1, predicate(D, send, A, C, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [aux, [are]], [vbar, [v, [sent]], [np, [det, [a]], [nbar, [n, [book]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-51-08', amadeus, '').
text_drs_eval(0, 1662, 'A book is sent to some men by John.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, book, countable, na, eq, 1)-1, object(C, man, countable, na, geq, 2)-1, predicate(D, send, A, B, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [book]]]], [vp, [aux, [is]], [vbar, [v, [sent]], [pp, [prep, [to]], [np, [det, [some]], [nbar, [n, [men]]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-13-18-51-46', amadeus, '').
text_drs_eval(0, 1663, 'Some books are sent to Mary by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1, object(C, book, countable, na, geq, 2)-1, predicate(D, send, B, C, A)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [books]]]], [vp, [aux, [are]], [vbar, [v, [sent]], [pp, [prep, [to]], [np, [pname, ['Mary']]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-20-14-21-00', amadeus, '').
text_drs_eval(0, 1664, 'Somebody is given something by somebody.', drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, object(C, somebody, countable, na, eq, 1)-1, predicate(D, give, C, B, A)-1]), [[specification, [s, [np, [pn, [somebody]]], [vp, [aux, [is]], [vbar, [v, [given]], [np, [pn, [something]]], [by, [by]], [np, [pn, [somebody]]]]]], ['.']]], '2006-08-14-20-08-39', amadeus, '').
text_drs_eval(0, 1665, 'Somebody A gives A A.', drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, give, A, A, A)-1]), [[specification, [s, [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['A']]]]], [vp, [vbar, [v, [gives]], [np, [np, [var, ['A']]]], [np, [np, [var, ['A']]]]]]], ['.']]], '2006-08-14-18-58-04', amadeus, '').
text_drs_eval(0, 1666, 'If an age of somebody X is 31 then X is a grown-up.', drs([], [drs([A, B, C], [object(A, age, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, be, A, int(31))-1])=>drs([D, E], [object(D, 'grown-up', countable, na, eq, 1)-1, predicate(E, be, B, D)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [age]], [pp, [prep, [of]], [np, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]], [then], [s, [np, [var, ['X']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['grown-up']]]]]]]], ['.']]], '2007-09-01-17-02-26', '130.60.155.177', '').
text_drs_eval(0, 1667, 'A temperature is 0.', drs([A, B], [object(A, temperature, countable, na, eq, 1)-1, predicate(B, be, A, int(0))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [temperature]]]], [vp, [vbar, [v, [is]], [np, [int, [0]]]]]], ['.']]], '2007-09-01-17-02-38', '130.60.155.177', '').
text_drs_eval(0, 1668, 'A temperature is -30.', drs([A, B], [object(A, temperature, countable, na, eq, 1)-1, predicate(B, be, A, int(-30))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [temperature]]]], [vp, [vbar, [v, [is]], [np, [int, [-30]]]]]], ['.']]], '2007-09-01-17-02-47', '130.60.155.177', '').
text_drs_eval(0, 1669, 'John has a zip-code which is 12343.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'zip-code', countable, na, eq, 1)-1, predicate(C, be, B, int(12343))-1, predicate(D, have, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, ['zip-code']], [rel_cl, [comp, [which]], [vp, [vbar, [v, [is]], [np, [int, [12343]]]]]]]]]]], ['.']]], '2007-09-01-17-03-01', '130.60.155.177', '').
text_drs_eval(0, 1670, 'John sleeps as-soon-as-possible.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, sleep, A)-1, modifier_adv(B, 'as-soon-as-possible', pos)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [sleeps]]], [adv, ['as-soon-as-possible']]]]], ['.']]], '2007-05-09-11-04-23', '130.60.156.229', '').
text_drs_eval(0, 1671, 'It is false that John\'s age is 30.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([B, C], [relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1, predicate(C, be, B, int(30))-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [30]]]]]]]], ['.']]], '2007-09-01-17-03-14', '130.60.155.177', '').
text_drs_eval(0, 1672, 'John\'s age is not 30.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1, -drs([C], [predicate(C, be, B, int(30))-1])]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [age]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [int, [30]]]]]], ['.']]], '2007-09-01-17-03-27', '130.60.155.177', '').
text_drs_eval(0, 1673, 'There is a long zip-code ZC.', drs([], []), [], '2008-07-09-15-27-07', '130.60.155.206', '').
text_drs_eval(0, 1674, 'There is a long zip-code " 90210 ".', drs([], []), [], '2007-04-10-15-47-12', '130.60.155.177', '').
text_drs_eval(0, 1675, 'A persona-non-grata enters a zip-code.', drs([A, B, C], [object(A, 'persona-non-grata', countable, na, eq, 1)-1, object(B, 'zip-code', countable, na, eq, 1)-1, predicate(C, enter, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, ['persona-non-grata']]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, ['zip-code']]]]]]], ['.']]], '2007-05-07-16-43-45', '130.60.156.229', '').
text_drs_eval(0, 1676, 'The customer enters a card and a numeric personal-code. If it is not valid then SM rejects the card.', drs([A, B, C, D, E, F], [object(A, 'SimpleMat', named, na, eq, 1)-2, object(B, card, countable, na, eq, 1)-1, predicate(C, enter, F, E)-1, object(D, 'personal-code', countable, na, eq, 1)-1, property(D, numeric, pos)-1, has_part(E, B)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1, object(F, customer, countable, na, eq, 1)-1, drs([], [-drs([G, H], [property(G, valid, pos)-2, predicate(H, be, D, G)-2])])=>drs([I], [predicate(I, reject, A, B)-2])]), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [numeric]], [nbar, [n, ['personal-code']]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [pname, ['SM']]], [vp, [vbar, [v, [rejects]], [np, [det, [the]], [nbar, [n, [card]]]]]]]], ['.']]], '2007-05-09-12-14-03', '130.60.156.229', '').
text_drs_eval(0, 1677, 'The customer enters a card and a numeric personal-code.', drs([A, B, C, D, E], [object(A, card, countable, na, eq, 1)-1, predicate(B, enter, E, D)-1, object(C, 'personal-code', countable, na, eq, 1)-1, property(C, numeric, pos)-1, has_part(D, A)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, object(E, customer, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [enters]], [np_coord, [np, [det, [a]], [nbar, [n, [card]]]], [coord, [and]], [np, [det, [a]], [nbar, [adj, [numeric]], [nbar, [n, ['personal-code']]]]]]]]], ['.']]], '2007-05-09-12-14-10', '130.60.156.229', '').
text_drs_eval(0, 1678, 'How does a man sell a visa-card?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, object(B, 'visa-card', countable, na, eq, 1)-1/7, predicate(C, sell, A, B)-1/5, query(C, how)-1/1]))]), [[sentence, [query, [question, [qpn, how], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, sell], [np, [det, a], [nbar, [n, 'visa-card']]]]]]], ?], '.']], '2009-05-13-14-10-34', '130.60.155.193', '').
text_drs_eval(0, 1679, 'Who is there?', drs([], [question(drs([A], [query(A, who)-1/1]))]), [[sentence, [query, [question, [topic, [np, [qpn, who]], [quant, 'is there']]], ?], '.']], '2009-05-13-14-10-35', '130.60.155.193', '').
text_drs_eval(0, 1680, 'How is there?', drs([], []), [], '2006-08-15-18-25-41', amadeus, '').
text_drs_eval(0, 1681, 'It is false that there are John and Mary.', drs([], []), [], '2008-01-03-16-28-36', '130.60.206.88', '').
text_drs_eval(0, 1682, 'A woman waits. A man is interested-in her.', drs([A, B, C, D, E], [object(A, woman, countable, na, eq, 1)-1, predicate(B, wait, A)-1, object(C, man, countable, na, eq, 1)-2, property(D, 'interested-in', pos, A)-2, predicate(E, be, C, D)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [pn, [her]]]]|F]]]], ['.']]], '2007-05-09-12-14-15', '130.60.156.229', '').
text_drs_eval(0, 1683, 'A woman waits. A man is interested-in she.', drs([], []), [], '2006-08-15-21-05-15', amadeus, '').
text_drs_eval(0, 1684, 'A woman waits. A man is interested-in the woman.', drs([A, B, C, D, E], [object(A, woman, countable, na, eq, 1)-1, predicate(B, wait, A)-1, object(C, man, countable, na, eq, 1)-2, property(D, 'interested-in', pos, A)-2, predicate(E, be, C, D)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [det, [the]], [nbar, [n, [woman]]]]]|F]]]], ['.']]], '2007-05-09-12-14-21', '130.60.156.229', '').
text_drs_eval(0, 1685, 'A man is interested-in a woman who waits.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(C, wait, B)-1, property(D, 'interested-in', pos, B)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [waits]]]]]]]]|F]]]], ['.']]], '2007-05-09-12-14-27', '130.60.156.229', '').
text_drs_eval(0, 1686, 'A customer is rich and interested-in no money.', drs([], []), [], '2006-08-15-20-42-42', amadeus, '').
text_drs_eval(0, 1687, 'A customer is rich and interested-in every money.', drs([], []), [], '2006-08-15-20-42-55', amadeus, '').
text_drs_eval(0, 1688, 'Who is John fond-of?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, property(B, 'fond-of', pos, A)-1/4, predicate(C, be, named('John'), B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], is, [np, [pname, 'John']], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, 'fond-of']]]]]]], ?], '.']], '2009-05-13-14-10-36', '130.60.155.193', '').
text_drs_eval(0, 1689, 'There is X.', drs([A], [object(A, something, dom, na, na, na)-1]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.']], '2009-01-05-14-42-46', '130.60.155.206', '').
text_drs_eval(0, 1690, 'Augusts wait.', drs([A, B], [object(A, 'August', named, na, geq, 2)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [pname, ['Augusts']]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-08-15-21-01-25', amadeus, '').
text_drs_eval(0, 1691, 'John waits. A man brings him his pencil and brings him his own computer.', drs([A, B, C, D, E, F, G], [predicate(G, bring, C, F, A)-2, object(F, computer, countable, na, eq, 1)-2, relation(F, of, C)-2, predicate(E, bring, C, D, A)-2, object(D, pencil, countable, na, eq, 1)-2, relation(D, of, A)-2, object(C, man, countable, na, eq, 1)-2, predicate(B, wait, A)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [brings]], [np, [pn, [him]]], [np, [posspn, [his]], [nbar, [n, [pencil]]]]]], [coord, [and]], [vp, [vbar, [v, [brings]], [np, [pn, [him]]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-11-13-14-55-35', '130.60.155.161', '').
text_drs_eval(0, 1692, 'It is false that there is John.', drs([], []), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]]]], ['.']]], '2006-08-15-21-03-12', amadeus, '').
text_drs_eval(0, 1693, 'It is true that there is John.', drs([], []), [[specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [np, [var, ['John']]]]]]]], ['.']]], '2006-08-15-21-03-21', amadeus, '').
text_drs_eval(0, 1694, 'There is a man X. It is not the case that there is X.', drs([], []), [], '2006-08-15-21-23-21', amadeus, '').
text_drs_eval(0, 1695, 'There is a man. There is the man.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [man]]]]]]], ['.']]], '2006-08-15-21-33-04', amadeus, '').
text_drs_eval(0, 1696, 'There is a man. There are the man and a woman.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']]|A], '2008-01-03-16-29-02', '130.60.206.88', '').
text_drs_eval(0, 1697, 'There is a man. There are a woman and the man.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']]|A], '2008-01-03-16-29-16', '130.60.206.88', '').
text_drs_eval(0, 1698, 'There is a man. There is a woman. There are the man and the woman.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]], ['.']]|A], '2008-01-03-16-29-28', '130.60.206.88', '').
text_drs_eval(0, 1699, 'There is every man.', drs([], []), [[specification, [s, [np, [np, [var, ['There']]]], [vp, [vbar, [v, [is]], [np, [det, [every]], [nbar, [n, [man]]]]]]], ['.']]], '2006-08-15-21-34-50', amadeus, '').
text_drs_eval(0, 1700, 'There are a woman and every man.', drs([], []), [], '2006-08-15-21-35-07', amadeus, '').
text_drs_eval(0, 1701, 'There is a man. John sees Mary and a dog and the man.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-2, object(B, 'Mary', named, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, predicate(D, see, A, F)-2, object(E, dog, countable, na, eq, 1)-2, has_part(F, B)-2, has_part(F, E)-2, has_part(F, C)-2, object(F, na, countable, na, eq, 3)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['Mary']]], [coord, [and]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]], '2007-09-26-17-08-54', '130.60.155.177', '').
text_drs_eval(0, 1702, 'Every boy and a girl see a man.', drs([], []), [], '2006-08-15-21-40-08', amadeus, '').
text_drs_eval(0, 1703, 'Who who eats drinks?', drs([], []), [], '2008-09-23-08-49-48', '130.60.155.206', '').
text_drs_eval(0, 1704, 'What is written by who?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, query(B, who)-1/5, predicate(C, write, B, A)-1/3]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [v, written], by, [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-14-10-38', '130.60.155.193', '').
text_drs_eval(0, 1705, 'A man whose age is 31 waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, age, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, be, B, int(31))-1, predicate(D, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-09-01-17-03-40', '130.60.155.177', '').
text_drs_eval(0, 1706, 'John whose age is 31 waits.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, A)-1, object(C, age, countable, na, eq, 1)-1, relation(C, of, A)-1, predicate(D, be, C, int(31))-1]), [[specification, [s, [np, [pname, ['John']], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-09-01-17-03-51', '130.60.155.177', '').
text_drs_eval(0, 1707, 'A man whose age is 31 likes a cat.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, age, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, be, B, int(31))-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, like, A, D)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-09-01-17-04-03', '130.60.155.177', '').
text_drs_eval(0, 1708, 'A man whose age is 31 likes Mary.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, age, countable, na, eq, 1)-1, relation(C, of, B)-1, predicate(D, be, C, int(31))-1, predicate(E, like, B, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]]]], [vp, [vbar, [v, [likes]], [np, [pname, ['Mary']]]]]], ['.']]], '2007-09-01-17-04-12', '130.60.155.177', '').
text_drs_eval(0, 1709, 'Every dog which barks or which eats does not see a man.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [predicate(B, bark, A)-1])v drs([C], [predicate(C, eat, A)-1])])=>drs([], [-drs([D, E], [object(D, man, countable, na, eq, 1)-1, predicate(E, see, A, D)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [dog]], [rel_cl_coord, [rel_cl, [comp, [which]], [vp, [vbar, [v, [barks]]]]], [coord, [or]], [rel_cl, [comp, [which]], [vp, [vbar, [v, [eats]]]]]]]], [vp, [aux, ['{does not}']], [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2006-08-16-16-10-35', amadeus, '').
text_drs_eval(0, 1710, 'John\'s', drs([], []), [], '2007-01-14-15-52-30', '130.60.155.211', '').
text_drs_eval(0, 1711, 'If there is somebody Y and somebody X does not love Y then X hates Y.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, -drs([C], [predicate(C, love, B, A)-1])])=>drs([D], [predicate(D, hate, B, A)-1])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['Y']]]]]]], [coord, [and]], [s, [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [aux, ['{does not}']], [vbar, [v, [love]], [np, [np, [var, ['Y']]]]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [hates]], [np, [np, [var, ['Y']]]]]]]], ['.']]], '2006-08-16-18-54-41', amadeus, '').
text_drs_eval(0, 1712, 'A man who sees who waits.', drs([], []), [], '2006-08-17-08-57-33', amadeus, '').
text_drs_eval(0, 1713, 'A man who sees a dog and who waits.', drs([], []), [], '2006-08-17-08-58-33', amadeus, '').
text_drs_eval(0, 1714, 'A man who sees who waits?', drs([], [question(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, query(B, who)-1/5, predicate(C, see, A, B)-1/4, predicate(D, wait, A)-1/6]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [qpn, who]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-14-10-39', '130.60.155.193', '').
text_drs_eval(0, 1715, 'At least 1 men wait.', drs([], []), [], '2007-04-13-14-51-41', '130.60.155.177', '').
text_drs_eval(0, 1716, 'There is a man X. It is false that the man X waits.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B], [predicate(B, wait, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']], [specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [the]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2006-08-17-18-18-54', amadeus, '').
text_drs_eval(0, 1717, 'At most 1 men wait.', drs([], []), [], '2007-04-13-14-52-04', '130.60.155.177', '').
text_drs_eval(0, 1718, 'At least 0 man waits.', drs([], []), [], '2006-08-17-18-19-42', amadeus, '').
text_drs_eval(0, 1719, 'At least 0 men wait.', drs([A, B], [object(A, man, countable, na, geq, 0)-1/4, predicate(B, wait, A)-1/5]), [[specification, [s, [np, [nump, [genqu, 'at least'], 0], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2010-01-18-11-12-57', '89.206.64.72', '').
text_drs_eval(0, 1720, '-3 men wait.', drs([], []), [], '2006-08-17-18-20-12', amadeus, '').
text_drs_eval(0, 1721, 'At least -3 men wait.', drs([], []), [], '2006-08-17-18-20-31', amadeus, '').
text_drs_eval(0, 1722, 'At most 0 men wait.', drs([A, B], [[predicate(B, wait, A)-1/5, object(A, man, countable, na, leq, 0)-1/4]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 0], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2010-01-18-11-13-08', '89.206.64.72', '').
text_drs_eval(0, 1723, 'At least 1 man wait.', drs([], []), [], '2006-08-17-18-22-34', amadeus, '').
text_drs_eval(0, 1724, 'At least 1 men waits.', drs([], []), [], '2006-08-17-18-22-44', amadeus, '').
text_drs_eval(0, 1725, 'Every man an age of who is 31 likes a cat.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, age, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, be, B, int(31))-1])=>drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, like, A, D)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [age]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-09-01-17-04-26', '130.60.155.177', '').
text_drs_eval(0, 1726, 'Less than 0 men wait.', drs([A, B], [[predicate(B, wait, A)-1/5, object(A, man, countable, na, less, 0)-1/4]]), [[specification, [s, [np, [nump, [genqu, 'less than'], 0], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2010-01-18-11-13-24', '89.206.64.72', '').
text_drs_eval(0, 1727, 'A man\'s dog barks. The man\'s dog barks.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, relation(D, of, A)-2, object(D, dog, countable, na, eq, 1)-2, predicate(E, bark, D)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [poss_spec, [poss_np, [det, [the]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-22-14-54-09', amadeus, '').
text_drs_eval(0, 1728, 'Which dog of which cat barks?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, dog, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, cat, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, predicate(C, bark, A)-1/6]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, dog], [pp, [prep, of], [np, [qdet, which], [nbar, [n, cat]]]]]], [vp, [vbar, [vbar, [v, barks]]]]], ?], '.']], '2009-05-13-14-10-40', '130.60.155.193', '').
text_drs_eval(0, 1729, 'There is the dog of John.', drs([], []), [], '2006-08-17-19-20-06', amadeus, '').
text_drs_eval(0, 1730, 'There is nobody who sees something.', drs([], [-drs([A, B, C], [object(A, something, dom, na, na, na)-1, predicate(B, see, C, A)-1, object(C, somebody, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [nobody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [pn, [something]]]]]]]]], ['.']]], '2006-08-17-22-34-47', amadeus, '').
text_drs_eval(0, 1731, 'There is somebody who sees nothing.', drs([A], [object(A, somebody, countable, na, eq, 1)-1, drs([B], [object(B, something, dom, na, na, na)-1])=>drs([], [-drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [pn, [nothing]]]]]]]]], ['.']]], '2006-08-17-22-35-42', amadeus, '').
text_drs_eval(0, 1732, 'There is nobody who sees nothing.', drs([], [-drs([A], [drs([B], [object(B, something, dom, na, na, na)-1])=>drs([], [-drs([C], [predicate(C, see, A, B)-1])]), object(A, somebody, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [nobody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [pn, [nothing]]]]]]]]], ['.']]], '2006-08-17-22-35-57', amadeus, '').
text_drs_eval(0, 1733, 'If there is a man then he waits and there is a woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, wait, A)-1, object(C, woman, countable, na, eq, 1)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], [coord, [and]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]]], ['.']]], '2006-08-18-14-38-13', amadeus, '').
text_drs_eval(0, 1734, 'If there is a man then he waits and a woman owns a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [predicate(B, wait, A)-1, object(C, woman, countable, na, eq, 1)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, own, C, D)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2006-08-18-14-40-15', amadeus, '').
text_drs_eval(0, 1735, 'There is a man. Every man sees the man.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-2])=>drs([C], [predicate(C, see, B, B)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]], ['.']]], '2006-08-18-16-04-04', amadeus, '').
text_drs_eval(0, 1736, 'There is a dog. Every man likes the dog. Every woman hates the dog.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-2])=>drs([C], [predicate(C, like, B, A)-2]), drs([D], [object(D, woman, countable, na, eq, 1)-3])=>drs([E], [predicate(E, hate, D, A)-3])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [hates]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-18-17-08-59', amadeus, '').
text_drs_eval(0, 1737, 'There is a dog. Every man likes the dog. There is a dog. Every woman hates the dog.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-2])=>drs([D], [predicate(D, like, C, A)-2]), object(B, dog, countable, na, eq, 1)-3, drs([E], [object(E, woman, countable, na, eq, 1)-4])=>drs([F], [predicate(F, hate, E, B)-4])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [hates]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-18-17-39-05', amadeus, '').
text_drs_eval(0, 1738, 'There is a man X. Every man sees X.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-2])=>drs([C], [predicate(C, see, B, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']], [specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [np, [var, ['X']]]]]]], ['.']]], '2006-08-18-18-06-41', amadeus, '').
text_drs_eval(0, 1739, 'Every man who loves a woman who loves the man smiles.', drs([], [drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(C, love, B, A)-1, predicate(D, love, A, B)-1])=>drs([E], [predicate(E, smile, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [loves]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [loves]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]]]]]]], [vp, [vbar, [v, [smiles]]]]], ['.']]], '2006-08-18-18-46-31', amadeus, '').
text_drs_eval(0, 1740, 'There is a man X. If X eats then X drinks.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, eat, A)-2])=>drs([C], [predicate(C, drink, A)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [eats]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [drinks]]]]]], ['.']]], '2006-08-18-18-50-24', amadeus, '').
text_drs_eval(0, 1741, 'If there is a man then it is false that it is possible that he sees a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [can(drs([B, C], [object(B, cat, countable, na, eq, 1)-1/18, predicate(C, see, A, B)-1/16]))])])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [neg, 'it is false'], [cp, that, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]], '.']], '2010-10-27-09-25-02', '89.206.64.27', '').
text_drs_eval(0, 1742, 'There is proposition P that Mary sleeps. It is true that P.', drs([], []), [], '2006-08-28-16-21-18', amadeus, '').
text_drs_eval(0, 1743, 'There is proposition P that Mary sleeps. It is false that P.', drs([], []), [], '2006-08-28-16-22-02', amadeus, '').
text_drs_eval(0, 1744, 'There is proposition P that Mary sleeps. It is possible that P.', drs([], []), [], '2006-08-28-16-23-00', amadeus, '').
text_drs_eval(0, 1745, 'There is proposition P that Mary sleeps. It is not provable that P.', drs([], []), [], '2006-08-28-16-23-12', amadeus, '').
text_drs_eval(0, 1746, 'There is proposition P that Mary sleeps. John believes that P.', drs([], []), [], '2006-08-28-16-23-27', amadeus, '').
text_drs_eval(0, 1747, 'There is proposition P that Mary sleeps. P is true.', drs([], []), [[specification, [prop, [quant, ['{there is}']], [p, [proposition]], 'P', [cp, ['_that_'], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['P']]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [true]]]]]]], ['.']]], '2006-08-20-15-36-13', amadeus, '').
text_drs_eval(0, 1748, 'There is proposition P that Mary sleeps. There is proposition Q that Mary waits. It is true that P. It is true that R.', drs([], []), [[specification, [prop, [quant, ['{there is}']], [p, [proposition]], 'P', [cp, ['_that_'], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']], [specification, [prop, [quant, ['{there is}']], [p, [proposition]], 'Q', [cp, ['_that_'], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [waits]]]]]]], ['.']], [specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [proposition, [var, ['P']]]]], ['.']], [specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [proposition, [var, ['R']]]]], ['.']]], '2006-08-20-15-41-20', amadeus, '').
text_drs_eval(0, 1749, 'There is proposition P that there is a man. There is proposition Q that it is false that P. A woman believes that Q.', drs([], []), [], '2006-08-28-16-25-17', amadeus, '').
text_drs_eval(0, 1750, 'There is proposition P that Mary sleeps. There is proposition Q that John believes that P. Mary assumes that Q.', drs([], []), [], '2006-08-28-16-25-16', amadeus, '').
text_drs_eval(0, 1751, 'There is a husband. She sleeps.', drs([], []), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [husband]]]]]], [s, [np, [pn, [she]]], [vp, [vbar, [v, [sleeps]]]]]], '2007-11-05-11-47-18', '130.60.155.231', '').
text_drs_eval(0, 1752, 'John\'s card is correct.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, card, countable, na, eq, 1)-1, property(C, correct, pos)-1, predicate(D, be, B, C)-1]), [[specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]], ['.']]], '2006-08-22-11-52-28', amadeus, '').
text_drs_eval(0, 1753, 'Mary is sent some books by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1, object(C, book, countable, na, geq, 2)-1, predicate(D, send, B, C, A)-1]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [sent]], [np, [det, [some]], [nbar, [n, [books]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-20-14-21-30', amadeus, '').
text_drs_eval(0, 1754, 'There is Bill.', drs([], []), [], '2007-01-14-15-53-45', '130.60.155.211', '').
text_drs_eval(0, 1755, 'There is Proposition P that Mary sleeps. It is true that P.', drs([], []), [], '2006-08-28-16-25-10', amadeus, '').
text_drs_eval(0, 1756, 'What does John live in?', drs([], [question(drs([A, B], [query(A, what)-1/1, predicate(B, live, named('John'))-1/4, modifier_pp(B, in, A)-1/5]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, live]], [vmod, [pp, [prep, in]]]]]], ?], '.']], '2009-05-13-14-10-43', '130.60.155.193', '').
text_drs_eval(0, 1757, 'From what does John come?', drs([], [question(drs([A, B], [query(A, what)-1/2, predicate(B, come, named('John'))-1/5, modifier_pp(B, from, A)-1/1]))]), [[sentence, [query, [question, [pp, [prep, 'From'], [np, [qpn, what]]], does, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, come]]]]], ?], '.']], '2009-05-13-14-07-50', '130.60.155.193', '').
text_drs_eval(0, 1758, 'There is proposition P that there is proposition Q that a dog barks. It is false that P.', drs([], []), [], '2006-08-24-21-08-13', amadeus, '').
text_drs_eval(0, 1759, 'There is proposition P that a dog barks and that a cat eats. It is true that P.', drs([], []), [], '2006-08-28-16-25-07', amadeus, '').
text_drs_eval(0, 1760, 'There is proposition P that a dog barks. John knows that P.', drs([], []), [], '2006-08-28-16-25-09', amadeus, '').
text_drs_eval(0, 1761, 'There is proposition P that a dog barks and that John knows that P.', drs([], []), [[specification, [prop, [quant, ['{there is}']], [p, [proposition]], 'P', [cp, ['_that_'], [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [proposition, [var, ['P']]]]]]]]]]], ['.']]], '2006-08-20-18-12-38', amadeus, '').
text_drs_eval(0, 1762, 'There is proposition P that a dog barks and John knows that P.', drs([], []), [], '2006-08-24-21-07-44', amadeus, '').
text_drs_eval(0, 1763, 'P :: A dog barks. It is false that P.', drs([], []), [], '2006-08-21-14-19-59', amadeus, '').
text_drs_eval(0, 1764, 'Q :: A cat sleeps. P :: A dog barks and it is false that Q. John believes that P.', drs([], []), [], '2006-08-21-14-20-35', amadeus, '').
text_drs_eval(0, 1765, 'P :: Every man waits. It is true that P.', drs([], []), [], '2006-08-21-14-22-07', amadeus, '').
text_drs_eval(0, 1766, 'P :: Every man waits. It is true that P and that P.', drs([], []), [], '2006-08-25-11-43-16', amadeus, '').
text_drs_eval(0, 1767, 'X :: A man waits. It is true that X. It is false that X.', drs([], []), [], '2006-08-24-21-06-24', amadeus, '').
text_drs_eval(0, 1768, 'A: A dog barks. B: Every cat knows that A. C: Every dog knows that it is true that B. It is true that C.', drs([], []), [], '2006-08-28-00-15-18', amadeus, '').
text_drs_eval(0, 1769, 'Are there no men?', drs([], []), [[query, [question, [topic, [quant, ['{are there}']], [np, [det, [no]], [nbar, [n, [men]]]]]], [?]]], '2007-04-13-18-17-09', '130.60.155.177', '').
text_drs_eval(0, 1770, 'P: A dog barks. It is false that P.', drs([], []), [], '2006-08-28-00-16-47', amadeus, '').
text_drs_eval(0, 1771, 'Proposition Q: A cat sleeps. Proposition P: A dog barks and it is false that Q. John believes that P.', drs([], []), [], '2009-04-02-13-14-04', '130.60.155.206', '').
text_drs_eval(0, 1772, 'Proposition P: Every man waits. It is true that P.', drs([], []), [], '2009-04-02-13-14-10', '130.60.155.206', '').
text_drs_eval(0, 1773, 'Fact F: A man waits.', drs([], []), [], '2009-04-02-13-13-58', '130.60.155.206', '').
text_drs_eval(0, 1774, 'A man\'s dog barks. It waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, wait, B)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-21-18-20-21', amadeus, '').
text_drs_eval(0, 1775, 'A man\'s dog barks. The man waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-22-14-53-56', amadeus, '').
text_drs_eval(0, 1776, 'A ball of a girl is blue. John sees the ball of the girl. Mary sees a ball of the girl.', drs([A, B, C, D, E, F, G, H, I], [object(B, 'Mary', named, na, eq, 1)-3, object(A, 'John', named, na, eq, 1)-2, object(C, ball, countable, na, eq, 1)-1, object(D, girl, countable, na, eq, 1)-1, relation(C, of, D)-1, property(E, blue, pos)-1, predicate(F, be, C, E)-1, predicate(G, see, A, C)-2, object(H, ball, countable, na, eq, 1)-3, relation(H, of, D)-3, predicate(I, see, B, H)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [ball]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [girl]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [blue]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [ball]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [girl]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [ball]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [girl]]]]]]]]]], ['.']]], '2006-08-22-11-37-01', amadeus, '').
text_drs_eval(0, 1777, 'John beats a mother of a brother of a wife of John.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, mother, countable, na, eq, 1)-1, object(C, brother, countable, na, eq, 1)-1, object(D, wife, countable, na, eq, 1)-1, relation(D, of, A)-1, relation(C, of, D)-1, relation(B, of, C)-1, predicate(E, beat, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [beats]], [np, [det, [a]], [nbar, [n, [mother]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [brother]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [wife]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]]]]]]]], ['.']]], '2006-08-22-11-41-37', amadeus, '').
text_drs_eval(0, 1778, 'Fact P: Mary sleeps. It is false that P.', drs([], []), [], '2009-04-02-13-14-21', '130.60.155.206', '').
text_drs_eval(0, 1779, 'Fact P: Mary sleeps.', drs([], []), [], '2009-04-02-13-14-28', '130.60.155.206', '').
text_drs_eval(0, 1780, 'Proposition P: Mary sleeps.', drs([], []), [[specification, [prop, [prop, [prop]], 'P', [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2006-08-22-12-01-50', amadeus, '').
text_drs_eval(0, 1781, 'Proposition P: Mary sleeps. It is possible that P.', drs([], []), [], '2009-04-02-13-14-33', '130.60.155.206', '').
text_drs_eval(0, 1782, 'Fact P: Mary sleeps. It is true that P.', drs([], []), [], '2009-04-02-13-14-39', '130.60.155.206', '').
text_drs_eval(0, 1783, 'Fact P: Mary sleeps. It is not provable that P.', drs([], []), [], '2009-04-02-13-14-46', '130.60.155.206', '').
text_drs_eval(0, 1784, 'A man\'s dog barks. The dog of the man is happy.', drs([A, B, C, D, E], [relation(B, of, A)-1, predicate(C, bark, B)-1, property(D, happy, pos)-2, predicate(E, be, B, D)-2, object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[s, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]]], '2007-11-05-11-05-37', '130.60.155.231', '').
text_drs_eval(0, 1785, 'The man\'s dog barks. The dog of the man is happy.', drs([A, B, C, D, E], [relation(A, of, C)-1, object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, object(C, man, countable, na, eq, 1)-1, property(D, happy, pos)-2, predicate(E, be, A, D)-2]), [[specification, [s, [np, [poss_np, [det, the], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-08-12-12-22-38', '84.74.167.232', '').
text_drs_eval(0, 1786, 'There is a boy. A man of his group waits.', drs([A, B, C, D], [object(A, boy, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, B)-2, object(C, group, countable, na, eq, 1)-2, relation(B, of, C)-2, predicate(D, wait, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, boy]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man], [pp, [prep, of], [np, [posspn, his], [nbar, [n, group]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-23-14-56-39', '130.60.155.177', '').
text_drs_eval(0, 1787, 'A man of his group waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, group, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, wait, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man], [pp, [prep, of], [np, [posspn, his], [nbar, [n, group]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-23-14-57-03', '130.60.155.177', '').
text_drs_eval(0, 1788, 'Fact P: Mary sleeps. Fact P: Mary waits. It is false that P.', drs([], []), [], '2009-04-02-13-14-54', '130.60.155.206', '').
text_drs_eval(0, 1789, 'Every mother of someone is a parent of him/her.', drs([], [drs([A, B], [object(A, mother, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, relation(A, of, B)-1])=>drs([C, D], [object(C, parent, countable, na, eq, 1)-1, relation(C, of, C)-1, predicate(D, be, A, C)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, mother], [pp, [prep, of], [np, [pn, someone]]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, parent], [pp, [prep, of], [np, [pn, 'him/her']]]]]]]], '.']], '2008-10-23-14-57-17', '130.60.155.177', '').
text_drs_eval(0, 1790, '5 men\'s dog barks. The dog eats.', drs([A, B, C, D], [object(A, man, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, eat, B)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2006-08-22-13-19-19', amadeus, '').
text_drs_eval(0, 1791, '5 men\'s dog barks. The men eat.', drs([A, B, C, D], [object(A, man, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, eat, A)-2]), [[specification, [s, [np, [poss_spec, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [men]]]], [vp, [vbar, [v, [eat]]]]], ['.']]], '2006-08-22-13-20-00', amadeus, '').
text_drs_eval(0, 1792, '5 men\'s dog barks. The dog of the men eats.', drs([A, B, C, D], [relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, eat, B)-2, object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 5)-1]), [[s, [np, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [men]]]]]]], [vp, [vbar, [v, [eats]]]]]], '2007-11-05-11-15-12', '130.60.155.231', '').
text_drs_eval(0, 1793, 'There is a man. There is his card.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, card, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_spec, [poss_pn_coord, [posspn, [his]]]], [nbar, [n, [card]]]]]], ['.']]], '2006-08-22-14-05-32', amadeus, '').
text_drs_eval(0, 1794, 'There is 5 men\'s dog.', drs([A, B], [object(A, man, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_spec, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]]]], ['.']]], '2006-08-22-14-09-08', amadeus, '').
text_drs_eval(0, 1795, 'There is a dog of 5 men.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 5)-1, relation(A, of, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]]]]]]]], ['.']]], '2006-08-22-14-09-23', amadeus, '').
text_drs_eval(0, 1796, 'Proposition P: If a man waits then the man sleeps. It is false that P.', drs([], []), [], '2009-04-02-13-14-59', '130.60.155.206', '').
text_drs_eval(0, 1797, 'John\'s dog waits.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, wait, B)-1]), [[specification, [s, [np, [poss_spec, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-22-14-59-17', amadeus, '').
text_drs_eval(0, 1798, 'There is a man. His dog waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, dog, countable, na, eq, 1)-2, predicate(C, wait, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-03-18-17-52-46', '130.60.155.177', '').
text_drs_eval(0, 1799, 'Proposition P: A man waits. It is true that P.', drs([], []), [], '2009-04-02-13-15-07', '130.60.155.206', '').
text_drs_eval(0, 1800, 'If John does not eat and it is not the case that somebody feeds him then John is hungry.', drs([], []), [[specification, [cond_s, [if], [s_coord, [s, [np, [pname, ['John']]], [vp, [aux, ['{does not}']], [vbar, [v, [eat]]]]], [coord, [and]], [s, [np, [pn, [it]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [case]], [rel_cl, [comp, [that]], [np, [det, [a]], [nbar, [n, ['$body']]]], [vp, [vbar, [v, [feeds]], [np, [pn, [him]]], [np, [[]]]]]]]]]]]], [then], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [hungry]]]]]]]], ['.']]], '2007-12-14-17-19-01', '130.60.155.177', '').
text_drs_eval(0, 1801, 'If a person X likes the wine then John likes X. Mary likes all wine.', drs([A, B], [object(B, 'Mary', named, na, eq, 1)-2, object(A, 'John', named, na, eq, 1)-1, drs([C, D, E], [object(C, person, countable, na, eq, 1)-1, predicate(D, like, C, E)-1, object(E, wine, countable, na, eq, 1)-1])=>drs([F], [predicate(F, like, A, C)-1]), drs([G], [object(G, wine, mass, na, na, na)-2])=>drs([H], [predicate(H, like, B, G)-2])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [person]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [n, [wine]]]]]]], [then], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [np, [var, ['X']]]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [likes]], [np, [det, [all]], [nbar, [n, [wine]]]]]]], ['.']]], '2006-08-22-17-06-12', amadeus, '').
text_drs_eval(0, 1802, 'If a person buys an object from a merchant and keeps it then the person owns the object. If a merchant sells an object to a person then the person buys the object from the merchant. John sells the book "XML Bible" to Mary. Mary keeps the book.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-3, object(B, 'Mary', named, na, eq, 1)-3, drs([F, G, H, I, J], [object(F, person, countable, na, eq, 1)-1, object(G, merchant, countable, na, eq, 1)-1, object(H, object, countable, na, eq, 1)-1, predicate(I, buy, F, H)-1, modifier_pp(I, from, G)-1, predicate(J, keep, F, H)-1])=>drs([K], [predicate(K, own, F, H)-1]), drs([L, M, N, O], [object(L, merchant, countable, na, eq, 1)-2, object(M, person, countable, na, eq, 1)-2, object(N, object, countable, na, eq, 1)-2, predicate(O, sell, L, N)-2, modifier_pp(O, to, M)-2])=>drs([P], [predicate(P, buy, M, N)-2, modifier_pp(P, from, L)-2]), predicate(C, sell, A, string('XML Bible'), D)-3, object(D, book, countable, na, eq, 1)-3, modifier_pp(C, to, B)-3, predicate(E, keep, B, D)-4]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [person]]]], [vp_coord, [vp, [vbar, [vbar, [v, [buys]], [np, [det, [a]], [nbar, [n, [object]]]]], [pp, [prep, [from]], [np, [det, [a]], [nbar, [n, [merchant]]]]]]], [coord, [and]], [vp, [vbar, [v, [keeps]], [np, [pn, [it]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [person]]]], [vp, [vbar, [v, [owns]], [np, [det, [the]], [nbar, [n, [object]]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [merchant]]]], [vp, [vbar, [vbar, [v, [sells]], [np, [det, [a]], [nbar, [n, [object]]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [person]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [person]]]], [vp, [vbar, [vbar, [v, [buys]], [np, [det, [the]], [nbar, [n, [object]]]]], [pp, [prep, [from]], [np, [det, [the]], [nbar, [n, [merchant]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [sells]], [np, [det, [the]], [nbar, [n, [book]]]], [np, [string, ['XML Bible']]]], [pp, [prep, [to]], [np, [pname, ['Mary']]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [keeps]], [np, [det, [the]], [nbar, [n, [book]]]]]]], ['.']]], '2007-09-01-17-05-03', '130.60.155.177', '').
text_drs_eval(0, 1803, 'If there is a man then the man sees a dog that sees a cat that sees a rat and the dog sees a horse.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G, H, I], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, object(D, rat, countable, na, eq, 1)-1, predicate(E, see, C, D)-1, predicate(F, see, B, C)-1, predicate(G, see, A, B)-1, object(H, horse, countable, na, eq, 1)-1, predicate(I, see, B, H)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]]]]]]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [horse]]]]]]]]], ['.']]], '2007-08-14-20-23-36', '130.60.155.177', '').
text_drs_eval(0, 1804, 'If there is a man then the man sees a dog that sees a cat that sees a rat and the dog sees a horse that sees a cow.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G, H, I, J, K], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, object(D, rat, countable, na, eq, 1)-1, predicate(E, see, C, D)-1, predicate(F, see, B, C)-1, predicate(G, see, A, B)-1, object(H, horse, countable, na, eq, 1)-1, object(I, cow, countable, na, eq, 1)-1, predicate(J, see, H, I)-1, predicate(K, see, B, H)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]]]]]]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [horse]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cow]]]]]]]]]]]]]], ['.']]], '2007-08-14-20-24-23', '130.60.155.177', '').
text_drs_eval(0, 1805, 'There is a park in which a dog barks.', drs([A, B, C], [object(A, park, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, modifier_pp(C, in, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [park]], [rel_cl, [pp, [prep, [in]], [np, [relpn, [which]]]], [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [[]]]]]]]]]], ['.']]], '2006-08-22-20-16-09', amadeus, '').
text_drs_eval(0, 1806, 'Mary doesn\'t like some men who aren\'t rich.', drs([A], [object(A, 'Mary', named, na, eq, 1)-1, -drs([B, C], [object(B, man, countable, na, geq, 2)-1, -drs([D, E], [property(D, rich, pos)-1, predicate(E, be, B, D)-1]), predicate(C, like, A, B)-1])]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [aux, ['{are not}']], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [rich]]]]]]]]]]]], ['.']]], '2006-08-23-21-34-16', amadeus, '').
text_drs_eval(0, 1807, 'Everybody doesn\'t like a dog that doesn\'t bark.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, -drs([D], [predicate(D, bark, B)-1]), predicate(C, like, A, B)-1])])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [aux, ['{does not}']], [vbar, [v, [bark]]]]]]]]]], ['.']]], '2006-08-23-21-35-02', amadeus, '').
text_drs_eval(0, 1808, 'The furniture is good.', drs([A, B, C], [property(A, good, pos)-1, predicate(B, be, C, A)-1, object(C, furniture, mass, na, na, na)-1]), [[specification, [s, [np, [det, the], [nbar, [n, furniture]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, good]]]]]], '.']], '2008-07-18-20-11-04', '130.60.206.18', '').
text_drs_eval(0, 1809, 'A cat isn\'t hated by a dog.', drs([A], [object(A, cat, countable, na, eq, 1)-1, -drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, hate, B, A)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [aux, ['{is not}']], [vbar, [v, [hated]], [by, [by]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-24-12-54-30', amadeus, '').
text_drs_eval(0, 1810, 'If there is a man then it is false that the man likes a cat and that the man hates a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C, D, E], [object(B, cat, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, object(D, dog, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]]], ['.']]], '2006-08-24-12-57-23', amadeus, '').
text_drs_eval(0, 1811, 'If there is a man then the man sees a cow and it is false that the man likes a cat and that the man hates a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, cow, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([D, E, F, G], [object(D, cat, countable, na, eq, 1)-1, predicate(E, like, A, D)-1, object(F, dog, countable, na, eq, 1)-1, predicate(G, hate, A, F)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cow]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]]]], ['.']]], '2006-08-24-12-59-04', amadeus, '').
text_drs_eval(0, 1812, 'Proposition X: A man waits. It is true that X. It is false that X.', drs([], []), [], '2009-04-02-13-15-13', '130.60.155.206', '').
text_drs_eval(0, 1813, 'A man is v:sseen by a dog.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, sseen, B, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, [is]], [vbar, [v, [sseen]], [by, [by]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2006-08-24-22-25-54', amadeus, '').
text_drs_eval(0, 1814, 'A man is v:sseen.', drs([], []), [], '2006-08-24-22-25-17', amadeus, '').
text_drs_eval(0, 1815, 'Every man can eat and drink.', drs([], []), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [aux, [can]], [vbar, [v, [eat]]]], [coord, [and]], [vp, [vbar, [v, [drink]]]]]], ['.']]], '2007-12-23-12-02-40', '130.60.204.35', '').
text_drs_eval(0, 1816, 'Some men do wait.', drs([A, B], [object(A, man, countable, na, geq, 2)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [aux, [do]], [vbar, [v, [wait]]]]], ['.']]], '2006-08-24-22-12-56', amadeus, '').
text_drs_eval(0, 1817, 'A man does seen by a dog.', drs([], []), [], '2006-08-24-22-16-18', amadeus, '').
text_drs_eval(0, 1818, 'P: Every man waits. It is true that P and that P.', drs([], []), [], '2006-08-28-00-19-09', amadeus, '').
text_drs_eval(0, 1819, 'Proposition P: A dog likes everybody. It is true that P.', drs([], []), [], '2009-04-02-13-15-19', '130.60.155.206', '').
text_drs_eval(0, 1820, 'A dog of a man and a woman barks.', drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, D)-1, object(C, woman, countable, na, eq, 1)-1, has_part(D, B)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, bark, A)-1]), [[s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [woman]]]]]]]], [vp, [vbar, [v, [barks]]]]]], '2007-09-26-17-09-36', '130.60.155.177', '').
text_drs_eval(0, 1821, 'John\'s n:home-page is an n:URI "http://www.example.org/John".', drs([], []), [], '2007-04-10-15-47-28', '130.60.155.177', '').
text_drs_eval(0, 1822, 'Mary is v:given an apple by John.', drs([A, B, C, D], [object(B, 'John', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, given, B, C, A)-1]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [given]], [np, [det, [a]], [nbar, [n, [apple]]]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2006-08-27-18-47-31', amadeus, '').
text_drs_eval(0, 1823, 'An apple is v:given to John by Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, given, B, C, A)-1]), [[specification, [s, [np, [det, an], [nbar, [n, apple]]], [vp, [aux, is], [vbar, [v, given], to, [np, [pname, 'John']], by, [np, [pname, 'Mary']]]]], '.']], '2009-01-05-11-08-05', '130.60.155.206', '').
text_drs_eval(0, 1824, 'John and Mary\'s dogs bark.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, bark, E)-1, relation(D, of, B)-1, object(D, dog, countable, na, geq, 2)-1, has_part(E, A)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [poss_np, [pname, ['Mary']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dogs]]]]], [vp, [vbar, [v, [bark]]]]]], '2007-09-26-17-10-02', '130.60.155.177', '').
text_drs_eval(0, 1825, 'Some dogs of Mary and John bark.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, object(C, dog, countable, na, geq, 2)-1, has_part(D, A)-1, relation(C, of, D)-1, has_part(D, B)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, bark, C)-1]), [[specification, [s, [np, [det, some], [nbar, [n, dogs], [pp, [prep, of], [np_coord, [np, [pname, 'Mary']], [coord, and], [np, [pname, 'John']]]]]], [vp, [vbar, [v, bark]]]], '.']], '2008-10-06-14-48-05', '130.60.155.206', '').
text_drs_eval(0, 1826, 'John and some dogs of Mary bark.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, bark, E)-1, object(D, dog, countable, na, geq, 2)-1, relation(D, of, B)-1, has_part(E, A)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [det, [some]], [nbar, [n, [dogs]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]], [vp, [vbar, [v, [bark]]]]]], '2007-09-26-17-10-15', '130.60.155.177', '').
text_drs_eval(0, 1827, 'There are John and Mary. His and her dog barks.', drs([], []), [], '2006-08-28-16-08-49', amadeus, '').
text_drs_eval(0, 1828, 'There are John and Mary. His and her dogs bark.', drs([], []), [], '2006-08-28-16-09-06', amadeus, '').
text_drs_eval(0, 1829, 'There are John and Mary. He and her dogs bark.', drs([], []), [], '2008-01-03-16-29-39', '130.60.206.88', '').
text_drs_eval(0, 1830, 'A customer and a clerk\'s contract is valid.', drs([], []), [], '2006-08-28-16-09-23', amadeus, '').
text_drs_eval(0, 1831, 'A customer and a clerk\'s contracts are valid.', drs([A, B, C, D, E, F], [object(A, customer, countable, na, eq, 1)-1, property(B, valid, pos)-1, predicate(C, be, F, B)-1, object(D, clerk, countable, na, eq, 1)-1, relation(E, of, D)-1, object(E, contract, countable, na, geq, 2)-1, has_part(F, A)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [det, [a]], [nbar, [n, [customer]]]], [coord, [and]], [np, [poss_np, [det, [a]], [nbar, [n, [clerk]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [contracts]]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [valid]]]]]]]], '2007-09-26-17-11-01', '130.60.155.177', '').
text_drs_eval(0, 1832, 'John and Mary\'s contracts are valid.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, property(C, valid, pos)-1, predicate(D, be, F, C)-1, relation(E, of, B)-1, object(E, contract, countable, na, geq, 2)-1, has_part(F, A)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1]), [[s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [poss_np, [pname, ['Mary']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [contracts]]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [valid]]]]]]]], '2007-09-26-17-11-13', '130.60.155.177', '').
text_drs_eval(0, 1833, '5 men and a woman\'s card works.', drs([], []), [], '2006-08-28-21-05-22', amadeus, '').
text_drs_eval(0, 1834, '5 men\'s card works.', drs([A, B, C], [object(A, man, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, work, B)-1]), [[specification, [s, [np, [poss_spec, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]]], [nbar, [n, [card]]]], [vp, [vbar, [v, [works]]]]], ['.']]], '2006-08-27-21-10-01', amadeus, '').
text_drs_eval(0, 1835, 'There is a man. The man\'s dog\'s card works.', drs([], []), [], '2006-08-27-21-11-32', amadeus, '').
text_drs_eval(0, 1836, 'There is a man. His dog\'s card works.', drs([], []), [], '2006-08-28-21-04-08', amadeus, '').
text_drs_eval(0, 1837, 'Proposition A: A dog barks. Proposition B: Every cat knows that A. Proposition C: Every dog knows that it is true that B. It is true that C.', drs([], []), [], '2009-04-02-13-15-26', '130.60.155.206', '').
text_drs_eval(0, 1838, 'Proposition P: A dog barks. It is false that P.', drs([], []), [], '2009-04-02-13-15-32', '130.60.155.206', '').
text_drs_eval(0, 1839, 'Proposition P: Every man waits. It is true that P and that P.', drs([], []), [], '2009-04-02-13-15-38', '130.60.155.206', '').
text_drs_eval(0, 1840, 'Proposition P: A dog sees everybody that waits. It is true that P.', drs([], []), [], '2009-04-02-13-15-43', '130.60.155.206', '').
text_drs_eval(0, 1841, 'Proposition P: A dog sees nobody that waits. It is true that P.', drs([], []), [], '2009-04-02-13-15-49', '130.60.155.206', '').
text_drs_eval(0, 1842, 'A dog sees nobody.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [pn, [nobody]]]]]], ['.']]], '2006-08-28-00-27-55', amadeus, '').
text_drs_eval(0, 1843, 'Nobody that waits waits.', drs([], [drs([A, B], [predicate(A, wait, B)-1, object(B, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, wait, B)-1])])]), [[specification, [s, [nbar, [pn, [nobody]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2006-08-28-00-28-20', amadeus, '').
text_drs_eval(0, 1844, 'A dog sees nobody that waits.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B, C], [predicate(B, wait, C)-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([D], [predicate(D, see, A, C)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [nobody]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2007-01-09-20-23-02', '130.60.155.211', '').
text_drs_eval(0, 1845, 'Proposition P: There is a man. Proposition Q: He waits. It is true that P and that Q.', drs([], []), [], '2009-04-02-13-16-01', '130.60.155.206', '').
text_drs_eval(0, 1846, 'Proposition P: Mary sleeps. It is true that P.', drs([], []), [], '2009-04-02-13-16-06', '130.60.155.206', '').
text_drs_eval(0, 1847, 'Proposition P: Mary sleeps. It is false that P.', drs([], []), [], '2009-04-02-13-16-12', '130.60.155.206', '').
text_drs_eval(0, 1848, 'Proposition P: Mary sleeps. It is not provable that P.', drs([], []), [], '2009-04-02-13-16-17', '130.60.155.206', '').
text_drs_eval(0, 1849, 'Proposition P: Mary sleeps. John believes that P.', drs([], []), [], '2009-04-02-13-16-23', '130.60.155.206', '').
text_drs_eval(0, 1850, '5 clerks\' card is valid.', drs([A, B, C, D], [object(A, clerk, countable, na, eq, 5)-1, relation(B, of, A)-1, object(B, card, countable, na, eq, 1)-1, property(C, valid, pos)-1, predicate(D, be, B, C)-1]), [[specification, [s, [np, [poss_np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [clerks]]], ['|', [gen_marker, ['\'']]]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2006-08-28-17-22-08', amadeus, '').
text_drs_eval(0, 1851, '5 men are seen by everybody.', drs([A], [object(A, man, countable, na, eq, 5)-1, drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, see, B, A)-1])]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [5]]], [nbar, [n, [men]]]], [vp, [aux, [are]], [vbar, [v, [seen]], [by, [by]], [np, [pn, [everybody]]]]]], ['.']]], '2006-08-28-17-24-54', amadeus, '').
text_drs_eval(0, 1852, 'Some men\'s dog barks.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [poss_np, [det, [some]], [nbar, [n, [men]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-28-17-34-12', amadeus, '').
text_drs_eval(0, 1853, 'No man\'s dog barks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C], [predicate(C, bark, B)-1])])]), [[specification, [s, [np, [poss_np, [det, [no]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-11-20-17-44-55', '130.60.155.231', '').
text_drs_eval(0, 1854, 'There are some men. Their dog barks.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, relation(C, of, A)-2, predicate(B, bark, C)-2, object(C, dog, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]]]]]], ['.']], [specification, [s, [np, [poss_pn_coord, [posspn, [their]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-28-19-54-27', amadeus, '').
text_drs_eval(0, 1855, 'There are a man\'s dog and a cat.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, has_part(D, B)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1]), [[top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [poss_np, [det, [a]], [nbar, [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], '2007-09-26-17-11-38', '130.60.155.177', '').
text_drs_eval(0, 1856, 'A rich man\'s dog barks.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, property(A, rich, pos)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [adj, [rich]], [n, [man]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-29-12-00-16', amadeus, '').
text_drs_eval(0, 1857, 'A rich man X\'s dog barks.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, property(A, rich, pos)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[specification, [s, [np, [poss_np, [det, [a]], [nbar, [adj, [rich]], [n, [man]], [appos_coord, [appos, [var, ['X']]]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-08-29-12-00-53', amadeus, '').
text_drs_eval(0, 1858, 'A rich man X\'s dog barks. X waits.', drs([A, B, C, D], [relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-2, property(A, rich, pos)-1, object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[s, [np, [poss_np, [det, [a]], [nbar, [adj, [rich]], [n, [man]], [appos, [var, ['X']]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [s, [np, [var, ['X']]], [vp, [vbar, [v, [waits]]]]]], '2007-11-05-09-28-40', '130.60.155.231', '').
text_drs_eval(0, 1859, 'A man "X"\'s dog barks.', drs([], []), [], '2007-04-10-15-48-29', '130.60.155.177', '').
text_drs_eval(0, 1860, 'A man "X"\'s dog barks. The man "X" waits.', drs([], []), [], '2007-04-10-15-49-03', '130.60.155.177', '').
text_drs_eval(0, 1861, '2 men X and Y\'s dog barks.', drs([], []), [[s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['X']]]]], [coord, [and]], [np, [poss_np, [var, ['Y']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [barks]]]]]], '2007-10-17-16-48-27', '130.60.155.177', '').
text_drs_eval(0, 1862, 'Everything that affiliatedWith something that affiliatedWith something affiliatedWith it.', drs([], []), [], '2008-07-22-13-41-43', '130.60.155.206', '').
text_drs_eval(0, 1863, 'Everybody sees 3 things that wait.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C, D], [object(B, thing, countable, na, eq, 3)-1, predicate(C, wait, B)-1, predicate(D, see, A, B)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [things]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [wait]]]]]]]]]], ['.']]], '2006-08-29-14-13-39', amadeus, '').
text_drs_eval(0, 1864, 'Everybody sees 3 things that are some dogs.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, thing, countable, na, eq, 3)-1, object(C, dog, countable, na, geq, 2)-1, predicate(D, be, B, C)-1, predicate(E, see, A, B)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [things]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [are]], [np, [det, [some]], [nbar, [n, [dogs]]]]]]]]]]]], ['.']]], '2006-08-29-14-14-36', amadeus, '').
text_drs_eval(0, 1865, 'Everybody sees 3 things that are some dogs or that are some cats.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C], [object(B, thing, countable, na, eq, 3)-1, drs([D, E], [object(D, dog, countable, na, geq, 2)-1, predicate(E, be, B, D)-1])v drs([F, G], [object(F, cat, countable, na, geq, 2)-1, predicate(G, be, B, F)-1]), predicate(C, see, A, B)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [things]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [are]], [np, [det, [some]], [nbar, [n, [dogs]]]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [are]], [np, [det, [some]], [nbar, [n, [cats]]]]]]]]]]]]], ['.']]], '2006-08-29-14-16-04', amadeus, '').
text_drs_eval(0, 1866, 'Everybody sees 3 men who wait.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C, D], [object(B, man, countable, na, eq, 3)-1, predicate(C, wait, B)-1, predicate(D, see, A, B)-1])]), [[specification, [s, [np, [pn, [everybody]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [wait]]]]]]]]]], ['.']]], '2006-12-18-21-58-41', unknown, '').
text_drs_eval(0, 1867, 'No cards are valid.', drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [property(B, valid, pos)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [cards]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2007-07-18-14-39-55', '130.60.155.177', '').
text_drs_eval(0, 1868, 'John who has a card enters it.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, predicate(B, enter, A, C)-1, object(C, card, countable, na, eq, 1)-1, predicate(D, have, A, C)-1]), [[specification, [s, [np, [pname, ['John']], [rel_cl, [comp, [who]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [card]]]]]]]], [vp, [vbar, [v, [enters]], [np, [pn, [it]]]]]], ['.']]], '2006-08-30-20-42-33', amadeus, '').
text_drs_eval(0, 1869, 'There is a man. John does not like the man.', drs([A, B], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, -drs([C], [predicate(C, like, A, B)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [the]], [nbar, [n, [man]]]]]]], ['.']]], '2007-08-19-15-38-30', '130.60.155.177', '').
text_drs_eval(0, 1870, 'A man owns a dog. A man owns a cat. John sees the man who owns a dog.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, object(E, man, countable, na, eq, 1)-2, object(F, cat, countable, na, eq, 1)-2, predicate(G, own, E, F)-2, predicate(H, see, A, B)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]], '.']], '2008-08-12-10-12-18', '130.60.206.55', '').
text_drs_eval(0, 1871, 'Every goat likes some grass and likes some water and doesn\'t like something that is not some grass and that is not some water.', drs([], [drs([A], [object(A, goat, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, grass, mass, na, na, na)-1, predicate(C, like, A, B)-1, object(D, water, mass, na, na, na)-1, predicate(E, like, A, D)-1, -drs([F, G], [object(F, something, dom, na, na, na)-1, predicate(G, like, A, F)-1, -drs([H, I], [object(H, grass, mass, na, na, na)-1, predicate(I, be, F, H)-1]), -drs([J, K], [object(J, water, mass, na, na, na)-1, predicate(K, be, F, J)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [goat]]]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [some]], [nbar, [n, [grass]]]]]], [coord, [and]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [some]], [nbar, [n, [water]]]]]], [coord, [and]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [nbar, [pn, [something]], [rel_cl_coord, [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [some]], [nbar, [n, [grass]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [some]], [nbar, [n, [water]]]]]]]]]]]]]], ['.']]], '2006-10-29-16-12-09', amadeus, '').
text_drs_eval(0, 1872, 'Every pet is a dog or is a cat ,and is not something that is a dog and that is a cat.', drs([], [drs([A], [object(A, pet, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, be, A, D)-1]), -drs([F, G, H, I, J, K], [object(F, something, dom, na, na, na)-1, predicate(G, be, A, F)-1, object(H, dog, countable, na, eq, 1)-1, predicate(I, be, F, H)-1, object(J, cat, countable, na, eq, 1)-1, predicate(K, be, F, J)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [pet]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, ['{, and}']], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [nbar, [pn, [something]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]], ['.']]], '2006-10-30-20-16-23', amadeus, '').
text_drs_eval(0, 1873, 'If there is a pet X then X is a dog or X is a cat ,and it is false that X is a dog and that X is a cat.', drs([], [drs([A], [object(A, pet, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, be, A, D)-1]), -drs([F, G, H, I], [object(F, dog, countable, na, eq, 1)-1, predicate(G, be, A, F)-1, object(H, cat, countable, na, eq, 1)-1, predicate(I, be, A, H)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [pet]], [appos_coord, [appos, [var, ['X']]]]]]]], [then], [s_coord, [s_coord, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [or]], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], [coord, ['{, and}']], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]]], ['.']]], '2006-10-30-20-23-11', amadeus, '').
text_drs_eval(0, 1874, 'Every pet is a dog or is a cat ,and is a cow.', drs([], [drs([A], [object(A, pet, countable, na, eq, 1)-1])=>drs([B, C], [drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])v drs([F, G], [object(F, cat, countable, na, eq, 1)-1, predicate(G, be, A, F)-1]), object(B, cow, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [pet]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, ['{, and}']], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cow]]]]]]]], ['.']]], '2006-10-30-20-45-53', amadeus, '').
text_drs_eval(0, 1875, 'Every pet is a dog or is a cat ,and is not a cow.', drs([], [drs([A], [object(A, pet, countable, na, eq, 1)-1])=>drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, be, A, D)-1]), -drs([F, G], [object(F, cow, countable, na, eq, 1)-1, predicate(G, be, A, F)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [pet]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [coord, ['{, and}']], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [cow]]]]]]]], ['.']]], '2006-10-30-20-50-33', amadeus, '').
text_drs_eval(0, 1876, 'Every pet is not a cow ,and is a dog or is a cat.', drs([], [drs([A], [object(A, pet, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, cow, countable, na, eq, 1)-1, predicate(C, be, A, B)-1]), drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])v drs([F, G], [object(F, cat, countable, na, eq, 1)-1, predicate(G, be, A, F)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [pet]]]], [vp_coord, [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [cow]]]]]], [coord, ['{, and}']], [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2006-10-30-20-58-35', amadeus, '').
text_drs_eval(0, 1877, 'Every man works or eats and sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, work, A)-1])v drs([C, D], [predicate(C, eat, A)-1, predicate(D, sleep, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [works]]]], [coord, [or]], [vp_coord, [vp, [vbar, [v, [eats]]]], [coord, [and]], [vp, [vbar, [v, [sleeps]]]]]]], ['.']]], '2006-10-31-14-10-41', amadeus, '').
text_drs_eval(0, 1878, 'Every man works or eats ,and sleeps or drinks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, work, A)-1])v drs([C], [predicate(C, eat, A)-1]), drs([D], [predicate(D, sleep, A)-1])v drs([E], [predicate(E, drink, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [works]]]], [coord, [or]], [vp, [vbar, [v, [eats]]]]], [coord, ['{, and}']], [vp_coord, [vp, [vbar, [v, [sleeps]]]], [coord, [or]], [vp, [vbar, [v, [drinks]]]]]]], ['.']]], '2006-10-31-15-13-09', amadeus, '').
text_drs_eval(0, 1879, 'Every man sees a dog that barks or works.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, see, A, B)-1])v drs([E], [predicate(E, work, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [works]]]]]], ['.']]], '2006-10-31-16-38-00', amadeus, '').
text_drs_eval(0, 1880, 'Every man works or sees a dog that barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, work, A)-1])v drs([C, D, E], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1, predicate(E, see, A, C)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [works]]]], [coord, [or]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]]]], ['.']]], '2006-10-31-16-38-36', amadeus, '').
text_drs_eval(0, 1881, 'Some men are at least 2 men.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, object(B, man, countable, na, geq, 2)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [are]], [np, [numberp, [gen_quant, ['{at least}']], [number, [2]]], [nbar, [n, [men]]]]]]], ['.']]], '2006-10-31-16-44-54', amadeus, '').
text_drs_eval(0, 1882, 'Proposition A: A man X has a card. Proposition B: The man X has a code. It is true that A and it is true that B.', drs([], []), [], '2009-04-02-13-16-32', '130.60.155.206', '').
text_drs_eval(0, 1883, 'If a message is from someone from which John awaits a delivery then the message is important.', drs([], []), [], '2007-11-20-11-29-03', '130.60.155.231', '').
text_drs_eval(0, 1884, 'There is a dog of John. There is a dog of Mary. The dog of John barks.', drs([A, B, C, D, E], [relation(C, of, A)-1, relation(D, of, B)-2, predicate(E, bark, C)-3, object(C, dog, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, object(D, dog, countable, na, eq, 1)-2, object(B, 'Mary', named, na, eq, 1)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]]], [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [barks]]]]]], '2007-11-05-11-16-20', '130.60.155.231', '').
text_drs_eval(0, 1885, 'Every man sees a dog that barks or sees himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, see, A, B)-1])v drs([E], [predicate(E, see, A, A)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]]], ['.']]], '2006-11-01-16-54-27', amadeus, '').
text_drs_eval(0, 1886, 'Every man sees a dog that barks or sees itself.', drs([], []), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp_coord, [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [v, barks]]]]]]]], [coord, or], [vp, [vbar, [v, sees], [np, [pn, itself]]]]]], '.']], '2008-07-30-01-09-54', '130.60.204.7', '').
text_drs_eval(0, 1887, 'Every man hears a dog that does not bark and sees a cat that does not sleep.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, -drs([F], [predicate(F, bark, B)-1]), predicate(C, hear, A, B)-1, object(D, cat, countable, na, eq, 1)-1, -drs([G], [predicate(G, sleep, D)-1]), predicate(E, see, A, D)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [hears]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [aux, ['{does not}']], [vbar, [v, [bark]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [aux, ['{does not}']], [vbar, [v, [sleep]]]]]]]]]]], ['.']]], '2006-11-01-20-49-49', amadeus, '').
text_drs_eval(0, 1888, 'If there is a man then he sees a cat X and it is false that X sees a mouse and that X sees a rat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([D, E, F, G], [object(D, mouse, countable, na, eq, 1)-1, predicate(E, see, B, D)-1, object(F, rat, countable, na, eq, 1)-1, predicate(G, see, B, F)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [appos_coord, [appos, [var, ['X']]]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]]]]]]]], ['.']]], '2007-08-14-20-25-02', '130.60.155.177', '').
text_drs_eval(0, 1889, 'If there is a man then he sees a cat X and it is possible that X sees a mouse and that X sees a rat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, can(drs([D, E, F, G], [object(D, mouse, countable, na, eq, 1)-1/20, predicate(E, see, B, D)-1/18, object(F, rat, countable, na, eq, 1)-1/26, predicate(G, see, B, F)-1/24]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [poss, 'it is possible'], [cp, that, [s_coord, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, mouse]]]]]]], [coord, and], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, rat]]]]]]]]]]]]], '.']], '2010-10-27-09-25-07', '89.206.64.27', '').
text_drs_eval(0, 1890, 'If there is a man then he sees a cat X and it is necessary that X sees a mouse and that X sees a rat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, must(drs([D, E, F, G], [object(D, mouse, countable, na, eq, 1)-1/20, predicate(E, see, B, D)-1/18, object(F, rat, countable, na, eq, 1)-1/26, predicate(G, see, B, F)-1/24]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [necessity, 'it is necessary'], [cp, that, [s_coord, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, mouse]]]]]]], [coord, and], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, rat]]]]]]]]]]]]], '.']], '2010-10-27-09-25-13', '89.206.64.27', '').
text_drs_eval(0, 1891, 'If there is a man then he sees a cat X and it is false that X eats and that X waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([D, E], [predicate(D, eat, B)-1, predicate(E, wait, B)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [appos_coord, [appos, [var, ['X']]]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [eats]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [waits]]]]]]]]]]], ['.']]], '2006-11-02-11-52-08', amadeus, '').
text_drs_eval(0, 1892, 'If there is a man then he sees a cat X and it is possible that X eats and that X waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, can(drs([D, E], [predicate(D, eat, B)-1/18, predicate(E, wait, B)-1/22]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [poss, 'it is possible'], [cp, that, [s_coord, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, eats]]]]], [coord, and], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, waits]]]]]]]]]]], '.']], '2010-10-27-09-25-20', '89.206.64.27', '').
text_drs_eval(0, 1893, 'If there is a man then he sees a cat X and it is necessary that X eats and that X waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, must(drs([D, E], [predicate(D, eat, B)-1/18, predicate(E, wait, B)-1/22]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [necessity, 'it is necessary'], [cp, that, [s_coord, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, eats]]]]], [coord, and], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, waits]]]]]]]]]]], '.']], '2010-10-27-09-25-27', '89.206.64.27', '').
text_drs_eval(0, 1894, 'If there is a man then he sees a cat X and it is false that X eats or that X waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([], [drs([D], [predicate(D, eat, B)-1])v drs([E], [predicate(E, wait, B)-1])])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [appos_coord, [appos, [var, ['X']]]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [eats]]]]]], [coord, [or]], [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [waits]]]]]]]]]], ['.']]], '2006-11-02-12-05-23', amadeus, '').
text_drs_eval(0, 1895, 'If there is a man then he sees a cat X and it is possible that X eats or that X waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, can(drs([], [drs([D], [predicate(D, eat, B)-1/18])v drs([E], [predicate(E, wait, B)-1/22])]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [poss, 'it is possible'], [s_coord, [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, waits]]]]]]]]]], '.']], '2010-10-27-09-25-35', '89.206.64.27', '').
text_drs_eval(0, 1896, 'If there is a man then he sees a cat X and it is necessary that X eats or that X waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, must(drs([], [drs([D], [predicate(D, eat, B)-1/18])v drs([E], [predicate(E, wait, B)-1/22])]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [necessity, 'it is necessary'], [s_coord, [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, waits]]]]]]]]]], '.']], '2010-10-27-09-25-40', '89.206.64.27', '').
text_drs_eval(0, 1897, 'If there is a man then he sees a cat X and it is false that X sees a mouse or that X sees a rat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([], [drs([D, E], [object(D, mouse, countable, na, eq, 1)-1, predicate(E, see, B, D)-1])v drs([F, G], [object(F, rat, countable, na, eq, 1)-1, predicate(G, see, B, F)-1])])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s_coord, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [appos_coord, [appos, [var, ['X']]]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]], [coord, [or]], [cp, ['_that_'], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rat]]]]]]]]]]]], ['.']]], '2007-08-14-20-26-08', '130.60.155.177', '').
text_drs_eval(0, 1898, 'If there is a man then he sees a cat X and it is necessary that X sees a mouse or that X sees a rat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, must(drs([], [drs([D, E], [object(D, mouse, countable, na, eq, 1)-1/20, predicate(E, see, B, D)-1/18])v drs([F, G], [object(F, rat, countable, na, eq, 1)-1/26, predicate(G, see, B, F)-1/24])]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [necessity, 'it is necessary'], [s_coord, [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, mouse]]]]]]]], [coord, or], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, rat]]]]]]]]]]]], '.']], '2010-10-27-09-25-52', '89.206.64.27', '').
text_drs_eval(0, 1899, 'If there is a man then he sees a cat X and it is possible that X sees a mouse or that X sees a rat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B, C], [object(B, cat, countable, na, eq, 1)-1/10, predicate(C, see, A, B)-1/8, can(drs([], [drs([D, E], [object(D, mouse, countable, na, eq, 1)-1/20, predicate(E, see, B, D)-1/18])v drs([F, G], [object(F, rat, countable, na, eq, 1)-1/26, predicate(G, see, B, F)-1/24])]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'X']]]]]]]], [coord, and], [s, [poss, 'it is possible'], [s_coord, [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, mouse]]]]]]]], [coord, or], [cp, that, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, rat]]]]]]]]]]]], '.']], '2010-10-27-09-25-58', '89.206.64.27', '').
text_drs_eval(0, 1900, 'Every man hears a dog that does not bark and sees a cat that sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(B, dog, countable, na, eq, 1)-1, -drs([G], [predicate(G, bark, B)-1]), predicate(C, hear, A, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, sleep, D)-1, predicate(F, see, A, D)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [hears]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [aux, ['{does not}']], [vbar, [v, [bark]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]]]]]]]], ['.']]], '2006-11-02-14-57-45', amadeus, '').
text_drs_eval(0, 1901, 'Every man hears a dog that barks and sees a cat that sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1, predicate(D, hear, A, B)-1, object(E, cat, countable, na, eq, 1)-1, predicate(F, sleep, E)-1, predicate(G, see, A, E)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [hears]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [barks]]]]]]]]], [coord, [and]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sleeps]]]]]]]]]]], ['.']]], '2006-11-02-14-59-09', amadeus, '').
text_drs_eval(0, 1902, 'Every man hates a dog that knows something or hates a cat that knows something.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, object(C, something, dom, na, na, na)-1, predicate(D, know, B, C)-1, predicate(E, hate, A, B)-1])v drs([F, G, H, I], [object(F, cat, countable, na, eq, 1)-1, object(G, something, dom, na, na, na)-1, predicate(H, know, F, G)-1, predicate(I, hate, A, F)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [knows]], [np, [pn, [something]]]]]]]]]], [coord, [or]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [knows]], [np, [pn, [something]]]]]]]]]]]], ['.']]], '2006-11-02-17-37-26', amadeus, '').
text_drs_eval(0, 1903, 'Every man sees 2 dogs that see 3 cats.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, dog, countable, na, eq, 2)-1, object(C, cat, countable, na, eq, 3)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [dogs]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [see]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [cats]]]]]]]]]]]], ['.']]], '2006-11-03-13-09-37', amadeus, '').
text_drs_eval(0, 1904, 'Every man sees 2 dogs that see a cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, dog, countable, na, eq, 2)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, see, A, B)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [dogs]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']]], '2006-11-03-13-16-40', amadeus, '').
text_drs_eval(0, 1905, 'Paris is a village or is a city.', drs([A], [object(A, 'Paris', named, na, eq, 1)-1, drs([B, C], [object(B, village, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])v drs([D, E], [object(D, city, countable, na, eq, 1)-1, predicate(E, be, A, D)-1])]), [[specification, [s, [np, [pname, ['Paris']]], [vp_coord, [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [village]]]]]], [coord, [or]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [city]]]]]]]], ['.']]], '2006-11-05-16-41-55', amadeus, '').
text_drs_eval(0, 1906, 'A n:named_entity waits.', drs([A, B], [object(A, named_entity, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [named_entity]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-30-17-35-23', '130.60.155.177', '').
text_drs_eval(0, 1907, 'John is 3.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, be, A, int(3))-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [int, [3]]]]]], ['.']]], '2007-09-01-17-05-20', '130.60.155.177', '').
text_drs_eval(0, 1908, '2 men are seen by 2 dogs.', drs([A, B, C], [object(A, man, countable, na, eq, 2)-1, object(B, dog, countable, na, eq, 2)-1, predicate(C, see, B, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]]]], [vp, [aux, [are]], [vbar, [v, [seen]], [by, [by]], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [dogs]]]]]]], ['.']]], '2006-11-11-14-08-59', amadeus, '').
text_drs_eval(0, 1909, 'Every goat eats at most 0 things that are not some grass.', drs([], [drs([A], [object(A, goat, countable, na, eq, 1)-1/2])=>drs([B, C], [[predicate(C, eat, A, B)-1/3, -drs([D, E], [object(D, grass, mass, na, na, na)-1/12, predicate(E, be, B, D)-1/9]), object(B, thing, countable, na, leq, 0)-1/7]])]), [[specification, [s, [np, [det, every], [nbar, [n, goat]]], [vp, [vbar, [vcompl, [v, eats], [np, [nump, [genqu, 'at most'], 0], [nbar, [n, things], [rel_cl, [comp, that], [vp, [aux, are, not], [np, [det, some], [nbar, [n, grass]]]]]]]]]]], '.']], '2010-01-18-11-13-33', '89.206.64.72', '').
text_drs_eval(0, 1910, 'Everybody who is John is a man.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [predicate(B, be, C, A)-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([D, E], [object(D, man, countable, na, eq, 1)-1, predicate(E, be, C, D)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [pname, ['John']]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2006-11-18-20-21-36', amadeus, '').
text_drs_eval(0, 1911, 'No password is "god".', drs([], [drs([A], [object(A, password, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, be, A, string(god))-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [password]]]], [vp, [vbar, [v, [is]], [np, [string, [god]]]]]], ['.']]], '2007-09-01-16-35-33', '130.60.155.177', '').
text_drs_eval(0, 1912, 'A man is taller than no dog.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C, D], [property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [det, [no]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-14-46', '130.60.156.229', '').
text_drs_eval(0, 1913, 'Every man is taller than no dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C, D], [property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [det, [no]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-14-55', '130.60.156.229', '').
text_drs_eval(0, 1914, 'No man is taller than every dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1])])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [det, [every]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-15-01', '130.60.156.229', '').
text_drs_eval(0, 1915, 'No man is taller than no dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [-drs([C, D], [property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1])])])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [det, [no]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-15-06', '130.60.156.229', '').
text_drs_eval(0, 1916, 'No man is taller than a dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1, property(C, tall, comp_than, B)-1, predicate(D, be, A, C)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [taller]], [conj, [than]], [np, [det, [a]], [nbar, [n, [dog]]]]]|E]]]], ['.']]], '2007-05-09-12-15-12', '130.60.156.229', '').
text_drs_eval(0, 1917, 'A customer is richer than Mary and taller than no dog.', drs([], []), [], '2006-11-22-13-15-38', amadeus, '').
text_drs_eval(0, 1918, 'If someone X waits then X is a customer. Someone X waits.', drs([A, B], [drs([C, D], [object(C, somebody, countable, na, eq, 1)-1, predicate(D, wait, C)-1])=>drs([E, F], [object(E, customer, countable, na, eq, 1)-1, predicate(F, be, C, E)-1]), object(A, somebody, countable, na, eq, 1)-2, predicate(B, wait, A)-2]), [[specification, [cond_s, if, [s, [np, [pn, someone], [appos, [var, 'X']]], [vp, [vbar, [v, waits]]]], then, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]]], '.'], [specification, [s, [np, [pn, someone], [appos, [var, 'X']]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-37-18', '130.60.204.15', '').
text_drs_eval(0, 1919, 'There is a man X. If X owns a dog then the dog hates a cat.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C], [object(B, dog, countable, na, eq, 1)-2, predicate(C, own, A, B)-2])=>drs([D, E], [object(D, cat, countable, na, eq, 1)-2, predicate(E, hate, B, D)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']], [specification, [cond_s, [if], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-11-25-14-28-32', amadeus, '').
text_drs_eval(0, 1920, 'does not John like Mary?', drs([], []), [], '2007-06-12-10-50-50', '130.60.156.66', '').
text_drs_eval(0, 1921, 'can John like Mary?', drs([], [question(drs([], [can(drs([A], [predicate(A, like, named('John'), named('Mary'))-1/3]))]))]), [[query, [question, can, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, like], [np, [pname, 'Mary']]]]]], ?]], '2010-10-27-09-26-04', '89.206.64.27', '').
text_drs_eval(0, 1922, 'must John like Mary?', drs([], [question(drs([], [must(drs([A], [predicate(A, like, named('John'), named('Mary'))-1/3]))]))]), [[query, [question, must, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, like], [np, [pname, 'Mary']]]]]], ?]], '2010-10-27-09-26-10', '89.206.64.27', '').
text_drs_eval(0, 1923, 'What does not a customer enter?', drs([], []), [], '2007-06-12-10-51-06', '130.60.156.66', '').
text_drs_eval(0, 1924, 'What can a customer enter?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/4, can(drs([B, C], [query(B, what)-1/1, predicate(C, enter, A, B)-1/5]))]))]), [[query, [question, [np, [qpn, what]], can, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter]]]]], ?]], '2010-10-27-09-26-16', '89.206.64.27', '').
text_drs_eval(0, 1925, 'What must a customer enter?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/4, must(drs([B, C], [query(B, what)-1/1, predicate(C, enter, A, B)-1/5]))]))]), [[query, [question, [np, [qpn, what]], must, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter]]]]], ?]], '2010-10-27-09-26-23', '89.206.64.27', '').
text_drs_eval(0, 1926, 'Into what does not a customer enter a card?', drs([], []), [], '2007-06-12-10-52-33', '130.60.156.66', '').
text_drs_eval(0, 1927, 'Into what can a customer enter a card?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/5, can(drs([B, C, D], [object(B, card, countable, na, eq, 1)-1/8, query(C, what)-1/2, predicate(D, enter, A, B)-1/6, modifier_pp(D, into, C)-1/1]))]))]), [[query, [question, [pp, [prep, 'Into'], [np, [qpn, what]]], can, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?]], '2010-10-27-09-26-28', '89.206.64.27', '').
text_drs_eval(0, 1928, 'Where does not a customer enter a card?', drs([], []), [], '2007-06-12-10-53-24', '130.60.156.66', '').
text_drs_eval(0, 1929, 'Where must a customer enter a card?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/4, must(drs([B, C], [object(B, card, countable, na, eq, 1)-1/7, predicate(C, enter, A, B)-1/5, query(C, where)-1/1]))]))]), [[query, [question, [qpn, where], must, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?]], '2010-10-27-09-26-39', '89.206.64.27', '').
text_drs_eval(0, 1930, 'If there is an animal X then an animal Y is smaller than the animal X and the animal X eats the animal Y.', drs([], [drs([A], [object(A, animal, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, animal, countable, na, eq, 1)-1, property(C, small, comp_than, A)-1, predicate(D, be, B, C)-1, predicate(E, eat, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [appos, [var, 'X']]]]]], then, [s_coord, [s, [np, [det, an], [nbar, [n, animal], [appos, [var, 'Y']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, smaller], [conj, than], [np, [det, the], [nbar, [n, animal], [appos, [var, 'X']]]]]]]]], [coord, and], [s, [np, [det, the], [nbar, [n, animal], [appos, [var, 'X']]]], [vp, [vbar, [v, eats], [np, [det, the], [nbar, [n, animal], [appos, [var, 'Y']]]]]]]]], '.']], '2008-08-15-20-34-09', '130.60.204.15', '').
text_drs_eval(0, 1931, 'Somebody X sees somebody X.', drs([], []), [[specification, [s, [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]]]]], ['.']]], '2006-11-28-16-27-28', amadeus, '').
text_drs_eval(0, 1932, 'A customer inserts a card carefully or manually.', drs([], []), [], '2006-11-29-15-51-58', amadeus, '').
text_drs_eval(0, 1933, 'A dog eats nothing that is a mouse.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B, C, D], [object(B, mouse, countable, na, eq, 1)-1, predicate(C, be, D, B)-1, object(D, something, dom, na, na, na)-1])=>drs([], [-drs([E], [predicate(E, eat, A, D)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]], [nbar, [pn, [nothing]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]]]]], ['.']]], '2007-01-09-20-21-04', '130.60.155.211', '').
text_drs_eval(0, 1934, 'A dog does not eat something that is a mouse.', drs([A], [object(A, dog, countable, na, eq, 1)-1, -drs([B, C, D, E], [object(B, something, dom, na, na, na)-1, predicate(C, eat, A, B)-1, object(D, mouse, countable, na, eq, 1)-1, predicate(E, be, B, D)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [aux, ['{does not}']], [vbar, [v, [eat]], [nbar, [pn, [something]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [mouse]]]]]]]]]]], ['.']]], '2006-12-11-20-33-05', amadeus, '').
text_drs_eval(0, 1935, 'No group contains a member X1 and contains a member X2 that comes-from an institution that X1 that is not X2 comes-from.', drs([], []), [], '2008-09-23-08-50-55', '130.60.155.206', '').
text_drs_eval(0, 1936, 'John is not been by Mary.', drs([], []), [], '2006-12-18-22-07-06', unknown, '').
text_drs_eval(0, 1937, 'If there is a man then a human is the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, human, countable, na, eq, 1)-1, predicate(C, be, B, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [human]]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']]], '2006-12-15-21-44-31', amadeus, '').
text_drs_eval(0, 1938, 'If there is a man then a human must be the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B], [object(B, human, countable, na, eq, 1)-1/8, must(drs([C], [predicate(C, be, B, A)-1/9]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, must, be], [np, [det, the], [nbar, [n, man]]]]]], '.']], '2010-10-27-09-26-45', '89.206.64.27', '').
text_drs_eval(0, 1939, 'If there is a man then a human can be the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B], [object(B, human, countable, na, eq, 1)-1/8, can(drs([C], [predicate(C, be, B, A)-1/9]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, can, be], [np, [det, the], [nbar, [n, man]]]]]], '.']], '2010-10-27-09-26-50', '89.206.64.27', '').
text_drs_eval(0, 1940, 'If there is a man then a human can not be the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B], [object(B, human, countable, na, eq, 1)-1/8, -drs([], [can(drs([C], [predicate(C, be, B, A)-1/9]))])])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, can, 'not be'], [np, [det, the], [nbar, [n, man]]]]]], '.']], '2010-10-27-09-26-55', '89.206.64.27', '').
text_drs_eval(0, 1941, 'If there is a man then a human does not have to be the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([B], [object(B, human, countable, na, eq, 1)-1/8, -drs([], [must(drs([C], [predicate(C, be, B, A)-1/9]))])])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, does, 'not have to be'], [np, [det, the], [nbar, [n, man]]]]]], '.']], '2010-10-27-09-27-01', '89.206.64.27', '').
text_drs_eval(0, 1942, 'If there is a dog then it is false that a cat is the dog.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, be, B, A)-1])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [then], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]], ['.']]], '2006-12-16-16-42-52', amadeus, '').
text_drs_eval(0, 1943, 'For every dog the dog is not a cat.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, cat, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [dog]]]], [s, [np, [det, [the]], [nbar, [n, [dog]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2006-12-16-16-44-30', amadeus, '').
text_drs_eval(0, 1944, 'For every dog a cat is not the dog.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B], [object(B, cat, countable, na, eq, 1)-1, -drs([C], [predicate(C, be, B, A)-1])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [dog]]]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]], ['.']]], '2006-12-16-16-45-01', amadeus, '').
text_drs_eval(0, 1945, 'If there is a man then it is necessary that a human is the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([], [must(drs([B, C], [object(B, human, countable, na, eq, 1)-1/12, predicate(C, be, B, A)-1/13]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, is], [np, [det, the], [nbar, [n, man]]]]]]]], '.']], '2010-10-27-09-27-19', '89.206.64.27', '').
text_drs_eval(0, 1946, 'If there is a man then it is possible that a human is the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([], [can(drs([B, C], [object(B, human, countable, na, eq, 1)-1/12, predicate(C, be, B, A)-1/13]))])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [poss, 'it is possible'], [cp, that, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, is], [np, [det, the], [nbar, [n, man]]]]]]]], '.']], '2010-10-27-09-27-32', '89.206.64.27', '').
text_drs_eval(0, 1947, 'If there is a man then it is not necessary that a human is the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [must(drs([B, C], [object(B, human, countable, na, eq, 1)-1/13, predicate(C, be, B, A)-1/14]))])])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [unnecessity, 'it is not necessary'], [cp, that, [s, [np, [det, a], [nbar, [n, human]]], [vp, [aux, is], [np, [det, the], [nbar, [n, man]]]]]]]], '.']], '2010-10-27-09-27-37', '89.206.64.27', '').
text_drs_eval(0, 1948, 'If there is a man then it is not possible that there is a human that is the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [can(drs([B, C], [object(B, human, countable, na, eq, 1)-1/15, predicate(C, be, B, A)-1/17]))])])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], then, [s, [impossibility, 'it is not possible'], [cp, that, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, human], [rel_cl, [comp, that], [vp, [aux, is], [np, [det, the], [nbar, [n, man]]]]]]]]]]]], '.']], '2010-10-27-09-27-42', '89.206.64.27', '').
text_drs_eval(0, 1949, 'A x1 x2 x3 x4.', drs([], []), [], '2007-07-18-14-40-37', '130.60.155.177', '').
text_drs_eval(0, 1950, 'There is a dog. A man does not hit the dog. The dog barks.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, -drs([D], [predicate(D, hit, B, A)-2]), predicate(C, bark, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, ['{does not}']], [vbar, [v, [hit]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2006-12-18-21-12-05', amadeus, '').
text_drs_eval(0, 1951, 'More than 3 clerks wait. John knows the clerks. Less than 2 clerks meet. John knows the clerks.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-2, object(B, clerk, countable, na, greater, 3)-1, predicate(C, wait, B)-1, predicate(D, know, A, B)-2, [predicate(F, meet, E)-3, object(E, clerk, countable, na, less, 2)-3], predicate(G, know, A, E)-4]), [[specification, [s, [np, [nump, [genqu, 'more than'], 3], [nbar, [n, clerks]]], [vp, [vbar, [vbar, [v, wait]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, knows], [np, [det, the], [nbar, [n, clerks]]]]]]], '.'], [specification, [s, [np, [nump, [genqu, 'less than'], 2], [nbar, [n, clerks]]], [vp, [vbar, [vbar, [v, meet]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, knows], [np, [det, the], [nbar, [n, clerks]]]]]]], '.']], '2009-03-02-11-29-27', '130.60.155.206', '').
text_drs_eval(0, 1952, 'A a:x1 n:x2 v:x3 a:x4.', drs([A, B], [object(A, x2, countable, na, eq, 1)-1, property(A, x1, pos)-1, predicate(B, x3, A)-1, modifier_adv(B, x4, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [adj, [x1]], [nbar, [n, [x2]]]]], [vp, [vbar, [vbar, [v, [x3]]], [adv, [x4]]]]], ['.']]], '2006-12-18-22-12-22', unknown, '').
text_drs_eval(0, 1953, 'Not a man waits.', drs([], []), [], '2007-08-08-09-57-55', '130.60.155.231', '').
text_drs_eval(0, 1954, 'Not there is a man.', drs([], []), [], '2007-08-08-09-58-05', '130.60.155.231', '').
text_drs_eval(0, 1955, 'There is a man "<".', drs([], []), [], '2007-11-06-17-33-20', '130.60.155.177', '').
text_drs_eval(0, 1956, 'More than 3 men wait.', drs([A, B], [object(A, man, countable, na, greater, 3)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, ['{more than}']], [number, [3]]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2006-12-21-16-37-31', '130.60.155.211', '').
text_drs_eval(0, 1957, 'John does not believe that Mary sleeps.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, -drs([C, D], [predicate(C, believe, A, D)-1, D:drs([E], [predicate(E, sleep, B)-1])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [v, believe], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, sleeps]]]]]]]], '.']], '2008-08-19-19-02-40', '130.60.155.177', '').
text_drs_eval(0, 1958, 'One man sleeps.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, sleep, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, ['One']]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-01-09-20-17-49', '130.60.155.211', '').
text_drs_eval(0, 1959, 'A man & waits.', drs([], []), [], '2007-09-01-17-05-32', '130.60.155.177', '').
text_drs_eval(0, 1960, 'A man < waits.', drs([], []), [], '2007-11-06-17-33-39', '130.60.155.177', '').
text_drs_eval(0, 1961, 'A dog sees no man that waits.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1])=>drs([], [-drs([D], [predicate(D, see, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [no]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]]], ['.']]], '2007-01-09-18-56-15', '130.60.155.211', '').
text_drs_eval(0, 1962, 'A man sees not everything.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([B], [object(B, something, dom, na, na, na)-1])=>drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, ['{not everything}']]]]]], ['.']]], '2007-08-08-09-56-04', '130.60.155.231', '').
text_drs_eval(0, 1963, 'A man does not see everything.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([B], [object(B, something, dom, na, na, na)-1])=>drs([C], [predicate(C, see, A, B)-1])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, ['{does not}']], [vbar, [v, [see]], [np, [pn, [everything]]]]]], ['.']]], '2007-01-09-19-34-10', '130.60.155.211', '').
text_drs_eval(0, 1964, 'There is no man that sees something.', drs([], [-drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, see, A, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [pn, [something]]]]]]]]]], ['.']]], '2007-01-09-19-52-47', '130.60.155.211', '').
text_drs_eval(0, 1965, 'If there is nobody then a dog barks.', drs([], [drs([], [-drs([A], [object(A, somebody, countable, na, eq, 1)-1])])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [pn, [nobody]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-01-09-20-33-54', '130.60.155.211', '').
text_drs_eval(0, 1966, 'If nobody waits then a dog barks.', drs([], [drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, wait, A)-1])])])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, [if], [s, [np, [pn, [nobody]]], [vp, [vbar, [v, [waits]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-01-09-20-34-39', '130.60.155.211', '').
text_drs_eval(0, 1967, 'If there is nobody that waits then a dog barks.', drs([], [drs([], [-drs([A, B], [predicate(A, wait, B)-1, object(B, somebody, countable, na, eq, 1)-1])])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [nobody]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-06-12-10-54-41', '130.60.156.66', '').
text_drs_eval(0, 1968, 'If there is no man that waits then a dog barks.', drs([], [drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [no]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [waits]]]]]]]]], [then], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-01-09-20-43-44', '130.60.155.211', '').
text_drs_eval(0, 1969, 'Not not everybody waits.', drs([], []), [], '2007-08-08-09-58-18', '130.60.155.231', '').
text_drs_eval(0, 1970, 'Not nothing waits.', drs([], []), [], '2007-08-08-09-58-29', '130.60.155.231', '').
text_drs_eval(0, 1971, 'It is false that every man waits.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, wait, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2007-01-09-21-53-44', '130.60.155.211', '').
text_drs_eval(0, 1972, 'Not a man waits and that a dog barks.', drs([], []), [], '2007-01-09-21-58-11', '130.60.155.211', '').
text_drs_eval(0, 1973, 'It is true that every man is a human.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, human, countable, na, eq, 1)-1, predicate(C, be, A, B)-1])]), [[specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [human]]]]]]]]], ['.']]], '2007-01-10-17-37-38', '130.60.155.211', '').
text_drs_eval(0, 1974, 'Is it true that every man is a human?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/6])=>drs([B, C], [object(B, human, countable, na, eq, 1)-1/9, predicate(C, be, A, B)-1/7])]))]), [[sentence, [query, [question, [truth, 'is it true'], [cp, that, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, human]]]]]]]]], ?], '.']], '2009-05-13-14-04-31', '130.60.155.193', '').
text_drs_eval(0, 1975, 'Every who is a human?', drs([], []), [], '2007-12-23-12-04-10', '130.60.204.35', '').
text_drs_eval(0, 1976, 'A man owns not more than 2 cars.', drs([], []), [], '2008-08-19-19-57-15', '130.60.155.177', '').
text_drs_eval(0, 1977, 'A man owns not at least 2 cars.', drs([], []), [], '2008-08-19-19-57-25', '130.60.155.177', '').
text_drs_eval(0, 1978, 'A man owns not at most 2 cars.', drs([], []), [], '2008-08-19-19-57-32', '130.60.155.177', '').
text_drs_eval(0, 1979, 'John owns 2 or more cars.', drs([], []), [], '2007-12-20-13-31-07', '130.60.155.231', '').
text_drs_eval(0, 1980, 'John owns not 2 or more cars.', drs([], []), [], '2007-12-20-13-31-48', '130.60.155.231', '').
text_drs_eval(0, 1981, 'John owns 2 or 3 cars.', drs([], []), [], '2007-12-20-13-32-18', '130.60.155.231', '').
text_drs_eval(0, 1982, 'John owns at most 2 cars.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, [predicate(C, own, A, B)-1, object(B, car, countable, na, leq, 2)-1]]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, owns], [np, [nump, [genqu, 'at most'], 2], [nbar, [n, cars]]]]]]], '.']], '2009-03-02-11-29-39', '130.60.155.206', '').
text_drs_eval(0, 1983, 'At most 2 cars are owned by John.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, [predicate(C, own, A, B)-1, object(B, car, countable, na, leq, 2)-1]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, cars]]], [vp, [aux, are], [vbar, [vcompl, [v, owned], by, [np, [pname, 'John']]]]]], '.']], '2009-03-02-11-29-49', '130.60.155.206', '').
text_drs_eval(0, 1984, 'John owns at most 2 cars that Mary likes.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, [predicate(E, own, A, C)-1, predicate(D, like, B, C)-1, object(C, car, countable, na, leq, 2)-1]]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, owns], [np, [nump, [genqu, 'at most'], 2], [nbar, [n, cars], [rel_cl, [comp, that], [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, likes]]]]]]]]]]], '.']], '2009-03-02-11-29-57', '130.60.155.206', '').
text_drs_eval(0, 1985, 'A dog """ barks.', drs([], []), [], '2007-02-22-16-05-20', '130.60.155.211', '').
text_drs_eval(0, 1986, 'A dog " barks.', drs([], []), [], '2007-02-22-16-05-38', '130.60.155.211', '').
text_drs_eval(0, 1987, 'A dog """" barks.', drs([], []), [], '2007-01-11-22-09-25', '130.60.155.211', '').
text_drs_eval(0, 1988, 'A dog """"" barks.', drs([], []), [], '2007-03-18-17-57-29', '130.60.155.177', '').
text_drs_eval(0, 1989, 'Every man\'s car contains an instruction that codes its development.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, car, countable, na, eq, 1)-1])=>drs([C, D, E, F], [object(C, instruction, countable, na, eq, 1)-1, relation(D, of, B)-1, object(D, development, countable, na, eq, 1)-1, predicate(E, code, C, D)-1, predicate(F, contain, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, every], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, car]]], [vp, [vbar, [v, contains], [np, [det, an], [nbar, [n, instruction], [rel_cl, [comp, that], [vp, [vbar, [v, codes], [np, [posspn, its], [nbar, [n, development]]]]]]]]]]], '.']], '2008-10-23-14-57-56', '130.60.155.177', '').
text_drs_eval(0, 1990, 'Every cellular n:life-form\'s n:DNA contains some a:genetic n:instructions that code its a:biological n:development.', drs([], [drs([A, B], [object(A, 'life-form', countable, na, eq, 1)-1, property(A, cellular, pos)-1, relation(B, of, A)-1, object(B, 'DNA', countable, na, eq, 1)-1])=>drs([C, D, E, F], [object(C, instructions, countable, na, geq, 2)-1, property(C, genetic, pos)-1, relation(D, of, B)-1, object(D, development, countable, na, eq, 1)-1, property(D, biological, pos)-1, predicate(E, code, C, D)-1, predicate(F, contain, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, every], [nbar, [adj, cellular], [n, 'life-form']], [gen_marker, '\'s']], [nbar, [n, 'DNA']]], [vp, [vbar, [v, contains], [np, [det, some], [nbar, [adj, genetic], [nbar, [n, instructions], [rel_cl, [comp, that], [vp, [vbar, [v, code], [np, [posspn, its], [nbar, [adj, biological], [nbar, [n, development]]]]]]]]]]]]], '.']], '2008-10-23-14-58-18', '130.60.155.177', '').
text_drs_eval(0, 1991, 'There are less than 0 cars.', drs([A], [[object(A, car, countable, na, less, 0)-1/6]]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [genqu, 'less than'], 0], [nbar, [n, cars]]]]], '.']], '2010-01-18-11-13-45', '89.206.64.72', '').
text_drs_eval(0, 1992, 'There are more than 0 cars.', drs([A], [object(A, car, countable, na, greater, 0)-1/6]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [genqu, 'more than'], 0], [nbar, [n, cars]]]]], '.']], '2010-01-18-11-13-55', '89.206.64.72', '').
text_drs_eval(0, 1993, 'There are at least 0 cars.', drs([A], [object(A, car, countable, na, geq, 0)-1/6]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [genqu, 'at least'], 0], [nbar, [n, cars]]]]], '.']], '2010-01-18-11-14-02', '89.206.64.72', '').
text_drs_eval(0, 1994, 'There are at most 0 cars.', drs([A], [[object(A, car, countable, na, leq, 0)-1/6]]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [genqu, 'at most'], 0], [nbar, [n, cars]]]]], '.']], '2010-01-18-11-14-10', '89.206.64.72', '').
text_drs_eval(0, 1995, 'No man owns at least 0 cars.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [object(B, car, countable, na, geq, 0)-1/7, predicate(C, own, A, B)-1/3])])]), [[specification, [s, [np, [det, no], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, owns], [np, [nump, [genqu, 'at least'], 0], [nbar, [n, cars]]]]]]], '.']], '2010-01-18-11-14-19', '89.206.64.72', '').
text_drs_eval(0, 1996, 'John owns -2 kg of apples.', drs([], []), [], '2007-01-14-17-48-07', '130.60.155.211', '').
text_drs_eval(0, 1997, 'There are 0 cars.', drs([A], [object(A, car, countable, na, eq, 0)-1/4]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, 0], [nbar, [n, cars]]]]], '.']], '2010-01-18-11-14-34', '89.206.64.72', '').
text_drs_eval(0, 1998, 'There are 0 kg of apples.', drs([A], [object(A, apple, countable, kg, eq, 0)-1/6]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [meas_spec, [nump, 0], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, apples]]]]], '.']], '2010-01-18-11-14-42', '89.206.64.72', '').
text_drs_eval(0, 1999, 'Every man\'s car contains an instruction that codes his development.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, car, countable, na, eq, 1)-1])=>drs([C, D, E, F], [object(C, instruction, countable, na, eq, 1)-1, relation(D, of, A)-1, object(D, development, countable, na, eq, 1)-1, predicate(E, code, C, D)-1, predicate(F, contain, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [car]]]], [vp, [vbar, [v, [contains]], [np, [det, [a]], [nbar, [n, [instruction]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [codes]], [np, [posspn, [his]], [nbar, [n, [development]]]]]]]]]]]], ['.']]], '2007-11-20-17-45-17', '130.60.155.231', '').
text_drs_eval(0, 2000, 'Every man\'s car contains an instruction that codes its own development.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, car, countable, na, eq, 1)-1])=>drs([C, D, E, F], [object(C, instruction, countable, na, eq, 1)-1, relation(D, of, C)-1, object(D, development, countable, na, eq, 1)-1, predicate(E, code, C, D)-1, predicate(F, contain, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [car]]]], [vp, [vbar, [v, [contains]], [np, [det, [a]], [nbar, [n, [instruction]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [codes]], [np, [posspn, ['{its own}']], [nbar, [n, [development]]]]]]]]]]]], ['.']]], '2007-11-20-17-45-24', '130.60.155.231', '').
text_drs_eval(0, 2001, 'Every man\'s car contains some instructions that code its own development.', drs([], []), [], '2008-10-23-14-59-38', '130.60.155.206', '').
text_drs_eval(0, 2002, 'At least one man waits. At least 2 women sleep.', drs([A, B, C, D], [object(A, man, countable, na, geq, 1)-1, predicate(B, wait, A)-1, object(C, woman, countable, na, geq, 2)-2, predicate(D, sleep, C)-2]), [[specification, [s, [np, [numberp, [gen_quant, ['{at least}']], [number, [one]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [numberp, [gen_quant, ['{at least}']], [number, [2]]], [nbar, [n, [women]]]], [vp, [vbar, [v, [sleep]]]]], ['.']]], '2007-05-04-19-47-49', '130.60.155.177', '').
text_drs_eval(0, 2003, 'At most one man waits. At most 2 women sleep.', drs([A, B, C, D], [[predicate(B, wait, A)-1, object(A, man, countable, na, leq, 1)-1], [predicate(D, sleep, C)-2, object(C, woman, countable, na, leq, 2)-2]]), [[specification, [s, [np, [nump, [genqu, 'at most'], one], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, women]]], [vp, [vbar, [vbar, [v, sleep]]]]], '.']], '2009-03-02-11-30-05', '130.60.155.206', '').
text_drs_eval(0, 2004, 'More than one man waits. More than 2 women sleep.', drs([A, B, C, D], [object(A, man, countable, na, greater, 1)-1, predicate(B, wait, A)-1, object(C, woman, countable, na, greater, 2)-2, predicate(D, sleep, C)-2]), [[specification, [s, [np, [numberp, [gen_quant, ['{more than}']], [number, [one]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [numberp, [gen_quant, ['{more than}']], [number, [2]]], [nbar, [n, [women]]]], [vp, [vbar, [v, [sleep]]]]], ['.']]], '2007-05-04-19-48-20', '130.60.155.177', '').
text_drs_eval(0, 2005, 'Less than one man waits. Less than 2 women sleep.', drs([A, B, C, D], [[predicate(B, wait, A)-1, object(A, man, countable, na, less, 1)-1], [predicate(D, sleep, C)-2, object(C, woman, countable, na, less, 2)-2]]), [[specification, [s, [np, [nump, [genqu, 'less than'], one], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [nump, [genqu, 'less than'], 2], [nbar, [n, women]]], [vp, [vbar, [vbar, [v, sleep]]]]], '.']], '2009-03-02-11-30-14', '130.60.155.206', '').
text_drs_eval(0, 2006, 'Mary is not a woman who likes an apple.', drs([A], [-drs([B, C, D, E], [predicate(E, be, A, B)-1, predicate(D, like, B, C)-1, object(B, woman, countable, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1]), object(A, 'Mary', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['Mary']]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [apple]]]]]]]]]]]], ['.']]], '2007-11-05-15-21-42', '130.60.155.177', '').
text_drs_eval(0, 2007, 'If a car X sees a branch Y and it is false that X sees a rental and that X sees a service then X sees the branch Y.', drs([], [drs([A, B, C], [object(A, car, countable, na, eq, 1)-1, object(B, branch, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([D, E, F, G], [object(D, rental, countable, na, eq, 1)-1, predicate(E, see, A, D)-1, object(F, service, countable, na, eq, 1)-1, predicate(G, see, A, F)-1])])=>drs([H], [predicate(H, see, A, B)-1])]), [[cond_s, [if], [s_coord, [s, [np, [det, [a]], [nbar, [n, [car]], [appos, [var, ['X']]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [branch]], [appos, [var, ['Y']]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [var, ['X']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rental]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [var, ['X']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [service]]]]]]]]]]]], [then], [s, [np, [var, ['X']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [branch]], [appos, [var, ['Y']]]]]]]]]], '2007-10-17-16-56-25', '130.60.155.177', '').
text_drs_eval(0, 2008, 'If a car X sees a branch Y and it is false that X is something Z that sees a rental and that Z sees a service then X sees the branch Y.', drs([], [drs([A, B, C], [object(A, car, countable, na, eq, 1)-1, object(B, branch, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([D, E, F, G, H, I], [object(D, something, dom, na, na, na)-1, predicate(E, be, A, D)-1, object(F, rental, countable, na, eq, 1)-1, predicate(G, see, D, F)-1, object(H, service, countable, na, eq, 1)-1, predicate(I, see, D, H)-1])])=>drs([J], [predicate(J, see, A, B)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [det, [a]], [nbar, [n, [car]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [branch]], [appos_coord, [appos, [var, ['Y']]]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [is]], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['Z']]]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [rental]]]]]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [np, [var, ['Z']]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [service]]]]]]]]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [branch]], [appos_coord, [appos, [var, ['Y']]]]]]]]]], ['.']]], '2007-01-18-14-47-54', '130.60.155.211', '').
text_drs_eval(0, 2009, 'Every program that calls a program that calls a program calls itself.', drs([], [drs([A, B, C, D, E], [object(A, program, countable, na, eq, 1)-1, object(B, program, countable, na, eq, 1)-1, object(C, program, countable, na, eq, 1)-1, predicate(D, call, B, C)-1, predicate(E, call, A, B)-1])=>drs([F], [predicate(F, call, A, A)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, program], [rel_cl, [comp, that], [vp, [vbar, [v, calls], [np, [det, a], [nbar, [n, program], [rel_cl, [comp, that], [vp, [vbar, [v, calls], [np, [det, a], [nbar, [n, program]]]]]]]]]]]]], [vp, [vbar, [v, calls], [np, [pn, itself]]]]], '.']], '2008-07-30-01-10-26', '130.60.204.7', '').
text_drs_eval(0, 2010, 'Everything that knows something that hears something sees itself.', drs([], [drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, object(C, something, dom, na, na, na)-1, predicate(D, hear, B, C)-1, predicate(E, know, A, B)-1])=>drs([F], [predicate(F, see, A, A)-1])]), [[specification, [s, [np, [pn, everything], [rel_cl, [comp, that], [vp, [vbar, [v, knows], [np, [pn, something], [rel_cl, [comp, that], [vp, [vbar, [v, hears], [np, [pn, something]]]]]]]]]], [vp, [vbar, [v, sees], [np, [pn, itself]]]]], '.']], '2008-07-30-01-12-54', '130.60.204.7', '').
text_drs_eval(0, 2011, 'A man that sees a boy that waits hears himself.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, boy, countable, na, eq, 1)-1, predicate(C, wait, B)-1, predicate(D, see, A, B)-1, predicate(E, hear, A, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, boy], [rel_cl, [comp, that], [vp, [vbar, [v, waits]]]]]]]]]]], [vp, [vbar, [v, hears], [np, [pn, himself]]]]], '.']], '2008-07-30-01-13-26', '130.60.204.7', '').
text_drs_eval(0, 2012, 'Every man gives every woman every apple.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, woman, countable, na, eq, 1)-1])=>drs([], [drs([C], [object(C, apple, countable, na, eq, 1)-1])=>drs([D], [predicate(D, give, A, C, B)-1])])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [every]], [nbar, [n, [woman]]]], [np, [det, [every]], [nbar, [n, [apple]]]]]]], ['.']]], '2007-01-27-23-56-45', '130.60.155.211', '').
text_drs_eval(0, 2013, 'If there is a man X1 then if there is a woman X2 then if there is an apple X3 then the man X1 gives the woman X2 the apple X3.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, woman, countable, na, eq, 1)-1])=>drs([], [drs([C], [object(C, apple, countable, na, eq, 1)-1])=>drs([D], [predicate(D, give, A, C, B)-1])])])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X1']]]]]]]], [then], [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]], [appos_coord, [appos, [var, ['X2']]]]]]]], [then], [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [apple]], [appos_coord, [appos, [var, ['X3']]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X1']]]]]], [vp, [vbar, [v, [gives]], [np, [det, [the]], [nbar, [n, [woman]], [appos_coord, [appos, [var, ['X2']]]]]], [np, [det, [the]], [nbar, [n, [apple]], [appos_coord, [appos, [var, ['X3']]]]]]]]]]]], ['.']]], '2007-01-27-23-57-05', '130.60.155.211', '').
text_drs_eval(0, 2014, 'If someone owns something that contains something X then he/she owns X.', drs([], [drs([A, B, C, D, E], [object(A, somebody, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, object(C, something, dom, na, na, na)-1, predicate(D, contain, B, C)-1, predicate(E, own, A, B)-1])=>drs([F], [predicate(F, own, A, C)-1])]), [[specification, [cond_s, if, [s, [np, [pn, someone]], [vp, [vbar, [v, owns], [np, [pn, something], [rel_cl, [comp, that], [vp, [vbar, [v, contains], [np, [pn, something], [appos, [var, 'X']]]]]]]]]], then, [s, [np, [pn, 'he/she']], [vp, [vbar, [v, owns], [np, [var, 'X']]]]]], '.']], '2008-08-15-20-38-46', '130.60.204.15', '').
text_drs_eval(0, 2015, 'There is a man who Mary is seen by.', drs([A, B, C], [object(A, 'Mary', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, A)-1]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [pname, ['Mary']]], [vp, [aux, [is]], [vbar, [v, [seen]], [by, [by]], [np, [[]]]]]]]]]]], '2007-10-26-15-04-13', '130.60.155.231', '').
text_drs_eval(0, 2016, 'John, wait!', drs([], [command(drs([A], [predicate(A, wait, named('John'))-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vbar, [v, wait]]]]], !], '.']], '2009-05-13-14-04-32', '130.60.155.193', '').
text_drs_eval(0, 2017, 'John enter the house!', drs([], []), [], '2007-11-12-18-07-56', '130.60.155.177', '').
text_drs_eval(0, 2018, 'men wait.', drs([], []), [], '2007-02-22-20-59-39', '130.60.155.211', '').
text_drs_eval(0, 2019, 'There is a man who does not see every dog that he sees. A man who sees a dog and who does not see the dog waits.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, -drs([], [drs([F, G], [object(F, dog, countable, na, eq, 1)-1, predicate(G, see, A, F)-1])=>drs([H], [predicate(H, see, A, F)-1])]), object(B, man, countable, na, eq, 1)-2, object(C, dog, countable, na, eq, 1)-2, predicate(D, see, B, C)-2, -drs([I], [predicate(I, see, B, C)-2]), predicate(E, wait, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [aux, ['{does not}']], [vbar, [v, [see]], [np, [det, [every]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [comp, [who]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [aux, ['{does not}']], [vbar, [v, [see]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-02-22-15-45-26', '130.60.155.211', '').
text_drs_eval(0, 2020, 'Who of a man waits?', drs([], []), [], '2007-12-23-12-04-30', '130.60.204.35', '').
text_drs_eval(0, 2021, 'Proposition P: Mary sleeps. Proposition P: Mary waits.', drs([], []), [[specification, [prop, [prop, ['Proposition']], [var, ['P']], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]], ['.']], [specification, [prop, [prop, ['Proposition']], [var, ['P']], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-02-23-12-26-36', '84.74.94.155', '').
text_drs_eval(0, 2022, 'Proposition P: It is false that P.', drs([], []), [[specification, [prop, [prop, ['Proposition']], [var, ['P']], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [var, ['P']]]]], ['.']]], '2007-02-23-12-35-14', '84.74.94.155', '').
text_drs_eval(0, 2023, 'Proposition P: It is false that P. John believes that P.', drs([], []), [[specification, [prop, [prop, ['Proposition']], [var, ['P']], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [var, ['P']]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [believes]], [cp, ['_that_'], [var, ['P']]]]]], ['.']]], '2007-02-23-12-35-18', '84.74.94.155', '').
text_drs_eval(0, 2024, 'Proposition P: It is false that Q. Proposition Q: It is false that P.', drs([], []), [[specification, [prop, 'Proposition', [var, 'P'], :, [s, [neg, 'it is false'], [cp, that, [var, 'Q']]]], '.'], [specification, [prop, 'Proposition', [var, 'Q'], :, [s, [neg, 'it is false'], [cp, that, [var, 'P']]]], '.']], '2008-08-19-15-59-17', '130.60.155.208', '').
text_drs_eval(0, 2025, 'It is true that P.', drs([], []), [[specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [var, ['P']]]], ['.']]], '2007-02-23-12-37-58', '84.74.94.155', '').
text_drs_eval(0, 2026, 'Proposition P: Mary sleeps. It is true that Q.', drs([], []), [[specification, [prop, [prop, ['Proposition']], [var, ['P']], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sleeps]]]]]], ['.']], [specification, [modality, [truth, ['{it is true}']], [cp, ['_that_'], [var, ['Q']]]], ['.']]], '2007-02-23-12-38-16', '84.74.94.155', '').
text_drs_eval(0, 2027, 'Proposition P: Mary sleeps. It is true that P. It is false that P. John believes that P.', drs([], []), [], '2009-04-02-13-16-38', '130.60.155.206', '').
text_drs_eval(0, 2028, 'A man\'s who waits?', drs([], []), [], '2007-12-23-12-04-51', '130.60.204.35', '').
text_drs_eval(0, 2029, 'Every customer can access every public resource.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/2])=>drs([], [can(drs([], [drs([B], [object(B, resource, countable, na, eq, 1)-1/7, property(B, public, pos)-1/6])=>drs([C], [predicate(C, access, A, B)-1/4])]))])]), [[specification, [s, [np, [det, every], [nbar, [n, customer]]], [vp, [aux, can], [vbar, [vcompl, [v, access], [np, [det, every], [nbar, [adj, public], [nbar, [n, resource]]]]]]]], '.']], '2010-10-27-09-28-01', '89.206.64.27', '').
text_drs_eval(0, 2030, 'A dog is interested-in a bone and bad.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np_coord, [np, [det, [a]], [nbar, [n, [bone]]]], [coord, [and]], [np, [det, [???]], [nbar, [n, [bad]]]]]]|A]]]], ['.']]], '2007-05-04-18-39-18', '130.60.155.177', '').
text_drs_eval(0, 2031, 'John, buy a car!', drs([], [command(drs([A, B], [object(A, car, countable, na, eq, 1)-1/5, predicate(B, buy, named('John'), A)-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-14-04-33', '130.60.155.193', '').
text_drs_eval(0, 2032, 'John, buys a car!', drs([], []), [], '2007-03-07-15-43-58', '130.60.156.229', '').
text_drs_eval(0, 2033, 'John buy a car!', drs([], []), [], '2007-03-07-15-44-09', '130.60.156.229', '').
text_drs_eval(0, 2034, 'John buys a car!', drs([], []), [], '2007-03-07-15-44-21', '130.60.156.229', '').
text_drs_eval(0, 2035, 'Buy a car!', drs([], []), [], '2007-03-07-15-44-40', '130.60.156.229', '').
text_drs_eval(0, 2036, 'John, buy a car! Bill, buy a car!', drs([], [command(drs([A, B], [object(A, car, countable, na, eq, 1)-1/5, predicate(B, buy, named('John'), A)-1/3])), command(drs([C, D], [object(C, car, countable, na, eq, 1)-2/5, predicate(D, buy, named('Bill'), C)-2/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.'], [sentence, [command, [s, [np, [pname, 'Bill']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-14-04-35', '130.60.155.193', '').
text_drs_eval(0, 2037, 'A man, buy a car!', drs([], [command(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, car, countable, na, eq, 1)-1/6, predicate(C, buy, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-14-04-36', '130.60.155.193', '').
text_drs_eval(0, 2038, 'Every man, buy a car!', drs([], [command(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C], [object(B, car, countable, na, eq, 1)-1/6, predicate(C, buy, A, B)-1/4])]))]), [[sentence, [command, [s, [np, [det, every], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-14-04-38', '130.60.155.193', '').
text_drs_eval(0, 2039, 'No man, buy a car!', drs([], []), [], '2007-03-07-15-46-05', '130.60.156.229', '').
text_drs_eval(0, 2040, 'A man that waits, buy a car!', drs([], [command(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, wait, A)-1/4, object(C, car, countable, na, eq, 1)-1/8, predicate(D, buy, A, C)-1/6]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-13-57-52', '130.60.155.193', '').
text_drs_eval(0, 2041, 'John and Mary, buy a car!', drs([], [command(drs([A, B, C], [has_part(C, named('John'))-1/'', object(A, car, countable, na, eq, 1)-1/7, predicate(B, buy, C, A)-1/5, has_part(C, named('Mary'))-1/'', object(C, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-13-57-52', '130.60.155.193', '').
text_drs_eval(0, 2042, 'Some customers, buy a car!', drs([], [command(drs([A, B, C], [object(A, customer, countable, na, geq, 2)-1/2, object(B, car, countable, na, eq, 1)-1/6, predicate(C, buy, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, some], [nbar, [n, customers]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-13-13-57-54', '130.60.155.193', '').
text_drs_eval(0, 2043, 'John, be loved by Mary!', drs([], []), [], '2007-03-07-15-48-24', '130.60.156.229', '').
text_drs_eval(0, 2044, 'John, do not touch the machine!', drs([], [command(drs([], [-drs([A, B], [predicate(A, touch, named('John'), B)-1/5, object(B, machine, countable, na, eq, 1)-1/7])]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [aux, do, not], [vbar, [vcompl, [v, touch], [np, [det, the], [nbar, [n, machine]]]]]]], !], '.']], '2009-05-13-13-57-56', '130.60.155.193', '').
text_drs_eval(0, 2045, 'John, hit himself!', drs([], []), [], '2009-05-15-08-20-05', '130.60.155.193', '').
text_drs_eval(0, 2046, 'John, hit yourself!', drs([], [command(drs([A], [predicate(A, hit, named('John'), named('John'))-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, hit], [np, [pn, yourself]]]]]], !], '.']], '2009-05-15-08-20-13', '130.60.155.193', '').
text_drs_eval(0, 2047, 'John, sell your own car!', drs([], [command(drs([A, B], [relation(A, of, named('John'))-1/4, object(A, car, countable, na, eq, 1)-1/6, predicate(B, sell, named('John'), A)-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, sell], [np, [posspn, 'your own'], [nbar, [n, car]]]]]]], !], '.']], '2009-05-15-08-20-25', '130.60.155.193', '').
text_drs_eval(0, 2048, 'John, buy a dog that likes you!', drs([], [command(drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1/5, predicate(B, like, A, named('John'))-1/7, predicate(C, buy, named('John'), A)-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]], !], '.']], '2009-05-15-10-19-26', '80.219.71.81', '').
text_drs_eval(0, 2049, 'John, buy a dog that is owned by Bill and that likes him!', drs([], [command(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/5, predicate(B, own, named('Bill'), A)-1/8, predicate(C, like, A, named('Bill'))-1/13, predicate(D, buy, named('John'), A)-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, him]]]]]]]]]]]]], !], '.']], '2009-05-13-13-57-58', '130.60.155.193', '').
text_drs_eval(0, 2050, 'John, buy a dog that is owned by Bill and that likes you!', drs([], [command(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/5, predicate(B, own, named('Bill'), A)-1/8, predicate(C, like, A, named('John'))-1/13, predicate(D, buy, named('John'), A)-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]]], !], '.']], '2009-05-15-09-14-09', '130.60.155.193', '').
text_drs_eval(0, 2051, 'No dogs bark.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([], [-drs([B], [predicate(B, bark, A)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [dogs]]]], [vp, [vbar, [v, [bark]]]]], ['.']]], '2007-07-18-14-40-53', '130.60.155.177', '').
text_drs_eval(0, 2052, 'All dogs bark.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B], [predicate(B, bark, A)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [dogs]]]], [vp, [vbar, [v, [bark]]]]], ['.']]], '2007-07-18-14-41-13', '130.60.155.177', '').
text_drs_eval(0, 2053, 'For all dogs a man waits.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [dogs]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-07-18-14-41-31', '130.60.155.177', '').
text_drs_eval(0, 2054, 'Not all dogs bark.', drs([], [-drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B], [predicate(B, bark, A)-1])])]), [[specification, [neg_s, [pneg, ['{not}']], [s, [np, [det, [all]], [nbar, [n, [dogs]]]], [vp, [vbar, [v, [bark]]]]]], ['.']]], '2007-07-18-14-41-47', '130.60.155.177', '').
text_drs_eval(0, 2055, 'For all dogs a man sees the dogs.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])]), [[specification, [top_s, [topic, [quant, for], [np, [det, all], [nbar, [n, dogs]]]], [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, dogs]]]]]]], '.']], '2008-10-22-16-03-59', '130.60.155.177', '').
text_drs_eval(0, 2056, 'For all sand a man sees the sand.', drs([], [drs([A], [object(A, sand, mass, na, na, na)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [sand]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [sand]]]]]]]], ['.']]], '2007-03-07-20-54-01', '130.60.155.177', '').
text_drs_eval(0, 2057, 'For all dog a man waits.', drs([], []), [], '2007-03-07-20-54-28', '130.60.155.177', '').
text_drs_eval(0, 2058, 'There is a dog. For all dogs a man sees the dog.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-2])=>drs([C, D], [object(C, man, countable, na, eq, 1)-2, predicate(D, see, C, A)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], '.'], [specification, [top_s, [topic, [quant, for], [np, [det, all], [nbar, [n, dogs]]]], [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, dog]]]]]]], '.']], '2008-10-22-16-04-17', '130.60.155.177', '').
text_drs_eval(0, 2059, 'There is a dog. For every dog a man sees the dog.', drs([A], [object(A, dog, countable, na, eq, 1)-1, drs([B], [object(B, dog, countable, na, eq, 1)-2])=>drs([C, D], [object(C, man, countable, na, eq, 1)-2, predicate(D, see, C, B)-2])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [dog]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-03-07-21-03-47', '130.60.155.177', '').
text_drs_eval(0, 2060, 'All laundry are wet.', drs([], []), [], '2007-03-07-21-05-25', '130.60.155.177', '').
text_drs_eval(0, 2061, 'All laundries is wet.', drs([], []), [], '2007-03-07-21-05-44', '130.60.155.177', '').
text_drs_eval(0, 2062, 'All laundries are wet.', drs([], [drs([A], [object(A, laundry, countable, na, eq, 1)-1])=>drs([B, C], [property(B, wet, pos)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [laundries]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [wet]]]]]]], ['.']]], '2007-07-18-14-43-45', '130.60.155.177', '').
text_drs_eval(0, 2063, 'All laundry is wet.', drs([], [drs([A], [object(A, laundry, mass, na, na, na)-1])=>drs([B, C], [property(B, wet, pos)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [wet]]]]]]], ['.']]], '2007-03-07-21-06-14', '130.60.155.177', '').
text_drs_eval(0, 2064, 'All men meet themselves.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, meet, A, A)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [men]]]], [vp, [vbar, [v, [meet]], [np, [pn, [themselves]]]]]], ['.']]], '2007-07-18-14-44-01', '130.60.155.177', '').
text_drs_eval(0, 2065, 'The card of John is the card of Bill.', drs([A, B, C, D, E], [relation(E, of, A)-1, relation(D, of, B)-1, predicate(C, be, E, D)-1, object(E, card, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, object(D, card, countable, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1]), [[s, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pname, ['Bill']]]]]]]]]], '2007-11-05-11-18-14', '130.60.155.231', '').
text_drs_eval(0, 2066, 'John sleeps in the park from the morning until the evening.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, predicate(B, sleep, A)-1, modifier_pp(B, in, C)-1, modifier_pp(B, from, D)-1, modifier_pp(B, until, E)-1, object(C, park, countable, na, eq, 1)-1, object(D, morning, countable, na, eq, 1)-1, object(E, evening, countable, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [park]]]]], [pp, [prep, [from]], [np, [det, [the]], [nbar, [n, [morning]]]]], [pp, [prep, [until]], [np, [det, [the]], [nbar, [n, [evening]]]]]]]], ['.']]], '2007-07-04-13-36-18', '130.60.206.45', '').
text_drs_eval(0, 2067, 'A user can pay a resource through p:fast-pay.', drs([A], [object(A, user, countable, na, eq, 1)-1/2, can(drs([B, C], [object(B, resource, countable, na, eq, 1)-1/6, predicate(C, pay, A, B)-1/4, modifier_pp(C, through, named('fast-pay'))-1/7]))]), [[specification, [s, [np, [det, a], [nbar, [n, user]]], [vp, [aux, can], [vbar, [vcompl, [v, pay], [np, [det, a], [nbar, [n, resource]]]], [vmod, [pp, [prep, through], [np, [pname, 'fast-pay']]]]]]], '.']], '2010-10-27-09-28-06', '89.206.64.27', '').
text_drs_eval(0, 2068, 'John\'s dog eats. Mary\'s dog drinks. A dog of John waits.', drs([A, B, C, D, E, F, G, H], [object(B, 'Mary', named, na, eq, 1)-2, object(A, 'John', named, na, eq, 1)-1, relation(C, of, A)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, eat, C)-1, relation(E, of, B)-2, object(E, dog, countable, na, eq, 1)-2, predicate(F, drink, E)-2, object(G, dog, countable, na, eq, 1)-3, relation(G, of, A)-3, predicate(H, wait, G)-3]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [poss_np, [pname, ['Mary']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [drinks]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-03-18-16-02-59', '130.60.155.177', '').
text_drs_eval(0, 2069, 'There is a man. John enters every card which is his card.', drs([A, B], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, drs([C, D, E], [object(C, card, countable, na, eq, 1)-2, relation(D, of, A)-2, object(D, card, countable, na, eq, 1)-2, predicate(E, be, C, D)-2])=>drs([F], [predicate(F, enter, A, C)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, enters], [np, [det, every], [nbar, [n, card], [rel_cl, [np, [relpn, which]], [vp, [aux, is], [vbar, [np, [posspn, his], [nbar, [n, card]]]]]]]]]]], '.']], '2008-10-23-14-58-35', '130.60.155.177', '').
text_drs_eval(0, 2070, 'There is a man whose dog barks. There is a woman whose dog barks.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, object(D, woman, countable, na, eq, 1)-2, object(E, dog, countable, na, eq, 1)-2, relation(E, of, D)-2, predicate(F, bark, E)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2007-04-04-14-33-01', '130.60.156.229', '').
text_drs_eval(0, 2071, 'If someone eats something X then he/she owns X.', drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, eat, A, B)-1])=>drs([D], [predicate(D, own, A, B)-1])]), [[specification, [cond_s, [if], [s, [nbar, [pn, [someone]]], [vp, [vbar, [v, [eats]], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['X']]]]]]]], [then], [s, [np, [pn, ['he/she']]], [vp, [vbar, [v, [owns]], [np, [np, [var, ['X']]]]]]]], ['.']]], '2007-08-15-16-34-11', '130.60.155.177', '').
text_drs_eval(0, 2072, 'There is a man whose dog barks and whose cat eats.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, relation(C, of, A)-1, predicate(B, bark, C)-1, object(C, dog, countable, na, eq, 1)-1, relation(E, of, A)-1, predicate(D, eat, E)-1, object(E, cat, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [eats]]]]]]]]]], ['.']]], '2007-03-19-15-09-30', '130.60.155.177', '').
text_drs_eval(0, 2073, 'John works in a bank and a morning.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, bank, countable, na, eq, 1)-1, predicate(C, work, A)-1, modifier_pp(C, in, E)-1, object(D, morning, countable, na, eq, 1)-1, has_part(E, B)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [works]]], [pp, [prep, [in]], [np_coord, [np, [det, [a]], [nbar, [n, [bank]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [morning]]]]]]]]], ['.']]], '2007-05-09-11-05-07', '130.60.156.229', '').
text_drs_eval(0, 2074, 'The password of an account is known by the owner of the account.', drs([A, B, C, D], [predicate(A, know, B, C)-1, relation(C, of, D)-1, object(D, account, countable, na, eq, 1)-1, object(C, password, countable, na, eq, 1)-1, relation(B, of, D)-1, object(B, owner, countable, na, eq, 1)-1]), [[s, [np, [det, [the]], [nbar, [n, [password]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [account]]]]]]], [vp, [aux, [is]], [vbar, [v, [known]], [by, [by]], [np, [det, [the]], [nbar, [n, [owner]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [account]]]]]]]]]]], '2007-10-26-15-11-57', '130.60.155.231', '').
text_drs_eval(0, 2075, 'John is considered a criminal.', drs([], []), [], '2007-08-06-17-21-34', '130.60.204.12', '').
text_drs_eval(0, 2076, 'Everything "Go!" waits.', drs([], []), [], '2007-04-10-15-23-18', '130.60.155.177', '').
text_drs_eval(0, 2077, 'Everybody of John\'s dog waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, somebody, countable, na, eq, 1)-1])=>drs([D], [predicate(D, wait, C)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [pp, [prep, [of]], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-03-21-18-20-27', '130.60.155.177', '').
text_drs_eval(0, 2078, 'There is a man. Everybody of his dog waits.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C], [object(B, somebody, countable, na, eq, 1)-2, relation(C, of, B)-2, object(C, dog, countable, na, eq, 1)-2, relation(B, of, C)-2])=>drs([D], [predicate(D, wait, B)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pn, everybody], [pp, [prep, of], [np, [posspn, his], [nbar, [n, dog]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-23-14-59-28', '130.60.155.177', '').
text_drs_eval(0, 2079, 'Everybody of his dog waits.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, relation(A, of, B)-1])=>drs([C], [predicate(C, wait, A)-1])]), [[specification, [s, [np, [pn, everybody], [pp, [prep, of], [np, [posspn, his], [nbar, [n, dog]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-23-15-01-11', '130.60.155.206', '').
text_drs_eval(0, 2080, 'Everybody of his own dog waits.', drs([], []), [], '2008-10-23-15-01-06', '130.60.155.206', '').
text_drs_eval(0, 2081, 'Everybody X of a dog of X waits.', drs([], [drs([A, B], [object(A, dog, countable, na, eq, 1)-1, relation(A, of, B)-1, relation(B, of, A)-1, object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [appos_coord, [appos, [var, ['X']]]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [np, [var, ['X']]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-03-21-18-23-05', '130.60.155.177', '').
text_drs_eval(0, 2082, 'There is a vehicle which is a red Ford.', drs([], []), [], '2008-07-09-15-27-13', '130.60.155.206', '').
text_drs_eval(0, 2083, 'John knows that Bill is Mary.', drs([A, B, C, D, E], [object(C, 'Mary', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1, predicate(D, know, A, E)-1, E:drs([F], [predicate(F, be, B, C)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [is]], [np, [pname, ['Mary']]]]]]]]]], ['.']]], '2007-03-27-20-03-57', '130.60.155.177', '').
text_drs_eval(0, 2084, 'Every man whose car a cat sees smiles.', drs([], [drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, relation(C, of, A)-1, object(C, car, countable, na, eq, 1)-1, predicate(D, see, B, C)-1])=>drs([E], [predicate(E, smile, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [car]]]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]], [vp, [vbar, [v, [smiles]]]]], ['.']]], '2007-04-02-14-27-17', '130.60.155.177', '').
text_drs_eval(0, 2085, 'Every man a car of who a cat sees smiles.', drs([], [drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, car, countable, na, eq, 1)-1, relation(C, of, A)-1, predicate(D, see, B, C)-1])=>drs([E], [predicate(E, smile, A)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [[]]]]]]]], [vp, [vbar, [v, [smiles]]]]], ['.']]], '2007-04-02-14-27-48', '130.60.155.177', '').
text_drs_eval(0, 2086, 'John is every man.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([C], [predicate(C, be, A, B)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [every]], [nbar, [n, [man]]]]]]], ['.']]], '2007-04-02-14-29-14', '130.60.155.177', '').
text_drs_eval(0, 2087, 'How does every man wait?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/4])=>drs([B], [predicate(B, wait, A)-1/5, query(B, how)-1/1])]))]), [[sentence, [query, [question, [qpn, how], does, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-58-00', '130.60.155.193', '').
text_drs_eval(0, 2088, '2 kg of some apples wait.', drs([], []), [], '2007-04-02-16-25-30', '130.60.155.177', '').
text_drs_eval(0, 2089, 'A man whose dog barks waits. The man eats.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-1, predicate(E, eat, A)-2]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [eats]]]]], ['.']]], '2007-04-04-17-26-40', '130.60.155.177', '').
text_drs_eval(0, 2090, 'A man whose dog barks waits. The dog of a man eats.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-1, predicate(E, eat, B)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [vbar, [v, eats]]]], '.']], '2008-08-12-16-44-09', '130.60.155.208', '').
text_drs_eval(0, 2091, 'A man whose dog barks waits. The dog of the man eats.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-1, predicate(E, eat, B)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]], [vp, [vbar, [v, eats]]]], '.']], '2008-08-12-16-44-41', '130.60.155.208', '').
text_drs_eval(0, 2092, 'How does who see what?', drs([], [question(drs([A, B, C], [query(A, who)-1/3, query(B, what)-1/5, predicate(C, see, A, B)-1/4, query(C, how)-1/1]))]), [[sentence, [query, [question, [qpn, how], does, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, see], [np, [qpn, what]]]]]], ?], '.']], '2009-05-13-13-58-02', '130.60.155.193', '').
text_drs_eval(0, 2093, 'For all men a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [men]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-07-18-14-44-17', '130.60.155.177', '').
text_drs_eval(0, 2094, 'Everybody whose dog barks or whose cat eats waits.', drs([], [drs([A], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, relation(D, of, A)-1, predicate(E, eat, D)-1]), object(A, somebody, countable, na, eq, 1)-1])=>drs([F], [predicate(F, wait, A)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl_coord, [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [or]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [eats]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-04-21-54-22', '130.60.155.177', '').
text_drs_eval(0, 2095, 'If there is somebody X1, and a dog of X1 barks or a cat of X1 eats then X1 waits.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1, drs([B, C], [object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, relation(D, of, A)-1, predicate(E, eat, D)-1])])=>drs([F], [predicate(F, wait, A)-1])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X1']]]]]]], [coord, ['{, and}']], [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [np, [var, ['X1']]]]]]], [vp, [vbar, [v, [barks]]]]], [coord, [or]], [s, [np, [det, [a]], [nbar, [n, [cat]], [pp, [prep, [of]], [np, [np, [var, ['X1']]]]]]], [vp, [vbar, [v, [eats]]]]]]], [then], [s, [np, [np, [var, ['X1']]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-04-04-21-54-45', '130.60.155.177', '').
text_drs_eval(0, 2096, 'p:Pi is a ratio. p:Pi is a ratio.', drs([A, B, C, D, E], [object(A, 'Pi', named, na, eq, 1)-1, object(B, ratio, countable, na, eq, 1)-1, predicate(C, be, A, B)-1, object(D, ratio, countable, na, eq, 1)-2, predicate(E, be, A, D)-2]), [[specification, [s, [np, [pname, ['Pi']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [ratio]]]]]]], ['.']], [specification, [s, [np, [pname, ['Pi']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [ratio]]]]]]], ['.']]], '2007-08-20-22-01-32', '130.60.155.177', '').
text_drs_eval(0, 2097, 'Every empty string is "".', drs([], [drs([A], [object(A, string, countable, na, eq, 1)-1, property(A, empty, pos)-1])=>drs([B], [predicate(B, be, A, string(''))-1])]), [[specification, [s, [np, [det, [every]], [nbar, [adj, [empty]], [nbar, [n, [string]]]]], [vp, [vbar, [v, [is]], [np, [string, ['']]]]]], ['.']]], '2007-09-01-16-36-03', '130.60.155.177', '').
text_drs_eval(0, 2098, 'A space is " ".', drs([A, B], [object(A, space, countable, na, eq, 1)-1, predicate(B, be, A, string(' '))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [space]]]], [vp, [vbar, [v, [is]], [np, [string, [' ']]]]]], ['.']]], '2007-09-01-16-36-15', '130.60.155.177', '').
text_drs_eval(0, 2099, '1 men wait.', drs([], []), [], '2007-04-13-15-02-51', '130.60.155.177', '').
text_drs_eval(0, 2100, '1 man waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [numberp, [gen_quant, [[]]], [number, [1]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-05-04-19-49-23', '130.60.155.177', '').
text_drs_eval(0, 2101, 'There are more than 1 dog.', drs([], []), [], '2007-04-13-15-03-17', '130.60.155.177', '').
text_drs_eval(0, 2102, 'There is more than 1 dog.', drs([A], [object(A, dog, countable, na, greater, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [numberp, [gen_quant, ['{more than}']], [number, [1]]], [nbar, [n, [dog]]]]]], ['.']]], '2007-05-04-19-49-36', '130.60.155.177', '').
text_drs_eval(0, 2103, 'For all cats a man sleeps.', drs([], [drs([A], [object(A, cat, countable, na, eq, 1)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, sleep, B)-1])]), [[specification, [top_s, [topic, [quant, ['{for all}']], [nbar, [n, [cats]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2007-07-18-14-44-33', '130.60.155.177', '').
text_drs_eval(0, 2104, 'John is a man. John is a man.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, be, A, B)-1, object(D, man, countable, na, eq, 1)-2, predicate(E, be, A, D)-2]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2007-08-19-15-40-14', '130.60.155.177', '').
text_drs_eval(0, 2105, 'No men are some humans.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, human, countable, na, geq, 2)-1, predicate(C, be, A, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [men]]]], [vp, [vbar, [v, [are]], [np, [det, [some]], [nbar, [n, [humans]]]]]]], ['.']]], '2007-07-18-14-44-53', '130.60.155.177', '').
text_drs_eval(0, 2106, 'A man of some water waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, water, mass, na, na, na)-1, relation(A, of, B)-1, predicate(C, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [pp, [prep, [of]], [np, [det, [some]], [nbar, [n, [water]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-07-15-54-41', '130.60.155.177', '').
text_drs_eval(0, 2107, 'There is some water a man of which waits.', drs([A, B, C], [object(A, water, mass, na, na, na)-1, object(B, man, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, wait, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [water]], [rel_cl, [np, [det, [a]], [nbar, [n, [man]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2007-08-15-19-21-23', '130.60.155.177', '').
text_drs_eval(0, 2108, 'There is some water whose man waits.', drs([A, B, C], [object(A, water, mass, na, na, na)-1, object(B, man, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, wait, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [water]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2007-08-15-19-21-49', '130.60.155.177', '').
text_drs_eval(0, 2109, 'Every man owns a dog blahblah.', drs([], []), [], '2007-05-16-14-40-17', '130.60.155.177', '').
text_drs_eval(0, 2110, 'There is a man that owns at least 3 cars. The man that owns at least 3 cars waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, car, countable, na, geq, 3)-1, predicate(C, own, A, B)-1, predicate(D, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [owns]], [np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [nbar, [n, [cars]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [owns]], [np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [nbar, [n, [cars]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-08-15-41-07', '130.60.155.177', '').
text_drs_eval(0, 2111, 'There are 10 hours of work.', drs([], []), [], '2007-12-10-17-02-03', '130.60.155.231', '').
text_drs_eval(0, 2112, 'There is 1 kg of n:laundry.', drs([A], [object(A, laundry, countable, kg, eq, 1)-1]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [meas_spec, [nump, [num, 1]], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, laundry]]]]], '.']], '2008-08-04-16-40-44', '130.60.155.206', '').
text_drs_eval(0, 2113, 'There is more than 1 kg of laundry.', drs([A], [object(A, laundry, mass, kg, greater, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [measure_np, [numberp, [gen_quant, ['{more than}']], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]]]], ['.']]], '2007-12-18-12-32-37', '130.60.155.231', '').
text_drs_eval(0, 2114, '14 is 15.', drs([A], [predicate(A, be, int(14), int(15))-1]), [[specification, [s, [np, [int, [14]]], [vp, [vbar, [v, [is]], [np, [int, [15]]]]]], ['.']]], '2007-09-01-17-05-50', '130.60.155.177', '').
text_drs_eval(0, 2115, '"" is an empty string.', drs([A, B], [object(A, string, countable, na, eq, 1)-1, property(A, empty, pos)-1, predicate(B, be, string(''), A)-1]), [[specification, [s, [np, [string, ['']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [adj, [empty]], [nbar, [n, [string]]]]]]]], ['.']]], '2007-09-01-16-36-30', '130.60.155.177', '').
text_drs_eval(0, 2116, '1 is 2.3 is 4.', drs([], []), [], '2007-04-10-15-39-03', '130.60.155.177', '').
text_drs_eval(0, 2117, '3.14 is a real.', drs([A, B], [object(A, real, countable, na, eq, 1)-1, predicate(B, be, real(3.14), A)-1]), [[specification, [s, [np, [real, [3.14]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [real]]]]]]], ['.']]], '2007-09-01-17-06-01', '130.60.155.177', '').
text_drs_eval(0, 2118, 'There are 2 kg of apples of John.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, apple, countable, kg, eq, 2)-1, relation(B, of, A)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]]], ['.']]], '2007-12-10-19-40-46', '130.60.155.177', '').
text_drs_eval(0, 2119, '2.3 and 88 and "abc" are some values.', drs([A, B, C], [object(A, value, countable, na, geq, 2)-1, predicate(B, be, C, A)-1, has_part(C, real(2.3))-1, has_part(C, int(88))-1, has_part(C, string(abc))-1, object(C, na, countable, na, eq, 3)-1]), [[specification, [s, [np_coord, [np, [real, [2.3]]], [coord, [and]], [np_coord, [np, [int, [88]]], [coord, [and]], [np, [string, [abc]]]]], [vp, [vbar, [v, [are]], [np, [det, [some]], [nbar, [n, [values]]]]]]], ['.']]], '2007-09-01-17-06-13', '130.60.155.177', '').
text_drs_eval(0, 2120, '"&" is a string.', drs([A, B], [object(A, string, countable, na, eq, 1)-1, predicate(B, be, string(&), A)-1]), [[specification, [s, [np, [string, [&]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [string]]]]]]], ['.']]], '2007-09-01-16-36-42', '130.60.155.177', '').
text_drs_eval(0, 2121, '"<" is a string.', drs([A, B], [object(A, string, countable, na, eq, 1)-1, predicate(B, be, string(<), A)-1]), [[specification, [s, [np, [string, [<]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [string]]]]]]], ['.']]], '2007-09-01-16-36-53', '130.60.155.177', '').
text_drs_eval(0, 2122, 'John\'s n:home-page is "http://www.example.org/John".', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, 'home-page', countable, na, eq, 1)-1, predicate(C, be, B, string('http://www.example.org/John'))-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, ['home-page']]]], [vp, [vbar, [v, [is]], [np, [string, ['http://www.example.org/John']]]]]], ['.']]], '2007-09-01-16-37-14', '130.60.155.177', '').
text_drs_eval(0, 2123, '1 is smaller than 2.', drs([A, B], [property(A, small, comp_than, int(2))-1, predicate(B, be, int(1), A)-1]), [[specification, [s, [np, [int, [1]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [smaller]], [conj, [than]], [np, [int, [2]]]]|C]]]], ['.']]], '2007-09-01-17-06-23', '130.60.155.177', '').
text_drs_eval(0, 2124, '3.14 is a ratio of a circumference of a circle to its diameter.', drs([A, B, C, D, E], [relation(A, of, D)-1, object(A, diameter, countable, na, eq, 1)-1, object(B, ratio, countable, na, eq, 1)-1, object(C, circumference, countable, na, eq, 1)-1, object(D, circle, countable, na, eq, 1)-1, relation(C, of, D)-1, relation(B, of, C)-1, predicate(E, be, real(3.14), B)-1, modifier_pp(E, to, A)-1]), [[specification, [s, [np, [real, [3.14]]], [vp, [vbar, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [ratio]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [circumference]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [circle]]]]]]]]]]], [pp, [prep, [to]], [np, [posspn, [its]], [nbar, [n, [diameter]]]]]]]], ['.']]], '2007-09-01-17-06-42', '130.60.155.177', '').
text_drs_eval(0, 2125, 'There is 5. It waits.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [integer, [5]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-04-10-16-07-58', '130.60.155.177', '').
text_drs_eval(0, 2126, 'There is 5.', drs([], []), [], '2007-09-21-19-41-53', '130.60.155.177', '').
text_drs_eval(0, 2127, 'A man gives a woman "abc".', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(C, give, A, string(abc), B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [woman]]]], [np, [string, [abc]]]]]], ['.']]], '2007-09-01-16-37-29', '130.60.155.177', '').
text_drs_eval(0, 2128, 'If a dog of the master of somebody X barks then X sleeps.', drs([], [drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, relation(A, of, B)-1, relation(B, of, C)-1, object(C, somebody, countable, na, eq, 1)-1, object(B, master, countable, na, eq, 1)-1, predicate(D, bark, A)-1])=>drs([E], [predicate(E, sleep, C)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [master]], [pp, [prep, [of]], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]]]]]]]], [vp, [vbar, [v, [barks]]]]], [then], [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [sleeps]]]]]], ['.']]], '2007-08-10-20-15-22', '130.60.155.177', '').
text_drs_eval(0, 2129, 'Every uncle of the children of somebody X is a brother of X.', drs([], [drs([A, B, C], [object(A, uncle, countable, na, eq, 1)-1, relation(A, of, B)-1, relation(B, of, C)-1, object(C, somebody, countable, na, eq, 1)-1, object(B, child, countable, na, geq, 2)-1])=>drs([D, E], [object(D, brother, countable, na, eq, 1)-1, relation(D, of, C)-1, predicate(E, be, A, D)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [uncle]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [children]], [pp, [prep, [of]], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [brother]], [pp, [prep, [of]], [np, [np, [var, ['X']]]]]]]]]], ['.']]], '2007-08-10-20-14-40', '130.60.155.177', '').
text_drs_eval(0, 2130, 'Every brother of somebody X is an uncle of the children of X.', drs([], [drs([A, B], [object(A, brother, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, relation(A, of, B)-1])=>drs([C, D, E], [object(C, uncle, countable, na, eq, 1)-1, relation(C, of, D)-1, relation(D, of, B)-1, object(D, child, countable, na, geq, 2)-1, predicate(E, be, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [brother]], [pp, [prep, [of]], [nbar, [pn, [somebody]], [appos_coord, [appos, [var, ['X']]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [uncle]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [children]], [pp, [prep, [of]], [np, [np, [var, ['X']]]]]]]]]]]]], ['.']]], '2007-05-09-16-20-37', '130.60.155.177', '').
text_drs_eval(0, 2131, 'There is a man var:John.', drs([], []), [], '2007-07-18-14-46-33', '130.60.155.177', '').
text_drs_eval(0, 2132, 'If X likes Y then Y likes X.', drs([], [drs([A, B, C], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, predicate(C, like, A, B)-1])=>drs([D], [predicate(D, like, B, A)-1])]), [[specification, [cond_s, if, [s, [np, [var, 'X']], [vp, [vbar, [v, likes], [np, [var, 'Y']]]]], then, [s, [np, [var, 'Y']], [vp, [vbar, [v, likes], [np, [var, 'X']]]]]], '.']], '2008-07-10-10-46-28', '130.60.155.206', '').
text_drs_eval(0, 2133, 'If var:X likes var:Y then var:Y likes var:X.', drs([], []), [], '2007-05-16-14-39-09', '130.60.155.177', '').
text_drs_eval(0, 2134, 'At least 2 scores of John are 30.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, score, countable, na, geq, 2)-1, relation(B, of, A)-1, predicate(C, be, B, int(30))-1]), [[specification, [s, [np, [numberp, [gen_quant, ['{at least}']], [number, [2]]], [nbar, [n, [scores]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [are]], [np, [int, [30]]]]]], ['.']]], '2007-09-01-17-06-53', '130.60.155.177', '').
text_drs_eval(0, 2135, 'At most 1 man\'s dog barks.', drs([A, B, C], [[predicate(C, bark, B)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, object(A, man, countable, na, leq, 1)-1]]), [[specification, [s, [np, [poss_np, [nump, [genqu, 'at most'], 1], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]], '.']], '2009-03-02-11-30-22', '130.60.155.206', '').
text_drs_eval(0, 2136, 'Everybody sees at most 1 thing.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C], [[predicate(C, see, A, B)-1, object(B, thing, countable, na, leq, 1)-1]])]), [[specification, [s, [np, [pn, everybody]], [vp, [vbar, [vcompl, [v, sees], [np, [nump, [genqu, 'at most'], 1], [nbar, [n, thing]]]]]]], '.']], '2009-03-02-11-30-30', '130.60.155.206', '').
text_drs_eval(0, 2137, 'Every goal is something that at most 1 person scores.', drs([], [drs([A], [object(A, goal, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, something, dom, na, na, na)-1, [predicate(D, score, C, B)-1, object(C, person, countable, na, leq, 1)-1], predicate(E, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, goal]]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, something], [rel_cl, [comp, that], [np, [nump, [genqu, 'at most'], 1], [nbar, [n, person]]], [vp, [vbar, [vcompl, [v, scores]]]]]]]]]], '.']], '2009-03-02-11-30-39', '130.60.155.206', '').
text_drs_eval(0, 2138, 'It is false that there is 1 man.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [numberp, [gen_quant, [[]]], [number, [1]]], [nbar, [n, [man]]]]]]]], ['.']]], '2007-05-09-16-21-27', '130.60.155.177', '').
text_drs_eval(0, 2139, 'A man X gives an apple to a woman Y. Y accepts the apple and eats it. She is happy and he has no apple.', drs([A, B, C, D, E, F, G, H], [object(A, man, countable, na, eq, 1)-1, object(B, apple, countable, na, eq, 1)-1, object(C, woman, countable, na, eq, 1)-1, predicate(D, give, A, B, C)-1, predicate(E, accept, C, B)-2, predicate(F, eat, C, B)-2, property(G, happy, pos)-3, predicate(H, be, C, G)-3, drs([I], [object(I, apple, countable, na, eq, 1)-3])=>drs([], [-drs([J], [predicate(J, have, A, I)-3])])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [apple]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [woman]], [appos_coord, [appos, [var, ['Y']]]]]]]]]], ['.']], [specification, [s, [np, [np, [var, ['Y']]]], [vp_coord, [vp, [vbar, [v, [accepts]], [np, [det, [the]], [nbar, [n, [apple]]]]]], [coord, [and]], [vp, [vbar, [v, [eats]], [np, [pn, [it]]]]]]], ['.']], [specification, [s_coord, [s, [np, [pn, [she]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [has]], [np, [det, [no]], [nbar, [n, [apple]]]]]]]], ['.']]], '2007-05-09-16-22-04', '130.60.155.177', '').
text_drs_eval(0, 2140, 'John gives an apple to Mary. Mary accepts the apple and eats it. She is happy and he has no apple.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, give, A, C, B)-1, predicate(E, accept, B, C)-2, predicate(F, eat, B, C)-2, property(G, happy, pos)-3, predicate(H, be, B, G)-3, drs([I], [object(I, apple, countable, na, eq, 1)-3])=>drs([], [-drs([J], [predicate(J, have, A, I)-3])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [apple]]]], [pp, [prep, [to]], [np, [pname, ['Mary']]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp_coord, [vp, [vbar, [v, [accepts]], [np, [det, [the]], [nbar, [n, [apple]]]]]], [coord, [and]], [vp, [vbar, [v, [eats]], [np, [pn, [it]]]]]]], ['.']], [specification, [s_coord, [s, [np, [pn, [she]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], [coord, [and]], [s, [np, [pn, [he]]], [vp, [vbar, [v, [has]], [np, [det, [no]], [nbar, [n, [apple]]]]]]]], ['.']]], '2007-05-09-12-15-51', '130.60.156.229', '').
text_drs_eval(0, 2141, 'A text is read John.', drs([], []), [], '2007-08-10-20-12-45', '130.60.155.177', '').
text_drs_eval(0, 2142, '3.14 is real.', drs([A, B], [property(A, real, pos)-1, predicate(B, be, real(3.14), A)-1]), [[specification, [s, [np, [real, [3.14]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [real]]]]]]], ['.']]], '2007-09-01-17-07-03', '130.60.155.177', '').
text_drs_eval(0, 2143, 'There is 1 hour of work.', drs([], []), [], '2007-12-10-17-02-13', '130.60.155.231', '').
text_drs_eval(0, 2144, 'There is 10 hour of work.', drs([], []), [], '2007-04-18-12-18-12', '130.60.156.229', '').
text_drs_eval(0, 2145, 'There are 10 hour of work.', drs([], []), [], '2007-04-18-12-18-50', '130.60.156.229', '').
text_drs_eval(0, 2146, 'There is 10 hours of work.', drs([], []), [], '2007-04-18-12-18-40', '130.60.156.229', '').
text_drs_eval(0, 2147, 'There is 1 hours of work.', drs([], []), [], '2007-04-18-12-19-26', '130.60.156.229', '').
text_drs_eval(0, 2148, 'There are 1 hour of work.', drs([], []), [], '2007-04-18-12-20-36', '130.60.156.229', '').
text_drs_eval(0, 2149, 'There are 1 hours of work.', drs([], []), [], '2007-04-18-12-21-10', '130.60.156.229', '').
text_drs_eval(0, 2150, 'Every age of a man is an integer.', drs([], [drs([A, B], [object(A, age, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1])=>drs([C, D], [object(C, integer, countable, na, eq, 1)-1, predicate(D, be, A, C)-1])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [age]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [integer]]]]]]], ['.']]], '2007-05-09-16-22-22', '130.60.155.177', '').
text_drs_eval(0, 2151, 'A card of somebody is valid.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, relation(A, of, B)-1, property(C, valid, pos)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [nbar, [pn, [somebody]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2007-05-09-16-22-32', '130.60.155.177', '').
text_drs_eval(0, 2152, '" " is a string.', drs([A, B], [object(A, string, countable, na, eq, 1)-1, predicate(B, be, string(' '), A)-1]), [[specification, [s, [np, [string, [' ']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [string]]]]]]], ['.']]], '2007-09-01-16-37-40', '130.60.155.177', '').
text_drs_eval(0, 2153, 'John eats. He who waits has a dog.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, eats]]]], '.']], '2008-09-23-08-50-27', '130.60.155.206', '').
text_drs_eval(0, 2154, 'John has a card. He who waits uses it which is valid.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, has], [np, [det, a], [nbar, [n, card]]]]]], '.']], '2008-09-23-08-50-34', '130.60.155.206', '').
text_drs_eval(0, 2155, 'John has a card. He that waits uses it that is valid.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, has], [np, [det, a], [nbar, [n, card]]]]]], '.']], '2008-09-23-08-50-45', '130.60.155.206', '').
text_drs_eval(0, 2156, 'Who who waits sleeps?', drs([], []), [], '2008-09-23-08-51-05', '130.60.155.206', '').
text_drs_eval(0, 2157, 'John eats. He which waits has a dog.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [eats]]]]], ['.']]|A], '2007-04-19-13-46-57', '130.60.156.229', '').
text_drs_eval(0, 2158, 'John has a card. He uses it who is valid.', drs([], []), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]|A], '2007-04-19-13-47-16', '130.60.156.229', '').
text_drs_eval(0, 2159, 'Who that waits sleeps?', drs([], []), [], '2008-09-23-08-51-12', '130.60.155.206', '').
text_drs_eval(0, 2160, 'Who which waits sleeps?', drs([], []), [], '2007-04-19-13-48-44', '130.60.156.229', '').
text_drs_eval(0, 2161, 'What which succeeds exists?', drs([], []), [], '2008-09-23-08-51-20', '130.60.155.206', '').
text_drs_eval(0, 2162, 'There is a man. He whose dog barks waits.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.']], '2008-09-23-08-51-39', '130.60.155.206', '').
text_drs_eval(0, 2163, 'John owns a car that Mary likes and that Bill likes.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-1, object(D, car, countable, na, eq, 1)-1, predicate(E, like, B, D)-1, predicate(F, like, C, D)-1, predicate(G, own, A, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]], [rel_cl_coord, [rel_cl, [comp, [that]], [np, [pname, ['Mary']]], [vp, [vbar, [v, [likes]], [np, [[]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [np, [pname, ['Bill']]], [vp, [vbar, [v, [likes]], [np, [[]]]]]]]]]]]], ['.']]], '2007-04-30-17-36-31', '130.60.155.177', '').
text_drs_eval(0, 2164, 'John sees someone X of a customer who is important.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, object(D, customer, countable, na, eq, 1)-1, property(E, important, pos)-1, predicate(F, be, D, E)-1, relation(B, of, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [nbar, [pn, [someone]], [appos_coord, [appos, [var, ['X']]]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [customer]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [important]]]]]]]]]]]]]], ['.']]], '2007-08-08-11-11-44', '130.60.155.231', '').
text_drs_eval(0, 2165, 'a man sees Every dog and If There is A dog then The dog Is An animal.', drs([], []), [], '2008-07-14-13-45-38', '130.60.155.206', '').
text_drs_eval(0, 2166, 'Whose dog barks.', drs([], []), [], '2007-04-27-14-45-10', '130.60.155.177', '').
text_drs_eval(0, 2167, 'whose dog barks?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, dog, countable, na, eq, 1)-1/2, predicate(C, bark, B)-1/3]))]), [[sentence, [query, [question, [np, [qdet, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]], ?], '.']], '2009-05-13-13-58-03', '130.60.155.193', '').
text_drs_eval(0, 2168, 'Whose dog barks?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, dog, countable, na, eq, 1)-1/2, predicate(C, bark, B)-1/3]))]), [[sentence, [query, [question, [np, [qdet, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]], ?], '.']], '2009-05-13-13-58-04', '130.60.155.193', '').
text_drs_eval(0, 2169, 'John is as important as Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, property(C, important, pos_as, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [as], [adj, [important]], [conj, [as]], [np, [pname, ['Mary']]]]|E]]]], ['.']]], '2007-05-09-12-16-03', '130.60.156.229', '').
text_drs_eval(0, 2170, 'An as important as Mary customer.', drs([], []), [], '2007-05-03-13-25-28', '130.60.156.229', '').
text_drs_eval(0, 2171, 'There is an as important as Mary customer.', drs([], []), [], '2007-05-03-13-25-43', '130.60.156.229', '').
text_drs_eval(0, 2172, 'John is more important.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, property(B, important, comp)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['more important']]]]]]], ['.']]], '2007-05-09-12-16-12', '130.60.156.229', '').
text_drs_eval(0, 2173, 'There is a more important person.', drs([A], [object(A, person, countable, na, eq, 1)-1, property(A, important, comp)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, ['more important']], [nbar, [n, [person]]]]]]], ['.']]], '2007-05-09-12-16-34', '130.60.156.229', '').
text_drs_eval(0, 2174, 'John is most important.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, property(B, important, sup)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['most important']]]]]]], ['.']]], '2007-05-09-12-16-39', '130.60.156.229', '').
text_drs_eval(0, 2175, 'There is a most important person.', drs([A], [object(A, person, countable, na, eq, 1)-1, property(A, important, sup)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, ['most important']], [nbar, [n, [person]]]]]]], ['.']]], '2007-05-09-12-16-44', '130.60.156.229', '').
text_drs_eval(0, 2176, 'John is more fond-of Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, property(C, 'fond-of', comp, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['more fond-of']], [np, [pname, ['Mary']]]]|E]]]], ['.']]], '2007-05-09-16-15-16', '130.60.155.177', '').
text_drs_eval(0, 2177, 'There is a more fond-of Mary person.', drs([], []), [], '2007-05-03-13-28-11', '130.60.156.229', '').
text_drs_eval(0, 2178, 'John is as fond-of Mary as Bill.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-1, property(D, 'fond-of', B, pos_as, subj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [as], [adj, ['fond-of']], [np, [pname, ['Mary']]], [as], [np, [pname, ['Bill']]]]|F]]]], ['.']]], '2007-05-09-16-15-32', '130.60.155.177', '').
text_drs_eval(0, 2179, 'John is as fond-of Mary as of Bill.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-1, property(D, 'fond-of', B, pos_as, obj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [as], [adj, ['fond-of']], [np, [pname, ['Mary']]], [as], [of], [np, [pname, ['Bill']]]]|F]]]], ['.']]], '2007-05-09-16-15-46', '130.60.155.177', '').
text_drs_eval(0, 2180, 'John is more fond-of Mary than Bill.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-1, property(D, 'fond-of', B, comp_than, subj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['more fond-of']], [np, [pname, ['Mary']]], [than], [np, [pname, ['Bill']]]]|F]]]], ['.']]], '2007-05-09-16-15-56', '130.60.155.177', '').
text_drs_eval(0, 2181, 'John is more fond-of Mary than of Bill.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-1, property(D, 'fond-of', B, comp_than, obj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['more fond-of']], [np, [pname, ['Mary']]], [than], [of], [np, [pname, ['Bill']]]]|F]]]], ['.']]], '2007-05-09-16-16-10', '130.60.155.177', '').
text_drs_eval(0, 2182, 'John is more fond-of no customer than every clerk.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, customer, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([C], [object(C, clerk, countable, na, eq, 1)-1])=>drs([D, E], [property(D, 'fond-of', B, comp_than, subj, C)-1, predicate(E, be, A, D)-1])])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more], ['fond-of']], [np, [det, [no]], [nbar, [n, [customer]]]], [than], [np, [det, [every]], [nbar, [n, [clerk]]]]]]]]], ['.']]], '2007-12-23-12-06-23', '130.60.204.35', '').
text_drs_eval(0, 2183, 'John is fond-of Mary than Bill.', drs([], []), [], '2007-05-04-10-53-28', '130.60.156.229', '').
text_drs_eval(0, 2184, 'John is most fond-of Mary than Bill.', drs([], []), [], '2007-05-04-10-53-36', '130.60.156.229', '').
text_drs_eval(0, 2185, 'John is rich and richer and richest.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, property(B, rich, pos)-1, property(B, rich, comp)-1, property(B, rich, sup)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]], [coord, [and]], [ap_coord, [ap, [adj, [richer]]], [coord, [and]], [ap_coord, [ap, [adj, [richest]]]]]]]]], ['.']]], '2007-05-09-12-16-50', '130.60.156.229', '').
text_drs_eval(0, 2186, 'John and Mary wait.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, has_part(D, A)-1, predicate(C, wait, D)-1, has_part(D, B)-1, object(D, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-12-23-12-06-43', '130.60.204.35', '').
text_drs_eval(0, 2187, 'If a man likes somebody that is a person then the person owns a car.', drs([], [drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, object(D, person, countable, na, eq, 1)-1, predicate(E, be, B, D)-1])=>drs([F, G], [object(F, car, countable, na, eq, 1)-1, predicate(G, own, D, F)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [nbar, [pn, [somebody]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [person]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [person]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-05-07-20-30-43', '130.60.155.177', '').
text_drs_eval(0, 2188, 'John snores loudly and loudly loudly and most loudly.', drs([], []), [], '2007-06-12-11-06-46', '130.60.156.66', '').
text_drs_eval(0, 2189, 'if the n:present-value of a n:lease-payment of an asset is greater than 90 percent of something of the fair value of the asset then the asset is a n:finance-lease.', drs([], [drs([A, B, C, D, E, F, G, H], [object(A, percent, countable, na, eq, 90)-1, object(B, something, dom, na, na, na)-1, relation(B, of, C)-1, relation(A, of, B)-1, property(D, great, comp_than, A)-1, predicate(E, be, F, D)-1, relation(F, of, G)-1, relation(G, of, H)-1, object(H, asset, countable, na, eq, 1)-1, object(G, 'lease-payment', countable, na, eq, 1)-1, object(F, 'present-value', countable, na, eq, 1)-1, relation(C, of, H)-1, property(C, fair, pos)-1, object(C, value, countable, na, eq, 1)-1])=>drs([I, J], [object(I, 'finance-lease', countable, na, eq, 1)-1, predicate(J, be, H, I)-1])]), [[cond_s, [if], [s, [np, [det, [the]], [nbar, [n, ['present-value']], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, ['lease-payment']], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [asset]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [greater]], [conj, [than]], [np, [numberp, [gen_quant, [[]]], [number, [90]]], [nbar, [n, [percent]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, ['$thing']], [pp, [prep, [of]], [np, [det, [the]], [nbar, [adj, [fair]], [nbar, [n, [value]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [asset]]]]]]]]]]]]]]]|K]]]], [then], [s, [np, [det, [the]], [nbar, [n, [asset]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['finance-lease']]]]]]]]], '2007-10-26-15-17-53', '130.60.155.231', '').
text_drs_eval(0, 2190, 'No man is something that likes Mary and hates John.', drs([A, B], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([], [-drs([D, E, F, G], [object(D, something, dom, na, na, na)-1, predicate(E, be, C, D)-1, predicate(F, like, D, A)-1, predicate(G, hate, C, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [is]], [nbar, [pn, [something]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [pname, ['Mary']]]]]]]]], [coord, [and]], [vp, [vbar, [v, [hates]], [np, [pname, ['John']]]]]]], ['.']]], '2007-05-10-16-59-42', '130.60.155.177', '').
text_drs_eval(0, 2191, 'No man is something that likes Mary and that hates John.', drs([A, B], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([], [-drs([D, E, F, G], [object(D, something, dom, na, na, na)-1, predicate(E, be, C, D)-1, predicate(F, like, D, A)-1, predicate(G, hate, D, B)-1])])]), [[specification, [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [nbar, [pn, [something]], [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [pname, ['Mary']]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [hates]], [np, [pname, ['John']]]]]]]]]]], ['.']]], '2007-05-10-17-00-00', '130.60.155.177', '').
text_drs_eval(0, 2192, 'John does not see less than 3 cars that Bill owns.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, -drs([C, D, E], [[predicate(E, see, A, C)-1, predicate(D, own, B, C)-1, object(C, car, countable, na, less, 3)-1]])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vcompl, [v, see], [np, [nump, [genqu, 'less than'], 3], [nbar, [n, cars], [rel_cl, [comp, that], [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, owns]]]]]]]]]]], '.']], '2009-03-02-11-30-47', '130.60.155.206', '').
text_drs_eval(0, 2193, 'A man slooowly walks.', drs([], []), [], '2007-05-16-14-37-38', '130.60.155.177', '').
text_drs_eval(0, 2194, 'John is manually in a park.', drs([], []), [], '2008-01-16-17-23-23', '130.60.155.177', '').
text_drs_eval(0, 2195, 'there is a dog which barks and that eats.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1, predicate(C, eat, A)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl_coord, [rel_cl, [np, [relpn, [which]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]]]]]]], ['.']]], '2007-12-20-13-34-37', '130.60.155.231', '').
text_drs_eval(0, 2196, 'There are not at most 5 men.', drs([], []), [], '2008-08-19-19-57-40', '130.60.155.177', '').
text_drs_eval(0, 2197, 'There are not at least 5 men.', drs([], []), [], '2008-08-19-19-57-48', '130.60.155.177', '').
text_drs_eval(0, 2198, '3.1415926536 approximates Pi.', drs([A], [predicate(A, approximate, real(3.1415926536), named('Pi'))-1/2]), [[specification, [s, [np, [real, 3.1415926536]], [vp, [vbar, [vcompl, [v, approximates], [np, [pname, 'Pi']]]]]], '.']], '2011-07-20-23-20-50', '89.206.71.199', '').
text_drs_eval(0, 2199, 'John waits. He that sleeps waits.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, waits]]]], '.']], '2008-09-23-08-52-00', '130.60.155.206', '').
text_drs_eval(0, 2200, 'How is John?', drs([], [question(drs([A], [query(A, how)-1/1, predicate(A, be, named('John'))-1/2]))]), [[sentence, [query, [question, [qpn, how], is, [np, [pname, 'John']]], ?], '.']], '2009-05-13-13-58-05', '130.60.155.193', '').
text_drs_eval(0, 2201, 'Xxx are a company.', drs([], []), [], '2008-07-09-15-27-19', '130.60.155.206', '').
text_drs_eval(0, 2202, 'A card is taken manually by John.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1/2, property(B, taken, pos)-1/4, predicate(C, be, A, B)-1/3, modifier_pp(C, by, named('John'))-1/6, modifier_adv(C, manually, pos)-1/5]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, taken]]], [vmod, [adv, manually], [pp, [prep, by], [np, [pname, 'John']]]]]], '.']], '2009-05-19-17-21-26', '130.60.155.193', '').
text_drs_eval(0, 2203, 'There are 1234.', drs([], []), [], '2007-09-21-19-42-20', '130.60.155.177', '').
text_drs_eval(0, 2204, 'There are "ABCD".', drs([], []), [], '2007-09-21-19-43-19', '130.60.155.177', '').
text_drs_eval(0, 2205, 'There are 1 and "2" and 3.', drs([], []), [], '2008-01-03-16-29-50', '130.60.206.88', '').
text_drs_eval(0, 2206, 'Jimmy\'s dog barks.', drs([A, B, C], [object(A, 'Jimmy', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1]), [[s, [np, [poss_np, [var, ['Jimmy']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], '2007-10-16-20-18-04', '130.60.155.177', '').
text_drs_eval(0, 2207, 'For all men the man likes himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/3])=>drs([B, C], [object(C, man, countable, na, eq, 1)-1/5, predicate(B, like, C, C)-1/6])]), [[specification, [top_s, [topic, [quant, for], [np, [det, all], [nbar, [n, men]]]], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, likes], [np, [pn, himself]]]]]]], '.']], '2009-11-12-23-58-37', '84.74.139.220', '').
text_drs_eval(0, 2208, 'A man has 2 tons of apples.', drs([], []), [], '2007-12-10-17-02-24', '130.60.155.231', '').
text_drs_eval(0, 2209, 'A man visits a town ZZZZZ1.', drs([], []), [], '2008-07-30-17-49-31', '130.60.155.177', '').
text_drs_eval(0, 2210, 'All men see themselves.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, see, A, A)-1])]), [[specification, [s, [np, [det, [all]], [nbar, [n, [men]]]], [vp, [vbar, [v, [see]], [np, [pn, [themselves]]]]]], ['.']]], '2007-06-13-09-16-10', '130.60.155.177', '').
text_drs_eval(0, 2211, 'All men sees himself.', drs([], []), [], '2007-06-13-09-16-24', '130.60.155.177', '').
text_drs_eval(0, 2212, 'All men see himself.', drs([], []), [[specification, [s, [np, [det, [all]], [nbar, [n, [men]]]], [vp, [vbar, [v, [see]], [np, [pn, [himself]]]]]], ['.']]], '2007-06-13-09-16-42', '130.60.155.177', '').
text_drs_eval(0, 2213, 'John waits. All men see him.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, A)-1, drs([C], [object(C, man, countable, na, eq, 1)-2])=>drs([D], [predicate(D, see, C, A)-2])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [all]], [nbar, [n, [men]]]], [vp, [vbar, [v, [see]], [np, [pn, [him]]]]]], ['.']]], '2007-06-13-09-17-15', '130.60.155.177', '').
text_drs_eval(0, 2214, 'John waits. All men see himself.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, waits]]]], '.']], '2008-10-22-16-11-06', '130.60.155.177', '').
text_drs_eval(0, 2215, 'John waits. Some men see himself.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, waits]]]], '.']], '2008-10-02-14-50-55', '130.60.155.206', '').
text_drs_eval(0, 2216, 'John does not see anybody.', drs([], []), [], '2007-12-04-18-49-38', '130.60.155.177', '').
text_drs_eval(0, 2217, 'John waits. A man brings him his pencil and his own computer.', drs([A, B, C, D, E, F, G], [object(G, na, countable, na, eq, 2)-2, has_part(G, F)-2, has_part(G, D)-2, object(F, computer, countable, na, eq, 1)-2, relation(F, of, C)-2, predicate(E, bring, C, G, A)-2, object(D, pencil, countable, na, eq, 1)-2, relation(D, of, A)-2, object(C, man, countable, na, eq, 1)-2, predicate(B, wait, A)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [pn, [him]]], [np_coord, [np, [posspn, [his]], [nbar, [n, [pencil]]]], [coord, [and]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-11-13-13-13-35', '130.60.155.177', '').
text_drs_eval(0, 2218, 'Everybody who is a father of a man that owns a car is a parent.', drs([], [drs([A, B, C, D, E, F], [object(A, father, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, car, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, relation(A, of, B)-1, predicate(E, be, F, A)-1, object(F, somebody, countable, na, eq, 1)-1])=>drs([G, H], [object(G, parent, countable, na, eq, 1)-1, predicate(H, be, F, G)-1])]), [[specification, [s, [nbar, [pn, [everybody]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [father]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]]]]]]]]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [parent]]]]]]], ['.']]], '2007-08-08-11-12-38', '130.60.155.231', '').
text_drs_eval(0, 2219, 'Every pet is something that is a cat or that is a dog, and that is not something that is a cat and that is a dog.', drs([], [drs([A], [object(A, pet, countable, na, eq, 1)-1])=>drs([B, C], [object(B, something, dom, na, na, na)-1, drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, be, B, D)-1])v drs([F, G], [object(F, dog, countable, na, eq, 1)-1, predicate(G, be, B, F)-1]), -drs([H, I, J, K, L, M], [object(H, something, dom, na, na, na)-1, object(I, cat, countable, na, eq, 1)-1, predicate(J, be, H, I)-1, object(K, dog, countable, na, eq, 1)-1, predicate(L, be, H, K)-1, predicate(M, be, B, H)-1]), predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, pet]]], [vp, [aux, is], [vbar, [np, [pn, something], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog]]]]]]], [coord, ', and'], [rel_cl, [comp, that], [vp, [aux, is, not], [vbar, [np, [pn, something], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]], [coord, and], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog]]]]]]]]]]]]]]]], '.']], '2008-08-19-19-03-55', '130.60.155.177', '').
text_drs_eval(0, 2220, 'Every n:influent-stream is something that v:flows-into a cave and that v:flows-through a sink or that v:discharges-through something.', drs([], [drs([A], [object(A, 'influent-stream', countable, na, eq, 1)-1])=>drs([B, C], [object(B, something, dom, na, na, na)-1, predicate(C, be, A, B)-1, drs([D, E, F, G], [object(D, cave, countable, na, eq, 1)-1, predicate(E, 'flows-into', B, D)-1, object(F, sink, countable, na, eq, 1)-1, predicate(G, 'flows-through', B, F)-1])v drs([H, I], [object(H, something, dom, na, na, na)-1, predicate(I, 'discharges-through', B, H)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, ['influent-stream']]]], [vp, [vbar, [v, [is]], [nbar, [pn, [something]], [rel_cl_coord, [rel_cl_coord, [rel_cl, [comp, [that]], [vp, [vbar, [v, ['flows-into']], [np, [det, [a]], [nbar, [n, [cave]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [vp, [vbar, [v, ['flows-through']], [np, [det, [a]], [nbar, [n, [sink]]]]]]]], [coord, [or]], [rel_cl, [comp, [that]], [vp, [vbar, [v, ['discharges-through']], [nbar, [pn, [something]]]]]]]]]]], ['.']]], '2007-06-25-19-09-43', '130.60.155.177', '').
text_drs_eval(0, 2221, 'There is a man. John likes his a:own car.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, relation(C, of, B)-2, object(C, car, countable, na, eq, 1)-2, property(C, own, pos)-2, predicate(D, like, A, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [posspn, [his]], [nbar, [adj, [own]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-12-20-13-37-27', '130.60.155.231', '').
text_drs_eval(0, 2222, 'France is something that is not America and that is not England and that is not Germany.', drs([A, B, C, D, E, F], [object(A, 'France', named, na, eq, 1)-1, object(B, 'America', named, na, eq, 1)-1, object(C, 'England', named, na, eq, 1)-1, object(D, 'Germany', named, na, eq, 1)-1, object(E, something, dom, na, na, na)-1, -drs([G], [predicate(G, be, E, B)-1]), -drs([H], [predicate(H, be, E, C)-1]), -drs([I], [predicate(I, be, E, D)-1]), predicate(F, be, A, E)-1]), [[specification, [s, [np, [var, ['France']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, ['$thing']], [rel_cl_coord, [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [var, ['America']]]]]], [coord, [and]], [rel_cl_coord, [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [var, ['England']]]]]], [coord, [and]], [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [var, ['Germany']]]]]]]]]]]]], ['.']]], '2008-01-02-16-43-32', '130.60.206.8', '').
text_drs_eval(0, 2223, 'A man silently and patiently walks quickly and fast in a street manually and happily in a morning always.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, morning, countable, na, eq, 1)-1, object(C, street, countable, na, eq, 1)-1, predicate(D, walk, A)-1, modifier_adv(D, quickly, pos)-1, modifier_adv(D, fast, pos)-1, modifier_pp(D, in, C)-1, modifier_adv(D, manually, pos)-1, modifier_adv(D, happily, pos)-1, modifier_pp(D, in, B)-1, modifier_adv(D, always, pos)-1, modifier_adv(D, silently, pos)-1, modifier_adv(D, patiently, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [adv_coord, [adv, [silently]], [coord, [and]], [adv, [patiently]]], [vbar, [vbar, [v, [walks]]], [adv_coord, [adv, [quickly]], [coord, [and]], [adv, [fast]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [street]]]]], [adv_coord, [adv, [manually]], [coord, [and]], [adv, [happily]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [morning]]]]], [adv, [always]]]]]], ['.']]], '2007-07-04-14-31-13', '130.60.206.45', '').
text_drs_eval(0, 2224, 'Christmases like Mary.', drs([A, B, C], [object(A, 'Christmas', named, na, geq, 2)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, like, A, B)-1]), [[specification, [s, [np, [pname, ['Christmases']]], [vp, [vbar, [v, [like]], [np, [pname, ['Mary']]]]]], ['.']]], '2008-01-07-00-46-54', '130.60.206.18', '').
text_drs_eval(0, 2225, 'Who is a child X whose mother is somebody whose husband is somebody whose child is not the child X?', drs([], [question(drs([A, B, C, D, E, F, G, H, I, J], [query(A, who)-1/1, object(B, child, countable, na, eq, 1)-1/4, object(C, mother, countable, na, eq, 1)-1/7, relation(C, of, B)-1/6, object(D, somebody, countable, na, eq, 1)-1/10, object(E, husband, countable, na, eq, 1)-1/12, relation(E, of, D)-1/11, object(F, somebody, countable, na, eq, 1)-1/15, object(G, child, countable, na, eq, 1)-1/17, relation(G, of, F)-1/16, -drs([K], [predicate(K, be, G, B)-1/18]), predicate(H, be, E, F)-1/13, predicate(I, be, C, D)-1/8, predicate(J, be, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, child], [appos, [var, 'X']], [rel_cl, [np, [posspn, whose], [nbar, [n, mother]]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, somebody], [rel_cl, [np, [posspn, whose], [nbar, [n, husband]]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, somebody], [rel_cl, [np, [posspn, whose], [nbar, [n, child]]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, the], [nbar, [n, child], [appos, [var, 'X']]]]]]]]]]]]]]]]]]]]]]]], ?], '.']], '2009-05-13-13-58-07', '130.60.155.193', '').
text_drs_eval(0, 2226, 'John\'age is 21.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1, predicate(C, be, B, int(21))-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'']]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [21]]]]]], ['.']]], '2007-09-01-17-07-39', '130.60.155.177', '').
text_drs_eval(0, 2227, 'John\'s clerks carry their lunch into school.', drs([], []), [], '2007-08-13-15-44-54', '130.60.155.177', '').
text_drs_eval(0, 2228, 'This is not an ACE text!!!', drs([], []), [], '2008-06-26-16-23-00', tkuhn, 'dummy entry with id 2228. this id was missing for an unknown reason').
text_drs_eval(0, 2229, 'If a man likes a dog that likes a cat and the man likes a cow that likes a sheep then the man owns a car.', drs([], [drs([A, B, C, D, E, F, G, H, I], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, like, B, C)-1, predicate(E, like, A, B)-1, object(F, cow, countable, na, eq, 1)-1, object(G, sheep, countable, na, eq, 1)-1, predicate(H, like, F, G)-1, predicate(I, like, A, F)-1])=>drs([J, K], [object(J, car, countable, na, eq, 1)-1, predicate(K, own, A, J)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cow]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [sheep]]]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-07-11-22-02-59', '130.60.155.177', '').
text_drs_eval(0, 2230, 'If there is a man, and the man likes a dog that likes a cat or the man likes a cow that likes a sheep then the man owns a car.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C, D, E], [object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, like, B, C)-1, predicate(E, like, A, B)-1])v drs([F, G, H, I], [object(F, cow, countable, na, eq, 1)-1, object(G, sheep, countable, na, eq, 1)-1, predicate(H, like, F, G)-1, predicate(I, like, A, F)-1])])=>drs([J, K], [object(J, car, countable, na, eq, 1)-1, predicate(K, own, A, J)-1])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, ['{, and}']], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], [coord, [or]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [cow]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [sheep]]]]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-07-11-22-04-44', '130.60.155.177', '').
text_drs_eval(0, 2231, 'There is a man that sees a woman that owns a cat. Who is the man? Who is the woman?', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/4, object(B, woman, countable, na, eq, 1)-1/8, object(C, cat, countable, na, eq, 1)-1/12, predicate(D, own, B, C)-1/10, predicate(E, see, A, B)-1/6, question(drs([F, G], [query(F, who)-2/1, predicate(G, be, F, A)-2/2])), question(drs([H, I], [query(H, who)-3/1, predicate(I, be, H, B)-3/2]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, woman], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]]]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [np, [det, the], [nbar, [n, man]]]]]]], ?], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [np, [det, the], [nbar, [n, woman]]]]]]], ?], '.']], '2009-05-13-13-58-08', '130.60.155.193', '').
text_drs_eval(0, 2232, 'What are some men?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, object(B, man, countable, na, geq, 2)-1/4, predicate(C, be, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, are], [vbar, [vcompl, [np, [det, some], [nbar, [n, men]]]]]]], ?], '.']], '2009-05-13-13-58-09', '130.60.155.193', '').
text_drs_eval(0, 2233, 'John is allowed to walk.', drs([], []), [], '2007-07-19-13-22-27', '130.60.155.177', '').
text_drs_eval(0, 2234, 'Everyone who is in the n:cc of some mail can access its content.', drs([], [drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1/2, relation(C, of, D)-1/10, object(D, mail, mass, na, na, na)-1/12, object(C, cc, countable, na, eq, 1)-1/9, predicate(B, be, A)-1/4, modifier_pp(B, in, C)-1/5])=>drs([], [can(drs([E, F], [relation(E, of, D)-1/15, object(E, content, countable, na, eq, 1)-1/16, predicate(F, access, A, E)-1/14]))])]), [[specification, [s, [np, [pn, everyone], [rel_cl, [np, [relpn, who]], [vp, [aux, is], [pp, [prep, in], [np, [det, the], [nbar, [n, cc], [pp, [prep, of], [np, [det, some], [nbar, [n, mail]]]]]]]]]], [vp, [aux, can], [vbar, [vcompl, [v, access], [np, [posspn, its], [nbar, [n, content]]]]]]], '.']], '2010-10-27-09-28-11', '89.206.64.27', '').
text_drs_eval(0, 2235, 'More than 3 clerks wait. John knows the clerks. Less than 2 clerks sit. John knows the clerks.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-2, object(B, clerk, countable, na, greater, 3)-1, predicate(C, wait, B)-1, predicate(D, know, A, B)-2, [predicate(F, sit, E)-3, object(E, clerk, countable, na, less, 2)-3], predicate(G, know, A, E)-4]), [[specification, [s, [np, [nump, [genqu, 'more than'], 3], [nbar, [n, clerks]]], [vp, [vbar, [vbar, [v, wait]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, knows], [np, [det, the], [nbar, [n, clerks]]]]]]], '.'], [specification, [s, [np, [nump, [genqu, 'less than'], 2], [nbar, [n, clerks]]], [vp, [vbar, [vbar, [v, sit]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, knows], [np, [det, the], [nbar, [n, clerks]]]]]]], '.']], '2009-03-02-11-30-55', '130.60.155.206', '').
text_drs_eval(0, 2236, 'p:Peeter owns a car.', drs([A, B, C], [object(A, 'Peeter', named, na, eq, 1)-1, object(B, car, countable, na, eq, 1)-1, predicate(C, own, A, B)-1]), [[specification, [s, [np, [pname, ['Peeter']]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]], ['.']]], '2007-08-22-13-18-53', '130.60.155.177', '').
text_drs_eval(0, 2237, 'John tries to walk.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, try, A, C)-1, C:drs([D], [predicate(D, walk, A)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, tries], to, [vp, [vbar, [vbar, [v, walk]]]]]]], '.']], '2009-01-06-10-41-53', '130.60.155.206', '').
text_drs_eval(0, 2238, 'John does not have to walk.', drs([], [-drs([], [must(drs([A], [predicate(A, walk, named('John'))-1/6]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'not have to'], [vbar, [vbar, [v, walk]]]]], '.']], '2010-10-27-09-28-19', '89.206.64.27', '').
text_drs_eval(0, 2239, 'Who does a dog see who is a man?', drs([], []), [], '2007-10-26-15-25-59', '130.60.155.231', '').
text_drs_eval(0, 2240, 'John sees what?', drs([], [question(drs([A, B], [query(A, what)-1/3, predicate(B, see, named('John'), A)-1/2]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [qpn, what]]]]]], ?], '.']], '2009-05-13-13-58-10', '130.60.155.193', '').
text_drs_eval(0, 2241, 'If there are a man and a manager then the man is a:officially the manager.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, has_part(C, A)-1, object(B, manager, countable, na, eq, 1)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1])=>drs([D, E], [property(D, officially, pos, B)-1, predicate(E, be, A, D)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, manager]]]]]], then, [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, officially], [np, [det, the], [nbar, [n, manager]]]]]]]]], '.']], '2008-08-19-16-04-53', '130.60.155.208', '').
text_drs_eval(0, 2242, 'If there are a man and a manager then the man is often the manager.', drs([], []), [], '2007-10-26-15-27-38', '130.60.155.231', '').
text_drs_eval(0, 2243, 'For every customer the customer has a card and the customer has a code.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, card, countable, na, eq, 1)-1, predicate(C, have, A, B)-1, object(D, code, countable, na, eq, 1)-1, predicate(E, have, A, D)-1])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [customer]]]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]], ['.']]], '2007-07-22-22-57-55', '130.60.155.177', '').
text_drs_eval(0, 2244, 'What does John not like?', drs([], [question(drs([], [-drs([A, B], [query(A, what)-1/1, predicate(B, like, named('John'), A)-1/5])]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [pname, 'John']], [vp, [aux, not], [vbar, [vcompl, [v, like]]]]], ?], '.']], '2009-05-13-13-58-11', '130.60.155.193', '').
text_drs_eval(0, 2245, 'What John does not like?', drs([], []), [], '2007-08-16-14-57-28', '130.60.155.177', '').
text_drs_eval(0, 2246, 'if there is a declaration whose name is a user and whose password is a string and the string is the password of the user then the user is authenticated.', drs([], [drs([A, B, C, D, E, F, G, H, I], [relation(B, of, A)-1, relation(E, of, A)-1, relation(I, of, C)-1, predicate(D, be, B, C)-1, predicate(G, be, E, F)-1, predicate(H, be, F, I)-1, object(A, declaration, countable, na, eq, 1)-1, object(B, name, countable, na, eq, 1)-1, object(C, user, countable, na, eq, 1)-1, object(E, password, countable, na, eq, 1)-1, object(F, string, countable, na, eq, 1)-1, object(I, password, countable, na, eq, 1)-1])=>drs([J, K], [property(J, authenticated, pos)-1, predicate(K, be, C, J)-1])]), [[cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [declaration]], [rel_cl_coord, [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [name]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [user]]]]]]], [coord, [and]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [password]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [string]]]]]]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [string]]]], [vp, [vbar, [v, [is]], [np, [det, [the]], [nbar, [n, [password]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [user]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [user]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [authenticated]]]]]]]]], '2007-11-05-11-20-29', '130.60.155.231', '').
text_drs_eval(0, 2247, '"', drs([], []), [], '2009-01-05-15-22-47', '130.60.155.206', '').
text_drs_eval(0, 2248, 'If the id of a user is valid then the user is authenticated.', drs([], [drs([A, B, C, D], [property(A, valid, pos)-1, predicate(B, be, C, A)-1, relation(C, of, D)-1, object(D, user, countable, na, eq, 1)-1, object(C, id, countable, na, eq, 1)-1])=>drs([E, F], [property(E, authenticated, pos)-1, predicate(F, be, D, E)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [the]], [nbar, [n, [id]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [user]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [user]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [authenticated]]]]]]]], ['.']]], '2007-08-08-10-20-57', '130.60.155.231', '').
text_drs_eval(0, 2249, 'If a man likes Mary and Mary hates a dog then the man owns a car.', drs([A], [object(A, 'Mary', named, na, eq, 1)-1, drs([B, C, D, E], [object(B, man, countable, na, eq, 1)-1, predicate(C, like, B, A)-1, object(D, dog, countable, na, eq, 1)-1, predicate(E, hate, A, D)-1])=>drs([F, G], [object(F, car, countable, na, eq, 1)-1, predicate(G, own, B, F)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [likes]], [np, [pname, ['Mary']]]]]], [coord, [and]], [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [hates]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-07-28-18-25-36', '130.60.155.177', '').
text_drs_eval(0, 2250, 'There is a customer such that the customer has a card and the customer has a code.', drs([A, B, C, D, E], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, have, A, B)-1, object(D, code, countable, na, eq, 1)-1, predicate(E, have, A, D)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [customer]]]]], [conj, ['{such that}']], [s_coord, [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [card]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]], ['.']]], '2007-07-29-20-21-19', '130.60.155.177', '').
text_drs_eval(0, 2251, 'There is a man who does not provably eat. The man who does not provably eat drinks.', drs([A, B], [predicate(B, drink, A)-2, ~drs([C], [predicate(C, eat, A)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [aux, ['{does not provably}']], [vbar, [v, [eat]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [aux, ['{does not provably}']], [vbar, [v, [eat]]]]]]], [vp, [vbar, [v, [drinks]]]]], ['.']]], '2007-11-12-18-10-03', '130.60.155.177', '').
text_drs_eval(0, 2252, 'A child of who is a patricide whose child is somebody who is not a patricide?', drs([], [question(drs([A, B, C, D, E, F, G], [object(A, child, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, object(C, patricide, countable, na, eq, 1)-1/7, object(D, child, countable, na, eq, 1)-1/9, relation(D, of, C)-1/8, object(E, somebody, countable, na, eq, 1)-1/12, -drs([H, I], [object(H, patricide, countable, na, eq, 1)-1/17, predicate(I, be, E, H)-1/14]), predicate(F, be, D, E)-1/10, predicate(G, be, A, C)-1/5]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, child], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide], [rel_cl, [np, [posspn, whose], [nbar, [n, child]]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, somebody], [rel_cl, [np, [relpn, who]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]]]]]]]]]]]]], ?], '.']], '2009-05-13-13-58-12', '130.60.155.193', '').
text_drs_eval(0, 2253, 'if a valid n:credential has an id type then the n:credential is an id.', drs([], []), [], '2007-08-01-17-47-55', '130.60.155.177', '').
text_drs_eval(0, 2254, 'If a user is authenticated and his subscription covers a resource then the user can download the resource.', drs([], [drs([A, B, C, D, E, F], [object(A, user, countable, na, eq, 1)-1/3, property(B, authenticated, pos)-1/5, predicate(C, be, A, B)-1/4, relation(D, of, A)-1/7, object(D, subscription, countable, na, eq, 1)-1/8, object(E, resource, countable, na, eq, 1)-1/11, predicate(F, cover, D, E)-1/9])=>drs([], [can(drs([G], [predicate(G, download, A, E)-1/16]))])]), [[specification, [cond_s, if, [s_coord, [s, [np, [det, a], [nbar, [n, user]]], [vp, [aux, is], [ap_coord, [ap, [adj, authenticated]]]]], [coord, and], [s, [np, [posspn, his], [nbar, [n, subscription]]], [vp, [vbar, [vcompl, [v, covers], [np, [det, a], [nbar, [n, resource]]]]]]]], then, [s, [np, [det, the], [nbar, [n, user]]], [vp, [aux, can], [vbar, [vcompl, [v, download], [np, [det, the], [nbar, [n, resource]]]]]]]], '.']], '2010-10-27-09-28-25', '89.206.64.27', '').
text_drs_eval(0, 2255, 'If a user is authenticated and pays for a resource then he can download it.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1/3, property(B, authenticated, pos)-1/5, predicate(C, be, A, B)-1/4, object(D, resource, countable, na, eq, 1)-1/10, predicate(E, pay, A)-1/7, modifier_pp(E, for, D)-1/8])=>drs([], [can(drs([F], [predicate(F, download, A, D)-1/14]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, user]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, authenticated]]]], [coord, and], [vp, [vbar, [vbar, [v, pays]], [vmod, [pp, [prep, for], [np, [det, a], [nbar, [n, resource]]]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, can], [vbar, [vcompl, [v, download], [np, [pn, it]]]]]]], '.']], '2010-10-27-09-28-32', '89.206.64.27', '').
text_drs_eval(0, 2256, 'If a user is happy and pays for something then he can wait.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1/3, property(B, happy, pos)-1/5, predicate(C, be, A, B)-1/4, object(D, something, dom, na, na, na)-1/10, predicate(E, pay, A)-1/7, modifier_pp(E, for, D)-1/8])=>drs([], [can(drs([F], [predicate(F, wait, A)-1/14]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, user]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, happy]]]], [coord, and], [vp, [vbar, [vbar, [v, pays]], [vmod, [pp, [prep, for], [np, [pn, something]]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]]], '.']], '2010-10-27-09-28-37', '89.206.64.27', '').
text_drs_eval(0, 2257, 'Every customer has at least 2 cards and their associated codes. If a customer C approaches an automatic teller and she inserts her own card that is valid carefully into a slot and types a correct code of the card then the automatic teller accepts the card and displays "Card accepted" and C is happy. No card that does not have a correct code is accepted. It is false that a customer\'s card is valid, and is expired or is cancelled. If a card is not provably invalid then it is accepted. If a customer owns a card and can prove that it is lost then a bank must replace it.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/2])=>drs([B, C, D, E], [object(B, card, countable, na, geq, 2)-1/7, has_part(E, B)-1/'', predicate(C, have, A, E)-1/3, relation(D, of, B)-1/9, object(D, code, countable, na, geq, 2)-1/11, property(D, associated, pos)-1/10, has_part(E, D)-1/'', object(E, na, countable, na, eq, 2)-1/'']), drs([F, G, H, I, J, K, L, M, N, O], [object(F, customer, countable, na, eq, 1)-2/3, object(G, teller, countable, na, eq, 1)-2/8, property(G, automatic, pos)-2/7, predicate(H, approach, F, G)-2/5, relation(I, of, G)-2/12, object(I, card, countable, na, eq, 1)-2/14, object(J, slot, countable, na, eq, 1)-2/21, property(K, valid, pos)-2/17, predicate(L, be, I, K)-2/16, modifier_pp(L, into, J)-2/19, modifier_adv(L, carefully, pos)-2/18, predicate(M, insert, G, I)-2/11, object(N, code, countable, na, eq, 1)-2/26, property(N, correct, pos)-2/25, relation(N, of, I)-2/27, predicate(O, type, G, N)-2/23])=>drs([P, Q, R, S], [predicate(P, accept, G, I)-2/34, predicate(Q, display, G, string('Card accepted'))-2/38, property(R, happy, pos)-2/43, predicate(S, be, F, R)-2/42]), drs([T], [object(T, card, countable, na, eq, 1)-3/2, -drs([U, V], [object(U, code, countable, na, eq, 1)-3/9, property(U, correct, pos)-3/8, predicate(V, have, T, U)-3/6])])=>drs([], [-drs([W, X], [property(W, accepted, pos)-3/11, predicate(X, be, T, W)-3/10])]), -drs([Y, Z, A1, B1], [object(Y, customer, countable, na, eq, 1)-4/6, relation(Z, of, Y)-4/7, object(Z, card, countable, na, eq, 1)-4/9, property(A1, valid, pos)-4/11, predicate(B1, be, Z, A1)-4/10, drs([C1, D1], [property(C1, expired, pos)-4/15, predicate(D1, be, Z, C1)-4/14])v drs([E1, F1], [property(E1, cancelled, pos)-4/18, predicate(F1, be, Z, E1)-4/17])]), drs([G1], [object(G1, card, countable, na, eq, 1)-5/3, ~drs([H1, I1], [property(H1, invalid, pos)-5/7, predicate(I1, be, G1, H1)-5/4])])=>drs([J1, K1], [property(J1, accepted, pos)-5/11, predicate(K1, be, G1, J1)-5/10]), drs([L1, M1, N1], [object(L1, customer, countable, na, eq, 1)-6/3, object(M1, card, countable, na, eq, 1)-6/6, predicate(N1, own, L1, M1)-6/4, can(drs([O1, P1], [predicate(O1, prove, L1, P1)-6/9, P1:drs([Q1, R1], [property(Q1, lost, pos)-6/13, predicate(R1, be, M1, Q1)-6/12])]))])=>drs([S1], [object(S1, bank, countable, na, eq, 1)-6/16, must(drs([T1], [predicate(T1, replace, S1, M1)-6/18]))])]), [[specification, [s, [np, [det, every], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, has], [np_coord, [np, [nump, [genqu, 'at least'], 2], [nbar, [n, cards]]], [coord, and], [np, [posspn, their], [nbar, [adj, associated], [nbar, [n, codes]]]]]]]]], '.'], [specification, [cond_s, if, [s_coord, [s, [np, [det, a], [nbar, [n, customer], [appos, [var, 'C']]]], [vp, [vbar, [vcompl, [v, approaches], [np, [det, an], [nbar, [adj, automatic], [nbar, [n, teller]]]]]]]], [coord, and], [s, [np, [pn, she]], [vp_coord, [vp, [vbar, [vcompl, [v, inserts], [np, [posspn, 'her own'], [nbar, [n, card], [rel_cl, [comp, that], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]], [vmod, [adv, carefully], [pp, [prep, into], [np, [det, a], [nbar, [n, slot]]]]]]]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, types], [np, [det, a], [nbar, [adj, correct], [nbar, [n, code], [pp, [prep, of], [np, [det, the], [nbar, [n, card]]]]]]]]]]]]], then, [s_coord, [s, [np, [det, the], [nbar, [adj, automatic], [nbar, [n, teller]]]], [vp_coord, [vp, [vbar, [vcompl, [v, accepts], [np, [det, the], [nbar, [n, card]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, displays], [np, [string, '"Card accepted"']]]]]]], [coord, and], [s, [np, [var, 'C']], [vp, [aux, is], [ap_coord, [ap, [adj, happy]]]]]]], '.'], [specification, [s, [np, [det, no], [nbar, [n, card], [rel_cl, [comp, that], [vp, [aux, does, not], [vbar, [vcompl, [v, have], [np, [det, a], [nbar, [adj, correct], [nbar, [n, code]]]]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, accepted]]]]], '.'], [specification, [s, [neg, 'it is false'], [cp, that, [s, [np, [poss_np, [det, a], [nbar, [n, customer]], [gen_marker, '\'s']], [nbar, [n, card]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]], [coord, ', and'], [vp, [aux, is], [ap_coord, [ap, [adj, expired]]]], [coord, or], [vp, [aux, is], [ap_coord, [ap, [adj, cancelled]]]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is, 'not provably'], [ap_coord, [ap, [adj, invalid]]]]], then, [s, [np, [pn, it]], [vp, [aux, is], [ap_coord, [ap, [adj, accepted]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, customer]]], [vp_coord, [vp, [vbar, [vcompl, [v, owns], [np, [det, a], [nbar, [n, card]]]]]], [coord, and], [vp, [aux, can], [vbar, [cp, that, [s, [np, [pn, it]], [vp, [aux, is], [ap_coord, [ap, [adj, lost]]]]]]]]]], then, [s, [np, [det, a], [nbar, [n, bank]]], [vp, [aux, must], [vbar, [vcompl, [v, replace], [np, [pn, it]]]]]]], '.']], '2010-11-12-08-51-26', '89.206.69.32', '').
text_drs_eval(0, 2258, 'John does.', drs([], []), [], '2007-08-16-14-57-57', '130.60.155.177', '').
text_drs_eval(0, 2259, 'If a user is happy and pays for something then he does not wait.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1, property(B, happy, pos)-1, predicate(C, be, A, B)-1, object(D, something, dom, na, na, na)-1, predicate(E, pay, A)-1, modifier_pp(E, for, D)-1])=>drs([], [-drs([F], [predicate(F, wait, A)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [user]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]], [coord, [and]], [vp, [vbar, [vbar, [v, [pays]]], [pp, [prep, [for]], [nbar, [pn, [something]]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [aux, ['{does not}']], [vbar, [v, [wait]]]]]], ['.']]], '2007-08-10-14-24-20', '130.60.155.231', '').
text_drs_eval(0, 2260, 'If a user is happy and pays for something then he sees everything.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1, property(B, happy, pos)-1, predicate(C, be, A, B)-1, object(D, something, dom, na, na, na)-1, predicate(E, pay, A)-1, modifier_pp(E, for, D)-1])=>drs([], [drs([F], [object(F, something, dom, na, na, na)-1])=>drs([G], [predicate(G, see, A, F)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [user]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]], [coord, [and]], [vp, [vbar, [vbar, [v, [pays]]], [pp, [prep, [for]], [nbar, [pn, [something]]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everything]]]]]]], ['.']]], '2007-08-08-10-18-27', '130.60.155.231', '').
text_drs_eval(0, 2261, 'If a user charges the price of a resource then the user pays for the resource.', drs([], [drs([A, B, C, D], [object(A, user, countable, na, eq, 1)-1, predicate(B, charge, A, C)-1, relation(C, of, D)-1, object(D, resource, countable, na, eq, 1)-1, object(C, price, countable, na, eq, 1)-1])=>drs([E], [predicate(E, pay, A)-1, modifier_pp(E, for, D)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [user]]]], [vp, [vbar, [v, [charges]], [np, [det, [the]], [nbar, [n, [price]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [resource]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [user]]]], [vp, [vbar, [vbar, [v, [pays]]], [pp, [prep, [for]], [np, [det, [the]], [nbar, [n, [resource]]]]]]]]], ['.']]], '2007-08-06-11-40-06', '130.60.204.12', '').
text_drs_eval(0, 2262, 'There is a price of a resource. The price of a resource is high. The resource is valid.', drs([A, B, C, D, E, F], [object(A, price, countable, na, eq, 1)-1, object(B, resource, countable, na, eq, 1)-1, relation(A, of, B)-1, property(C, high, pos)-2, predicate(D, be, A, C)-2, property(E, valid, pos)-3, predicate(F, be, B, E)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, price], [pp, [prep, of], [np, [det, a], [nbar, [n, resource]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, price], [pp, [prep, of], [np, [det, a], [nbar, [n, resource]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, high]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, resource]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-08-12-10-31-37', '130.60.206.55', '').
text_drs_eval(0, 2263, 'A user is seen a clerk.', drs([], []), [], '2007-08-06-17-21-06', '130.60.204.12', '').
text_drs_eval(0, 2264, 'If a user is charged the price of a resource then the user pays for the resource.', drs([], []), [], '2007-08-06-17-20-51', '130.60.204.12', '').
text_drs_eval(0, 2265, 'Not for each of some men every dog of him barks.', drs([], [-drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([], [drs([C], [object(C, dog, countable, na, eq, 1)-1, relation(C, of, B)-1])=>drs([D], [predicate(D, bark, C)-1])])])]), [[specification, [neg_s, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [s, [np, [det, [every]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [him]]]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2007-08-08-09-45-32', '130.60.155.231', '').
text_drs_eval(0, 2266, 'Not for each of some men every dog of the man barks.', drs([], [-drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([], [drs([C, D], [object(C, dog, countable, na, eq, 1)-1, relation(C, of, D)-1, object(D, man, countable, na, eq, 1)-1])=>drs([E], [predicate(E, bark, C)-1])])])]), [[specification, [top_s, [topic, [neg, not], [quant, 'for each of'], [np, [det, some], [nbar, [n, men]]]], [s, [np, [det, every], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]], [vp, [vbar, [v, barks]]]]], '.']], '2008-10-22-16-11-43', '130.60.155.177', '').
text_drs_eval(0, 2267, 'not each of 2 girls lifts a table.', drs([], [-drs([A], [object(A, girl, countable, na, eq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, table, countable, na, eq, 1)-1, predicate(D, lift, B, C)-1])])]), [[specification, [neg_s, [pneg, ['{not}']], [s, [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [girls]]]]], [vp, [vbar, [v, [lifts]], [np, [det, [a]], [nbar, [n, [table]]]]]]]], ['.']]], '2007-08-08-09-48-41', '130.60.155.231', '').
text_drs_eval(0, 2268, 'If there is a man then that John waits.', drs([], []), [], '2007-08-13-15-36-40', '130.60.155.177', '').
text_drs_eval(0, 2269, 'if a user is happy and pays for something then he does not wait.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1, property(B, happy, pos)-1, predicate(C, be, A, B)-1, object(D, something, dom, na, na, na)-1, predicate(E, pay, A)-1, modifier_pp(E, for, D)-1])=>drs([], [-drs([F], [predicate(F, wait, A)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [user]]]], [vp_coord, [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]], [coord, [and]], [vp, [vbar, [vbar, [v, [pays]]], [pp, [prep, [for]], [nbar, [pn, [something]]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [aux, ['{does not}']], [vbar, [v, [wait]]]]]], ['.']]], '2007-08-08-10-19-02', '130.60.155.231', '').
text_drs_eval(0, 2270, 'There is a man. He waits. His card is correct.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-2, relation(C, of, A)-3, object(C, card, countable, na, eq, 1)-3, property(D, correct, pos)-3, predicate(E, be, C, D)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]], ['.']]], '2007-11-22-17-46-09', '84.74.90.129', '').
text_drs_eval(0, 2271, 'A man is seen by him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, [is]], [vbar, [v, [seen]], [by, [by]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-18-00-13', '84.74.90.129', '').
text_drs_eval(0, 2272, 'Him sees a man.', drs([A, B, C], [object(A, 'Him', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, A, B)-1]), [[specification, [s, [np, [var, ['Him']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [man]]]]]]], ['.']]], '2007-11-22-18-00-46', '84.74.90.129', '').
text_drs_eval(0, 2273, 'There is a man. John sees him. John checks his card. John sees a card in his hand.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, see, A, B)-2, relation(D, of, B)-3, object(D, card, countable, na, eq, 1)-3, predicate(E, check, A, D)-3, relation(F, of, B)-4, object(F, hand, countable, na, eq, 1)-4, object(G, card, countable, na, eq, 1)-4, predicate(H, see, A, G)-4, modifier_pp(H, in, F)-4]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [checks]], [np, [posspn, [his]], [nbar, [n, [card]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [hand]]]]]]]], ['.']]], '2007-11-22-17-48-06', '84.74.90.129', '').
text_drs_eval(0, 2274, 'A man sees him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-18-01-00', '84.74.90.129', '').
text_drs_eval(0, 2275, 'A woman checks her card.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [checks]], [np, [posspn, [her]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-18-01-41', '84.74.90.129', '').
text_drs_eval(0, 2276, 'A man sees a card in his hand.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [hand]]]]]]]], ['.']]], '2007-11-22-18-01-55', '84.74.90.129', '').
text_drs_eval(0, 2277, 'John has a brother who he likes.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, brother, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, predicate(D, have, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [brother]], [rel_cl, [np, [relpn, [who]]], [np, [pn, [he]]], [vp, [vbar, [v, [likes]], [np, [[]]]]]]]]]]], ['.']]], '2007-11-22-17-51-14', '84.74.90.129', '').
text_drs_eval(0, 2278, 'A man sees a card of him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [pn, [him]]]]]]]]], ['.']]], '2007-11-22-18-02-12', '84.74.90.129', '').
text_drs_eval(0, 2279, 'A man of his group sleeps.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, group, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, sleep, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man], [pp, [prep, of], [np, [posspn, his], [nbar, [n, group]]]]]], [vp, [vbar, [v, sleeps]]]], '.']], '2008-10-23-14-45-24', '130.60.155.177', '').
text_drs_eval(0, 2280, 'A man sees himself. A woman enters her own card. A man is in his own garden.', drs([A, B, C, D, E, F, G, H], [object(A, man, countable, na, eq, 1)-1, predicate(B, see, A, A)-1, object(C, woman, countable, na, eq, 1)-2, relation(D, of, C)-2, object(D, card, countable, na, eq, 1)-2, predicate(E, enter, C, D)-2, object(F, man, countable, na, eq, 1)-3, relation(G, of, F)-3, object(G, garden, countable, na, eq, 1)-3, predicate(H, be, F)-3, modifier_pp(H, in, G)-3]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [enters]], [np, [posspn, ['{her own}']], [nbar, [n, [card]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [posspn, ['{his own}']], [nbar, [n, [garden]]]]]]]], ['.']]], '2007-08-10-19-26-08', '130.60.155.177', '').
text_drs_eval(0, 2281, 'A man is seen by himself.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, [is]], [vbar, [v, [seen]], [by, [by]], [np, [pn, [himself]]]]]], ['.']]], '2007-11-22-17-58-21', '84.74.90.129', '').
text_drs_eval(0, 2282, 'If a man owns a book then he can read it.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/3, object(B, book, countable, na, eq, 1)-1/6, predicate(C, own, A, B)-1/4])=>drs([], [can(drs([D], [predicate(D, read, A, B)-1/10]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, owns], [np, [det, a], [nbar, [n, book]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, can], [vbar, [vcompl, [v, read], [np, [pn, it]]]]]]], '.']], '2010-10-27-09-28-57', '89.206.64.27', '').
text_drs_eval(0, 2283, 'If a man owns a book then he must read it.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/3, object(B, book, countable, na, eq, 1)-1/6, predicate(C, own, A, B)-1/4])=>drs([], [must(drs([D], [predicate(D, read, A, B)-1/10]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, owns], [np, [det, a], [nbar, [n, book]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, must], [vbar, [vcompl, [v, read], [np, [pn, it]]]]]]], '.']], '2010-10-27-09-29-02', '89.206.64.27', '').
text_drs_eval(0, 2284, 'If a man owns a book then he does not read it.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, book, countable, na, eq, 1)-1, predicate(C, own, A, B)-1])=>drs([], [-drs([D], [predicate(D, read, A, B)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [book]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [aux, ['{does not}']], [vbar, [v, [read]], [np, [pn, [it]]]]]]], ['.']]], '2007-08-10-19-27-23', '130.60.155.177', '').
text_drs_eval(0, 2285, 'If a man owns a book then he does not provably read it.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, book, countable, na, eq, 1)-1, predicate(C, own, A, B)-1])=>drs([], [~drs([D], [predicate(D, read, A, B)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [book]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [aux, ['{does not provably}']], [vbar, [v, [read]], [np, [pn, [it]]]]]]], ['.']]], '2007-08-10-19-27-58', '130.60.155.177', '').
text_drs_eval(0, 2286, 'If a user pays for something then he does not wait.', drs([], [drs([A, B, C], [object(A, user, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, pay, A)-1, modifier_pp(C, for, B)-1])=>drs([], [-drs([D], [predicate(D, wait, A)-1])])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [user]]]], [vp, [vbar, [vbar, [v, [pays]]], [pp, [prep, [for]], [nbar, [pn, [something]]]]]]], [then], [s, [np, [pn, [he]]], [vp, [aux, ['{does not}']], [vbar, [v, [wait]]]]]], ['.']]], '2007-08-10-19-29-35', '130.60.155.177', '').
text_drs_eval(0, 2287, 'If a user pays for something then he can wait.', drs([], [drs([A, B, C], [object(A, user, countable, na, eq, 1)-1/3, object(B, something, dom, na, na, na)-1/7, predicate(C, pay, A)-1/4, modifier_pp(C, for, B)-1/5])=>drs([], [can(drs([D], [predicate(D, wait, A)-1/11]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, user]]], [vp, [vbar, [vbar, [v, pays]], [vmod, [pp, [prep, for], [np, [pn, something]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]]], '.']], '2010-10-27-09-29-06', '89.206.64.27', '').
text_drs_eval(0, 2288, 'If a user is authenticated and pays for a resource then a man can download it.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1/3, property(B, authenticated, pos)-1/5, predicate(C, be, A, B)-1/4, object(D, resource, countable, na, eq, 1)-1/10, predicate(E, pay, A)-1/7, modifier_pp(E, for, D)-1/8])=>drs([F], [object(F, man, countable, na, eq, 1)-1/13, can(drs([G], [predicate(G, download, F, D)-1/15]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, user]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, authenticated]]]], [coord, and], [vp, [vbar, [vbar, [v, pays]], [vmod, [pp, [prep, for], [np, [det, a], [nbar, [n, resource]]]]]]]]], then, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, download], [np, [pn, it]]]]]]], '.']], '2010-10-27-09-29-11', '89.206.64.27', '').
text_drs_eval(0, 2289, 'If a user is authenticated and pays for a resource then the man can download it.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1/3, property(B, authenticated, pos)-1/5, predicate(C, be, A, B)-1/4, object(D, resource, countable, na, eq, 1)-1/10, predicate(E, pay, A)-1/7, modifier_pp(E, for, D)-1/8])=>drs([F], [object(F, man, countable, na, eq, 1)-1/13, can(drs([G], [predicate(G, download, F, D)-1/15]))])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, user]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, authenticated]]]], [coord, and], [vp, [vbar, [vbar, [v, pays]], [vmod, [pp, [prep, for], [np, [det, a], [nbar, [n, resource]]]]]]]]], then, [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vcompl, [v, download], [np, [pn, it]]]]]]], '.']], '2010-10-27-09-29-16', '89.206.64.27', '').
text_drs_eval(0, 2290, 'A man who sees a dog and who does not see the dog waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([E], [predicate(E, see, A, B)-1]), predicate(D, wait, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, dog]]]]]], [coord, and], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, see], [np, [det, the], [nbar, [n, dog]]]]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-26-16-45-59', '84.74.167.232', '').
text_drs_eval(1, 2291, 'The man who sees a dog and who does not see the dog waits.', drs([A, B, C, D], [predicate(A, wait, B)-1, -drs([E, F], [predicate(F, see, B, E)-1, object(E, dog, countable, na, eq, 1)-1]), predicate(D, see, B, C)-1, object(C, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, dog]]]]]], [coord, and], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, see], [np, [det, the], [nbar, [n, dog]]]]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-26-22-29-49', '84.74.167.232', 'There should be 1 dog. Reason: The unresolved DRS does not contain an anaphor for the second dog.  Replacing "the man" by "a man" gives the expected result.').
text_drs_eval(0, 2292, 'that John waits.', drs([], []), [], '2007-08-13-15-36-55', '130.60.155.177', '').
text_drs_eval(0, 2293, 'There is [[[[.', drs([], []), [], '2007-09-21-19-45-25', '130.60.155.177', '').
text_drs_eval(0, 2294, 'If a user is authenticated and pays for a resource then he does not believe that he can download it.', drs([], [drs([A, B, C, D, E], [object(A, user, countable, na, eq, 1)-1/3, property(B, authenticated, pos)-1/5, predicate(C, be, A, B)-1/4, object(D, resource, countable, na, eq, 1)-1/10, predicate(E, pay, A)-1/7, modifier_pp(E, for, D)-1/8])=>drs([], [-drs([F, G], [predicate(F, believe, A, G)-1/15, G:drs([], [can(drs([H], [predicate(H, download, A, D)-1/19]))])])])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, user]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, authenticated]]]], [coord, and], [vp, [vbar, [vbar, [v, pays]], [vmod, [pp, [prep, for], [np, [det, a], [nbar, [n, resource]]]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [cp, that, [s, [np, [pn, he]], [vp, [aux, can], [vbar, [vcompl, [v, download], [np, [pn, it]]]]]]]]]]], '.']], '2010-10-27-09-29-22', '89.206.64.27', '').
text_drs_eval(0, 2295, 'If a man waits then his dog barks.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])=>drs([C, D], [relation(C, of, A)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, waits]]]], then, [s, [np, [posspn, his], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]], '.']], '2008-08-19-12-22-18', '130.60.204.40', '').
text_drs_eval(0, 2296, 'If a man waits then his own dog barks.', drs([], []), [], '2008-10-06-14-49-31', '130.60.155.206', '').
text_drs_eval(0, 2297, 'Everybody\'s age is larger than 0.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1])=>drs([C, D], [property(C, large, comp_than, int(0))-1, predicate(D, be, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, ['$body']]], [gen_marker, ['\'s']]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [larger]], [conj, [than]], [np, [int, [0]]]]]]]], ['.']]], '2007-11-20-17-45-38', '130.60.155.231', '').
text_drs_eval(0, 2298, 'If somebody\'s age is 31 then his address is "Poland".', drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, age, countable, na, eq, 1)-1, predicate(C, be, B, int(31))-1])=>drs([D, E], [relation(D, of, A)-1, object(D, address, countable, na, eq, 1)-1, predicate(E, be, D, string('Poland'))-1])]), [[specification, [cond_s, [if], [s, [np, [poss_np, [pn, [somebody]], ['|'], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [int, [31]]]]]], [then], [s, [np, [posspn, [his]], [nbar, [n, [address]]]], [vp, [vbar, [v, [is]], [np, [string, ['Poland']]]]]]], ['.']]], '2007-09-01-17-08-39', '130.60.155.177', '').
text_drs_eval(0, 2299, 'Everybody X\'s dog barks.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, bark, B)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, ['$body']], [appos, [var, ['X']]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-11-20-17-45-46', '130.60.155.231', '').
text_drs_eval(0, 2300, 'Mary smiles. She\'s dog barks.', drs([], []), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [smiles]]]]], ['.']]|A], '2007-08-13-15-05-15', '130.60.155.177', '').
text_drs_eval(0, 2301, 'Not everyone\'s dog barks.', drs([], [-drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, bark, B)-1])])]), [[specification, [s, [np, [poss_np, [det, ['{not every}']], [nbar, [n, ['$one']]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-11-20-17-45-52', '130.60.155.231', '').
text_drs_eval(0, 2302, 'A man which\'s dog barks is happy.', drs([], []), [], '2007-08-13-15-05-03', '130.60.155.177', '').
text_drs_eval(0, 2303, 'John sees himself\'s dog.', drs([], []), [], '2007-08-13-15-04-51', '130.60.155.177', '').
text_drs_eval(0, 2304, 'A man who\'s dog barks is happy.', drs([], []), [], '2007-08-13-15-05-37', '130.60.155.177', '').
text_drs_eval(0, 2305, 'John sees everybody\'s dogs.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [object(B, somebody, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, dog, countable, na, geq, 2)-1])=>drs([D], [predicate(D, see, A, C)-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [poss_np, [det, [every]], [nbar, [n, ['$body']]], [gen_marker, ['\'s']]], [nbar, [n, [dogs]]]]]]], ['.']]], '2007-11-20-17-45-59', '130.60.155.231', '').
text_drs_eval(0, 2306, 'John sees 3 men whose dog barks.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 3)-1, object(C, dog, countable, na, eq, 1)-1, relation(C, of, B)-1, predicate(D, bark, C)-1, predicate(E, see, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]], [rel_cl, [np, [poss_pn_coord, [posspn, [whose]]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]]], ['.']]], '2007-08-15-19-13-45', '130.60.155.177', '').
text_drs_eval(0, 2307, 'John and Mary a dog of who barks wait.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, wait, F)-1, object(D, dog, countable, na, eq, 1)-1, relation(D, of, B)-1, predicate(E, bark, D)-1, has_part(F, A)-1, has_part(F, B)-1, object(F, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-08-13-16-59-40', '130.60.155.177', '').
text_drs_eval(0, 2308, 'There is a man 3 dogs of who bark.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 3)-1, relation(B, of, A)-1, predicate(C, bark, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [bark]]]]]]]]], ['.']]], '2007-11-20-11-29-22', '130.60.155.231', '').
text_drs_eval(0, 2309, 'Which card of a man is valid?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, card, countable, na, eq, 1)-1/2, object(B, man, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, property(C, valid, pos)-1/7, predicate(D, be, A, C)-1/6]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, card], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-13-58-14', '130.60.155.193', '').
text_drs_eval(0, 2310, 'Which card of who is valid?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, card, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, property(C, valid, pos)-1/6, predicate(D, be, A, C)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, card], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-13-58-17', '130.60.155.193', '').
text_drs_eval(0, 2311, 'Which card of who is what?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, card, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, query(C, what)-1/6, predicate(D, be, A, C)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, card], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [np, [qpn, what]]]]]], ?], '.']], '2009-05-13-13-58-22', '130.60.155.193', '').
text_drs_eval(0, 2312, 'Which dog of who likes who?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, dog, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, query(C, who)-1/6, predicate(D, like, A, C)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, dog], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [vbar, [vcompl, [v, likes], [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-58-23', '130.60.155.193', '').
text_drs_eval(0, 2313, 'Not each of 4 men waits.', drs([], [-drs([A], [object(A, man, countable, na, eq, 4)-1, drs([B], [has_part(A, B)-1])=>drs([C], [predicate(C, wait, B)-1])])]), [[specification, [s, [np, [neg, [not]], [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [4]]], [nbar, [n, [men]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-13-17-39-06', '130.60.155.177', '').
text_drs_eval(0, 2314, 'There are 4 men. Not each of them waits.', drs([A], [object(A, man, countable, na, eq, 4)-1, -drs([], [drs([B], [has_part(A, B)-2])=>drs([C], [predicate(C, wait, B)-2])])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [4]]], [nbar, [n, [men]]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [s, [np, [quant, ['{each of}']], [np, [pn, [them]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-08-13-18-10-18', '130.60.155.177', '').
text_drs_eval(0, 2315, 'John likes 3 dogs. Not each of them barks.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, dog, countable, na, eq, 3)-1, predicate(C, like, A, B)-1, -drs([], [drs([D], [has_part(B, D)-2])=>drs([E], [predicate(E, bark, D)-2])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]]]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [s, [np, [quant, ['{each of}']], [np, [pn, [them]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-08-13-18-11-11', '130.60.155.177', '').
text_drs_eval(0, 2316, 'There are 4 men. Not for each of them a dog barks.', drs([A], [object(A, man, countable, na, eq, 4)-1, -drs([], [drs([B], [has_part(A, B)-2])=>drs([C, D], [object(C, dog, countable, na, eq, 1)-2, predicate(D, bark, C)-2])])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [4]]], [nbar, [n, [men]]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for each of}']], [np, [pn, [them]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2007-08-13-18-13-36', '130.60.155.177', '').
text_drs_eval(0, 2317, 'John likes 3 dogs. Not for each of them a cat smiles.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, dog, countable, na, eq, 3)-1, predicate(C, like, A, B)-1, -drs([], [drs([D], [has_part(B, D)-2])=>drs([E, F], [object(E, cat, countable, na, eq, 1)-2, predicate(F, smile, E)-2])])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]]]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for each of}']], [np, [pn, [them]]]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [smiles]]]]]]], ['.']]], '2007-08-13-18-14-10', '130.60.155.177', '').
text_drs_eval(0, 2318, 'There is a dog. Not for each of a customer and a clerk a code is valid.', drs([A], [object(A, dog, countable, na, eq, 1)-1, -drs([B, C, D], [object(B, customer, countable, na, eq, 1)-2, object(C, clerk, countable, na, eq, 1)-2, has_part(D, B)-2, has_part(D, C)-2, object(D, na, countable, na, eq, 2)-2, drs([E], [has_part(D, E)-2])=>drs([F, G, H], [object(F, code, countable, na, eq, 1)-2, property(G, valid, pos)-2, predicate(H, be, F, G)-2])])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [top_s, [topic, [quant, ['{for each of}']], [np_coord, [np, [det, [a]], [nbar, [n, [customer]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [clerk]]]]]], [s, [np, [det, [a]], [nbar, [n, [code]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]], ['.']]], '2007-08-13-18-29-28', '130.60.155.177', '').
text_drs_eval(0, 2319, 'There is a dog. Not each of a customer and a clerk waits.', drs([A], [object(A, dog, countable, na, eq, 1)-1, -drs([B, C, D], [object(B, customer, countable, na, eq, 1)-2, object(C, clerk, countable, na, eq, 1)-2, has_part(D, B)-2, has_part(D, C)-2, object(D, na, countable, na, eq, 2)-2, drs([E], [has_part(D, E)-2])=>drs([F], [predicate(F, wait, E)-2])])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [neg_s, [pneg, ['{not}']], [s, [np, [quant, ['{each of}']], [np_coord, [np, [det, [a]], [nbar, [n, [customer]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [clerk]]]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-08-13-18-30-06', '130.60.155.177', '').
text_drs_eval(0, 2320, 'For each of a customer and a clerk a dog barks.', drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, has_part(C, A)-1, object(B, clerk, countable, na, eq, 1)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, drs([D], [has_part(C, D)-1])=>drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1])]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np_coord, [np, [det, [a]], [nbar, [n, [customer]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [clerk]]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2008-01-04-14-43-47', '130.60.204.113', '').
text_drs_eval(0, 2321, 'There are some men who see a woman a cat of who smiles.', drs([A, B, C, D, E], [object(A, man, countable, na, geq, 2)-1, object(B, woman, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, relation(C, of, B)-1, predicate(D, smile, C)-1, predicate(E, see, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [woman]], [rel_cl, [np, [det, [a]], [nbar, [n, [cat]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [smiles]]]]]]]]]]]]]], ['.']]], '2007-08-13-19-42-41', '130.60.155.177', '').
text_drs_eval(0, 2322, 'There is a man a dog of who barks and eats.', drs([], []), [], '2007-11-06-18-36-50', '130.60.155.177', '').
text_drs_eval(0, 2323, 'SimpleMat goes further and sees some abaci.', drs([A, B, C, D], [object(A, 'SimpleMat', named, na, eq, 1)-1, predicate(B, go, A)-1, modifier_adv(B, far, comp)-1, object(C, abacus, countable, na, geq, 2)-1, predicate(D, see, A, C)-1]), [[specification, [s, [np, [pname, ['SimpleMat']]], [vp_coord, [vp, [vbar, [vbar, [v, [goes]]], [adv, [further]]]], [coord, [and]], [vp, [vbar, [v, [sees]], [np, [det, [some]], [nbar, [n, [abaci]]]]]]]], ['.']]], '2007-08-14-20-35-40', '130.60.155.177', '').
text_drs_eval(0, 2324, 'Everybody X\'s dog likes X.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C], [predicate(C, like, B, A)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, ['$body']], [appos, [var, ['X']]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [likes]], [np, [var, ['X']]]]]], ['.']]], '2007-11-20-17-46-10', '130.60.155.231', '').
text_drs_eval(0, 2325, 'There is somebody X\'s dog. X likes the dog.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pn, [somebody]], ['|', [appos_coord, [appos, [var, ['X']]]]], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [np, [var, ['X']]]], [vp, [vbar, [v, [likes]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-08-14-22-01-37', '130.60.155.177', '').
text_drs_eval(0, 2326, 'Everybody X\'s friend likes everybody that likes X.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, friend, countable, na, eq, 1)-1])=>drs([], [drs([C, D], [object(C, somebody, countable, na, eq, 1)-1, predicate(D, like, C, A)-1])=>drs([E], [predicate(E, like, B, C)-1])])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, ['$body']], [appos, [var, ['X']]]], [gen_marker, ['\'s']]], [nbar, [n, [friend]]]], [vp, [vbar, [v, [likes]], [np, [det, [every]], [nbar, [n, ['$body']], [rel_cl, [comp, [that]], [vp, [vbar, [v, [likes]], [np, [var, ['X']]]]]]]]]]], ['.']]], '2007-11-20-17-47-00', '130.60.155.231', '').
text_drs_eval(0, 2327, '2 men X and Y wait. X sleeps. Y drinks.', drs([], []), [[specification, [s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['X']]]]], [coord, [and]], [np, [var, ['Y']]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [var, ['X']]], [vp, [vbar, [v, [sleeps]]]]], ['.']], [specification, [s, [np, [var, ['Y']]], [vp, [vbar, [v, [drinks]]]]], ['.']]], '2007-12-29-18-04-56', '130.60.204.10', '').
text_drs_eval(0, 2328, '2 men X and Y\'s dog waits. X sleeps. Y drinks.', drs([], []), [[s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['X']]]]], [coord, [and]], [np, [poss_np, [var, ['Y']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [waits]]]]], [s, [np, [var, ['X']]], [vp, [vbar, [v, [sleeps]]]]], [s, [np, [var, ['Y']]], [vp, [vbar, [v, [drinks]]]]]], '2007-10-17-16-49-13', '130.60.155.177', '').
text_drs_eval(0, 2329, 'Somebody X and Y\'s dog waits.', drs([], []), [], '2007-08-15-12-37-08', '130.60.155.177', '').
text_drs_eval(0, 2330, 'A man X and Y\'s dog waits.', drs([A, B, C, D, E, F], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, predicate(C, man, A, B)-1, object(D, something, dom, na, na, na)-1, relation(E, of, D)-1, object(E, dog, countable, na, eq, 1)-1, predicate(F, wait, E)-1]), [[specification, [s_coord, [s, [np, [var, 'A']], [vp, [vbar, [v, man], [np, [var, 'X']]]]], [coord, and], [s, [np, [poss_np, [var, 'Y'], [gen_marker, '\'s']], [nbar, [n, dog]]], [vp, [vbar, [v, waits]]]]], '.']], '2008-07-30-18-23-05', '130.60.155.177', '').
text_drs_eval(0, 2331, 'For every man it is false that a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [man]]]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]], ['.']]], '2007-08-15-16-01-11', '130.60.155.177', '').
text_drs_eval(0, 2332, 'For no man it is false that a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])])]), [[specification, [top_s, [topic, [quant, ['{for no}']], [nbar, [n, [man]]]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]], ['.']]], '2007-08-15-16-01-20', '130.60.155.177', '').
text_drs_eval(0, 2333, 'For no men a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])])]), [[specification, [top_s, [topic, [quant, ['{for no}']], [nbar, [n, [men]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-08-15-16-02-36', '130.60.155.177', '').
text_drs_eval(0, 2334, 'For no man a dog sees the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])])]), [[specification, [top_s, [topic, [quant, ['{for no}']], [nbar, [n, [man]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]]]]]]]], ['.']]], '2007-08-15-16-02-51', '130.60.155.177', '').
text_drs_eval(0, 2335, 'A man who a woman is seen by waits.', drs([A, B, C, D], [predicate(D, wait, A)-1, predicate(C, see, A, B)-1, object(B, woman, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [aux, [is]], [vbar, [v, [seen]], [by, [by]], [np, [[]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-06-18-38-58', '130.60.155.177', '').
text_drs_eval(0, 2336, 'There is somebody. There is something. He waits.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-2, predicate(C, wait, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [something]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-15-16-14-21', '130.60.155.177', '').
text_drs_eval(0, 2337, 'There is somebody. There is something X. He waits.', drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-2, predicate(C, wait, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [somebody]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['X']]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-15-16-34-23', '130.60.155.177', '').
text_drs_eval(0, 2338, 'There is something X. He waits.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['X']]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-08-15-16-34-32', '130.60.155.177', '').
text_drs_eval(0, 2339, 'A man sees everything X of Mary that eats.', drs([A, B], [object(A, 'Mary', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, drs([C, D], [relation(D, of, A)-1, predicate(C, eat, A)-1, object(D, something, dom, na, na, na)-1])=>drs([E], [predicate(E, see, B, D)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everything]], [appos_coord, [appos, [var, ['X']]]], [pp, [prep, [of]], [np, [pname, ['Mary']], [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]]]]]]]], ['.']]], '2007-08-15-17-16-44', '130.60.155.177', '').
text_drs_eval(0, 2340, 'A man sees everything X that eats.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C], [predicate(B, eat, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D], [predicate(D, see, A, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everything]], [appos_coord, [appos, [var, ['X']]]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]]]]]]]]], ['.']]], '2007-08-15-17-17-14', '130.60.155.177', '').
text_drs_eval(0, 2341, 'A man sees everything X that eats X.', drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B, C], [predicate(B, eat, C, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D], [predicate(D, see, A, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everything]], [appos_coord, [appos, [var, ['X']]]], [rel_cl, [comp, [that]], [vp, [vbar, [v, [eats]], [np, [np, [var, ['X']]]]]]]]]]], ['.']]], '2007-08-15-17-17-26', '130.60.155.177', '').
text_drs_eval(0, 2342, 'A man sees everything X of Mary.', drs([A, B], [object(A, 'Mary', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, drs([C], [relation(C, of, A)-1, object(C, something, dom, na, na, na)-1])=>drs([D], [predicate(D, see, B, C)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [nbar, [pn, [everything]], [appos_coord, [appos, [var, ['X']]]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]]], ['.']]], '2007-08-15-17-18-24', '130.60.155.177', '').
text_drs_eval(0, 2343, 'Each of 2 cards are green.', drs([], []), [], '2007-08-15-18-25-37', '130.60.155.177', '').
text_drs_eval(0, 2344, 'Each of every man waits.', drs([], []), [], '2007-08-15-18-27-44', '130.60.155.177', '').
text_drs_eval(0, 2345, 'There are 3 men 3 cards of who are valid.', drs([A, B, C, D], [object(A, man, countable, na, eq, 3)-1, object(B, card, countable, na, eq, 3)-1, relation(B, of, A)-1, property(C, valid, pos)-1, predicate(D, be, B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]], [rel_cl, [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [cards]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [are]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]], ['.']]], '2007-08-15-18-56-21', '130.60.155.177', '').
text_drs_eval(0, 2346, 'There is a man 3 dogs of which bark.', drs([], []), [], '2007-11-20-11-29-17', '130.60.155.231', '').
text_drs_eval(0, 2347, 'John sees 3 men whose dogs bark.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 3)-1, object(C, dog, countable, na, geq, 2)-1, relation(C, of, B)-1, predicate(D, bark, C)-1, predicate(E, see, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]], [rel_cl, [np, [posspn, [whose]], [nbar, [n, [dogs]]]], [vp, [vbar, [v, [bark]]]]]]]]]], ['.']]], '2007-12-17-16-59-28', '130.60.155.231', '').
text_drs_eval(0, 2348, 'John sees a man whose dogs bark.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, geq, 2)-1, relation(C, of, B)-1, predicate(D, bark, C)-1, predicate(E, see, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [posspn, [whose]], [nbar, [n, [dogs]]]], [vp, [vbar, [v, [bark]]]]]]]]]], ['.']]], '2007-12-17-16-59-37', '130.60.155.231', '').
text_drs_eval(0, 2349, 'There is a man a dog of whose cat sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, relation(C, of, A)-1, relation(B, of, C)-1, predicate(D, sleep, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [posspn, [whose]], [nbar, [n, [cat]]]]]]], [vp, [vbar, [v, [sleeps]]]]]]]]], ['.']]], '2007-12-11-11-49-40', '130.60.155.231', '').
text_drs_eval(0, 2350, 'There is a man a cat\'s mouse of who sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, object(B, cat, countable, na, eq, 1)-1/6, relation(C, of, B)-1/7, object(C, mouse, countable, na, eq, 1)-1/9, relation(C, of, A)-1/10, predicate(D, sleep, C)-1/12]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [poss_np, [det, a], [nbar, [n, cat]], [gen_marker, '\'s']], [nbar, [n, mouse], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2009-11-18-08-40-27', '130.60.155.164', '').
text_drs_eval(0, 2351, 'There is at least 1 man. The man is happy.', drs([A, B, C], [object(A, man, countable, na, geq, 1)-1, property(B, happy, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [nump, [genqu, 'at least'], [num, 1]], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-08-12-16-57-08', '130.60.155.208', '').
text_drs_eval(0, 2352, 'There is at least 1 man. The men are happy.', drs([A, B, C, D], [object(A, man, countable, na, geq, 1)-1, property(B, happy, pos)-2, predicate(C, be, D, B)-2, object(D, man, countable, na, geq, 2)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [nump, [genqu, 'at least'], [num, 1]], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, men]]], [vp, [aux, are], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-08-12-17-03-07', '130.60.155.208', '').
text_drs_eval(0, 2353, 'A cat is not hated by John.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, -drs([C], [predicate(C, hate, A, B)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [aux, ['{is not}']], [vbar, [v, [hated]], [by, [by]], [np, [pname, ['John']]]]]], ['.']]], '2007-08-17-21-37-05', '130.60.155.177', '').
text_drs_eval(0, 2354, 'There is a man. The red man sleeps.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, sleep, C)-2, property(C, red, pos)-2, object(C, man, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [red]], [nbar, [n, [man]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-08-19-16-56-41', '130.60.155.177', '').
text_drs_eval(0, 2355, 'There is a red man. The man sleeps.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, property(A, red, pos)-1, predicate(B, sleep, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [red]], [nbar, [n, [man]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-08-19-16-57-13', '130.60.155.177', '').
text_drs_eval(0, 2356, 'There is a man. The man the card of who is valid sleeps.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, predicate(B, sleep, C)-2, predicate(E, be, F, D)-2, property(D, valid, pos)-2, object(C, man, countable, na, eq, 1)-2, relation(F, of, C)-2, object(F, card, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-08-19-16-57-46', '130.60.155.177', '').
text_drs_eval(0, 2357, 'There is a man the card of who is valid. The man sleeps.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, property(B, valid, pos)-1, predicate(C, be, D, B)-1, relation(D, of, A)-1, object(D, card, countable, na, eq, 1)-1, predicate(E, sleep, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-08-19-16-58-03', '130.60.155.177', '').
text_drs_eval(0, 2358, 'If there are a number X and a number Y, and X>Y or X<Y then it is false that X=Y.', drs([], [drs([A, B, C], [object(A, number, countable, na, eq, 1)-1, object(B, number, countable, na, eq, 1)-1, has_part(C, A)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, drs([], [formula(A, >, B)-1])v drs([], [formula(A, <, B)-1])])=>drs([], [-drs([], [formula(A, =, B)-1])])]), [[specification, [cond_s, [if], [s_coord, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['X']]]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['Y']]]]]]]]], [coord, ['{, and}']], [s_coord, [formula, [np, [var, ['X']]], [>], [np, [var, ['Y']]]], [coord, [or]], [formula, [np, [var, ['X']]], [<], [np, [var, ['Y']]]]]], [then], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [formula, [np, [var, ['X']]], [=], [np, [var, ['Y']]]]]]], ['.']]], '2007-08-21-17-23-06', '130.60.155.231', '').
text_drs_eval(0, 2359, 'Bill\'s age is a number X. John believes that X<40. Mary knows that X=45.', drs([A, B, C, D, E, F, G, H, I, J], [object(A, 'Bill', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-2, object(C, 'Mary', named, na, eq, 1)-3, relation(D, of, A)-1, object(D, age, countable, na, eq, 1)-1, object(E, number, countable, na, eq, 1)-1, predicate(F, be, D, E)-1, predicate(G, believe, B, H)-2, H:drs([], [formula(E, <, int(40))-2]), predicate(I, know, C, J)-3, J:drs([], [formula(E, =, int(45))-3])]), [[specification, [s, [np, [poss_np, [pname, ['Bill']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [age]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['X']]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [believes]], [cp, ['_that_'], [formula, [var, ['X']], [<], [int, [40]]]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [formula, [var, ['X']], [=], [int, [45]]]]]]], ['.']]], '2007-09-01-17-09-24', '130.60.155.177', '').
text_drs_eval(0, 2360, 'If something X is greater than something Y then X>Y.', drs([], [drs([A, B, C, D], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, property(C, great, comp_than, B)-1, predicate(D, be, A, C)-1])=>drs([], [formula(A, >, B)-1])]), [[specification, [cond_s, [if], [s, [nbar, [pn, [something]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [greater]], [conj, [than]], [nbar, [pn, [something]], [appos_coord, [appos, [var, ['Y']]]]]]|E]]]], [then], [formula, [np, [var, ['X']]], [>], [np, [var, ['Y']]]]], ['.']]], '2007-08-21-17-23-44', '130.60.155.231', '').
text_drs_eval(0, 2361, '{1,"a",[3,4],John} is a set.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, set, countable, na, eq, 1)-1, predicate(C, be, set([int(1), string(a), list([int(3), int(4)]), A]), B)-1]), [[specification, [s, [np, [set, ['{'], [int, [1]], [','], [string, [a]], [','], [list, ['['], [int, [3]], [','], [int, [4]], [']']], [','], [pname, ['John']], ['}']]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [set]]]]]]], ['.']]], '2007-09-01-17-09-55', '130.60.155.177', '').
text_drs_eval(0, 2362, 'It is not possible that there is a number X and that X=X+1.', drs([], [-drs([], [can(drs([A], [object(A, number, countable, na, eq, 1)-1/9, formula(A, =, expr(+, A, int(1)))-1/14]))])]), [[specification, [s, [impossibility, 'it is not possible'], [cp, that, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, number], [appos, [var, 'X']]]]]], [coord, and], [cp, that, [formula, [var, 'X'], =, [expr, [var, 'X'], [int, 1]]]]]]], '.']], '2010-10-27-09-29-27', '89.206.64.27', '').
text_drs_eval(0, 2363, 'If there are a number X and a number Y then the average of them is (X+Y)/2.', drs([], [drs([A, B, C], [object(A, number, countable, na, eq, 1)-1, object(B, number, countable, na, eq, 1)-1, has_part(C, A)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1])=>drs([D, E], [predicate(D, be, E, expr(/, expr(+, A, B), int(2)))-1, relation(E, of, C)-1, object(E, average, countable, na, eq, 1)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['X']]]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['Y']]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [average]], [pp, [prep, [of]], [np, [pn, [them]]]]]], [vp, [vbar, [v, [is]], [np, [exp, [brackets, ['('], [exp, [var, ['X']], [+], [var, ['Y']]], [')']], [/], [int, [2]]]]]]]], ['.']]], '2007-09-01-17-11-13', '130.60.155.177', '').
text_drs_eval(0, 2364, '[3.141, {1, 2, 3}, 4 + X, Y * (Z - 2), "ace"] is a list.', drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, object(C, something, dom, na, na, na)-1, object(D, list, countable, na, eq, 1)-1, predicate(E, be, list([real(3.141), set([int(1), int(2), int(3)]), expr(+, int(4), A), expr(*, B, expr(-, C, int(2))), string(ace)]), D)-1]), [[specification, [s, [np, [list, [real, 3.141], ',', [set, [int, 1], ',', [int, 2], ',', [int, 3]], ',', [expr, [int, 4], [var, 'X']], ',', [expr, [var, 'Y'], [brackets, '(', [expr, [var, 'Z'], [int, 2]], ')']], ',', [string, '"', ace, '"']]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, list]]]]]], '.']], '2008-07-10-10-46-45', '130.60.155.206', '').
text_drs_eval(0, 2365, 'person:Peeter owns a car. He drives.', drs([], []), [], '2008-06-26-17-42-56', '130.60.155.206', '').
text_drs_eval(0, 2366, 'p:Peeter owns a car. He drives.', drs([], []), [[specification, [s, [np, [pname, ['Peeter']]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [car]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [drives]]]]], ['.']]], '2007-08-20-22-02-08', '130.60.155.177', '').
text_drs_eval(0, 2367, 'If there is a n:knot-value X of a gale then X > 28 and X < 55.', drs([], [drs([A, B], [object(A, 'knot-value', countable, na, eq, 1)-1, object(B, gale, countable, na, eq, 1)-1, relation(A, of, B)-1])=>drs([], [formula(A, >, int(28))-1, formula(A, <, int(55))-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, ['knot-value']], [appos_coord, [appos, [var, ['X']]]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [gale]]]]]]]]], [then], [s_coord, [formula, [var, ['X']], [>], [int, [28]]], [coord, [and]], [formula, [var, ['X']], [<], [int, [55]]]]], ['.']]], '2007-09-01-16-55-48', '130.60.155.177', '').
text_drs_eval(0, 2368, 'There is a man at least 3 cars of who are liked by Mary.', drs([A, B, C, D], [object(A, 'Mary', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, car, countable, na, geq, 3)-1, relation(C, of, B)-1, predicate(D, like, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [nbar, [n, [cars]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [aux, [are]], [vbar, [v, [liked]], [by, [by]], [np, [pname, ['Mary']]]]]]]]]], ['.']]], '2007-08-21-21-57-48', '130.60.155.177', '').
text_drs_eval(0, 2369, 'For all integers X there is exactly one integer Y such that X + Y = 0.', drs([], [drs([A], [object(A, integer, countable, na, eq, 1)-1])=>drs([B], [[object(B, integer, countable, na, exactly, 1)-1], formula(expr(+, A, B), =, int(0))-1])]), [[specification, [top_s, [topic, [quant, for], [np, [det, all], [nbar, [n, integers], [appos, [var, 'X']]]]], [top_s, [topic, [quant, 'there is'], [np, [nump, [genqu, exactly], one], [nbar, [n, integer], [appos, [var, 'Y']]]]], [conj, '{such that}'], [formula, [expr, [var, 'X'], [var, 'Y']], =, [int, 0]]]], '.']], '2009-03-02-11-31-05', '130.60.155.206', '').
text_drs_eval(0, 2370, '2*(3-5/17) >= 1/2.', drs([], [formula(expr(*, int(2), expr(-, int(3), expr(/, int(5), int(17)))), >=, expr(/, int(1), int(2)))-1]), [[formula, [expr, [int, [2]], [*], [brackets, ['('], [expr, [int, [3]], [-], [expr, [int, [5]], [/], [int, [17]]]], [')']]], [>=], [expr, [int, [1]], [/], [int, [2]]]]], '2007-10-16-17-35-53', '130.60.155.177', '').
text_drs_eval(0, 2371, 'Is S contained by R1?', drs([], [question(drs([A, B, C], [object(A, something, dom, na, na, na)-1/2, object(B, something, dom, na, na, na)-1/5, predicate(C, contain, B, A)-1/3]))]), [[query, [question, is, [np, [var, 'S']], [vp, [vbar, [vcompl, [v, contained], by, [np, [var, 'R1']]]]]], ?]], '2009-05-26-07-57-21', '130.60.155.193', '').
text_drs_eval(0, 2372, 'A number is 2*[1,2].', drs([], []), [], '2007-09-04-12-16-53', '130.60.155.177', '').
text_drs_eval(0, 2373, 'A number is 2*{1,2}.', drs([], []), [], '2007-09-04-12-17-09', '130.60.155.177', '').
text_drs_eval(0, 2374, 'A string A is "abc" & [1,2].', drs([], []), [], '2007-09-04-12-17-21', '130.60.155.177', '').
text_drs_eval(0, 2375, '1 gives 2 3.', drs([A], [predicate(A, give, int(1), int(3), int(2))-1]), [[s, [np, [int, [1]]], [vp, [vbar, [v, [gives]], [np, [int, [2]]], [np, [int, [3]]]]]]], '2007-09-26-16-14-04', '130.60.155.177', '').
text_drs_eval(0, 2376, 'a man gives 2 3.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, give, A, int(3), int(2))-1]), [[s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [int, [2]]], [np, [int, [3]]]]]]], '2007-09-26-16-14-26', '130.60.155.177', '').
text_drs_eval(0, 2377, '1 gives a man 3.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, give, int(1), int(3), A)-1]), [[s, [np, [int, [1]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [man]]]], [np, [int, [3]]]]]]], '2007-09-26-16-14-39', '130.60.155.177', '').
text_drs_eval(0, 2378, '1 gives 2 a man.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, give, int(1), A, int(2))-1]), [[s, [np, [int, [1]]], [vp, [vbar, [v, [gives]], [np, [int, [2]]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], '2007-09-26-16-14-48', '130.60.155.177', '').
text_drs_eval(0, 2379, 'a man gives John 3.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, give, B, int(3), A)-1]), [[s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [pname, ['John']]], [np, [int, [3]]]]]]], '2007-09-26-16-15-07', '130.60.155.177', '').
text_drs_eval(0, 2380, 'a man gives 2 John.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, give, B, A, int(2))-1]), [[s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [int, [2]]], [np, [pname, ['John']]]]]]], '2007-09-26-16-15-35', '130.60.155.177', '').
text_drs_eval(0, 2381, '1 gives John a man.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, give, int(1), B, A)-1]), [[s, [np, [int, [1]]], [vp, [vbar, [v, [gives]], [np, [pname, ['John']]], [np, [det, [a]], [nbar, [n, [man]]]]]]]], '2007-09-26-16-16-24', '130.60.155.177', '').
text_drs_eval(0, 2382, 'There are a man X and the man X.', drs([], []), [[top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X']]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [man]], [appos, [var, ['X']]]]]]]]], '2007-11-02-19-33-37', '130.60.155.177', '').
text_drs_eval(0, 2383, 'There is a man. John sees Mary and a dog and the man. The man waits.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-2, object(B, 'Mary', named, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, predicate(D, see, A, F)-2, object(E, dog, countable, na, eq, 1)-2, has_part(F, B)-2, has_part(F, E)-2, has_part(F, C)-2, object(F, na, countable, na, eq, 3)-2, predicate(G, wait, C)-3]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np_coord, [np, [pname, ['Mary']]], [coord, [and]], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [the]], [nbar, [n, [man]]]]]]]]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], '2007-09-26-17-09-09', '130.60.155.177', '').
text_drs_eval(0, 2384, '1 < 2.', drs([], [formula(int(1), <, int(2))-1]), [[formula, [int, [1]], [<], [int, [2]]]], '2007-09-26-20-43-29', '130.60.155.177', '').
text_drs_eval(0, 2385, '1 + 2 = 3.', drs([], [formula(expr(+, int(1), int(2)), =, int(3))-1]), [[formula, [exp, [int, [1]], [+], [int, [2]]], [=], [int, [3]]]], '2007-09-26-20-43-43', '130.60.155.177', '').
text_drs_eval(0, 2386, 'It is false that 1 = 2 - 3.', drs([], [-drs([], [formula(int(1), =, expr(-, int(2), int(3)))-1])]), [[neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [formula, [int, [1]], [=], [exp, [int, [2]], [-], [int, [3]]]]]]], '2007-09-26-20-44-12', '130.60.155.177', '').
text_drs_eval(0, 2387, '1 < 2 and 2 < 3.', drs([], [formula(int(1), <, int(2))-1, formula(int(2), <, int(3))-1]), [[s_coord, [formula, [int, [1]], [<], [int, [2]]], [coord, [and]], [formula, [int, [2]], [<], [int, [3]]]]], '2007-09-26-20-47-25', '130.60.155.177', '').
text_drs_eval(0, 2388, '1 < 2 or 2 > 3.', drs([], [drs([], [formula(int(1), <, int(2))-1])v drs([], [formula(int(2), >, int(3))-1])]), [[s_coord, [formula, [int, [1]], [<], [int, [2]]], [coord, [or]], [formula, [int, [2]], [>], [int, [3]]]]], '2007-09-26-20-47-37', '130.60.155.177', '').
text_drs_eval(0, 2389, '{1} is contained by {2, 3}.', drs([A], [predicate(A, contain, set([int(2), int(3)]), set([int(1)]))-1]), [[s, [np, [set, ['{'], [int, [1]], ['}']]], [vp, [aux, [is]], [vbar, [v, [contained]], [by, [by]], [np, [set, ['{'], [int, [2]], [','], [int, [3]], ['}']]]]]]], '2007-09-27-13-00-08', '130.60.155.177', '').
text_drs_eval(0, 2390, '[1] is contained by [2, 3].', drs([A], [predicate(A, contain, list([int(2), int(3)]), list([int(1)]))-1]), [[s, [np, [list, ['['], [int, [1]], [']']]], [vp, [aux, [is]], [vbar, [v, [contained]], [by, [by]], [np, [list, ['['], [int, [2]], [','], [int, [3]], [']']]]]]]], '2007-09-27-13-00-25', '130.60.155.177', '').
text_drs_eval(0, 2391, 'There is each of 3 men.', drs([], []), [], '2007-12-04-14-36-45', '130.60.155.177', '').
text_drs_eval(0, 2392, 'There is a group of each of 3 men.', drs([A, B], [object(A, group, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 3)-1, drs([C], [has_part(B, C)-1])=>drs([], [relation(A, of, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [group]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]]]]]]]]]], ['.']]], '2007-12-20-13-41-31', '130.60.155.231', '').
text_drs_eval(0, 2393, 'For every integer X there are more than 2 integers Y such that X + Y > X.', drs([], [drs([A], [object(A, integer, countable, na, eq, 1)-1])=>drs([B], [object(B, integer, countable, na, greater, 2)-1, formula(expr(+, A, B), >, A)-1])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, [integer]], [appos_coord, [appos, [var, ['X']]]]]], [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, ['{more than}']], [number, [2]]], [nbar, [n, [integers]], [appos_coord, [appos, [var, ['Y']]]]]]], [conj, ['{such that}']], [formula, [exp, [var, ['X']], [+], [var, ['Y']]], [>], [var, ['X']]]]]], '2007-09-27-22-29-22', '130.60.155.177', '').
text_drs_eval(0, 2394, 'There is a number X. X = X.', drs([A], [object(A, number, countable, na, eq, 1)-1, formula(A, =, A)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['X']]]]]]]], [formula, [var, ['X']], [=], [var, ['X']]]], '2007-09-28-16-49-08', '130.60.155.177', '').
text_drs_eval(0, 2395, '{ John } waits.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, set([A]))-1]), [[s, [np, [set, ['{'], [pname, ['John']], ['}']]], [vp, [vbar, [v, [waits]]]]]], '2007-09-28-18-41-07', '130.60.155.177', '').
text_drs_eval(0, 2396, 'There is a natural number X. -1 < X.', drs([A], [object(A, number, countable, na, eq, 1)-1, property(A, natural, pos)-1, formula(int(-1), <, A)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [natural]], [nbar, [n, [number]], [appos_coord, [appos, [var, ['X']]]]]]]]], [formula, [int, [-1]], [<], [var, ['X']]]], '2007-09-28-20-53-48', '130.60.155.177', '').
text_drs_eval(0, 2397, 'It is false that John sleeps and that John does not sleep.', drs([A], [-drs([B], [-drs([C], [predicate(C, sleep, A)-1]), predicate(B, sleep, A)-1]), object(A, 'John', named, na, eq, 1)-1]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sleeps]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [aux, ['{does not}']], [vbar, [v, [sleep]]]]]]]]], ['.']]], '2007-11-05-15-45-51', '130.60.155.177', '').
text_drs_eval(0, 2398, 'If John and Mary wait then there is a dog and they sleep.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, wait, D)-1, has_part(D, A)-1, has_part(D, B)-1, object(D, na, countable, na, eq, 2)-1])=>drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, sleep, D)-1])]), [[cond_s, [if], [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]], [vp, [vbar, [v, [wait]]]]], [then], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [and]], [s, [np, [pn, [they]]], [vp, [vbar, [v, [sleep]]]]]]]], '2007-10-01-17-54-22', '130.60.155.177', '').
text_drs_eval(0, 2399, 'If John and Mary wait then a dog barks and they sleep.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, wait, D)-1, has_part(D, A)-1, has_part(D, B)-1, object(D, na, countable, na, eq, 2)-1])=>drs([E, F, G], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1, predicate(G, sleep, D)-1])]), [[cond_s, [if], [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]], [vp, [vbar, [v, [wait]]]]], [then], [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [s, [np, [pn, [they]]], [vp, [vbar, [v, [sleep]]]]]]]], '2007-10-01-17-54-52', '130.60.155.177', '').
text_drs_eval(0, 2400, 'If John and Mary wait then a dog barks or they sleep.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, wait, D)-1, has_part(D, A)-1, has_part(D, B)-1, object(D, na, countable, na, eq, 2)-1])=>drs([], [drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1])v drs([G], [predicate(G, sleep, D)-1])])]), [[cond_s, [if], [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]], [vp, [vbar, [v, [wait]]]]], [then], [s_coord, [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], [coord, [or]], [s, [np, [pn, [they]]], [vp, [vbar, [v, [sleep]]]]]]]], '2007-10-01-17-55-05', '130.60.155.177', '').
text_drs_eval(0, 2401, 'If John and Mary wait then they sleep.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, wait, D)-1, has_part(D, A)-1, has_part(D, B)-1, object(D, na, countable, na, eq, 2)-1])=>drs([E], [predicate(E, sleep, D)-1])]), [[cond_s, [if], [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]], [vp, [vbar, [v, [wait]]]]], [then], [s, [np, [pn, [they]]], [vp, [vbar, [v, [sleep]]]]]]], '2007-10-01-17-55-27', '130.60.155.177', '').
text_drs_eval(0, 2402, 'There are a dog and a cat. They sleep. John sees them. John likes them.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-3, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, has_part(D, B)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, sleep, D)-2, predicate(F, see, A, D)-3, predicate(G, like, A, D)-4]), [[top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [dog]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [cat]]]]]]], [s, [np, [pn, [they]]], [vp, [vbar, [v, [sleep]]]]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [pn, [them]]]]]], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [pn, [them]]]]]]], '2007-10-01-18-03-17', '130.60.155.177', '').
text_drs_eval(0, 2403, 'Every man knows that every man waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, know, A, C)-1, C:drs([], [drs([D], [object(D, man, countable, na, eq, 1)-1])=>drs([E], [predicate(E, wait, D)-1])])])]), [[s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]]]]], '2007-10-02-12-53-55', '130.60.155.177', '').
text_drs_eval(0, 2404, 'Every man knows that every man knows a man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, know, A, C)-1, C:drs([], [drs([D], [object(D, man, countable, na, eq, 1)-1])=>drs([E, F], [object(E, man, countable, na, eq, 1)-1, predicate(F, know, D, E)-1])])])]), [[s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [np, [det, [a]], [nbar, [n, [man]]]]]]]]]]]], '2007-10-02-12-54-32', '130.60.155.177', '').
text_drs_eval(0, 2405, 'Every man knows that every man drinks and that every woman eats.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, know, A, C)-1, C:drs([], [drs([D], [object(D, man, countable, na, eq, 1)-1])=>drs([E], [predicate(E, drink, D)-1]), drs([F], [object(F, woman, countable, na, eq, 1)-1])=>drs([G], [predicate(G, eat, F)-1])])])]), [[s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [s_coord, [s, [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [drinks]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [eats]]]]]]]]]]]], '2007-10-02-12-55-40', '130.60.155.177', '').
text_drs_eval(0, 2406, 'A number is 3 + 5 - 4 + 9.', drs([A, B], [object(A, number, countable, na, eq, 1)-1, predicate(B, be, A, expr(+, expr(-, expr(+, int(3), int(5)), int(4)), int(9)))-1]), [[s, [np, [det, [a]], [nbar, [n, [number]]]], [vp, [vbar, [v, [is]], [np, [expr, [expr, [expr, [int, [3]], [+], [int, [5]]], [-], [int, [4]]], [+], [int, [9]]]]]]]], '2007-10-16-12-02-32', '130.60.155.231', '').
text_drs_eval(0, 2407, 'Every man\'s dog chases a car.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [object(C, car, countable, na, eq, 1)-1, predicate(D, chase, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [chases]], [np, [det, [a]], [nbar, [n, [car]]]]]]], ['.']]], '2007-11-20-17-48-50', '130.60.155.231', '').
text_drs_eval(0, 2408, 'John sees not exactly 2 men.', drs([], []), [], '2008-08-19-19-57-58', '130.60.155.177', '').
text_drs_eval(0, 2409, 'Not exactly 2 men wait.', drs([], []), [], '2008-08-19-19-58-08', '130.60.155.177', '').
text_drs_eval(0, 2410, 'John likes nothing but meat.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [predicate(B, like, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D, E], [object(D, meat, mass, na, na, na)-1, predicate(E, be, C, D)-1])]), [[s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, ['{nothing but}']], [nbar, [n, [meat]]]]]]]], '2007-10-11-17-03-19', '130.60.155.177', '').
text_drs_eval(0, 2411, 'John likes nothing but Mary.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, like, A, D)-1, object(D, something, dom, na, na, na)-1])=>drs([E], [predicate(E, be, D, B)-1])]), [[s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, ['{nothing but}']], [pname, ['Mary']]]]]]], '2007-10-11-19-25-35', '130.60.155.177', '').
text_drs_eval(0, 2412, 'John likes nobody but Mary.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, like, A, D)-1, object(D, somebody, countable, na, eq, 1)-1])=>drs([E], [predicate(E, be, D, B)-1])]), [[s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, ['{nothing but}']], [pname, ['Mary']]]]]]], '2007-10-26-15-41-46', '130.60.155.231', '').
text_drs_eval(0, 2413, 'John likes nothing but raw meat.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [predicate(B, like, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D, E], [object(D, meat, mass, na, na, na)-1, property(D, raw, pos)-1, predicate(E, be, C, D)-1])]), [[s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, ['{nothing but}']], [nbar, [adj, [raw]], [nbar, [n, [meat]]]]]]]]], '2007-10-11-17-02-42', '130.60.155.177', '').
text_drs_eval(0, 2414, 'John likes nothing but fast cars.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [predicate(B, like, A, C)-1, object(C, something, dom, na, na, na)-1])=>drs([D, E], [object(D, car, countable, na, eq, 1)-1, property(D, fast, pos)-1, predicate(E, be, C, D)-1])]), [[s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, ['{nothing but}']], [nbar, [adj, [fast]], [nbar, [n, [cars]]]]]]]]], '2007-10-11-17-01-54', '130.60.155.177', '').
text_drs_eval(1, 2415, 'John likes nothing but Mary\'s cars.', drs([], []), [], '2007-10-11-17-02-19', '130.60.155.177', 'Maybe support this?').
text_drs_eval(0, 2416, 'John likes nothing but apple.', drs([], []), [], '2007-10-11-17-03-37', '130.60.155.177', '').
text_drs_eval(0, 2417, 'John likes nothing but cars of Mary.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([C, D], [predicate(C, like, A, D)-1, object(D, something, dom, na, na, na)-1])=>drs([E, F], [object(E, car, countable, na, eq, 1)-1, relation(E, of, B)-1, predicate(F, be, D, E)-1])]), [[s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, ['{nothing but}']], [nbar, [n, [cars]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]]]]]], '2007-10-11-17-04-59', '130.60.155.177', '').
text_drs_eval(1, 2418, 'John likes nothing but Mary who owns a car.', drs([], []), [], '2007-10-11-19-26-15', '130.60.155.177', 'Add support for: nothing but   proper name   RelCl').
text_drs_eval(0, 2419, 'Who likes nothing but Mary?', drs([], [question(drs([A], [query(A, who)-1/1, drs([B, C], [predicate(B, like, A, C)-1/2, object(C, something, dom, na, na, na)-1/4])=>drs([D], [predicate(D, be, C, named('Mary'))-1/''])]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, likes], [np, [det, [np, [pn, nothing]], but], [pname, 'Mary']]]]]], ?], '.']], '2009-05-13-13-58-25', '130.60.155.193', '').
text_drs_eval(0, 2420, 'Who likes nothing but raw meat?', drs([], [question(drs([A], [query(A, who)-1/1, drs([B, C], [predicate(B, like, A, C)-1/2, object(C, something, dom, na, na, na)-1/4])=>drs([D, E], [object(D, meat, mass, na, na, na)-1/7, property(D, raw, pos)-1/6, predicate(E, be, C, D)-1/''])]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, likes], [np, [det, [np, [pn, nothing]], but], [nbar, [adj, raw], [nbar, [n, meat]]]]]]]], ?], '.']], '2009-05-13-13-55-57', '130.60.155.193', '').
text_drs_eval(0, 2421, 'For every farmer for every donkey the farmer beats the donkey.', drs([], [drs([A], [object(A, farmer, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, donkey, countable, na, eq, 1)-1])=>drs([C], [predicate(C, beat, A, B)-1])])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, [farmer]]]], [top_s, [topic, [quant, ['{for every}']], [nbar, [n, [donkey]]]], [s, [np, [det, [the]], [nbar, [n, [farmer]]]], [vp, [vbar, [v, [beats]], [np, [det, [the]], [nbar, [n, [donkey]]]]]]]]]], '2007-10-11-20-38-53', '130.60.155.177', '').
text_drs_eval(0, 2422, 'For every farmer and for every donkey the farmer beats the donkey.', drs([], []), [], '2007-12-23-12-09-36', '130.60.204.35', '').
text_drs_eval(0, 2423, '1*3*4/7*8 is a term.', drs([A, B], [object(A, term, countable, na, eq, 1)-1, predicate(B, be, expr(*, expr(/, expr(*, expr(*, int(1), int(3)), int(4)), int(7)), int(8)), A)-1]), [[s, [np, [expr, [expr, [expr, [expr, [int, [1]], [*], [int, [3]]], [*], [int, [4]]], [/], [int, [7]]], [*], [int, [8]]]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [term]]]]]]]], '2007-10-16-12-07-34', '130.60.155.231', '').
text_drs_eval(0, 2424, 'Are there 3 things and 4 things?', drs([], [question(drs([A, B, C], [object(A, thing, countable, na, eq, 3)-1/4, has_part(C, A)-1/'', object(B, thing, countable, na, eq, 4)-1/7, has_part(C, B)-1/'', object(C, na, countable, na, eq, 2)-1/'']))]), [[sentence, [query, [question, [topic, [quant, 'are there'], [np_coord, [np, [nump, 3], [nbar, [n, things]]], [coord, and], [np, [nump, 4], [nbar, [n, things]]]]]], ?], '.']], '2009-05-13-13-58-27', '130.60.155.193', '').
text_drs_eval(0, 2425, 'Who hits himself?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, hit, A, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, hits], [np, [pn, himself]]]]]], ?], '.']], '2009-05-13-13-58-29', '130.60.155.193', '').
text_drs_eval(0, 2426, 'Who sees herself?', drs([], [question(drs([A, B], [query(A, who)-1/1, predicate(B, see, A, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [pn, herself]]]]]], ?], '.']], '2009-05-13-13-58-31', '130.60.155.193', '').
text_drs_eval(0, 2427, 'Who sees itself?', drs([], []), [question, [np, [qpn, [who]]], [vp, [vbar, [v, [sees]], [np, [pn, [itself]]]]]], '2007-10-16-17-29-38', '130.60.155.177', '').
text_drs_eval(0, 2428, 'Where does a man live?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, live, A)-1/5, query(B, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-13-58-31', '130.60.155.193', '').
text_drs_eval(0, 2429, 'What is given to Mary by John?', drs([], [question(drs([A, B], [query(A, what)-1/1, predicate(B, give, named('John'), A, named('Mary'))-1/3]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [v, given], to, [np, [pname, 'Mary']], by, [np, [pname, 'John']]]]]], ?], '.']], '2009-05-13-13-58-33', '130.60.155.193', '').
text_drs_eval(0, 2430, 'There is a man X. X\'s dog barks.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, dog, countable, na, eq, 1)-2, predicate(C, bark, B)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], [s, [np, [poss_np, [var, ['X']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], '2007-10-16-20-16-37', '130.60.155.177', '').
text_drs_eval(0, 2431, 'There is a man X. There is some food of X\'s dog.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, food, mass, na, na, na)-2, relation(C, of, A)-2, object(C, dog, countable, na, eq, 1)-2, relation(B, of, C)-2]), [[top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos_coord, [appos, [var, ['X']]]]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [food]], [pp, [prep, [of]], [np, [poss_np, [var, ['X']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]]]]]]], '2007-10-16-20-22-33', '130.60.155.177', '').
text_drs_eval(0, 2432, 'Everybody X likes X\'s dog.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C], [relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1])]), [[s, [np, [pn, [everybody]], [appos_coord, [appos, [var, ['X']]]]], [vp, [vbar, [v, [likes]], [np, [poss_np, [var, ['X']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]]]]], '2007-10-16-20-23-46', '130.60.155.177', '').
text_drs_eval(0, 2433, 'Jyri\'s dog hates Mari\'s cat.', drs([A, B, C, D, E], [object(A, 'Jyri', named, na, eq, 1)-1, object(B, 'Mari', named, na, eq, 1)-1, relation(C, of, A)-1, object(C, dog, countable, na, eq, 1)-1, relation(D, of, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, hate, C, D)-1]), [[s, [np, [poss_np, [var, ['Jyri']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [hates]], [np, [poss_np, [var, ['Mari']], [gen_marker, ['\'s']]], [nbar, [n, [cat]]]]]]]], '2007-10-16-20-24-10', '130.60.155.177', '').
text_drs_eval(0, 2434, 'Everybody X\'s dog hates X\'s cat.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [relation(C, of, A)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, hate, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, [every]], [nbar, [n, ['$body']], [appos, [var, ['X']]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [hates]], [np, [poss_np, [var, ['X']], [gen_marker, ['\'s']]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-11-20-17-47-14', '130.60.155.231', '').
text_drs_eval(0, 2435, 'If somebody X\'s dog Y hates Y\'s meat then X\'s cat likes Y.', drs([], [drs([A, B, C, D], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, relation(C, of, B)-1, object(C, meat, countable, na, eq, 1)-1, predicate(D, hate, B, C)-1])=>drs([E, F], [relation(E, of, A)-1, object(E, cat, countable, na, eq, 1)-1, predicate(F, like, E, B)-1])]), [[cond_s, [if], [s, [np, [poss_np, [pn, [somebody]], [[appos_coord, [appos, [var, ['X']]]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]], [appos_coord, [appos, [var, ['Y']]]]]], [vp, [vbar, [v, [hates]], [np, [poss_np, [var, ['Y']], [gen_marker, ['\'s']]], [nbar, [n, [meat]]]]]]], [then], [s, [np, [poss_np, [var, ['X']], [gen_marker, ['\'s']]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [likes]], [np, [var, ['Y']]]]]]]], '2007-10-16-20-26-44', '130.60.155.177', '').
text_drs_eval(0, 2436, '2 men X and Y\'s dog bark.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 2)-1, has_part(E, A)-1, predicate(B, bark, E)-1, object(C, something, dom, na, na, na)-1, relation(D, of, C)-1, object(D, dog, countable, na, eq, 1)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [poss_np, [var, 'Y'], [gen_marker, '\'s']], [nbar, [n, dog]]]], [vp, [vbar, [v, bark]]]], '.']], '2008-07-10-10-47-02', '130.60.155.206', '').
text_drs_eval(0, 2437, 'John owns not 3 cards.', drs([], []), [], '2007-12-23-12-09-52', '130.60.204.35', '').
text_drs_eval(0, 2438, 'For everything X a man knows X.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B, C], [object(B, man, countable, na, eq, 1)-1, predicate(C, know, B, A)-1])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, ['$thing']], [appos_coord, [appos, [var, ['X']]]]]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [np, [var, ['X']]]]]]]], '2007-10-17-15-23-32', '130.60.155.177', '').
text_drs_eval(0, 2439, 'For everything X for nothing Y X likes Y.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([], [drs([B], [object(B, something, dom, na, na, na)-1])=>drs([], [-drs([C], [predicate(C, like, A, B)-1])])])]), [[top_s, [topic, [quant, ['{for every}']], [nbar, [n, ['$thing']], [appos_coord, [appos, [var, ['X']]]]]], [top_s, [topic, [quant, ['{for no}']], [nbar, [n, ['$thing']], [appos_coord, [appos, [var, ['Y']]]]]], [s, [np, [var, ['X']]], [vp, [vbar, [v, [likes]], [np, [var, ['Y']]]]]]]]], '2007-10-17-15-24-37', '130.60.155.177', '').
text_drs_eval(0, 2440, 'For nobody X for everyone Y Y knows X.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, somebody, countable, na, eq, 1)-1])=>drs([C], [predicate(C, know, B, A)-1])])])]), [[top_s, [topic, [quant, ['{for no}']], [nbar, [n, ['$body']], [appos_coord, [appos, [var, ['X']]]]]], [top_s, [topic, [quant, ['{for every}']], [nbar, [n, ['$one']], [appos_coord, [appos, [var, ['Y']]]]]], [s, [np, [var, ['Y']]], [vp, [vbar, [v, [knows]], [np, [var, ['X']]]]]]]]], '2007-10-17-15-25-24', '130.60.155.177', '').
text_drs_eval(0, 2441, 'For every man\'s dog a cat waits.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C, D], [object(C, cat, countable, na, eq, 1)-1, predicate(D, wait, C)-1])]), [[specification, [top_s, [topic, [quant, ['{for}']], [np, [poss_np, [det, [every]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-11-20-17-51-01', '130.60.155.231', '').
text_drs_eval(0, 2442, '2 men and M2 drink. M2 talks. They eat.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 2)-1, has_part(D, A)-1, predicate(B, drink, D)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, talk, C)-2, predicate(F, eat, D)-3]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men]]], [coord, and], [np, [var, 'M2']]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [var, 'M2']], [vp, [vbar, [v, talks]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [vbar, [v, eat]]]], '.']], '2008-07-10-10-47-08', '130.60.155.206', '').
text_drs_eval(0, 2443, '2 men X and Y\'s dog wait. X sleeps. Y drinks.', drs([], []), [[specification, [s, [np_coord, [np, [numberp, [gen_quant, [[]]], [number, [2]]], [nbar, [n, [men]], [appos, [var, ['X']]]]], [coord, [and]], [np, [poss_np, [var, ['Y']], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [var, ['X']]], [vp, [vbar, [v, [sleeps]]]]], ['.']], [specification, [s, [np, [var, ['Y']]], [vp, [vbar, [v, [drinks]]]]], ['.']]], '2007-12-29-18-05-41', '130.60.204.10', '').
text_drs_eval(0, 2444, 'When is Christmas?', drs([], [question(drs([A], [query(A, when)-1/1, predicate(A, be, named('Christmas'))-1/2]))]), [[sentence, [query, [question, [qpn, when], is, [np, [pname, 'Christmas']]], ?], '.']], '2009-05-13-13-58-35', '130.60.155.193', '').
text_drs_eval(0, 2445, 'Where is Bill?', drs([], [question(drs([A], [query(A, where)-1/1, predicate(A, be, named('Bill'))-1/2]))]), [[sentence, [query, [question, [qpn, where], is, [np, [pname, 'Bill']]], ?], '.']], '2009-05-13-13-58-36', '130.60.155.193', '').
text_drs_eval(0, 2446, 'When is what?', drs([], [question(drs([A, B], [query(A, what)-1/3, query(B, when)-1/1, predicate(B, be, A)-1/2]))]), [[sentence, [query, [question, [qpn, when], is, [np, [qpn, what]]], ?], '.']], '2009-05-13-13-58-37', '130.60.155.193', '').
text_drs_eval(0, 2447, 'What is when?', drs([], [question(drs([A, B], [query(A, what)-1/1, query(B, when)-1/3, predicate(B, be, A)-1/2]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [qpn, when]]]]], ?], '.']], '2009-05-13-13-58-40', '130.60.155.193', '').
text_drs_eval(0, 2448, '1 =< 2 and 2 >= 1.', drs([], [formula(int(1), =<, int(2))-1, formula(int(2), >=, int(1))-1]), [[s_coord, [formula, [int, [1]], [=<], [int, [2]]], [coord, [and]], [formula, [int, [2]], [>=], [int, [1]]]]], '2007-10-19-15-18-18', '130.60.155.177', '').
text_drs_eval(0, 2449, 'Who is somebody that somebody that knows who knows?', drs([], [question(drs([A, B, C, D, E, F, G], [query(A, who)-1/1, object(B, somebody, countable, na, eq, 1)-1/4, object(C, somebody, countable, na, eq, 1)-1/7, query(D, who)-1/10, predicate(E, know, C, D)-1/9, predicate(F, know, C, B)-1/11, predicate(G, be, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, somebody], [rel_cl, [comp, that], [np, [pn, somebody], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, knows], [np, [qpn, who]]]]]]], [vp, [vbar, [vcompl, [v, knows]]]]]]]]]], ?], '.']], '2009-05-13-13-58-41', '130.60.155.193', '').
text_drs_eval(0, 2450, 'Who is known by somebody that knows who?', drs([], [question(drs([A, B, C, D, E], [query(A, who)-1/1, object(B, somebody, countable, na, eq, 1)-1/6, query(C, who)-1/9, predicate(D, know, B, C)-1/8, predicate(E, know, B, A)-1/3]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [v, known], by, [np, [pn, somebody], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, knows], [np, [qpn, who]]]]]]]]]]], ?], '.']], '2009-05-13-13-58-42', '130.60.155.193', '').
text_drs_eval(0, 2451, 'If there is John then there is somebody.', drs([], []), [], '2007-11-06-18-40-37', '130.60.155.177', '').
text_drs_eval(0, 2452, 'If there is John then there is something.', drs([], []), [], '2007-11-06-18-40-49', '130.60.155.177', '').
text_drs_eval(0, 2453, 'John is a father of who?', drs([], [question(drs([A, B, C], [object(A, father, countable, na, eq, 1)-1/4, query(B, who)-1/6, relation(A, of, B)-1/5, predicate(C, be, named('John'), A)-1/2]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, father], [pp, [prep, of], [np, [qpn, who]]]]]]]]], ?], '.']], '2009-05-13-13-58-43', '130.60.155.193', '').
text_drs_eval(0, 2454, 'Bill gives what to who?', drs([], [question(drs([A, B, C], [query(A, what)-1/3, query(B, who)-1/5, predicate(C, give, named('Bill'), A, B)-1/2]))]), [[sentence, [query, [question, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, gives], [np, [qpn, what]], to, [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-58-45', '130.60.155.193', '').
text_drs_eval(0, 2455, 'Bill gives what to who where?', drs([], [question(drs([A, B, C], [query(A, what)-1/3, query(B, who)-1/5, predicate(C, give, named('Bill'), A, B)-1/2, query(C, where)-1/6]))]), [[sentence, [query, [question, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, gives], [np, [qpn, what]], to, [np, [qpn, who]]], [vmod, [qpn, where]]]]], ?], '.']], '2009-05-13-13-58-46', '130.60.155.193', '').
text_drs_eval(0, 2456, 'Where does Bill give what to who?', drs([], [question(drs([A, B, C], [query(A, what)-1/5, query(B, who)-1/7, predicate(C, give, named('Bill'), A, B)-1/4, query(C, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, give], [np, [qpn, what]], to, [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-58-47', '130.60.155.193', '').
text_drs_eval(0, 2457, 'Bill lives in which city in which country for which reason?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/4, object(A, city, countable, na, eq, 1)-1/5, query(B, which)-1/7, object(B, country, countable, na, eq, 1)-1/8, query(C, which)-1/10, object(C, reason, countable, na, eq, 1)-1/11, predicate(D, live, named('Bill'))-1/2, modifier_pp(D, for, C)-1/9, modifier_pp(D, in, B)-1/6, modifier_pp(D, in, A)-1/3]))]), [[sentence, [query, [question, [np, [pname, 'Bill']], [vp, [vbar, [vbar, [v, lives]], [vmod, [pp, [prep, in], [np, [qdet, which], [nbar, [n, city]]]], [pp, [prep, in], [np, [qdet, which], [nbar, [n, country]]]], [pp, [prep, for], [np, [qdet, which], [nbar, [n, reason]]]]]]]], ?], '.']], '2009-05-13-13-58-48', '130.60.155.193', '').
text_drs_eval(0, 2458, 'John and Mary like what?', drs([], [question(drs([A, B, C], [has_part(C, named('John'))-1/'', query(A, what)-1/5, predicate(B, like, C, A)-1/4, has_part(C, named('Mary'))-1/'', object(C, na, countable, na, eq, 2)-1/'']))]), [[sentence, [query, [question, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], [vp, [vbar, [vcompl, [v, like], [np, [qpn, what]]]]]], ?], '.']], '2009-05-13-13-58-50', '130.60.155.193', '').
text_drs_eval(0, 2459, 'Bill gives which flowers to which women?', drs([], [question(drs([A, B, C], [query(A, which)-1/3, object(A, flower, countable, na, geq, 2)-1/4, query(B, which)-1/6, object(B, woman, countable, na, geq, 2)-1/7, predicate(C, give, named('Bill'), A, B)-1/2]))]), [[sentence, [query, [question, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, gives], [np, [qdet, which], [nbar, [n, flowers]]], to, [np, [qdet, which], [nbar, [n, women]]]]]]], ?], '.']], '2009-05-13-13-58-51', '130.60.155.193', '').
text_drs_eval(0, 2460, 'Which men give which flowers to which women?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, man, countable, na, geq, 2)-1/2, query(B, which)-1/4, object(B, flower, countable, na, geq, 2)-1/5, query(C, which)-1/7, object(C, woman, countable, na, geq, 2)-1/8, predicate(D, give, A, B, C)-1/3]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, give], [np, [qdet, which], [nbar, [n, flowers]]], to, [np, [qdet, which], [nbar, [n, women]]]]]]], ?], '.']], '2009-05-13-13-58-52', '130.60.155.193', '').
text_drs_eval(0, 2461, '2 kg of sugar are used by John for what?', drs([], [question(drs([A, B, C], [object(A, sugar, mass, kg, eq, 2)-1/4, query(B, what)-1/10, predicate(C, use, named('John'), A)-1/6, modifier_pp(C, for, B)-1/9]))]), [[sentence, [query, [question, [np, [meas_spec, [nump, 2], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, sugar]]], [vp, [aux, are], [vbar, [vcompl, [v, used], by, [np, [pname, 'John']]], [vmod, [pp, [prep, for], [np, [qpn, what]]]]]]], ?], '.']], '2009-05-13-13-53-14', '130.60.155.193', '').
text_drs_eval(0, 2462, 'Is a code entered by a customer?', drs([], [question(drs([A, B, C], [object(A, code, countable, na, eq, 1)-1/3, object(B, customer, countable, na, eq, 1)-1/7, predicate(C, enter, B, A)-1/4]))]), [[sentence, [query, [question, is, [np, [det, a], [nbar, [n, code]]], [vp, [vbar, [vcompl, [v, entered], by, [np, [det, a], [nbar, [n, customer]]]]]]], ?], '.']], '2009-05-13-13-53-16', '130.60.155.193', '').
text_drs_eval(0, 2463, 'What are the cars of John?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, predicate(B, be, A, C)-1/2, relation(C, of, named('John'))-1/5, object(C, car, countable, na, geq, 2)-1/4]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, are], [vbar, [vcompl, [np, [det, the], [nbar, [n, cars], [pp, [prep, of], [np, [pname, 'John']]]]]]]]], ?], '.']], '2009-05-13-13-53-17', '130.60.155.193', '').
text_drs_eval(0, 2464, 'Who are the children of John?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, predicate(B, be, A, C)-1/2, relation(C, of, named('John'))-1/5, object(C, child, countable, na, geq, 2)-1/4]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, are], [vbar, [vcompl, [np, [det, the], [nbar, [n, children], [pp, [prep, of], [np, [pname, 'John']]]]]]]]], ?], '.']], '2009-05-13-13-53-19', '130.60.155.193', '').
text_drs_eval(0, 2465, 'Each of not at most 5 boys buys a boat.', drs([], []), [], '2008-08-19-19-58-17', '130.60.155.177', '').
text_drs_eval(0, 2466, 'Not at most 3 dogs bark.', drs([], []), [], '2008-08-19-19-58-26', '130.60.155.177', '').
text_drs_eval(0, 2467, 'Not less than 3 dogs bark.', drs([], []), [], '2008-08-19-19-58-34', '130.60.155.177', '').
text_drs_eval(0, 2468, 'At least 3 men and at most 3 men wait. They are tired.', drs([A, B, C, D, E, F], [object(A, man, countable, na, geq, 3)-1, has_part(D, A)-1, predicate(B, wait, D)-1, [has_part(D, C)-1, object(C, man, countable, na, leq, 3)-1], object(D, na, countable, na, eq, 2)-1, property(E, tired, pos)-2, predicate(F, be, D, E)-2]), [[specification, [s, [np_coord, [np, [nump, [genqu, 'at least'], 3], [nbar, [n, men]]], [coord, and], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men]]]], [vp, [vbar, [vbar, [v, wait]]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [aux, are], [vbar, [vcompl, [ap_coord, [ap, [adj, tired]]]]]]], '.']], '2009-03-02-11-31-19', '130.60.155.206', '').
text_drs_eval(0, 2469, 'A man who is John waits. The man who is Bill sleeps.', drs([A, B, C, D, E, F, G, H], [object(G, man, countable, na, eq, 1)-2, predicate(H, be, G, B)-2, predicate(F, sleep, G)-2, predicate(E, wait, C)-1, predicate(D, be, C, A)-1, object(C, man, countable, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-2, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [pname, ['John']]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [pname, ['Bill']]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-11-11-11-45-52', '130.60.204.22', '').
text_drs_eval(0, 2470, 'A man who is a clerk waits. The man who is a customer sleeps.', drs([A, B, C, D, E, F, G, H], [object(F, man, countable, na, eq, 1)-2, object(G, customer, countable, na, eq, 1)-2, predicate(H, be, F, G)-2, predicate(E, sleep, F)-2, predicate(D, wait, A)-1, predicate(C, be, A, B)-1, object(B, clerk, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [clerk]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [np, [det, [a]], [nbar, [n, [customer]]]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-11-11-11-46-19', '130.60.204.22', '').
text_drs_eval(0, 2471, 'There is a man who owns a dog. There is a man who owns a cat. John sees the man who owns a dog.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, object(E, man, countable, na, eq, 1)-2, object(F, cat, countable, na, eq, 1)-2, predicate(G, own, E, F)-2, predicate(H, see, A, B)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]]]], ['.']]], '2007-11-23-00-21-42', '130.60.206.7', '').
text_drs_eval(0, 2472, 'There is a man whose dog barks. The dog of a man sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, sleep, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [vbar, [v, sleeps]]]], '.']], '2008-07-30-17-56-56', '130.60.155.177', '').
text_drs_eval(0, 2473, 'Proposition P: John sleeps. Mary waits.', drs([], []), [], '2009-04-02-13-16-44', '130.60.155.206', '').
text_drs_eval(0, 2474, 'Proposition P: A man believes that P. A dog believes that P.', drs([], []), [[prop, [prop, ['Proposition']], [var, ['P']], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [believes]], [cp, ['_that_'], [var, ['P']]]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [believes]], [cp, ['_that_'], [var, ['P']]]]]]], '2007-11-03-10-28-54', '84.72.55.11', '').
text_drs_eval(0, 2475, 'There are a man X and a man Y.', drs([A, B, C], [has_part(C, A)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, object(A, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1]), [[top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X']]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['Y']]]]]]]]], '2007-11-05-10-36-30', '130.60.155.231', '').
text_drs_eval(0, 2476, 'For each of a man X and a man Y there is a card.', drs([A, B, C], [has_part(C, A)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, object(A, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, drs([D], [has_part(C, D)-1])=>drs([E], [object(E, card, countable, na, eq, 1)-1])]), [[top_s, [topic, [quant, ['{for each of}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X']]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['Y']]]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]]]], '2007-11-05-10-36-42', '130.60.155.231', '').
text_drs_eval(0, 2477, 'Not for each of a man X and a man Y there is a card.', drs([], [-drs([A, B, C], [has_part(C, A)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, object(A, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, drs([D], [has_part(C, D)-1])=>drs([E], [object(E, card, countable, na, eq, 1)-1])])]), [[top_s, [topic, [neg, [not]], [quant, ['{for each of}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X']]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['Y']]]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]]]], '2007-11-05-10-36-49', '130.60.155.231', '').
text_drs_eval(0, 2478, 'John has a dog and has a cat. Who has a dog? Who has a cat?', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/4, predicate(B, have, named('John'), A)-1/2, object(C, cat, countable, na, eq, 1)-1/8, predicate(D, have, named('John'), C)-1/6, question(drs([E, F, G], [query(E, who)-2/1, object(F, dog, countable, na, eq, 1)-2/4, predicate(G, have, E, F)-2/2])), question(drs([H, I, J], [query(H, who)-3/1, object(I, cat, countable, na, eq, 1)-3/4, predicate(J, have, H, I)-3/2]))]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp_coord, [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, dog]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, cat]]]]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, dog]]]]]]], ?], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, cat]]]]]]], ?], '.']], '2009-05-13-13-53-20', '130.60.155.193', '').
text_drs_eval(0, 2479, 'There is a man. A dog of him eats. The dog of him barks.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-2, relation(B, of, A)-2, predicate(C, eat, B)-2, predicate(D, bark, B)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [him]]]]]], [vp, [vbar, [v, [eats]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [pn, [him]]]]]], [vp, [vbar, [v, [barks]]]]], ['.']]], '2007-12-20-13-42-20', '130.60.155.231', '').
text_drs_eval(0, 2480, 'There is a man. A dog of him eats. The dog of the man barks.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-2, relation(B, of, A)-2, predicate(C, eat, B)-2, predicate(D, bark, B)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [pn, him]]]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-12-17-10-27', '130.60.155.208', '').
text_drs_eval(0, 2481, 'There is a man a dog of who barks and who eats.', drs([A, B, C, D], [predicate(D, eat, A)-1, predicate(C, bark, B)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [barks]]]]], [coord, [and]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [eats]]]]]]]]]], ['.']]], '2007-11-06-18-37-13', '130.60.155.177', '').
text_drs_eval(0, 2482, 'There is a man a dog that eats of who barks.', drs([], []), [], '2007-11-06-18-37-49', '130.60.155.177', '').
text_drs_eval(0, 2483, 'There is a man a dog who eats of who barks.', drs([], []), [], '2007-11-06-18-37-53', '130.60.155.177', '').
text_drs_eval(0, 2484, 'There is a man. His dog X eats. There is a woman. Her dog drinks. The dog X barks.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, dog, countable, na, eq, 1)-2, predicate(C, eat, B)-2, object(D, woman, countable, na, eq, 1)-3, relation(E, of, D)-4, object(E, dog, countable, na, eq, 1)-4, predicate(F, drink, E)-4, predicate(G, bark, B)-5]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [posspn, his], [nbar, [n, dog], [appos, [var, 'X']]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman]]]]], '.'], [specification, [s, [np, [posspn, her], [nbar, [n, dog]]], [vp, [vbar, [v, drinks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [appos, [var, 'X']]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-15-20-34-30', '130.60.204.15', '').
text_drs_eval(0, 2485, 'There is a young man who is more fond-of Mary than of Sue. There is an old man who is more fond-of Sue than of Mary. John knows the man who is more fond-of Mary than of Sue.', drs([A, B, C, D, E, F, G, H, I, J], [predicate(J, know, C, D)-3, predicate(I, be, G, H)-2, property(H, 'fond-of', B, comp_than, obj, A)-2, property(G, old, pos)-2, object(G, man, countable, na, eq, 1)-2, predicate(F, be, D, E)-1, property(E, 'fond-of', A, comp_than, obj, B)-1, property(D, young, pos)-1, object(D, man, countable, na, eq, 1)-1, object(C, 'John', named, na, eq, 1)-3, object(B, 'Sue', named, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [young]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more], ['fond-of']], [np, [pname, ['Mary']]], [than], [of], [np, [pname, ['Sue']]]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [adj, [old]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more], ['fond-of']], [np, [pname, ['Sue']]], [than], [of], [np, [pname, ['Mary']]]]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [more], ['fond-of']], [np, [pname, ['Mary']]], [than], [of], [np, [pname, ['Sue']]]]]]]]]]]]], ['.']]], '2007-11-11-19-20-29', '130.60.155.177', '').
text_drs_eval(0, 2486, 'No group that contains less than 3 bad members and contains less than 3 good members forms a committee.', drs([], []), [], '2008-07-29-11-15-55', '130.60.155.206', '').
text_drs_eval(0, 2487, 'Mary likes John\'s red car.', drs([A, B, C, D], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, relation(C, of, B)-1, object(C, car, countable, na, eq, 1)-1, property(C, red, pos)-1, predicate(D, like, A, C)-1]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [likes]], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [adj, [red]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-11-09-15-46-44', '130.60.155.177', '').
text_drs_eval(0, 2488, 'There is John\'s fast and red car.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, car, countable, na, eq, 1)-1, property(B, fast, pos)-1, property(B, red, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [adj_coord, [adj, [fast]], [coord, [and]], [adj, [red]]], [nbar, [n, [car]]]]]]], ['.']]], '2007-11-09-15-47-14', '130.60.155.177', '').
text_drs_eval(0, 2489, 'There is John\'s most fast car.', drs([A, B], [property(B, fast, sup)-1, object(B, car, countable, na, eq, 1)-1, relation(B, of, A)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pname, ['John']], [gen_marker, ['\'s']]], [nbar, [adj, [most], [fast]], [nbar, [n, [car]]]]]]], ['.']]], '2007-11-09-15-47-58', '130.60.155.177', '').
text_drs_eval(0, 2490, 'Mary likes a man\'s red car.', drs([A, B, C, D], [predicate(D, like, A, C)-1, property(C, red, pos)-1, object(C, car, countable, na, eq, 1)-1, relation(C, of, B)-1, object(B, man, countable, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [likes]], [np, [poss_np, [det, [a]], [nbar, [n, [man]]], [gen_marker, ['\'s']]], [nbar, [adj, [red]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-11-09-15-54-40', '130.60.155.177', '').
text_drs_eval(0, 2491, 'Mary likes a rich man\'s red car.', drs([A, B, C, D], [predicate(D, like, A, C)-1, property(C, red, pos)-1, object(C, car, countable, na, eq, 1)-1, relation(C, of, B)-1, property(B, rich, pos)-1, object(B, man, countable, na, eq, 1)-1, object(A, 'Mary', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [likes]], [np, [poss_np, [det, [a]], [nbar, [adj, [rich]], [n, [man]]], [gen_marker, ['\'s']]], [nbar, [adj, [red]], [nbar, [n, [car]]]]]]]], ['.']]], '2007-11-09-15-54-58', '130.60.155.177', '').
text_drs_eval(0, 2492, 'For a man a dog barks.', drs([], []), [], '2007-11-09-17-38-57', '130.60.155.177', '').
text_drs_eval(0, 2493, 'For the man a dog barks.', drs([], []), [], '2007-11-09-17-39-03', '130.60.155.177', '').
text_drs_eval(0, 2494, 'For every card does a customer own it?', drs([], [question(drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1/3])=>drs([B, C], [object(B, customer, countable, na, eq, 1)-1/6, predicate(C, own, B, A)-1/7])]))]), [[sentence, [query, [topicalised_question, [topic, [quant, for], [np, [det, every], [nbar, [n, card]]]], [question, does, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, own], [np, [pn, it]]]]]]], ?], '.']], '2009-05-13-13-53-22', '130.60.155.193', '').
text_drs_eval(0, 2495, 'For no card does a customer own the card?', drs([], [question(drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1/3])=>drs([], [-drs([B, C], [object(B, customer, countable, na, eq, 1)-1/6, predicate(C, own, B, A)-1/7])])]))]), [[sentence, [query, [topicalised_question, [topic, [quant, for], [np, [det, no], [nbar, [n, card]]]], [question, does, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, own], [np, [det, the], [nbar, [n, card]]]]]]]], ?], '.']], '2009-05-13-13-53-23', '130.60.155.193', '').
text_drs_eval(0, 2496, 'For a card does a customer own it?', drs([], []), [], '2007-11-09-17-45-26', '130.60.155.177', '').
text_drs_eval(0, 2497, 'Not for no man a dog barks.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [predicate(C, bark, B)-1, object(B, dog, countable, na, eq, 1)-1])])])]), [[specification, [top_s, [topic, [quant, ['{not for}']], [np, [det, [no]], [nbar, [n, [man]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-11-09-18-09-08', '130.60.155.177', '').
text_drs_eval(0, 2498, 'Not for no man a dog likes John.', drs([A], [-drs([], [drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([], [-drs([C, D], [predicate(D, like, C, A)-1, object(C, dog, countable, na, eq, 1)-1])])]), object(A, 'John', named, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{not for}']], [np, [det, [no]], [nbar, [n, [man]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [likes]], [np, [pname, ['John']]]]]]], ['.']]], '2007-11-09-18-08-36', '130.60.155.177', '').
text_drs_eval(0, 2499, 'There is John\'s dog such that a cat sees the dog.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, see, C, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [poss_np, [pname, ['John']], ['|', [gen_marker, ['\'s']]]], [nbar, [n, [dog]]]]], [conj, ['{such that}']], [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-11-09-18-21-45', '130.60.155.177', '').
text_drs_eval(0, 2500, 'There is a man who sleeps on a bank. There is a man who sleeps on a bed. John sees the man who sleeps on a bank.', drs([A, B, C, D, E, F, G, H], [predicate(H, see, A, B)-3, modifier_pp(G, on, F)-2, predicate(G, sleep, E)-2, object(F, bed, countable, na, eq, 1)-2, object(E, man, countable, na, eq, 1)-2, modifier_pp(D, on, C)-1, predicate(D, sleep, B)-1, object(C, bank, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [on]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [on]], [np, [det, [a]], [nbar, [n, [bed]]]]]]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [on]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]]]]]]], ['.']]], '2007-11-12-14-49-29', '130.60.155.177', '').
text_drs_eval(0, 2501, 'There is a man who can wait. The man who can wait sleeps.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, can(drs([C], [predicate(C, wait, A)-1/7])), predicate(B, sleep, A)-2/6]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]]]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.']], '2010-10-27-09-29-32', '89.206.64.27', '').
text_drs_eval(0, 2502, 'For every man every dog barks for every cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])=>drs([], [drs([C], [object(C, cat, countable, na, eq, 1)-1])=>drs([D], [modifier_pp(D, for, C)-1, predicate(D, bark, B)-1])])])]), [[specification, [top_s, [topic, [quant, ['{for}']], [np, [det, [every]], [nbar, [n, [man]]]]], [s, [np, [det, [every]], [nbar, [n, [dog]]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [for]], [np, [det, [every]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2007-11-12-14-21-43', '130.60.155.177', '').
text_drs_eval(0, 2503, 'For every man a dog barks for every cat.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [drs([C], [object(C, cat, countable, na, eq, 1)-1])=>drs([D], [modifier_pp(D, for, C)-1, predicate(D, bark, B)-1]), object(B, dog, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{for}']], [np, [det, [every]], [nbar, [n, [man]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [vbar, [v, [barks]]], [pp, [prep, [for]], [np, [det, [every]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2007-11-12-14-22-00', '130.60.155.177', '').
text_drs_eval(0, 2504, 'A card of which man is valid?', drs([], [question(drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, man, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, property(C, valid, pos)-1/7, predicate(D, be, A, C)-1/6]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-13-53-24', '130.60.155.193', '').
text_drs_eval(0, 2505, 'A clerk enters a card of every customer. The card of every customer is valid.', drs([A, B, C, D, E], [predicate(E, be, B, D)-2, property(D, valid, pos)-2, predicate(C, enter, A, B)-1, drs([F], [object(F, customer, countable, na, eq, 1)-1])=>drs([], [relation(B, of, F)-1]), object(B, card, countable, na, eq, 1)-1, object(A, clerk, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [enters]], [np, [det, [a]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [customer]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [det, [every]], [nbar, [n, [customer]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], ['.']]], '2007-11-12-18-00-26', '130.60.155.177', '').
text_drs_eval(0, 2506, 'For a man\'s cat a dog barks.', drs([], []), [], '2007-11-12-18-58-22', '130.60.155.177', '').
text_drs_eval(0, 2507, 'For the man\'s cat a dog barks.', drs([], []), [], '2007-11-12-18-58-28', '130.60.155.177', '').
text_drs_eval(0, 2508, 'John eats nothing but raw and expensive meat.', drs([A], [drs([B, C], [object(C, something, dom, na, na, na)-1, predicate(B, eat, A, C)-1])=>drs([D, E], [predicate(E, be, C, D)-1, property(D, expensive, pos)-1, property(D, raw, pos)-1, object(D, meat, mass, na, na, na)-1]), object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [eats]], [np, [det, [np, [det, [no]], [nbar, [n, ['$thing']]]], [but]], [nbar, [adj_coord, [adj, [raw]], [coord, [and]], [adj, [expensive]]], [nbar, [n, [meat]]]]]]]], ['.']]], '2007-11-12-19-16-05', '130.60.155.177', '').
text_drs_eval(1, 2509, 'There is a man X. Mary likes nobody but X.', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X']]]]]]], ['.']]|A], '2007-11-12-20-52-15', '130.60.155.177', 'Could be supported.').
text_drs_eval(0, 2510, 'There is a man. His brother sees himself.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, brother, countable, na, eq, 1)-2, predicate(C, see, B, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [brother]]]], [vp, [vbar, [v, [sees]], [np, [pn, [himself]]]]]], ['.']]], '2007-11-22-21-17-29', '130.60.206.7', '').
text_drs_eval(0, 2511, 'There is a man whose dog barks. The dog of the man sleeps.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, sleep, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]], [vp, [vbar, [v, sleeps]]]], '.']], '2008-07-30-17-57-20', '130.60.155.177', '').
text_drs_eval(0, 2512, 'There is a man whose dog barks. A dog of a man sleeps.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, object(D, dog, countable, na, eq, 1)-2, object(E, man, countable, na, eq, 1)-2, relation(D, of, E)-2, predicate(F, sleep, D)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [posspn, [whose]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [man]]]]]]], [vp, [vbar, [v, [sleeps]]]]], ['.']]], '2007-12-23-12-10-39', '130.60.204.35', '').
text_drs_eval(0, 2513, 'There is a man who sleeps in a bed in the morning. There is a man who sleeps in a bank. The man who sleeps in the morning is tired.', drs([A, B, C, D, E, F, G, H, I], [predicate(I, be, A, H)-3, property(H, tired, pos)-3, modifier_pp(G, in, F)-2, predicate(G, sleep, E)-2, object(F, bank, countable, na, eq, 1)-2, object(E, man, countable, na, eq, 1)-2, object(D, morning, countable, na, eq, 1)-1, modifier_pp(C, in, D)-1, modifier_pp(C, in, B)-1, predicate(C, sleep, A)-1, object(B, bed, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bed]]]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [morning]]]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [bank]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [morning]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [tired]]]]]]], ['.']]], '2007-11-13-14-51-28', '130.60.155.161', '').
text_drs_eval(0, 2514, 'There is a man who sleeps safely and soundly. There is a man who sleeps fitfully. The man who sleeps safely is happy.', drs([A, B, C, D, E, F], [predicate(F, be, A, E)-3, property(E, happy, pos)-3, modifier_adv(D, fitfully, pos)-2, predicate(D, sleep, C)-2, object(C, man, countable, na, eq, 1)-2, modifier_adv(B, soundly, pos)-1, modifier_adv(B, safely, pos)-1, predicate(B, sleep, A)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [adv_coord, [adv, [safely]], [coord, [and]], [adv, [soundly]]]]]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [adv, [fitfully]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [adv, [safely]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]], ['.']]], '2007-11-13-14-51-50', '130.60.155.161', '').
text_drs_eval(0, 2515, 'John sees a man who sleeps with his own eyes.', drs([A, B, C, D, E], [predicate(E, see, A, B)-1, modifier_pp(D, with, C)-1, predicate(D, sleep, B)-1, object(C, eye, countable, na, geq, 2)-1, relation(C, of, B)-1, object(B, man, countable, na, eq, 1)-1, object(A, 'John', named, na, eq, 1)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [comp, [who]], [vp, [vbar, [vbar, [v, [sleeps]]], [pp, [prep, [with]], [np, [posspn, ['{his own}']], [nbar, [n, [eyes]]]]]]]]]]]]], ['.']]], '2007-11-13-14-53-04', '130.60.155.161', '').
text_drs_eval(0, 2516, 'A man X1 of a man waits. The man X1 is happy.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, wait, A)-1, property(D, happy, pos)-2, predicate(E, be, A, D)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X1']], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X1']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-08-19-12-27-04', '130.60.204.40', '').
text_drs_eval(0, 2517, 'A man whose 3 dogs bark waits.', drs([], []), [], '2007-12-23-12-11-03', '130.60.204.35', '').
text_drs_eval(0, 2518, 'For everybody\'s dog there is a cake.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1])=>drs([C], [object(C, cake, countable, na, eq, 1)-1])]), [[specification, [top_s, [topic, [quant, ['{for}']], [np, [poss_np, [det, [every]], [nbar, [n, ['$body']]], [gen_marker, ['\'s']]], [nbar, [n, [dog]]]]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cake]]]]]]], ['.']]], '2007-11-20-17-51-19', '130.60.155.231', '').
text_drs_eval(0, 2519, 'A man hits a dog the bone of which is green.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, property(C, green, pos)-1, predicate(D, be, E, C)-1, relation(E, of, B)-1, object(E, bone, countable, na, eq, 1)-1, predicate(F, hit, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [hits]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [np, [det, [the]], [nbar, [n, [bone]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]]]]]]], ['.']]], '2007-11-20-11-27-03', '130.60.155.231', '').
text_drs_eval(0, 2520, 'A girl whose cat a mouse of which smiles eats waits.', drs([A, B, C, D, E, F], [object(A, girl, countable, na, eq, 1)-1, object(B, cat, countable, na, eq, 1)-1, object(C, mouse, countable, na, eq, 1)-1, relation(C, of, B)-1, predicate(D, smile, C)-1, relation(B, of, A)-1, predicate(E, eat, B)-1, predicate(F, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [girl]], [rel_cl, [np, [posspn, [whose]], [nbar, [n, [cat]], [rel_cl, [np, [det, [a]], [nbar, [n, [mouse]], [pp, [prep, [of]], [np, [relpn, [which]]]]]], [vp, [vbar, [v, [smiles]]]]]]], [vp, [vbar, [v, [eats]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-20-11-28-21', '130.60.155.231', '').
text_drs_eval(0, 2521, 'There is a company from who John awaits a delivery.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, company, countable, na, eq, 1)-1, object(C, delivery, countable, na, eq, 1)-1, predicate(D, await, A, C)-1, modifier_pp(D, from, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [company]], [rel_cl, [pp, [prep, [from]], [np, [relpn, [who]]]], [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [awaits]], [np, [det, [a]], [nbar, [n, [delivery]]]]], [pp, [[]]]]]]]]]], ['.']]], '2007-11-20-11-28-32', '130.60.155.231', '').
text_drs_eval(0, 2522, 'If a message is from someone from who John awaits a delivery then the message is important.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D, E, F], [object(B, message, countable, na, eq, 1)-1, object(C, somebody, countable, na, eq, 1)-1, object(D, delivery, countable, na, eq, 1)-1, predicate(E, await, A, D)-1, modifier_pp(E, from, C)-1, predicate(F, be, B)-1, modifier_pp(F, from, C)-1])=>drs([G, H], [property(G, important, pos)-1, predicate(H, be, B, G)-1])]), [[specification, [cond_s, [if], [s, [np, [det, [a]], [nbar, [n, [message]]]], [vp, [vbar, [v, [is]], [pp, [prep, [from]], [np, [det, [a]], [nbar, [n, ['$one']], [rel_cl, [pp, [prep, [from]], [np, [relpn, [who]]]], [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [awaits]], [np, [det, [a]], [nbar, [n, [delivery]]]]], [pp, [[]]]]]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [message]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [important]]]]]]]], ['.']]], '2007-11-20-11-29-07', '130.60.155.231', '').
text_drs_eval(0, 2523, 'There are some cards each of which is valid.', drs([A], [object(A, card, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [property(C, valid, pos)-1, predicate(D, be, B, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [which]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]], ['.']]], '2007-11-20-11-37-28', '130.60.155.231', '').
text_drs_eval(0, 2524, 'There are some cards each of which has a code.', drs([A], [object(A, card, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, code, countable, na, eq, 1)-1, predicate(D, have, B, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [which]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]]], ['.']]], '2007-11-20-11-37-29', '130.60.155.231', '').
text_drs_eval(0, 2525, 'There are some cards each of which John knows.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, card, countable, na, geq, 2)-1, drs([C], [has_part(B, C)-1])=>drs([D], [predicate(D, know, A, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [which]]]], [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [np, [[]]]]]]]]]], ['.']]], '2007-11-20-11-37-41', '130.60.155.231', '').
text_drs_eval(0, 2526, 'There are some cards the code of each of which is valid.', drs([A, B, C, D], [object(A, card, countable, na, geq, 2)-1, property(B, valid, pos)-1, predicate(C, be, D, B)-1, drs([E], [has_part(A, E)-1])=>drs([], [relation(D, of, E)-1]), object(D, code, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [det, [the]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [which]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]], ['.']]], '2007-11-20-11-38-06', '130.60.155.231', '').
text_drs_eval(0, 2527, 'There are some cards a code of each of which is valid.', drs([A, B, C, D], [object(A, card, countable, na, geq, 2)-1, object(B, code, countable, na, eq, 1)-1, drs([E], [has_part(A, E)-1])=>drs([], [relation(B, of, E)-1]), property(C, valid, pos)-1, predicate(D, be, B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [det, [a]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [which]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]]]]]], ['.']]], '2007-11-20-11-38-14', '130.60.155.231', '').
text_drs_eval(0, 2528, 'There are some cards a code of each of which has a date.', drs([A, B, C, D], [object(A, card, countable, na, geq, 2)-1, object(B, code, countable, na, eq, 1)-1, drs([E], [has_part(A, E)-1])=>drs([], [relation(B, of, E)-1]), object(C, date, countable, na, eq, 1)-1, predicate(D, have, B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [det, [a]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [which]]]]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [date]]]]]]]]]]], ['.']]], '2007-11-20-11-38-23', '130.60.155.231', '').
text_drs_eval(0, 2529, 'There are some cards a code of each of which John knows.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, card, countable, na, geq, 2)-1, object(C, code, countable, na, eq, 1)-1, drs([E], [has_part(B, E)-1])=>drs([], [relation(C, of, E)-1]), predicate(D, know, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [det, [a]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [which]]]]]]], [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [np, [[]]]]]]]]]], ['.']]], '2007-11-20-11-38-33', '130.60.155.231', '').
text_drs_eval(0, 2530, 'There are some cards each of who is valid.', drs([], []), [], '2007-11-20-11-39-25', '130.60.155.231', '').
text_drs_eval(0, 2531, 'There are some men each of which is rich.', drs([], []), [], '2007-11-20-11-39-36', '130.60.155.231', '').
text_drs_eval(0, 2532, 'There are some men each of who is rich.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [property(C, rich, pos)-1, predicate(D, be, B, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [who]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [rich]]]]]]]]]]], ['.']]], '2007-11-20-11-39-40', '130.60.155.231', '').
text_drs_eval(0, 2533, 'There are some cards each of who has a code.', drs([], []), [], '2007-11-20-11-39-56', '130.60.155.231', '').
text_drs_eval(0, 2534, 'There are some men each of who has a car.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, car, countable, na, eq, 1)-1, predicate(D, have, B, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [who]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [car]]]]]]]]]]], ['.']]], '2007-11-20-11-40-06', '130.60.155.231', '').
text_drs_eval(0, 2535, 'There are some men each of which has a car.', drs([], []), [], '2007-11-20-11-40-10', '130.60.155.231', '').
text_drs_eval(0, 2536, 'There are some cards each of who John knows.', drs([], []), [], '2007-11-20-11-40-24', '130.60.155.231', '').
text_drs_eval(0, 2537, 'There are some men each of who John knows.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, drs([C], [has_part(B, C)-1])=>drs([D], [predicate(D, know, A, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [quant, ['{each of}']], [np, [relpn, [who]]]], [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [np, [[]]]]]]]]]], ['.']]], '2007-11-20-11-40-29', '130.60.155.231', '').
text_drs_eval(0, 2538, 'There are some men each of which John knows.', drs([], []), [], '2007-11-20-11-40-34', '130.60.155.231', '').
text_drs_eval(0, 2539, 'There are some cards the code of each of who is valid.', drs([], []), [], '2007-11-20-11-40-46', '130.60.155.231', '').
text_drs_eval(0, 2540, 'There are some men the car of each of who is fast.', drs([A, B, C, D], [object(A, man, countable, na, geq, 2)-1, property(B, fast, pos)-1, predicate(C, be, D, B)-1, drs([E], [has_part(A, E)-1])=>drs([], [relation(D, of, E)-1]), object(D, car, countable, na, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [det, [the]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]]]]]], ['.']]], '2007-11-20-11-40-54', '130.60.155.231', '').
text_drs_eval(0, 2541, 'There are some men the car of each of which is fast.', drs([], []), [], '2007-11-20-11-41-02', '130.60.155.231', '').
text_drs_eval(0, 2542, 'There are some men a car of each of who is fast.', drs([A, B, C, D], [object(A, man, countable, na, geq, 2)-1, object(B, car, countable, na, eq, 1)-1, drs([E], [has_part(A, E)-1])=>drs([], [relation(B, of, E)-1]), property(C, fast, pos)-1, predicate(D, be, B, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [det, [a]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]]]]]], ['.']]], '2007-11-20-11-41-08', '130.60.155.231', '').
text_drs_eval(0, 2543, 'There are some men a car of each of who John drives.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-1, object(C, car, countable, na, eq, 1)-1, drs([E], [has_part(B, E)-1])=>drs([], [relation(C, of, E)-1]), predicate(D, drive, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [det, [a]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]], [np, [pname, ['John']]], [vp, [vbar, [v, [drives]], [np, [[]]]]]]]]]], ['.']]], '2007-11-20-11-41-36', '130.60.155.231', '').
text_drs_eval(0, 2544, 'A man invites some friends the car of the boss of each of who is faster than each of the cars of the friends.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, friend, countable, na, geq, 2)-1, drs([G], [has_part(C, G)-1])=>drs([H, I], [property(H, fast, comp_than, G)-1, predicate(I, be, D, H)-1]), relation(D, of, E)-1, object(D, car, countable, na, eq, 1)-1, object(E, boss, countable, na, eq, 1)-1, drs([J], [has_part(B, J)-1])=>drs([], [relation(E, of, J)-1]), relation(C, of, B)-1, object(C, car, countable, na, geq, 2)-1, predicate(F, invite, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [invites]], [np, [det, [some]], [nbar, [n, [friends]], [rel_cl, [np, [det, [the]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [boss]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [faster]], [conj, [than]], [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [cars]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [friends]]]]]]]]]]]]]]]]]], ['.']]], '2007-11-21-15-58-20', '130.60.206.6', '').
text_drs_eval(0, 2545, 'A man invites some friends the car of the boss of each of who is fast.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, object(B, friend, countable, na, geq, 2)-1, property(C, fast, pos)-1, predicate(D, be, E, C)-1, relation(E, of, F)-1, object(E, car, countable, na, eq, 1)-1, object(F, boss, countable, na, eq, 1)-1, drs([H], [has_part(B, H)-1])=>drs([], [relation(F, of, H)-1]), predicate(G, invite, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [invites]], [np, [det, [some]], [nbar, [n, [friends]], [rel_cl, [np, [det, [the]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [det, [the]], [nbar, [n, [boss]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]]]]]]], ['.']]], '2007-11-21-15-58-30', '130.60.206.6', '').
text_drs_eval(0, 2546, 'A man invites some friends a car of a boss of each of who is fast.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, object(B, friend, countable, na, geq, 2)-1, object(C, car, countable, na, eq, 1)-1, object(D, boss, countable, na, eq, 1)-1, drs([H], [has_part(B, H)-1])=>drs([], [relation(D, of, H)-1]), relation(C, of, D)-1, property(E, fast, pos)-1, predicate(F, be, C, E)-1, predicate(G, invite, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [invites]], [np, [det, [some]], [nbar, [n, [friends]], [rel_cl, [np, [det, [a]], [nbar, [n, [car]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [boss]], [pp, [prep, [of]], [np, [quant, ['{each of}']], [np, [relpn, [who]]]]]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [fast]]]]]]]]]]]], ['.']]], '2007-11-20-12-01-05', '130.60.155.231', '').
text_drs_eval(0, 2547, 'there are some cards a code of which that have which is valid.', drs([], []), [], '2007-12-18-11-30-16', '130.60.155.231', '').
text_drs_eval(0, 2548, 'there are some cards not each of which has a code.', drs([A], [object(A, card, countable, na, geq, 2)-1, -drs([], [drs([B], [has_part(A, B)-1])=>drs([C, D], [object(C, code, countable, na, eq, 1)-1, predicate(D, have, B, C)-1])])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [neg, [not]], [quant, ['{each of}']], [np, [relpn, [which]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]]], ['.']]], '2007-11-20-15-46-42', '130.60.155.231', '').
text_drs_eval(0, 2549, 'there are some cards a code of not each of which John knows.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, card, countable, na, geq, 2)-1, object(C, code, countable, na, eq, 1)-1, -drs([], [drs([E], [has_part(B, E)-1])=>drs([], [relation(C, of, E)-1])]), predicate(D, know, A, C)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cards]], [rel_cl, [np, [det, [a]], [nbar, [n, [code]], [pp, [prep, [of]], [np, [neg, [not]], [quant, ['{each of}']], [np, [relpn, [which]]]]]]], [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [np, [[]]]]]]]]]], ['.']]], '2007-11-20-15-46-44', '130.60.155.231', '').
text_drs_eval(0, 2550, 'There is a city in which John lives.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, city, countable, na, eq, 1)-1, predicate(C, live, A)-1, modifier_pp(C, in, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [city]], [rel_cl, [pp, [prep, [in]], [np, [relpn, [which]]]], [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [lives]]], [pp, [[]]]]]]]]]], ['.']]], '2007-11-20-15-50-06', '130.60.155.231', '').
text_drs_eval(0, 2551, 'There are some cities in each of which John lives.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, city, countable, na, geq, 2)-1, drs([C], [has_part(B, C)-1])=>drs([D], [predicate(D, live, A)-1, modifier_pp(D, in, B)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cities]], [rel_cl, [pp, [prep, [in]], [np, [quant, ['{each of}']], [np, [relpn, [which]]]]], [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [lives]]], [pp, [[]]]]]]]]]], ['.']]], '2007-12-18-12-01-34', '130.60.155.231', '').
text_drs_eval(0, 2552, 'John sees Mary and less than 2 men.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, has_part(E, B)-1, predicate(C, see, A, E)-1, [has_part(E, D)-1, object(D, man, countable, na, less, 2)-1], object(E, na, countable, na, eq, 2)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np_coord, [np, [pname, 'Mary']], [coord, and], [np, [nump, [genqu, 'less than'], 2], [nbar, [n, men]]]]]]]], '.']], '2009-03-02-11-31-27', '130.60.155.206', '').
text_drs_eval(0, 2553, 'There are less than 4 men and less than 3 women and a man and John.', drs([], []), [], '2008-01-03-16-30-03', '130.60.206.88', '').
text_drs_eval(0, 2554, 'Less than 3 men and less than 4 women wait.', drs([A, B, C, D], [[has_part(D, A)-1, object(A, man, countable, na, less, 3)-1], predicate(B, wait, D)-1, [has_part(D, C)-1, object(C, woman, countable, na, less, 4)-1], object(D, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [nump, [genqu, 'less than'], 3], [nbar, [n, men]]], [coord, and], [np, [nump, [genqu, 'less than'], 4], [nbar, [n, women]]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2009-03-02-11-32-47', '130.60.155.206', '').
text_drs_eval(0, 2555, 'More than 3 men and less than 4 women wait.', drs([A, B, C, D], [object(A, man, countable, na, greater, 3)-1, has_part(D, A)-1, predicate(B, wait, D)-1, [has_part(D, C)-1, object(C, woman, countable, na, less, 4)-1], object(D, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [nump, [genqu, 'more than'], 3], [nbar, [n, men]]], [coord, and], [np, [nump, [genqu, 'less than'], 4], [nbar, [n, women]]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2009-03-02-11-33-43', '130.60.155.206', '').
text_drs_eval(0, 2556, 'Less than 3 men and more than 4 women wait.', drs([A, B, C, D], [[has_part(D, A)-1, object(A, man, countable, na, less, 3)-1], predicate(B, wait, D)-1, object(C, woman, countable, na, greater, 4)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1]), [[specification, [s, [np_coord, [np, [nump, [genqu, 'less than'], 3], [nbar, [n, men]]], [coord, and], [np, [nump, [genqu, 'more than'], 4], [nbar, [n, women]]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2009-03-02-11-33-50', '130.60.155.206', '').
text_drs_eval(0, 2557, 'There is a man. He waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-22-17-48-19', '84.74.90.129', '').
text_drs_eval(0, 2558, 'There is a man. His card is correct.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, card, countable, na, eq, 1)-2, property(C, correct, pos)-2, predicate(D, be, B, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [card]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [correct]]]]]]], ['.']]], '2007-11-22-17-45-25', '84.74.90.129', '').
text_drs_eval(0, 2559, 'There is a man. John checks his card.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, relation(C, of, B)-2, object(C, card, countable, na, eq, 1)-2, predicate(D, check, A, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [checks]], [np, [posspn, [his]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-17-47-22', '84.74.90.129', '').
text_drs_eval(0, 2560, 'There is a man.John sees a card in his hand.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, relation(C, of, B)-2, object(C, hand, countable, na, eq, 1)-2, object(D, card, countable, na, eq, 1)-2, predicate(E, see, A, D)-2, modifier_pp(E, in, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [hand]]]]]]]], ['.']]], '2007-11-22-17-47-38', '84.74.90.129', '').
text_drs_eval(0, 2561, 'There is a man. His wife waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, wife, countable, na, eq, 1)-2, predicate(C, wait, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [wife]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-11-22-17-48-39', '84.74.90.129', '').
text_drs_eval(0, 2562, 'There is a man. He sees a card.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-2, predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-17-49-05', '84.74.90.129', '').
text_drs_eval(0, 2563, 'There is a man. His wife sees a card.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, wife, countable, na, eq, 1)-2, object(C, card, countable, na, eq, 1)-2, predicate(D, see, B, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [wife]]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-17-49-31', '84.74.90.129', '').
text_drs_eval(0, 2564, 'There is a man. He gives a card to a dog.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-2, object(C, dog, countable, na, eq, 1)-2, predicate(D, give, A, B, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-11-22-17-49-54', '84.74.90.129', '').
text_drs_eval(0, 2565, 'There is a man. John sees him.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-17-51-21', '84.74.90.129', '').
text_drs_eval(0, 2566, 'There is a man. His wife gives a card to a dog.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-2, object(B, wife, countable, na, eq, 1)-2, object(C, card, countable, na, eq, 1)-2, object(D, dog, countable, na, eq, 1)-2, predicate(E, give, B, C, D)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [posspn, [his]], [nbar, [n, [wife]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-11-22-17-51-59', '84.74.90.129', '').
text_drs_eval(0, 2567, 'There is a man. A clerk sees him.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, predicate(C, see, B, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [sees]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-17-52-18', '84.74.90.129', '').
text_drs_eval(0, 2568, 'There is a man. A clerk checks his card.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, card, countable, na, eq, 1)-2, predicate(D, check, B, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [checks]], [np, [posspn, [his]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-17-54-35', '84.74.90.129', '').
text_drs_eval(0, 2569, 'There is a man. A clerk sees a card in his hand.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, hand, countable, na, eq, 1)-2, object(D, card, countable, na, eq, 1)-2, predicate(E, see, B, D)-2, modifier_pp(E, in, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [hand]]]]]]]], ['.']]], '2007-11-22-17-54-42', '84.74.90.129', '').
text_drs_eval(0, 2570, 'There is a card. A clerk gives it to a cashier.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, object(C, cashier, countable, na, eq, 1)-2, predicate(D, give, B, A, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [gives]], [np, [pn, [it]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [cashier]]]]]]]], ['.']]], '2007-11-22-17-55-09', '84.74.90.129', '').
text_drs_eval(0, 2571, 'There is a man. A clerk gives a card to him.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, object(C, card, countable, na, eq, 1)-2, predicate(D, give, B, C, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-17-55-29', '84.74.90.129', '').
text_drs_eval(0, 2572, 'There is a man. A clerk gives his card to him.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, card, countable, na, eq, 1)-2, predicate(D, give, B, C, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [gives]], [np, [posspn, [his]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-17-56-06', '84.74.90.129', '').
text_drs_eval(0, 2573, 'There is a man. A clerk gives his own card to him.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, clerk, countable, na, eq, 1)-2, relation(C, of, B)-2, object(C, card, countable, na, eq, 1)-2, predicate(D, give, B, C, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [clerk]]]], [vp, [vbar, [v, [gives]], [np, [posspn, ['{his own}']], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [pn, [him]]]]]]], ['.']]], '2007-11-22-17-57-19', '84.74.90.129', '').
text_drs_eval(0, 2574, 'A man sees himself.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]], '.']], '2008-08-17-10-44-34', '84.74.167.232', '').
text_drs_eval(0, 2575, 'A woman enters her own card.', drs([A, B, C], [object(A, woman, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, enter, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [woman]]]], [vp, [vbar, [v, [enters]], [np, [posspn, ['{her own}']], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-17-57-54', '84.74.90.129', '').
text_drs_eval(0, 2576, 'A man is in his own garden.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, garden, countable, na, eq, 1)-1, predicate(C, be, A)-1, modifier_pp(C, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [posspn, ['{his own}']], [nbar, [n, [garden]]]]]]]], ['.']]], '2007-11-23-00-21-50', '130.60.206.7', '').
text_drs_eval(0, 2577, 'a man sees his card.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sees]], [np, [posspn, [his]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-18-03-25', '84.74.90.129', '').
text_drs_eval(0, 2578, 'a man is interested-in him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, ['interested-in']], [np, [pn, [him]]]]]]]], ['.']]], '2007-11-22-18-04-10', '84.74.90.129', '').
text_drs_eval(0, 2579, 'a man is seen by him.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [aux, [is]], [vbar, [v, [seen]], [by, [by]], [np, [pn, [him]]]]]], ['.']]], '2007-11-22-18-04-23', '84.74.90.129', '').
text_drs_eval(0, 2580, 'a man gives his card to a dog.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [posspn, [his]], [nbar, [n, [card]]]], [pp, [prep, [to]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']]], '2007-11-22-18-05-08', '84.74.90.129', '').
text_drs_eval(0, 2581, 'a man gives a dog his card.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [det, [a]], [nbar, [n, [dog]]]], [np, [posspn, [his]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-18-05-21', '84.74.90.129', '').
text_drs_eval(0, 2582, 'a man gives him a card.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [pn, [him]]], [np, [det, [a]], [nbar, [n, [card]]]]]]], ['.']]], '2007-11-22-18-05-51', '84.74.90.129', '').
text_drs_eval(0, 2583, 'a man sees a brother of him.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, brother, countable, na, eq, 1)-1, relation(B, of, B)-1, predicate(C, see, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, brother], [pp, [prep, of], [np, [pn, him]]]]]]]], '.']], '2008-10-23-14-45-37', '130.60.155.177', '').
text_drs_eval(0, 2584, 'a man of his group waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, group, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, wait, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man], [pp, [prep, of], [np, [posspn, his], [nbar, [n, group]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-23-14-45-47', '130.60.155.177', '').
text_drs_eval(0, 2585, 'A man gives his dog his card in his house.', drs([], []), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [gives]], [np, [posspn, [his]], [nbar, [n, [dog]]]], [np, [posspn, [his]], [nbar, [n, [card]]]]], [pp, [prep, [in]], [np, [posspn, [his]], [nbar, [n, [house]]]]]]]], ['.']]], '2007-11-22-18-07-43', '84.74.90.129', '').
text_drs_eval(0, 2586, 'There is a card. A man brings it its pencil and brings it his own computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, pencil, countable, na, eq, 1)-2, predicate(D, bring, B, C, A)-2, relation(E, of, B)-2, object(E, computer, countable, na, eq, 1)-2, predicate(F, bring, B, E, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, [its]], [nbar, [n, [pencil]]]]]], [coord, [and]], [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-12-05-13-57-13', '84.73.69.87', '').
text_drs_eval(0, 2587, 'There is a card. A man brings it its pencil and its computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, pencil, countable, na, eq, 1)-2, has_part(F, C)-2, predicate(D, bring, B, F, A)-2, relation(E, of, C)-2, object(E, computer, countable, na, eq, 1)-2, has_part(F, E)-2, object(F, na, countable, na, eq, 2)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, card]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, brings], [np, [pn, it]], [np_coord, [np, [posspn, its], [nbar, [n, pencil]]], [coord, and], [np, [posspn, its], [nbar, [n, computer]]]]]]], '.']], '2008-10-23-14-46-31', '130.60.155.177', '').
text_drs_eval(0, 2588, 'There is a card. A man brings it its pencil. The man brings it his own computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, pencil, countable, na, eq, 1)-2, predicate(D, bring, B, C, A)-2, relation(E, of, B)-3, object(E, computer, countable, na, eq, 1)-3, predicate(F, bring, B, E, C)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, [its]], [nbar, [n, [pencil]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]], ['.']]], '2007-11-23-00-22-14', '130.60.206.7', '').
text_drs_eval(0, 2589, 'There is a card. A man brings it its friend and offers it his own computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, friend, countable, na, eq, 1)-2, predicate(D, bring, B, C, A)-2, relation(E, of, B)-2, object(E, computer, countable, na, eq, 1)-2, predicate(F, offer, B, E, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, [its]], [nbar, [n, [friend]]]]]], [coord, [and]], [vp, [vbar, [v, [offers]], [np, [pn, [it]]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-11-23-00-22-37', '130.60.206.7', '').
text_drs_eval(0, 2590, 'There is a card. A man brings it its man and offers it his own computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, man, countable, na, eq, 1)-2, predicate(D, bring, B, C, A)-2, relation(E, of, B)-2, object(E, computer, countable, na, eq, 1)-2, predicate(F, offer, B, E, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, [its]], [nbar, [n, [man]]]]]], [coord, [and]], [vp, [vbar, [v, [offers]], [np, [pn, [it]]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-11-23-00-22-59', '130.60.206.7', '').
text_drs_eval(0, 2591, 'There is a card. A man brings it its pencil and offers it his own computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, pencil, countable, na, eq, 1)-2, predicate(D, bring, B, C, A)-2, relation(E, of, B)-2, object(E, computer, countable, na, eq, 1)-2, predicate(F, offer, B, E, C)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np, [posspn, [its]], [nbar, [n, [pencil]]]]]], [coord, [and]], [vp, [vbar, [v, [offers]], [np, [pn, [it]]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-11-23-00-23-12', '130.60.206.7', '').
text_drs_eval(0, 2592, 'There is a card. A man brings it its pencil and his own computer.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, pencil, countable, na, eq, 1)-2, has_part(F, C)-2, predicate(D, bring, B, F, A)-2, relation(E, of, B)-2, object(E, computer, countable, na, eq, 1)-2, has_part(F, E)-2, object(F, na, countable, na, eq, 2)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [card]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [pn, [it]]], [np_coord, [np, [posspn, [its]], [nbar, [n, [pencil]]]], [coord, [and]], [np, [posspn, ['{his own}']], [nbar, [n, [computer]]]]]]]], ['.']]], '2007-11-23-00-23-31', '130.60.206.7', '').
text_drs_eval(0, 2593, 'A man brings a dog it.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bring, A, B, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [det, [a]], [nbar, [n, [dog]]]], [np, [pn, [it]]]]]], ['.']]], '2007-12-04-13-24-42', '130.60.155.177', '').
text_drs_eval(0, 2594, 'There is a dog. A man brings the dog the dog.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, predicate(C, bring, B, A, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [det, [the]], [nbar, [n, [dog]]]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-12-04-13-25-02', '130.60.155.177', '').
text_drs_eval(0, 2595, 'There is a dog. The dog barks. A man brings the dog the dog.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-2, object(C, man, countable, na, eq, 1)-3, predicate(D, bring, C, A, A)-3]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]], ['.']], [specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [brings]], [np, [det, [the]], [nbar, [n, [dog]]]], [np, [det, [the]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-12-04-13-14-25', '130.60.155.177', '').
text_drs_eval(0, 2596, 'A man gives John at most 3 apples.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, [predicate(D, give, B, C, A)-1, object(C, apple, countable, na, leq, 3)-1]]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, gives], [np, [pname, 'John']], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, apples]]]]]]], '.']], '2009-03-02-11-33-58', '130.60.155.206', '').
text_drs_eval(0, 2597, 'A man gives at least 3 apples to John.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, apple, countable, na, geq, 3)-1, predicate(D, give, B, C, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [gives]], [np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [nbar, [n, [apples]]]], [pp, [prep, [to]], [np, [pname, ['John']]]]]]], ['.']]], '2007-12-04-13-16-57', '130.60.155.177', '').
text_drs_eval(0, 2598, 'A man brings a card its pencil and his own computer.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1/2, object(B, card, countable, na, eq, 1)-1/5, relation(C, of, B)-1/6, object(C, pencil, countable, na, eq, 1)-1/7, has_part(F, C)-1/'', predicate(D, bring, A, F, B)-1/3, relation(E, of, A)-1/9, object(E, computer, countable, na, eq, 1)-1/11, has_part(F, E)-1/'', object(F, na, countable, na, eq, 2)-1/'']), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, brings], [np, [det, a], [nbar, [n, card]]], [np_coord, [np, [posspn, its], [nbar, [n, pencil]]], [coord, and], [np, [posspn, 'his own'], [nbar, [n, computer]]]]]]]], '.']], '2013-08-15-18-02-59', '89.206.118.100', '').
text_drs_eval(0, 2599, 'There is a man who owns each of 3 dogs. The man who owns each of 3 dogs waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 3)-1, drs([D], [has_part(B, D)-1])=>drs([E], [predicate(E, own, A, D)-1]), predicate(C, wait, A)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [quant, ['{each of}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-04-14-15-56', '130.60.155.177', '').
text_drs_eval(0, 2600, 'There are 3 dogs. There is a man who owns each of the dogs. The man who owns each of the dogs waits.', drs([A, B, C], [object(A, dog, countable, na, eq, 3)-1, object(B, man, countable, na, eq, 1)-2, drs([D], [has_part(A, D)-2])=>drs([E], [predicate(E, own, B, D)-2]), predicate(C, wait, B)-3]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [dogs]]]]]]]]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [man]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [owns]], [np, [quant, ['{each of}']], [np, [det, [the]], [nbar, [n, [dogs]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-04-14-17-08', '130.60.155.177', '').
text_drs_eval(0, 2601, 'There is not each of 3 men.', drs([], []), [], '2007-12-04-14-36-05', '130.60.155.177', '').
text_drs_eval(0, 2602, 'Is every man a human?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/3])=>drs([B, C], [object(B, human, countable, na, eq, 1)-1/5, predicate(C, be, A, B)-1/1])]))]), [[sentence, [query, [question, is, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vcompl, [np, [det, a], [nbar, [n, human]]]]]]], ?], '.']], '2009-05-13-13-53-26', '130.60.155.193', '').
text_drs_eval(0, 2603, 'John tells Mary that he waits.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, tell, A, B)-1, predicate(D, wait, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [tells]], [np, [pname, ['Mary']], [rel_cl, [comp, [that]], [np, [pn, [he]]], [vp, [vbar, [v, [waits]], [np, [[]]]]]]]]]], ['.']]], '2007-12-23-12-11-23', '130.60.204.35', '').
text_drs_eval(0, 2604, 'What does who see?', drs([], [question(drs([A, B, C], [query(A, who)-1/3, query(B, what)-1/1, predicate(C, see, A, B)-1/4]))]), [[sentence, [query, [question, [np, [qpn, what]], does, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, see]]]]], ?], '.']], '2009-05-13-13-53-27', '130.60.155.193', '').
text_drs_eval(0, 2605, 'If there is a a cat, there is Mary and it appears that she wants to pet this cat but my cats don\'t like anybody.', drs([], []), [], '2007-12-06-13-49-31', '84.73.69.87', '').
text_drs_eval(0, 2606, 'Who eats and drinks?', drs([], [question(drs([A, B, C], [query(A, who)-1/1, predicate(B, eat, A)-1/2, predicate(C, drink, A)-1/4]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp_coord, [vp, [vbar, [vbar, [v, eats]]]], [coord, and], [vp, [vbar, [vbar, [v, drinks]]]]]], ?], '.']], '2009-05-13-13-53-29', '130.60.155.193', '').
text_drs_eval(0, 2607, 'A man eats quickly and quickly.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, eat, A)-1/3, modifier_adv(B, quickly, pos)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]], [vmod, [adv_coord, [adv, quickly], [coord, and], [adv, quickly]]]]]], '.']], '2011-07-20-10-11-15', '89.206.71.56', '').
text_drs_eval(0, 2608, 'A man eats how in a park?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/7, predicate(C, eat, A)-1/3, modifier_pp(C, in, B)-1/5, query(C, how)-1/4]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]], [vmod, [qpn, how], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]]]]], ?], '.']], '2009-05-13-13-53-30', '130.60.155.193', '').
text_drs_eval(0, 2609, 'A man eats how in a park in a morning?', drs([], [question(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/7, object(C, morning, countable, na, eq, 1)-1/10, predicate(D, eat, A)-1/3, modifier_pp(D, in, C)-1/8, modifier_pp(D, in, B)-1/5, query(D, how)-1/4]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]], [vmod, [qpn, how], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]], ?], '.']], '2009-05-13-13-53-31', '130.60.155.193', '').
text_drs_eval(0, 2610, 'A man eats in a park how in a morning?', drs([], [question(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/6, object(C, morning, countable, na, eq, 1)-1/10, predicate(D, eat, A)-1/3, modifier_pp(D, in, C)-1/8, query(D, how)-1/7, modifier_pp(D, in, B)-1/4]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [qpn, how], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]], ?], '.']], '2009-05-13-13-53-33', '130.60.155.193', '').
text_drs_eval(0, 2611, 'A man eats in a park in a morning how?', drs([], [question(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/6, object(C, morning, countable, na, eq, 1)-1/9, predicate(D, eat, A)-1/3, query(D, how)-1/10, modifier_pp(D, in, C)-1/7, modifier_pp(D, in, B)-1/4]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [qpn, how]]]]], ?], '.']], '2009-05-13-13-53-34', '130.60.155.193', '').
text_drs_eval(0, 2612, 'A man eats quickly and in a park.', drs([], []), [], '2009-05-22-10-49-43', '130.60.155.193', '').
text_drs_eval(0, 2613, 'A man eats quickly in a park.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, eat, A)-1, modifier_adv(C, quickly, pos)-1, modifier_pp(C, in, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [eats]]], [adv, [quickly]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]]]]], ['.']]], '2007-12-06-17-13-45', '130.60.155.177', '').
text_drs_eval(0, 2614, 'A man eats in a park quickly.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, eat, A)-1, modifier_pp(C, in, B)-1, modifier_adv(C, quickly, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [vbar, [v, [eats]]], [pp, [prep, [in]], [np, [det, [a]], [nbar, [n, [park]]]]], [adv, [quickly]]]]], ['.']]], '2007-12-06-17-13-57', '130.60.155.177', '').
text_drs_eval(0, 2615, 'A man eats in a park and quickly.', drs([], []), [], '2007-12-20-13-44-30', '130.60.155.231', '').
text_drs_eval(0, 2616, 'A man eats how quickly?', drs([], []), [], '2007-12-20-13-45-35', '130.60.155.231', '').
text_drs_eval(0, 2617, 'A man eats how and quickly?', drs([], []), [], '2007-12-20-13-46-01', '130.60.155.231', '').
text_drs_eval(0, 2618, 'A man eats quickly and how?', drs([], []), [], '2007-12-20-13-46-22', '130.60.155.231', '').
text_drs_eval(0, 2619, 'A man eats quickly how?', drs([], []), [], '2007-12-20-13-46-32', '130.60.155.231', '').
text_drs_eval(0, 2620, 'There is a man X1. The man X1 runs quickly where?', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X1']]]]]]], ['.']]|A], '2007-12-20-13-46-43', '130.60.155.231', '').
text_drs_eval(0, 2621, 'Who eats or sleeps?', drs([], [question(drs([A], [query(A, who)-1/1, drs([B], [predicate(B, eat, A)-1/2])v drs([C], [predicate(C, sleep, A)-1/4])]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp_coord, [vp, [vbar, [vbar, [v, eats]]]], [coord, or], [vp, [vbar, [vbar, [v, sleeps]]]]]], ?], '.']], '2009-05-13-13-53-35', '130.60.155.193', '').
text_drs_eval(0, 2622, 'John\'s height is 180cm.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, height, countable, na, eq, 1)-1, predicate(C, be, B, int(180, cm))-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], [gen_marker, ['\'s']]], [nbar, [n, [height]]]], [vp, [vbar, [v, [is]], [np, [measure_number, [int, [180]], [measure_noun, [cm]]]]]]], ['.']]], '2007-12-07-17-46-10', '130.60.155.231', '').
text_drs_eval(0, 2623, 'John lifts 50.5 kg.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, lift, A, real(50.5, kg))-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [lifts]], [np, [measure_number, [real, [50.5]], [measure_noun, [kg]]]]]]], ['.']]], '2007-12-07-17-46-18', '130.60.155.231', '').
text_drs_eval(0, 2624, 'The size of a box is 3cm * 44mm * 1m.', drs([A, B, C], [predicate(A, be, B, expr(*, expr(*, int(3, cm), int(44, mm)), int(1, m)))-1, relation(B, of, C)-1, object(C, box, countable, na, eq, 1)-1, object(B, size, countable, na, eq, 1)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [size]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [box]]]]]]], [vp, [vbar, [v, [is]], [np, [expr, [expr, [measure_number, [int, [3]], [measure_noun, [cm]]], [*], [measure_number, [int, [44]], [measure_noun, [mm]]]], [*], [measure_number, [int, [1]], [measure_noun, [m]]]]]]]], ['.']]], '2007-12-07-17-46-25', '130.60.155.231', '').
text_drs_eval(0, 2625, 'John\'s speed is 10sec/60m.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, speed, countable, na, eq, 1)-1, predicate(C, be, B, expr(/, int(10, s), int(60, m)))-1]), [[specification, [s, [np, [poss_np, [pname, ['John']], [gen_marker, ['\'s']]], [nbar, [n, [speed]]]], [vp, [vbar, [v, [is]], [np, [expr, [measure_number, [int, [10]], [measure_noun, [sec]]], [/], [measure_number, [int, [60]], [measure_noun, [m]]]]]]]], ['.']]], '2007-12-10-17-02-35', '130.60.155.231', '').
text_drs_eval(0, 2626, 'John enters [1,2,].', drs([], []), [], '2007-12-10-13-11-59', '130.60.155.231', '').
text_drs_eval(0, 2627, 'John enters {1,2,}.', drs([], []), [], '2007-12-10-13-12-18', '130.60.155.231', '').
text_drs_eval(0, 2628, 'There is who?', drs([], [question(drs([A], [query(A, who)-1/3]))]), [[sentence, [query, [question, [topic, [quant, 'there is'], [np, [qpn, who]]]], ?], '.']], '2009-05-13-13-53-37', '130.60.155.193', '').
text_drs_eval(0, 2629, 'A value is - 3 kg.', drs([A, B], [object(A, value, countable, na, eq, 1)-1, predicate(B, be, A, int(-3, kg))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [value]]]], [vp, [vbar, [v, [is]], [np, [measure_number, [int, [-3]], [measure_noun, [kg]]]]]]], ['.']]], '2007-12-10-13-05-34', '130.60.155.231', '').
text_drs_eval(0, 2630, 'A value is - 3.5 kg.', drs([A, B], [object(A, value, countable, na, eq, 1)-1, predicate(B, be, A, real(-3.5, kg))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [value]]]], [vp, [vbar, [v, [is]], [np, [measure_number, [real, [-3.5]], [measure_noun, [kg]]]]]]], ['.']]], '2007-12-10-13-05-39', '130.60.155.231', '').
text_drs_eval(0, 2631, 'There are 10 h of work.', drs([A], [object(A, work, mass, h, eq, 10)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measurement_np, [numberp, [gen_quant, [[]]], [number, [10]]], [measurement_nbar, [measure_noun, [h]], [pp, [prep, [of]], [nbar, [n, [work]]]]]]]], ['.']]], '2007-12-10-17-02-56', '130.60.155.231', '').
text_drs_eval(0, 2632, 'There is 1 h of work.', drs([A], [object(A, work, mass, h, eq, 1)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [measurement_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measurement_nbar, [measure_noun, [h]], [pp, [prep, [of]], [nbar, [n, [work]]]]]]]], ['.']]], '2007-12-10-17-03-03', '130.60.155.231', '').
text_drs_eval(0, 2633, 'A man has 2 t of apples.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, apple, countable, t, eq, 2)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [t]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]]]]], ['.']]], '2007-12-10-19-41-25', '130.60.155.177', '').
text_drs_eval(0, 2634, 'John has 3 Â°C.', drs([], []), [], '2007-12-29-17-44-58', '130.60.204.10', '').
text_drs_eval(0, 2635, 'Who does John not see?', drs([], [question(drs([], [-drs([A, B], [query(A, who)-1/1, predicate(B, see, named('John'), A)-1/5])]))]), [[sentence, [query, [question, [np, [qpn, who]], does, [np, [pname, 'John']], [vp, [aux, not], [vbar, [vcompl, [v, see]]]]], ?], '.']], '2009-05-13-13-53-37', '130.60.155.193', '').
text_drs_eval(0, 2636, 'Is it false that every man is a human?', drs([], [question(drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/6])=>drs([B, C], [object(B, human, countable, na, eq, 1)-1/9, predicate(C, be, A, B)-1/7])])]))]), [[sentence, [query, [question, [truth, 'is it false'], [cp, that, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, human]]]]]]]]], ?], '.']], '2009-05-13-13-53-38', '130.60.155.193', '').
text_drs_eval(0, 2637, 'Is it false that every man is a human.', drs([], []), [], '2007-12-10-19-40-09', '130.60.155.177', '').
text_drs_eval(0, 2638, 'Is it true that every man is a human.', drs([], []), [], '2007-12-10-19-40-17', '130.60.155.177', '').
text_drs_eval(0, 2639, 'A man has 2 mol of apples.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, apple, countable, mol, eq, 2)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [has]], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [mol]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]]]]], ['.']]], '2007-12-10-19-44-52', '130.60.155.177', '').
text_drs_eval(0, 2640, 'Is it true that John likes Mary?', drs([], [question(drs([A], [predicate(A, like, named('John'), named('Mary'))-1/6]))]), [[sentence, [query, [question, [truth, 'is it true'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]]]], ?], '.']], '2009-05-13-13-53-40', '130.60.155.193', '').
text_drs_eval(0, 2641, 'Is it false that John likes Mary?', drs([], [question(drs([], [-drs([A], [predicate(A, like, named('John'), named('Mary'))-1/6])]))]), [[sentence, [query, [question, [truth, 'is it false'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]]]], ?], '.']], '2009-05-13-13-53-40', '130.60.155.193', '').
text_drs_eval(0, 2642, 'Is it true that John likes Mary and that Mary likes Bill?', drs([], [question(drs([A, B], [predicate(A, like, named('John'), named('Mary'))-1/6, predicate(B, like, named('Mary'), named('Bill'))-1/11]))]), [[sentence, [query, [question, [truth, 'is it true'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]], [coord, and], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Bill']]]]]]]]]], ?], '.']], '2009-05-13-13-53-42', '130.60.155.193', '').
text_drs_eval(0, 2643, 'Is it true that John likes Mary and Mary likes Bill?', drs([], []), [], '2007-12-10-19-49-54', '130.60.155.177', '').
text_drs_eval(0, 2644, 'Is it false that John likes Mary and that no dog likes every cat?', drs([], [question(drs([], [-drs([A], [predicate(A, like, named('John'), named('Mary'))-1/6, drs([B], [object(B, dog, countable, na, eq, 1)-1/11])=>drs([], [-drs([], [drs([C], [object(C, cat, countable, na, eq, 1)-1/14])=>drs([D], [predicate(D, like, B, C)-1/12])])])])]))]), [[sentence, [query, [question, [truth, 'is it false'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]], [coord, and], [cp, that, [s, [np, [det, no], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [v, likes], [np, [det, every], [nbar, [n, cat]]]]]]]]]]], ?], '.']], '2009-05-13-13-53-44', '130.60.155.193', '').
text_drs_eval(0, 2645, 'John has each of 2.', drs([], []), [], '2007-12-14-17-11-14', '130.60.155.231', '').
text_drs_eval(0, 2646, '2 wait.', drs([], []), [[specification, [s, [np, [int, [2]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-12-14-17-11-21', '130.60.155.231', '').
text_drs_eval(0, 2647, 'It is false that a customer inserts a card.', drs([], [-drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, insert, A, B)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [customer]]]], [vp, [vbar, [v, [inserts]], [np, [det, [a]], [nbar, [n, [card]]]]]]]]], ['.']]], '2007-12-14-16-58-58', '130.60.155.177', '').
text_drs_eval(0, 2648, 'It is false that some men wait.', drs([], [-drs([A, B], [object(A, man, countable, na, geq, 2)-1, predicate(B, wait, A)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [some]], [nbar, [n, [men]]]], [vp, [vbar, [v, [wait]]]]]]], ['.']]], '2007-12-14-17-00-20', '130.60.155.177', '').
text_drs_eval(0, 2649, 'It is false that everybody sees somebody.', drs([], [-drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B, C], [object(B, somebody, countable, na, eq, 1)-1, predicate(C, see, A, B)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, ['$body']]]], [vp, [vbar, [v, [sees]], [np, [det, [a]], [nbar, [n, ['$body']]]]]]]]], ['.']]], '2007-12-14-17-00-38', '130.60.155.177', '').
text_drs_eval(0, 2650, 'It is false that it is false that a man waits.', drs([], [-drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2007-12-14-17-01-40', '130.60.155.177', '').
text_drs_eval(0, 2651, 'It is false that if there is someone then he waits.', drs([], [-drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [predicate(B, wait, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, ['$one']]]]]], [then], [s, [np, [pn, [he]]], [vp, [vbar, [v, [waits]]]]]]]], ['.']]], '2007-12-14-17-01-57', '130.60.155.177', '').
text_drs_eval(0, 2652, 'It is false that there is some water.', drs([], [-drs([A], [object(A, water, mass, na, na, na)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [some]], [nbar, [n, [water]]]]]]]], ['.']]], '2007-12-14-17-02-52', '130.60.155.177', '').
text_drs_eval(0, 2653, 'It is false that no man does not wait.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [-drs([B], [predicate(B, wait, A)-1])])])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [no]], [nbar, [n, [man]]]], [vp, [aux, ['{does not}']], [vbar, [v, [wait]]]]]]], ['.']]], '2007-12-14-17-03-16', '130.60.155.177', '').
text_drs_eval(0, 2654, 'It is false that a man waits and a dog barks.', drs([A, B], [-drs([C, D], [object(C, man, countable, na, eq, 1)-1, predicate(D, wait, C)-1]), object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-12-14-17-03-37', '130.60.155.177', '').
text_drs_eval(0, 2655, 'It is false that there is a man and a dog barks.', drs([A, B], [-drs([C], [object(C, man, countable, na, eq, 1)-1]), object(A, dog, countable, na, eq, 1)-1, predicate(B, bark, A)-1]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]], ['.']]], '2007-12-14-17-03-58', '130.60.155.177', '').
text_drs_eval(0, 2656, 'It is false that a man who waits or who eats runs and sleeps.', drs([], [-drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, drs([D], [predicate(D, wait, A)-1])v drs([E], [predicate(E, eat, A)-1]), predicate(B, run, A)-1, predicate(C, sleep, A)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp_coord, [vp, [vbar, [v, [runs]]]], [coord, [and]], [vp, [vbar, [v, [sleeps]]]]]]]], ['.']]], '2007-12-14-17-04-28', '130.60.155.177', '').
text_drs_eval(0, 2657, 'It is false that a man who waits or who eats runs or sleeps.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])v drs([C], [predicate(C, eat, A)-1]), drs([D], [predicate(D, run, A)-1])v drs([E], [predicate(E, sleep, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp_coord, [vp, [vbar, [v, [runs]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]]]]], ['.']]], '2007-12-14-17-05-00', '130.60.155.177', '').
text_drs_eval(0, 2658, 'It is false that a man who waits or who eats runs or sleeps and barks.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, wait, A)-1])v drs([C], [predicate(C, eat, A)-1]), drs([D], [predicate(D, run, A)-1])v drs([E, F], [predicate(E, sleep, A)-1, predicate(F, bark, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp_coord, [vp, [vbar, [v, [runs]]]], [coord, [or]], [vp_coord, [vp, [vbar, [v, [sleeps]]]], [coord, [and]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2007-12-14-17-05-33', '130.60.155.177', '').
text_drs_eval(0, 2659, 'It is false that a man who waits or who eats runs or sleeps ,and barks.', drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C], [predicate(C, wait, A)-1])v drs([D], [predicate(D, eat, A)-1]), drs([E], [predicate(E, run, A)-1])v drs([F], [predicate(F, sleep, A)-1]), predicate(B, bark, A)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [waits]]]]], [coord, [or]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [eats]]]]]]]], [vp_coord, [vp_coord, [vp, [vbar, [v, [runs]]]], [coord, [or]], [vp, [vbar, [v, [sleeps]]]]], [coord, ['{, and}']], [vp, [vbar, [v, [barks]]]]]]]], ['.']]], '2007-12-14-17-06-07', '130.60.155.177', '').
text_drs_eval(0, 2660, 'It is false that there is a dog ,and there is a man or there is a woman ,and there is a cat.', drs([A], [-drs([B], [object(B, dog, countable, na, eq, 1)-1]), drs([C], [object(C, man, countable, na, eq, 1)-1])v drs([D], [object(D, woman, countable, na, eq, 1)-1]), object(A, cat, countable, na, eq, 1)-1]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], [coord, ['{, and}']], [s_coord, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [coord, ['{, and}']], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2007-12-14-17-06-35', '130.60.155.177', '').
text_drs_eval(0, 2661, 'It is false that there is a dog ,and that there is a man or that there is a woman ,and there is a cat.', drs([A], [-drs([B], [object(B, dog, countable, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])v drs([D], [object(D, woman, countable, na, eq, 1)-1])]), object(A, cat, countable, na, eq, 1)-1]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, ['{, and}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]], [coord, [or]], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]]]]], [coord, ['{, and}']], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-12-14-17-07-31', '130.60.155.177', '').
text_drs_eval(0, 2662, 'It is false that there is a dog ,and that there is a man or that there is a woman ,and that there is a cat.', drs([], [-drs([A, B], [object(A, dog, countable, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])v drs([D], [object(D, woman, countable, na, eq, 1)-1]), object(B, cat, countable, na, eq, 1)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, ['{, and}']], [s_coord, [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]], [coord, [or]], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]]], [coord, ['{, and}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]], ['.']]], '2007-12-14-17-08-12', '130.60.155.177', '').
text_drs_eval(0, 2663, 'It is false that there is a dog A. There is a man C or there is a woman E. It is false that there is a cat G.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1]), drs([B], [object(B, man, countable, na, eq, 1)-2])v drs([C], [object(C, woman, countable, na, eq, 1)-2]), -drs([D], [object(D, cat, countable, na, eq, 1)-3])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]], [appos, [var, ['A']]]]]]]]], ['.']], [specification, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['C']]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]], [appos, [var, ['E']]]]]]]], ['.']], [specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]], [appos, [var, ['G']]]]]]]]], ['.']]], '2007-12-14-17-11-00', '130.60.155.177', '').
text_drs_eval(0, 2664, 'It is false that there is a man ,and that the man sleeps or that the man waits.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, sleep, A)-1])v drs([C], [predicate(C, wait, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]], [coord, ['{, and}']], [s_coord, [cp, ['_that_'], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]]], [coord, [or]], [cp, ['_that_'], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2007-12-14-17-11-23', '130.60.155.177', '').
text_drs_eval(0, 2665, 'It is false that there is a dog and that it is false that there is a cat.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1, -drs([B], [object(B, cat, countable, na, eq, 1)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [and]], [cp, ['_that_'], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]]]], ['.']]], '2007-12-14-17-11-56', '130.60.155.177', '').
text_drs_eval(0, 2666, 'It is false that John runs. He walks.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, -drs([C], [predicate(C, run, A)-1]), predicate(B, walk, A)-2]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [runs]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2007-12-14-17-12-19', '130.60.155.177', '').
text_drs_eval(0, 2667, 'It is false that for every book the book has a title and the book has a code.', drs([], [-drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, title, countable, na, eq, 1)-1, predicate(C, have, A, B)-1, object(D, code, countable, na, eq, 1)-1, predicate(E, have, A, D)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{for}']], [np, [det, [every]], [nbar, [n, [book]]]]], [s_coord, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [title]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]]], ['.']]], '2007-12-14-17-12-50', '130.60.155.177', '').
text_drs_eval(0, 2668, 'It is false that if there is a book then the book has a title and the book has a code.', drs([], [-drs([], [drs([A], [object(A, book, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, title, countable, na, eq, 1)-1, predicate(C, have, A, B)-1, object(D, code, countable, na, eq, 1)-1, predicate(E, have, A, D)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [book]]]]]], [then], [s_coord, [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [title]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [book]]]], [vp, [vbar, [v, [has]], [np, [det, [a]], [nbar, [n, [code]]]]]]]]]]], ['.']]], '2007-12-14-17-13-14', '130.60.155.177', '').
text_drs_eval(0, 2669, 'It is false that there is a man and that there is a dog or that there is a cat.', drs([], [-drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1])v drs([C], [object(C, cat, countable, na, eq, 1)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [and]], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]], [coord, [or]], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2007-12-14-17-13-32', '130.60.155.177', '').
text_drs_eval(0, 2670, 'It is false that there is a man and that there is a dog or there is a cat.', drs([], [drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1])])v drs([C], [object(C, cat, countable, na, eq, 1)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [and]], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-12-14-17-14-27', '130.60.155.177', '').
text_drs_eval(0, 2671, 'It is false that there is a man ,and there is a dog or there is a cat.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1]), drs([B], [object(B, dog, countable, na, eq, 1)-1])v drs([C], [object(C, cat, countable, na, eq, 1)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [coord, ['{, and}']], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2007-12-14-17-14-50', '130.60.155.177', '').
text_drs_eval(0, 2672, 'It is false that John likes a dog ,and that a cat and a rat and a mouse see a cheese ,or that a man waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([], [drs([B, C, D, E, F, G, H, I], [object(B, dog, countable, na, eq, 1)-1, predicate(C, like, A, B)-1, object(D, cat, countable, na, eq, 1)-1, has_part(I, D)-1, object(E, cheese, countable, na, eq, 1)-1, predicate(F, see, I, E)-1, object(G, rat, countable, na, eq, 1)-1, has_part(I, G)-1, object(H, mouse, countable, na, eq, 1)-1, has_part(I, H)-1, object(I, na, countable, na, eq, 3)-1])v drs([J, K], [object(J, man, countable, na, eq, 1)-1, predicate(K, wait, J)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [s_coord, [s_coord, [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], [coord, ['{, and}']], [cp, ['_that_'], [s, [np_coord, [np, [det, [a]], [nbar, [n, [cat]]]], [coord, [and]], [np_coord, [np, [det, [a]], [nbar, [n, [rat]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [mouse]]]]]], [vp, [vbar, [v, [see]], [np, [det, [a]], [nbar, [n, [cheese]]]]]]]]], [coord, ['{, or}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]]], ['.']]], '2007-12-14-17-15-42', '130.60.155.177', '').
text_drs_eval(0, 2673, 'It is false that John runs. John walks.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, -drs([C], [predicate(C, run, A)-1]), predicate(B, walk, A)-2]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [runs]]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [walks]]]]], ['.']]], '2007-12-14-17-15-59', '130.60.155.177', '').
text_drs_eval(0, 2674, 'It is false that John walks. He runs.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, -drs([C], [predicate(C, walk, A)-1]), predicate(B, run, A)-2]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [walks]]]]]]], ['.']], [specification, [s, [np, [pn, [he]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2007-12-14-17-16-16', '130.60.155.177', '').
text_drs_eval(0, 2675, 'John walks. It is false that John runs.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, walk, A)-1, -drs([C], [predicate(C, run, A)-2])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [walks]]]]], ['.']], [specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [runs]]]]]]], ['.']]], '2007-12-14-17-16-31', '130.60.155.177', '').
text_drs_eval(0, 2676, 'It is false that there are 2 kg of dirty laundry.', drs([], [-drs([A], [object(A, laundry, mass, kg, eq, 2)-1, property(A, dirty, pos)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there are}']], [measurement_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measurement_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [dirty]], [nbar, [n, [laundry]]]]]]]]]]], ['.']]], '2007-12-14-17-16-46', '130.60.155.177', '').
text_drs_eval(0, 2677, 'It is false that there is a man or there is a dog.', drs([], [drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1])])v drs([B], [object(B, dog, countable, na, eq, 1)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-12-14-17-17-03', '130.60.155.177', '').
text_drs_eval(0, 2678, 'It is false that there is a man or that there is a dog.', drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([B], [object(B, dog, countable, na, eq, 1)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]], [coord, [or]], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]], ['.']]], '2007-12-14-17-17-19', '130.60.155.177', '').
text_drs_eval(0, 2679, 'It is false that it is not provable that John flies.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([], [~drs([B], [predicate(B, fly, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [modality, [naf, ['{it is not provable}']], [cp, ['_that_'], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [flies]]]]]]]]], ['.']]], '2007-12-14-17-17-44', '130.60.155.177', '').
text_drs_eval(0, 2680, 'It is false that everybody waits.', drs([], [-drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([B], [predicate(B, wait, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [every]], [nbar, [n, ['$body']]]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2007-12-14-17-18-03', '130.60.155.177', '').
text_drs_eval(0, 2681, 'It is false that it is necessary that John waits and that Mary sleeps.', drs([], [-drs([], [must(drs([A, B], [predicate(A, wait, named('John'))-1/10, predicate(B, sleep, named('Mary'))-1/14]))])]), [[specification, [s, [neg, 'it is false'], [cp, that, [s, [necessity, 'it is necessary'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], [coord, and], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]]]], '.']], '2010-10-27-09-29-37', '89.206.64.27', '').
text_drs_eval(0, 2682, 'If John does not eat and it is false that somebody feeds him then John is hungry.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([], [-drs([B], [predicate(B, eat, A)-1]), -drs([C, D], [object(C, somebody, countable, na, eq, 1)-1, predicate(D, feed, C, A)-1])])=>drs([E, F], [property(E, hungry, pos)-1, predicate(F, be, A, E)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [pname, ['John']]], [vp, [aux, ['{does not}']], [vbar, [v, [eat]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, ['$body']]]], [vp, [vbar, [v, [feeds]], [np, [pn, [him]]]]]]]]], [then], [s, [np, [pname, ['John']]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [hungry]]]]]]]], ['.']]], '2007-12-14-17-19-19', '130.60.155.177', '').
text_drs_eval(0, 2683, 'Zürich is a not Köln.', drs([], []), [], '2007-12-29-17-42-35', '130.60.204.10', '').
text_drs_eval(0, 2684, 'John is not happy.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([B, C], [property(B, happy, pos)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is, not], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-07-30-01-15-12', '130.60.204.7', '').
text_drs_eval(0, 2685, 'Who does not see himself?', drs([], [question(drs([A], [query(A, who)-1/1, -drs([B], [predicate(B, see, A, A)-1/4])]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, does, not], [vbar, [vcompl, [v, see], [np, [pn, himself]]]]]], ?], '.']], '2009-05-13-13-53-46', '130.60.155.193', '').
text_drs_eval(0, 2686, 'Everybody is not seen by who?', drs([], [question(drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [query(B, who)-1/7, predicate(C, see, B, A)-1/5])])]))]), [[sentence, [query, [question, [np, [pn, everybody]], [vp, [aux, is, not], [vbar, [vcompl, [v, seen], by, [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-53-47', '130.60.155.193', '').
text_drs_eval(0, 2687, 'Who sees who who does not see himself?', drs([], []), [], '2008-09-23-08-52-16', '130.60.155.206', '').
text_drs_eval(0, 2688, 'Who does not see who who does not see himself?', drs([], []), [], '2008-09-23-08-52-24', '130.60.155.206', '').
text_drs_eval(0, 2689, 'John does wait.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [aux, [does]], [vbar, [v, [wait]]]]], ['.']]], '2007-12-15-14-49-21', '130.60.206.19', '').
text_drs_eval(0, 2690, 'John does like Mary.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, like, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [aux, [does], ['']], [vbar, [v, [like]], [np, [pname, ['Mary']]]]]], ['.']]], '2007-12-26-17-16-25', '130.60.206.5', '').
text_drs_eval(0, 2691, 'It is false that there is a dog. There is a man or there is a woman ,and it is false that there is a cat.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1]), drs([B], [object(B, man, countable, na, eq, 1)-2])v drs([C], [object(C, woman, countable, na, eq, 1)-2]), -drs([D], [object(D, cat, countable, na, eq, 1)-2])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']], [specification, [s_coord, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [coord, ['{, and}']], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2007-12-15-19-55-23', '130.60.155.177', '').
text_drs_eval(0, 2692, 'It is false that there is a dog ,and there is a man or there is a woman ,and it is false that there is a cat.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1]), drs([B], [object(B, man, countable, na, eq, 1)-1])v drs([C], [object(C, woman, countable, na, eq, 1)-1]), -drs([D], [object(D, cat, countable, na, eq, 1)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], [coord, ['{, and}']], [s_coord, [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [coord, ['{, and}']], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]]], ['.']]], '2007-12-15-20-00-00', '130.60.155.177', '').
text_drs_eval(0, 2693, 'It is false that a man sleeps or waits.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1, drs([B], [predicate(B, sleep, A)-1])v drs([C], [predicate(C, wait, A)-1])])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp_coord, [vp, [vbar, [v, [sleeps]]]], [coord, [or]], [vp, [vbar, [v, [waits]]]]]]]], ['.']]], '2007-12-15-20-00-32', '130.60.155.177', '').
text_drs_eval(0, 2694, 'It is false that there is a man and the man sleeps or the man waits.', drs([], [drs([A, B], [-drs([C], [object(C, man, countable, na, eq, 1)-1]), predicate(A, sleep, B)-1, object(B, man, countable, na, eq, 1)-1])v drs([D], [predicate(D, wait, B)-1])]), [[specification, [s_coord, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]]], [coord, [or]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-12-15-20-03-35', '130.60.155.177', '').
text_drs_eval(0, 2695, 'It is false that there is a man ,and the man sleeps or the man waits.', drs([], [-drs([A], [object(A, man, countable, na, eq, 1)-1]), drs([B, C], [predicate(B, sleep, C)-1, object(C, man, countable, na, eq, 1)-1])v drs([D], [predicate(D, wait, C)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [coord, ['{, and}']], [s_coord, [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]], [coord, [or]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]], ['.']]], '2007-12-15-20-06-30', '130.60.155.177', '').
text_drs_eval(0, 2696, 'It is false that there is a man and a man sleeps or the man waits.', drs([], [drs([A, B], [-drs([C], [object(C, man, countable, na, eq, 1)-1]), object(A, man, countable, na, eq, 1)-1, predicate(B, sleep, A)-1])v drs([D], [predicate(D, wait, A)-1])]), [[specification, [s_coord, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]], [coord, [and]], [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [sleeps]]]]]], [coord, [or]], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-12-15-20-08-57', '130.60.155.177', '').
text_drs_eval(0, 2697, 'It is false that there is a man and a man sleeps or that the man waits.', drs([], []), [], '2007-12-15-20-09-19', '130.60.155.177', '').
text_drs_eval(0, 2698, 'It is false that there is a dog and it is false that there is a cat.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1]), -drs([B], [object(B, cat, countable, na, eq, 1)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], [coord, [and]], [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]]], ['.']]], '2007-12-15-20-09-48', '130.60.155.177', '').
text_drs_eval(0, 2699, 'It is false that there is a dog. It is false that there is a cat.', drs([], [-drs([A], [object(A, dog, countable, na, eq, 1)-1]), -drs([B], [object(B, cat, countable, na, eq, 1)-2])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]], ['.']], [specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]]], ['.']]], '2007-12-15-20-10-08', '130.60.155.177', '').
text_drs_eval(0, 2700, 'It is false that a man waits and that a dog barks.', drs([], [-drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, bark, C)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [s, [np, [det, [a]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2007-12-15-20-10-28', '130.60.155.177', '').
text_drs_eval(0, 2701, 'It is false that there is a man and that a dog barks.', drs([], [-drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, bark, B)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2007-12-15-20-10-51', '130.60.155.177', '').
text_drs_eval(0, 2702, 'It is false that there is a dog ,and that there is a man or there is a woman ,and there is a cat.', drs([A], [drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1])])v drs([D], [object(D, woman, countable, na, eq, 1)-1]), object(A, cat, countable, na, eq, 1)-1]), [[specification, [s_coord, [s_coord, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]], [coord, ['{, and}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [coord, ['{, and}']], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-12-15-20-11-21', '130.60.155.177', '').
text_drs_eval(0, 2703, 'Which man waits?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, predicate(B, wait, A)-1/3]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-13-53-49', '130.60.155.193', '').
text_drs_eval(0, 2704, 'John sees which man?', drs([], [question(drs([A, B], [query(A, which)-1/3, object(A, man, countable, na, eq, 1)-1/4, predicate(B, see, named('John'), A)-1/2]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [qdet, which], [nbar, [n, man]]]]]]], ?], '.']], '2009-05-13-13-53-49', '130.60.155.193', '').
text_drs_eval(0, 2705, 'A man the card of who is valid or who is green and who is happy waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, drs([C, D, E], [property(C, valid, pos)-1, predicate(D, be, E, C)-1, relation(E, of, A)-1, object(E, card, countable, na, eq, 1)-1])v drs([F, G, H, I], [property(F, green, pos)-1, predicate(G, be, A, F)-1, property(H, happy, pos)-1, predicate(I, be, A, H)-1]), predicate(B, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl_coord, [rel_cl, [np, [det, [the]], [nbar, [n, [card]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [valid]]]]]]], [coord, [or]], [rel_cl_coord, [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [green]]]]]]], [coord, [and]], [rel_cl, [np, [relpn, [who]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [happy]]]]]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-17-14-32-30', '130.60.155.231', '').
text_drs_eval(0, 2706, 'Which men wait?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, man, countable, na, geq, 2)-1/2, predicate(B, wait, A)-1/3]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-53-51', '130.60.155.193', '').
text_drs_eval(0, 2707, 'Which man eats and drinks?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, predicate(B, eat, A)-1/3, predicate(C, drink, A)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp_coord, [vp, [vbar, [vbar, [v, eats]]]], [coord, and], [vp, [vbar, [vbar, [v, drinks]]]]]], ?], '.']], '2009-05-13-13-53-51', '130.60.155.193', '').
text_drs_eval(0, 2708, 'There is which man?', drs([], [question(drs([A], [query(A, which)-1/3, object(A, man, countable, na, eq, 1)-1/4]))]), [[sentence, [query, [question, [topic, [quant, 'there is'], [np, [qdet, which], [nbar, [n, man]]]]], ?], '.']], '2009-05-13-13-53-53', '130.60.155.193', '').
text_drs_eval(0, 2709, 'A man 3 dogs of who bark waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 3)-1, relation(B, of, A)-1, predicate(C, bark, B)-1, predicate(D, wait, A)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [man]], [rel_cl, [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [dogs]], [pp, [prep, [of]], [np, [relpn, [who]]]]]], [vp, [vbar, [v, [bark]]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-17-17-00-17', '130.60.155.231', '').
text_drs_eval(0, 2710, 'Which man does not wait?', drs([], [question(drs([A], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, -drs([B], [predicate(B, wait, A)-1/5])]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-53-54', '130.60.155.193', '').
text_drs_eval(0, 2711, 'John does not own which car?', drs([], [question(drs([], [-drs([A, B], [query(A, which)-1/5, object(A, car, countable, na, eq, 1)-1/6, predicate(B, own, named('John'), A)-1/4])]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vcompl, [v, own], [np, [qdet, which], [nbar, [n, car]]]]]]], ?], '.']], '2009-05-13-13-53-55', '130.60.155.193', '').
text_drs_eval(0, 2712, 'Which dog of John barks?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, dog, countable, na, eq, 1)-1/2, relation(A, of, named('John'))-1/3, predicate(B, bark, A)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, dog], [pp, [prep, of], [np, [pname, 'John']]]]], [vp, [vbar, [vbar, [v, barks]]]]], ?], '.']], '2009-05-13-13-53-57', '130.60.155.193', '').
text_drs_eval(0, 2713, 'There is a man X. Which man X waits?', drs([], []), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]], [appos, [var, ['X']]]]]]], ['.']], [query, [question, [np, [qdet, [which]], [nbar, [n, [man]], [appos, [var, ['X']]]]], [vp, [vbar, [v, [waits]]]]], [?]]], '2007-12-17-17-16-16', '130.60.155.177', '').
text_drs_eval(0, 2714, 'Whose dogs wait?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, dog, countable, na, geq, 2)-1/2, predicate(C, wait, B)-1/3]))]), [[sentence, [query, [question, [np, [qdet, whose], [nbar, [n, dogs]]], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-53-58', '130.60.155.193', '').
text_drs_eval(0, 2715, 'Whose article whose title is "ACE" does Mary read?', drs([], [question(drs([A, B, C, D, E], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, article, countable, na, eq, 1)-1/2, object(C, title, countable, na, eq, 1)-1/4, relation(C, of, B)-1/3, predicate(D, be, C, string('ACE'))-1/5, predicate(E, read, named('Mary'), B)-1/9]))]), [[query, [question, [np, [qdet, whose], [nbar, [n, article], [rel_cl, [np, [posspn, whose], [nbar, [n, title]]], [vp, [aux, is], [np, [string, '"ACE"']]]]]], does, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, read]]]]], ?]], '2010-11-12-08-51-39', '89.206.69.32', '').
text_drs_eval(0, 2716, 'Whose article whose title is "ACE" is given to Mary by who?', drs([], [question(drs([A, B, C, D, E, F], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, article, countable, na, eq, 1)-1/2, object(C, title, countable, na, eq, 1)-1/4, relation(C, of, B)-1/3, predicate(D, be, C, string('ACE'))-1/5, query(E, who)-1/12, predicate(F, give, E, B, named('Mary'))-1/8]))]), [[query, [question, [np, [qdet, whose], [nbar, [n, article], [rel_cl, [np, [posspn, whose], [nbar, [n, title]]], [vp, [aux, is], [np, [string, '"ACE"']]]]]], [vp, [aux, is], [vbar, [vcompl, [v, given], [prep, to], [np, [pname, 'Mary']], by, [np, [qpn, who]]]]]], ?]], '2010-11-12-08-51-45', '89.206.69.32', '').
text_drs_eval(0, 2717, 'An item is given to who?', drs([], [question(drs([A, B, C, D], [object(A, item, countable, na, eq, 1)-1/2, query(B, who)-1/6, property(C, given, pos)-1/4, predicate(D, be, A, C)-1/3, modifier_pp(D, to, B)-1/5]))]), [[sentence, [query, [question, [np, [det, an], [nbar, [n, item]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, given]]]], [vmod, [pp, [prep, to], [np, [qpn, who]]]]]]], ?], '.']], '2009-05-13-13-54-02', '130.60.155.193', '').
text_drs_eval(0, 2718, 'Which dogs of John bark?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, dog, countable, na, geq, 2)-1/2, relation(A, of, named('John'))-1/3, predicate(B, bark, A)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, dogs], [pp, [prep, of], [np, [pname, 'John']]]]], [vp, [vbar, [vbar, [v, bark]]]]], ?], '.']], '2009-05-13-13-54-04', '130.60.155.193', '').
text_drs_eval(1, 2719, 'Which laundry is clean?', drs([A, B, C], [query(A, which)-1, object(A, laundry, countable, na, eq, 1)-1, property(B, clean, pos)-1, predicate(C, be, A, B)-1]), [[query, [question, [np, [qdet, [which]], [nbar, [n, [laundry]]]], [vp, [vbar, [v, [is]], [ap_coord, [ap, [adj, [clean]]]]]]], [?]]], '2007-12-17-18-00-41', '130.60.155.177', 'Gives a countable laundry. How to get a mass laundry?').
text_drs_eval(0, 2720, 'Which dog of John waits?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, dog, countable, na, eq, 1)-1/2, relation(A, of, named('John'))-1/3, predicate(B, wait, A)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, dog], [pp, [prep, of], [np, [pname, 'John']]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?], '.']], '2009-05-13-13-54-05', '130.60.155.193', '').
text_drs_eval(0, 2721, 'Which man sees every dog?', drs([], [question(drs([A], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, drs([B], [object(B, dog, countable, na, eq, 1)-1/5])=>drs([C], [predicate(C, see, A, B)-1/3])]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, every], [nbar, [n, dog]]]]]]], ?], '.']], '2009-05-13-13-54-06', '130.60.155.193', '').
text_drs_eval(0, 2722, 'John does not own which dog?', drs([], [question(drs([], [-drs([A, B], [query(A, which)-1/5, object(A, dog, countable, na, eq, 1)-1/6, predicate(B, own, named('John'), A)-1/4])]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vcompl, [v, own], [np, [qdet, which], [nbar, [n, dog]]]]]]], ?], '.']], '2009-05-13-13-54-08', '130.60.155.193', '').
text_drs_eval(0, 2723, 'There is a man X. Which man is X?', drs([A], [object(A, man, countable, na, eq, 1)-1/4, question(drs([B, C], [query(B, which)-2/1, object(B, man, countable, na, eq, 1)-2/2, predicate(C, be, B, A)-2/3]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], '.'], [sentence, [query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [aux, is], [vbar, [vcompl, [np, [var, 'X']]]]]], ?], '.']], '2009-05-13-13-54-09', '130.60.155.193', '').
text_drs_eval(0, 2724, 'which man\'s dog barks?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, relation(B, of, A)-1/3, object(B, dog, countable, na, eq, 1)-1/5, predicate(C, bark, B)-1/6]))]), [[sentence, [query, [question, [np, [poss_np, [qdet, which], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]], ?], '.']], '2009-05-13-13-54-11', '130.60.155.193', '').
text_drs_eval(0, 2725, 'There are some cities in which John lives.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, city, countable, na, geq, 2)-1, predicate(C, live, A)-1, modifier_pp(C, in, B)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [cities]], [rel_cl, [pp, [prep, [in]], [np, [relpn, [which]]]], [np, [pname, ['John']]], [vp, [vbar, [vbar, [v, [lives]]], [pp, [[]]]]]]]]]], ['.']]], '2007-12-18-12-01-42', '130.60.155.231', '').
text_drs_eval(0, 2726, 'There are less than 2 kg of dirty laundry.', drs([A], [[property(A, dirty, pos)-1, object(A, laundry, mass, kg, less, 2)-1]]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [meas_spec, [nump, [genqu, 'less than'], 2], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [adj, dirty], [nbar, [n, laundry]]]]]], '.']], '2009-03-02-11-34-16', '130.60.155.206', '').
text_drs_eval(0, 2727, 'There are at most 2 kg of dirty laundry.', drs([A], [[property(A, dirty, pos)-1, object(A, laundry, mass, kg, leq, 2)-1]]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [meas_spec, [nump, [genqu, 'at most'], 2], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [adj, dirty], [nbar, [n, laundry]]]]]], '.']], '2009-03-02-11-34-24', '130.60.155.206', '').
text_drs_eval(0, 2728, 'There are at least 2 kg of dirty laundry.', drs([A], [object(A, laundry, mass, kg, geq, 2)-1, property(A, dirty, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measure_np, [numberp, [gen_quant, ['{at least}']], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [dirty]], [nbar, [n, [laundry]]]]]]]]], ['.']]], '2007-12-18-12-30-34', '130.60.155.231', '').
text_drs_eval(0, 2729, 'There are 2 kg of dirty laundry.', drs([A], [object(A, laundry, mass, kg, eq, 2)-1, property(A, dirty, pos)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [dirty]], [nbar, [n, [laundry]]]]]]]]], ['.']]], '2007-12-18-12-30-48', '130.60.155.231', '').
text_drs_eval(0, 2730, 'It is false that there is a man ,and that there is a dog or there is a cat.', drs([], [drs([], [-drs([A, B], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1])])v drs([C], [object(C, cat, countable, na, eq, 1)-1])]), [[specification, [s_coord, [neg_s, [sneg, ['{it is false}']], [s_coord, [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]]]], [coord, ['{, and}']], [cp, ['_that_'], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [dog]]]]]]]]], [coord, [or]], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [cat]]]]]]], ['.']]], '2007-12-26-11-58-23', '84.75.130.73', '').
text_drs_eval(0, 2731, 'There is are 2 kg of apples.', drs([], []), [], '2008-07-29-11-16-13', '130.60.155.206', '').
text_drs_eval(0, 2732, 'A customer can enter what?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/2, can(drs([B, C], [query(B, what)-1/5, predicate(C, enter, A, B)-1/4]))]))]), [[query, [question, [np, [det, a], [nbar, [n, customer]]], [vp, [aux, can], [vbar, [vcompl, [v, enter], [np, [qpn, what]]]]]], ?]], '2010-10-27-09-29-42', '89.206.64.27', '').
text_drs_eval(0, 2733, 'More than 3 kg of white rice of John rot.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, rice, mass, kg, greater, 3)-1, property(B, white, pos)-1, relation(B, of, A)-1, predicate(C, rot, B)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, ['{more than}']], [number, [3]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [adj, [white]], [nbar, [n, [rice]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]]], [vp, [vbar, [v, [rot]]]]], ['.']]], '2007-12-18-14-48-36', '130.60.155.177', '').
text_drs_eval(1, 2734, 'More than 3 kg of John\'s white rice rot.', drs([], []), [], '2007-12-18-14-49-04', '130.60.155.177', 'Why is this not supported?').
text_drs_eval(1, 2735, 'More than 3 kg of John\'s rice rot.', drs([], []), [], '2007-12-18-14-49-24', '130.60.155.177', 'Why is this not supported?').
text_drs_eval(0, 2736, '1 kg of apples wait.', drs([A, B], [object(A, apple, countable, kg, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-12-26-11-57-28', '84.75.130.73', '').
text_drs_eval(0, 2737, 'If there is somebody X of a dog of X then X waits.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, relation(A, of, B)-1])=>drs([C], [predicate(C, wait, A)-1])]), [[specification, [cond_s, [if], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, ['$body']], [appos, [var, ['X']]], [pp, [prep, [of]], [np, [det, [a]], [nbar, [n, [dog]], [pp, [prep, [of]], [np, [var, ['X']]]]]]]]]]], [then], [s, [np, [var, ['X']]], [vp, [vbar, [v, [waits]]]]]], ['.']]], '2007-12-20-17-02-27', '130.60.155.177', '').
text_drs_eval(1, 2738, 'If there is a dog X of somebody Y of X then Y waits.', drs([], [drs([A, B], [object(A, dog, countable, na, eq, 1)-1, object(B, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, relation(A, of, B)-1])=>drs([C], [predicate(C, wait, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [appos, [var, 'X']], [pp, [prep, of], [np, [pn, somebody], [appos, [var, 'Y']], [pp, [prep, of], [np, [var, 'X']]]]]]]]], then, [s, [np, [var, 'Y']], [vp, [vbar, [v, waits]]]]], '.']], '2008-10-27-10-58-09', '84.74.167.232', 'Incomplete paraphrase "then somebody X1 of a dog of X1 waits."').
text_drs_eval(0, 2739, '((1+2)-3) = 0.', drs([], [formula(expr(-, expr(+, int(1), int(2)), int(3)), =, int(0))-1]), [[specification, [formula, [brackets, ['('], [expr, [brackets, ['('], [expr, [int, [1]], [+], [int, [2]]], [')']], [-], [int, [3]]], [')']], [=], [int, [0]]], ['.']]], '2007-12-20-17-05-57', '130.60.155.177', '').
text_drs_eval(0, 2740, 'For each of some men for each of some women a dog barks.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([C], [object(C, woman, countable, na, geq, 2)-1, drs([D], [has_part(C, D)-1])=>drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1])])]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [women]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2007-12-20-19-13-16', '130.60.155.177', '').
text_drs_eval(0, 2741, 'For each of some men for every woman a dog barks.', drs([A], [object(A, man, countable, na, geq, 2)-1, drs([B], [has_part(A, B)-1])=>drs([], [drs([C], [object(C, woman, countable, na, eq, 1)-1])=>drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, bark, D)-1])])]), [[specification, [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [men]]]]], [top_s, [topic, [quant, ['{for}']], [np, [det, [every]], [nbar, [n, [woman]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2007-12-20-19-14-00', '130.60.155.177', '').
text_drs_eval(0, 2742, 'For every man for each of some women a dog barks.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [object(B, woman, countable, na, geq, 2)-1, drs([C], [has_part(B, C)-1])=>drs([D, E], [object(D, dog, countable, na, eq, 1)-1, predicate(E, bark, D)-1])])]), [[specification, [top_s, [topic, [quant, ['{for}']], [np, [det, [every]], [nbar, [n, [man]]]]], [top_s, [topic, [quant, ['{for each of}']], [np, [det, [some]], [nbar, [n, [women]]]]], [s, [np, [det, [a]], [nbar, [n, [dog]]]], [vp, [vbar, [v, [barks]]]]]]], ['.']]], '2007-12-20-19-14-19', '130.60.155.177', '').
text_drs_eval(0, 2743, 'There is a man such that there is a woman such that the man knows the woman.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, woman, countable, na, eq, 1)-1, predicate(C, know, A, B)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [man]]]]], [conj, ['{such that}']], [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [woman]]]]], [conj, ['{such that}']], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [knows]], [np, [det, [the]], [nbar, [n, [woman]]]]]]]]], ['.']]], '2007-12-20-19-16-35', '130.60.155.177', '').
text_drs_eval(0, 2744, 'There is 2 kg of laundry X1.', drs([A], [object(A, laundry, mass, kg, eq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{there is}']], [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]], [appos, [var, ['X1']]]]]]]]], ['.']]], '2007-12-25-12-15-50', '130.60.206.10', '').
text_drs_eval(0, 2745, 'There are 2 kg of laundry X1.', drs([A], [object(A, laundry, mass, kg, eq, 2)-1]), [[specification, [top_s, [topic, [quant, ['{there are}']], [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]], [appos, [var, ['X1']]]]]]]]], ['.']]], '2007-12-25-12-15-57', '130.60.206.10', '').
text_drs_eval(0, 2746, '2 kg of laundry wait.', drs([A, B], [object(A, laundry, mass, kg, eq, 2)-1, predicate(B, wait, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-12-25-12-16-08', '130.60.206.10', '').
text_drs_eval(0, 2747, '1 kg of laundry wait.', drs([A, B], [object(A, laundry, mass, kg, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2007-12-25-12-16-13', '130.60.206.10', '').
text_drs_eval(0, 2748, '1 kg of laundry waits.', drs([A, B], [object(A, laundry, mass, kg, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [laundry]]]]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-25-12-16-17', '130.60.206.10', '').
text_drs_eval(0, 2749, '2 kg of apples exist.', drs([A, B], [object(A, apple, countable, kg, eq, 2)-1, predicate(B, exist, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]], [vp, [vbar, [v, [exist]]]]], ['.']]], '2007-12-25-12-17-09', '130.60.206.10', '').
text_drs_eval(0, 2750, '2 kg of apples exists.', drs([A, B], [object(A, apple, countable, kg, eq, 2)-1, predicate(B, exist, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]], [vp, [vbar, [v, [exists]]]]], ['.']]], '2007-12-25-12-17-14', '130.60.206.10', '').
text_drs_eval(0, 2751, '1 kg of apples exist.', drs([A, B], [object(A, apple, countable, kg, eq, 1)-1, predicate(B, exist, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]], [vp, [vbar, [v, [exist]]]]], ['.']]], '2007-12-25-12-17-21', '130.60.206.10', '').
text_drs_eval(0, 2752, '1 kg of apples exists.', drs([A, B], [object(A, apple, countable, kg, eq, 1)-1, predicate(B, exist, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [1]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]], [nbar, [n, [apples]]]]]], [vp, [vbar, [v, [exists]]]]], ['.']]], '2007-12-25-12-17-35', '130.60.206.10', '').
text_drs_eval(0, 2753, 'at most 3 l of good milk X of John are in the fridge.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, [modifier_pp(C, in, D)-1, predicate(C, be, B)-1, relation(B, of, A)-1, object(D, fridge, countable, na, eq, 1)-1, property(B, good, pos)-1, object(B, milk, mass, l, leq, 3)-1]]), [[specification, [s, [np, [meas_spec, [nump, [genqu, 'at most'], 3], [meas_nbar, [meas_n, l], [pp, [prep, of]]]], [nbar, [adj, good], [nbar, [n, milk], [appos, [var, 'X']], [pp, [prep, of], [np, [pname, 'John']]]]]], [vp, [aux, are], [vbar, [vcompl, [pp, [prep, in], [np, [det, the], [nbar, [n, fridge]]]]]]]], '.']], '2009-03-02-11-34-38', '130.60.155.206', '').
text_drs_eval(0, 2754, 'at least 3 l of good milk X which is owned by John is in the fridge.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, milk, mass, l, geq, 3)-1, property(B, good, pos)-1, predicate(C, own, A, B)-1, predicate(D, be, B)-1, modifier_pp(D, in, E)-1, object(E, fridge, countable, na, eq, 1)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, ['{at least}']], [number, [3]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]], [nbar, [adj, [good]], [nbar, [n, [milk]], [appos, [var, ['X']]], [rel_cl, [np, [relpn, [which]]], [vp, [aux, [is]], [vbar, [v, [owned]], [by, [by]], [np, [pname, ['John']]]]]]]]]]], [vp, [vbar, [v, [is]], [pp, [prep, [in]], [np, [det, [the]], [nbar, [n, [fridge]]]]]]]], ['.']]], '2007-12-25-12-48-37', '130.60.206.10', '').
text_drs_eval(0, 2755, 'there is a man who knows who?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, query(B, who)-1/7, predicate(C, know, A, B)-1/6]))]), [[sentence, [query, [question, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, knows], [np, [qpn, who]]]]]]]]]], ?], '.']], '2009-05-13-13-45-18', '130.60.155.193', '').
text_drs_eval(0, 2756, 'There are who?', drs([], [question(drs([A], [query(A, who)-1/3]))]), [[sentence, [query, [question, [topic, [quant, 'there are'], [np, [qpn, who]]]], ?], '.']], '2009-05-13-13-45-20', '130.60.155.193', '').
text_drs_eval(0, 2757, 'There are which customers who see who?', drs([], [question(drs([A, B, C], [query(A, which)-1/3, object(A, customer, countable, na, geq, 2)-1/4, query(B, who)-1/7, predicate(C, see, A, B)-1/6]))]), [[sentence, [query, [question, [topic, [quant, 'there are'], [np, [qdet, which], [nbar, [n, customers], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, see], [np, [qpn, who]]]]]]]]]], ?], '.']], '2009-05-13-13-45-21', '130.60.155.193', '').
text_drs_eval(0, 2758, 'Some men can not wait.', drs([A], [object(A, man, countable, na, geq, 2)-1/2, -drs([], [can(drs([B], [predicate(B, wait, A)-1/5]))])]), [[specification, [s, [np, [det, some], [nbar, [n, men]]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-29-51', '89.206.64.27', '').
text_drs_eval(0, 2759, 'John can not wait.', drs([], [-drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-29-57', '89.206.64.27', '').
text_drs_eval(0, 2760, 'A man can not be rich.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B, C], [property(B, rich, pos)-1/6, predicate(C, be, A, B)-1/3]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, 'not be'], [ap_coord, [ap, [adj, rich]]]]], '.']], '2010-10-27-09-30-05', '89.206.64.27', '').
text_drs_eval(0, 2761, 'A man can not give a woman an apple.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([B, C, D], [object(B, woman, countable, na, eq, 1)-1/7, object(C, apple, countable, na, eq, 1)-1/9, predicate(D, give, A, C, B)-1/5]))])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vcompl, [v, give], [np, [det, a], [nbar, [n, woman]]], [np, [det, an], [nbar, [n, apple]]]]]]], '.']], '2010-10-27-09-30-10', '89.206.64.27', '').
text_drs_eval(0, 2762, 'Mary does not like some men who are not rich.', drs([A], [object(A, 'Mary', named, na, eq, 1)-1, -drs([B, C], [object(B, man, countable, na, geq, 2)-1, -drs([D, E], [property(D, rich, pos)-1, predicate(E, be, B, D)-1]), predicate(C, like, A, B)-1])]), [[specification, [s, [np, [pname, ['Mary']]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [relpn, [who]]], [neg_vp, [v, [are]], [neg, [not]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [rich]]]]]]]]]]]], ['.']]], '2007-12-26-17-06-54', '130.60.206.5', '').
text_drs_eval(0, 2763, 'Everybody does not like a dog that does not bark.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1])=>drs([], [-drs([B, C], [object(B, dog, countable, na, eq, 1)-1, -drs([D], [predicate(D, bark, B)-1]), predicate(C, like, A, B)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, ['$body']]]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, [dog]], [rel_cl, [comp, [that]], [vp, [aux, ['{does not}']], [vbar, [v, [bark]]]]]]]]]], ['.']]], '2007-12-26-17-07-07', '130.60.206.5', '').
text_drs_eval(0, 2764, 'A cat is not hated by a dog.', drs([A], [object(A, cat, countable, na, eq, 1)-1, -drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, hate, B, A)-1])]), [[specification, [s, [np, [det, [a]], [nbar, [n, [cat]]]], [vp, [aux, ['{is not}']], [vbar, [v, [hated]], [by, [by]], [np, [det, [a]], [nbar, [n, [dog]]]]]]], ['.']]], '2007-12-26-17-07-16', '130.60.206.5', '').
text_drs_eval(0, 2765, 'Every goat likes some grass and likes some water and does not like something that is not some grass and that is not some water.', drs([], [drs([A], [object(A, goat, countable, na, eq, 1)-1])=>drs([B, C, D, E], [object(B, grass, mass, na, na, na)-1, predicate(C, like, A, B)-1, object(D, water, mass, na, na, na)-1, predicate(E, like, A, D)-1, -drs([F, G], [object(F, something, dom, na, na, na)-1, -drs([H, I], [object(H, grass, mass, na, na, na)-1, predicate(I, be, F, H)-1]), -drs([J, K], [object(J, water, mass, na, na, na)-1, predicate(K, be, F, J)-1]), predicate(G, like, A, F)-1])])]), [[specification, [s, [np, [det, [every]], [nbar, [n, [goat]]]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [some]], [nbar, [n, [grass]]]]]], [coord, [and]], [vp_coord, [vp, [vbar, [v, [likes]], [np, [det, [some]], [nbar, [n, [water]]]]]], [coord, [and]], [vp, [aux, ['{does not}']], [vbar, [v, [like]], [np, [det, [a]], [nbar, [n, ['$thing']], [rel_cl_coord, [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [some]], [nbar, [n, [grass]]]]]]], [coord, [and]], [rel_cl, [comp, [that]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [det, [some]], [nbar, [n, [water]]]]]]]]]]]]]]], ['.']]], '2007-12-26-17-07-33', '130.60.206.5', '').
text_drs_eval(0, 2766, 'which code does a customer enter?', drs([], [question(drs([A, B, C], [object(A, customer, countable, na, eq, 1)-1/5, query(B, which)-1/1, object(B, code, countable, na, eq, 1)-1/2, predicate(C, enter, A, B)-1/6]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, code]]], does, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter]]]]], ?], '.']], '2009-05-13-13-45-24', '130.60.155.193', '').
text_drs_eval(0, 2767, 'which code does who enter?', drs([], [question(drs([A, B, C], [query(A, who)-1/4, query(B, which)-1/1, object(B, code, countable, na, eq, 1)-1/2, predicate(C, enter, A, B)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, code]]], does, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, enter]]]]], ?], '.']], '2009-05-13-13-45-25', '130.60.155.193', '').
text_drs_eval(0, 2768, 'who gives what to who?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/1, query(B, what)-1/3, query(C, who)-1/5, predicate(D, give, A, B, C)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vcompl, [v, gives], [np, [qpn, what]], to, [np, [qpn, who]]]]]], ?], '.']], '2009-05-13-13-45-26', '130.60.155.193', '').
text_drs_eval(0, 2769, 'which code has a customer to enter?', drs([], []), [], '2007-12-26-17-41-00', '130.60.206.5', '').
text_drs_eval(0, 2770, 'what must a man own?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4, must(drs([B, C], [query(B, what)-1/1, predicate(C, own, A, B)-1/5]))]))]), [[query, [question, [np, [qpn, what]], must, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, own]]]]], ?]], '2010-10-27-09-30-15', '89.206.64.27', '').
text_drs_eval(0, 2771, 'what can a man not have?', drs([], [question(drs([A], [object(A, man, countable, na, eq, 1)-1/4, -drs([], [can(drs([B, C], [query(B, what)-1/1, predicate(C, have, A, B)-1/6]))])]))]), [[query, [question, [np, [qpn, what]], can, [np, [det, a], [nbar, [n, man]]], [vp, [aux, not], [vbar, [vcompl, [v, have]]]]], ?]], '2010-10-27-09-38-29', '89.206.64.27', '').
text_drs_eval(0, 2772, 'Which customer does not provably wait?', drs([], [question(drs([A], [query(A, which)-1/1, object(A, customer, countable, na, eq, 1)-1/2, ~drs([B], [predicate(B, wait, A)-1/6])]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, customer]]], [vp, [aux, does, 'not provably'], [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-45-30', '130.60.155.193', '').
text_drs_eval(0, 2773, 'Which customer does John not provably know?', drs([], [question(drs([], [~drs([A, B], [query(A, which)-1/1, object(A, customer, countable, na, eq, 1)-1/2, predicate(B, know, named('John'), A)-1/7])]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, customer]]], does, [np, [pname, 'John']], [vp, [aux, 'not provably'], [vbar, [vcompl, [v, know]]]]], ?], '.']], '2009-05-13-13-45-32', '130.60.155.193', '').
text_drs_eval(0, 2774, 'Which customer does John not provably not know?', drs([], [question(drs([], [~drs([], [-drs([A, B], [query(A, which)-1/1, object(A, customer, countable, na, eq, 1)-1/2, predicate(B, know, named('John'), A)-1/8])])]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, customer]]], does, [np, [pname, 'John']], [vp, [aux, 'not provably not'], [vbar, [vcompl, [v, know]]]]], ?], '.']], '2009-05-13-13-45-33', '130.60.155.193', '').
text_drs_eval(0, 2775, 'does John not have to wait?', drs([], [question(drs([], [-drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/6]))])]))]), [[query, [question, does, [np, [pname, 'John']], [vp, [aux, 'not have to'], [vbar, [vbar, [v, wait]]]]], ?]], '2010-10-27-09-30-27', '89.206.64.27', '').
text_drs_eval(0, 2776, 'Has John to wait?', drs([], []), [], '2007-12-26-17-41-11', '130.60.206.5', '').
text_drs_eval(0, 2777, 'which code does a customer have to enter?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/5, must(drs([B, C], [query(B, which)-1/1, object(B, code, countable, na, eq, 1)-1/2, predicate(C, enter, A, B)-1/8]))]))]), [[query, [question, [np, [qdet, which], [nbar, [n, code]]], does, [np, [det, a], [nbar, [n, customer]]], [vp, [aux, 'have to'], [vbar, [vcompl, [v, enter]]]]], ?]], '2010-10-27-09-30-33', '89.206.64.27', '').
text_drs_eval(0, 2778, 'Does John have to wait?', drs([], [question(drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/5]))]))]), [[query, [question, does, [np, [pname, 'John']], [vp, [aux, 'have to'], [vbar, [vbar, [v, wait]]]]], ?]], '2010-10-27-09-30-37', '89.206.64.27', '').
text_drs_eval(0, 2779, 'John does have to wait.', drs([], [must(drs([A], [predicate(A, wait, named('John'))-1/5]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'have to'], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-30-42', '89.206.64.27', '').
text_drs_eval(0, 2780, 'is a code entered by who?', drs([], []), [], '2007-12-26-17-48-36', '130.60.206.5', '').
text_drs_eval(0, 2781, 'is a code entered by a customer?', drs([], [question(drs([A, B, C], [object(A, code, countable, na, eq, 1)-1/3, object(B, customer, countable, na, eq, 1)-1/7, predicate(C, enter, B, A)-1/4]))]), [[sentence, [query, [question, is, [np, [det, a], [nbar, [n, code]]], [vp, [vbar, [vcompl, [v, entered], by, [np, [det, a], [nbar, [n, customer]]]]]]], ?], '.']], '2009-05-13-13-45-39', '130.60.155.193', '').
text_drs_eval(0, 2782, 'can a code be entered by a customer?', drs([], [question(drs([A], [object(A, code, countable, na, eq, 1)-1/3, can(drs([B, C], [object(B, customer, countable, na, eq, 1)-1/8, predicate(C, enter, B, A)-1/5]))]))]), [[query, [question, can, [np, [det, a], [nbar, [n, code]]], [vp, [aux, be], [vbar, [vcompl, [v, entered], by, [np, [det, a], [nbar, [n, customer]]]]]]], ?]], '2010-10-27-09-30-50', '89.206.64.27', '').
text_drs_eval(0, 2783, 'does a code have to be entered by someone?', drs([], [question(drs([A], [object(A, code, countable, na, eq, 1)-1/3, must(drs([B, C], [object(B, somebody, countable, na, eq, 1)-1/10, predicate(C, enter, B, A)-1/7]))]))]), [[query, [question, does, [np, [det, a], [nbar, [n, code]]], [vp, [aux, 'have to be'], [vbar, [vcompl, [v, entered], by, [np, [pn, someone]]]]]], ?]], '2010-10-27-09-30-55', '89.206.64.27', '').
text_drs_eval(0, 2784, 'must every code have a customer?', drs([], [question(drs([], [drs([A], [object(A, code, countable, na, eq, 1)-1/3])=>drs([], [must(drs([B, C], [object(B, customer, countable, na, eq, 1)-1/6, predicate(C, have, A, B)-1/4]))])]))]), [[query, [question, must, [np, [det, every], [nbar, [n, code]]], [vp, [vbar, [vcompl, [v, have], [np, [det, a], [nbar, [n, customer]]]]]]], ?]], '2010-10-27-09-31-00', '89.206.64.27', '').
text_drs_eval(0, 2785, 'is a customer not provably a clerk?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/3, ~drs([B, C], [object(B, clerk, countable, na, eq, 1)-1/7, predicate(C, be, A, B)-1/1])]))]), [[sentence, [query, [question, is, [np, [det, a], [nbar, [n, customer]]], [vp, [aux, 'not provably'], [vbar, [vcompl, [np, [det, a], [nbar, [n, clerk]]]]]]], ?], '.']], '2009-05-13-13-45-44', '130.60.155.193', '').
text_drs_eval(0, 2786, 'Which code does a customer have to enter?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/5, must(drs([B, C], [query(B, which)-1/1, object(B, code, countable, na, eq, 1)-1/2, predicate(C, enter, A, B)-1/8]))]))]), [[query, [question, [np, [qdet, which], [nbar, [n, code]]], does, [np, [det, a], [nbar, [n, customer]]], [vp, [aux, 'have to'], [vbar, [vcompl, [v, enter]]]]], ?]], '2010-10-27-09-31-10', '89.206.64.27', '').
text_drs_eval(0, 2787, 'Which code does a customer not have to enter?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/5, -drs([], [must(drs([B, C], [query(B, which)-1/1, object(B, code, countable, na, eq, 1)-1/2, predicate(C, enter, A, B)-1/9]))])]))]), [[query, [question, [np, [qdet, which], [nbar, [n, code]]], does, [np, [det, a], [nbar, [n, customer]]], [vp, [aux, 'not have to'], [vbar, [vcompl, [v, enter]]]]], ?]], '2010-10-27-09-31-15', '89.206.64.27', '').
text_drs_eval(0, 2788, 'Which codes must a customer enter?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/5, must(drs([B, C], [query(B, which)-1/1, object(B, code, countable, na, geq, 2)-1/2, predicate(C, enter, A, B)-1/6]))]))]), [[query, [question, [np, [qdet, which], [nbar, [n, codes]]], must, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter]]]]], ?]], '2010-10-27-09-31-19', '89.206.64.27', '').
text_drs_eval(0, 2789, 'Which cards must every customer enter into which slots?', drs([], [question(drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/5])=>drs([], [must(drs([B, C, D], [query(B, which)-1/1, object(B, card, countable, na, geq, 2)-1/2, query(C, which)-1/8, object(C, slot, countable, na, geq, 2)-1/9, predicate(D, enter, A, B)-1/6, modifier_pp(D, into, C)-1/7]))])]))]), [[query, [question, [np, [qdet, which], [nbar, [n, cards]]], must, [np, [det, every], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter]], [vmod, [pp, [prep, into], [np, [qdet, which], [nbar, [n, slots]]]]]]]], ?]], '2010-10-27-09-31-25', '89.206.64.27', '').
text_drs_eval(0, 2790, 'what is a dog living in?', drs([], [question(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/4, query(B, what)-1/1, property(C, living, pos)-1/5, predicate(D, be, A, C)-1/2, modifier_pp(D, in, B)-1/6]))]), [[sentence, [query, [question, [np, [qpn, what]], is, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, living]]]], [vmod, [pp, [prep, in]]]]]], ?], '.']], '2009-05-13-13-45-53', '130.60.155.193', '').
text_drs_eval(0, 2791, 'in what is a dog living in?', drs([], []), [], '2007-12-26-17-53-13', '130.60.206.5', '').
text_drs_eval(0, 2792, 'in what is a dog living?', drs([], [question(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/5, query(B, what)-1/2, property(C, living, pos)-1/6, predicate(D, be, A, C)-1/3, modifier_pp(D, in, B)-1/1]))]), [[sentence, [query, [question, [pp, [prep, in], [np, [qpn, what]]], is, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, living]]]]]]], ?], '.']], '2009-05-13-13-45-54', '130.60.155.193', '').
text_drs_eval(0, 2793, 'in what is a dog living in the morning?', drs([], [question(drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1/5, query(B, what)-1/2, property(C, living, pos)-1/6, predicate(D, be, A, C)-1/3, modifier_pp(D, in, E)-1/7, modifier_pp(D, in, B)-1/1, object(E, morning, countable, na, eq, 1)-1/9]))]), [[sentence, [query, [question, [pp, [prep, in], [np, [qpn, what]]], is, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, living]]]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]]]]], ?], '.']], '2009-05-13-13-45-55', '130.60.155.193', '').
text_drs_eval(0, 2794, 'in what is a dog living when?', drs([], [question(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/5, query(B, what)-1/2, property(C, living, pos)-1/6, predicate(D, be, A, C)-1/3, query(D, when)-1/7, modifier_pp(D, in, B)-1/1]))]), [[sentence, [query, [question, [pp, [prep, in], [np, [qpn, what]]], is, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, living]]]], [vmod, [qpn, when]]]]], ?], '.']], '2009-05-13-13-45-57', '130.60.155.193', '').
text_drs_eval(0, 2795, 'in what is who living?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/4, query(B, what)-1/2, property(C, living, pos)-1/5, predicate(D, be, A, C)-1/3, modifier_pp(D, in, B)-1/1]))]), [[sentence, [query, [question, [pp, [prep, in], [np, [qpn, what]]], is, [np, [qpn, who]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, living]]]]]]], ?], '.']], '2009-05-13-13-45-58', '130.60.155.193', '').
text_drs_eval(0, 2796, 'in what can a dog live?', drs([], [question(drs([A], [object(A, dog, countable, na, eq, 1)-1/5, can(drs([B, C], [query(B, what)-1/2, predicate(C, live, A)-1/6, modifier_pp(C, in, B)-1/1]))]))]), [[query, [question, [pp, [prep, in], [np, [qpn, what]]], can, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, live]]]]], ?]], '2010-10-27-09-31-30', '89.206.64.27', '').
text_drs_eval(0, 2797, 'in what does a dog live?', drs([], [question(drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1/5, query(B, what)-1/2, predicate(C, live, A)-1/6, modifier_pp(C, in, B)-1/1]))]), [[sentence, [query, [question, [pp, [prep, in], [np, [qpn, what]]], does, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-13-46-01', '130.60.155.193', '').
text_drs_eval(0, 2798, 'in what does a dog have to live?', drs([], [question(drs([A], [object(A, dog, countable, na, eq, 1)-1/5, must(drs([B, C], [query(B, what)-1/2, predicate(C, live, A)-1/8, modifier_pp(C, in, B)-1/1]))]))]), [[query, [question, [pp, [prep, in], [np, [qpn, what]]], does, [np, [det, a], [nbar, [n, dog]]], [vp, [aux, 'have to'], [vbar, [vbar, [v, live]]]]], ?]], '2010-10-27-09-31-34', '89.206.64.27', '').
text_drs_eval(0, 2799, 'in what does a dog not have to live?', drs([], [question(drs([A], [object(A, dog, countable, na, eq, 1)-1/5, -drs([], [must(drs([B, C], [query(B, what)-1/2, predicate(C, live, A)-1/9, modifier_pp(C, in, B)-1/1]))])]))]), [[query, [question, [pp, [prep, in], [np, [qpn, what]]], does, [np, [det, a], [nbar, [n, dog]]], [vp, [aux, 'not have to'], [vbar, [vbar, [v, live]]]]], ?]], '2010-10-27-09-31-39', '89.206.64.27', '').
text_drs_eval(0, 2800, 'in what does who not have to live for which reason?', drs([], [question(drs([A], [query(A, who)-1/4, -drs([], [must(drs([B, C, D], [query(B, what)-1/2, query(C, which)-1/10, object(C, reason, countable, na, eq, 1)-1/11, predicate(D, live, A)-1/8, modifier_pp(D, for, C)-1/9, modifier_pp(D, in, B)-1/1]))])]))]), [[query, [question, [pp, [prep, in], [np, [qpn, what]]], does, [np, [qpn, who]], [vp, [aux, 'not have to'], [vbar, [vbar, [v, live]], [vmod, [pp, [prep, for], [np, [qdet, which], [nbar, [n, reason]]]]]]]], ?]], '2010-10-27-09-31-44', '89.206.64.27', '').
text_drs_eval(0, 2801, 'in which house does John live?', drs([], [question(drs([A, B], [query(A, which)-1/2, object(A, house, countable, na, eq, 1)-1/3, predicate(B, live, named('John'))-1/6, modifier_pp(B, in, A)-1/1]))]), [[sentence, [query, [question, [pp, [prep, in], [np, [qdet, which], [nbar, [n, house]]]], does, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, live]]]]], ?], '.']], '2009-05-13-13-46-07', '130.60.155.193', '').
text_drs_eval(0, 2802, 'how can a customer enter a card?', drs([], [question(drs([A], [object(A, customer, countable, na, eq, 1)-1/4, can(drs([B, C], [object(B, card, countable, na, eq, 1)-1/7, predicate(C, enter, A, B)-1/5, query(C, how)-1/1]))]))]), [[query, [question, [qpn, how], can, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, enter], [np, [det, a], [nbar, [n, card]]]]]]], ?]], '2010-10-27-09-31-49', '89.206.64.27', '').
text_drs_eval(0, 2803, 'how does every customer have to enter his/her own card?', drs([], [question(drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/4])=>drs([], [must(drs([B, C], [relation(B, of, A)-1/8, object(B, card, countable, na, eq, 1)-1/12, predicate(C, enter, A, B)-1/7, query(C, how)-1/1]))])]))]), [[query, [question, [qpn, how], does, [np, [det, every], [nbar, [n, customer]]], [vp, [aux, 'have to'], [vbar, [vcompl, [v, enter], [np, [posspn, 'his/her own'], [nbar, [n, card]]]]]]], ?]], '2010-10-27-09-31-53', '89.206.64.27', '').
text_drs_eval(0, 2804, 'how does every customer have to enter his/her own card of which account?', drs([], [question(drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/4])=>drs([], [must(drs([B, C, D], [relation(B, of, A)-1/8, object(B, card, countable, na, eq, 1)-1/12, query(C, which)-1/14, object(C, account, countable, na, eq, 1)-1/15, relation(B, of, C)-1/13, predicate(D, enter, A, B)-1/7, query(D, how)-1/1]))])]))]), [[query, [question, [qpn, how], does, [np, [det, every], [nbar, [n, customer]]], [vp, [aux, 'have to'], [vbar, [vcompl, [v, enter], [np, [posspn, 'his/her own'], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, account]]]]]]]]]], ?]], '2010-10-27-09-31-59', '89.206.64.27', '').
text_drs_eval(0, 2805, 'Where can a card be bought by a customer?', drs([], [question(drs([A], [object(A, card, countable, na, eq, 1)-1/4, can(drs([B, C], [object(B, customer, countable, na, eq, 1)-1/9, predicate(C, buy, B, A)-1/6, query(C, where)-1/1]))]))]), [[query, [question, [qpn, where], can, [np, [det, a], [nbar, [n, card]]], [vp, [aux, be], [vbar, [vcompl, [v, bought], by, [np, [det, a], [nbar, [n, customer]]]]]]], ?]], '2010-10-27-09-32-04', '89.206.64.27', '').
text_drs_eval(0, 2806, 'Where can which cards be bought by a customer?', drs([], [question(drs([A], [query(A, which)-1/3, object(A, card, countable, na, geq, 2)-1/4, can(drs([B, C], [object(B, customer, countable, na, eq, 1)-1/9, predicate(C, buy, B, A)-1/6, query(C, where)-1/1]))]))]), [[query, [question, [qpn, where], can, [np, [qdet, which], [nbar, [n, cards]]], [vp, [aux, be], [vbar, [vcompl, [v, bought], by, [np, [det, a], [nbar, [n, customer]]]]]]], ?]], '2010-10-27-09-32-10', '89.206.64.27', '').
text_drs_eval(0, 2807, 'Where can which cards be bought by which customers of John?', drs([], [question(drs([A], [query(A, which)-1/3, object(A, card, countable, na, geq, 2)-1/4, can(drs([B, C], [query(B, which)-1/8, object(B, customer, countable, na, geq, 2)-1/9, relation(B, of, named('John'))-1/10, predicate(C, buy, B, A)-1/6, query(C, where)-1/1]))]))]), [[query, [question, [qpn, where], can, [np, [qdet, which], [nbar, [n, cards]]], [vp, [aux, be], [vbar, [vcompl, [v, bought], by, [np, [qdet, which], [nbar, [n, customers], [pp, [prep, of], [np, [pname, 'John']]]]]]]]], ?]], '2010-10-27-09-32-14', '89.206.64.27', '').
text_drs_eval(0, 2808, 'When is a string a password?', drs([], [question(drs([A, B, C], [object(A, string, countable, na, eq, 1)-1/4, object(B, password, countable, na, eq, 1)-1/6, predicate(C, be, A, B)-1/2, query(C, when)-1/1]))]), [[sentence, [query, [question, [qpn, when], is, [np, [det, a], [nbar, [n, string]]], [vp, [vbar, [vcompl, [np, [det, a], [nbar, [n, password]]]]]]], ?], '.']], '2009-05-13-13-46-18', '130.60.155.193', '').
text_drs_eval(0, 2809, 'When is a string a password of who?', drs([], [question(drs([A, B, C, D], [object(A, string, countable, na, eq, 1)-1/4, object(B, password, countable, na, eq, 1)-1/6, query(C, who)-1/8, relation(B, of, C)-1/7, predicate(D, be, A, B)-1/2, query(D, when)-1/1]))]), [[sentence, [query, [question, [qpn, when], is, [np, [det, a], [nbar, [n, string]]], [vp, [vbar, [vcompl, [np, [det, a], [nbar, [n, password], [pp, [prep, of], [np, [qpn, who]]]]]]]]], ?], '.']], '2009-05-13-13-46-19', '130.60.155.193', '').
text_drs_eval(0, 2810, 'Zürich is not Köln.', drs([A, B], [object(A, 'Zürich', named, na, eq, 1)-1, object(B, 'Köln', named, na, eq, 1)-1, -drs([C], [predicate(C, be, A, B)-1])]), [[specification, [s, [np, [var, ['Zürich']]], [neg_vp, [v, [is]], [neg, [not]], [vbar, [v, [[]]], [np, [var, ['Köln']]]]]], ['.']]], '2007-12-29-17-42-19', '130.60.204.10', '').
text_drs_eval(0, 2811, 'John has 3 °C.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, have, A, int(3, '°C'))-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [has]], [np, [measure_number, [int, [3]], [measure_noun, ['°C']]]]]]], ['.']]], '2007-12-29-17-45-10', '130.60.204.10', '').
text_drs_eval(0, 2812, 'There are John and 2 men ManGroup. ManGroup are happy.', drs([], []), [], '2008-01-03-16-30-17', '130.60.206.88', '').
text_drs_eval(0, 2813, '2 men M1 and M2 drink. M1 talk.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 2)-1, has_part(D, A)-1, predicate(B, drink, D)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, talk, A)-2]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'M1']]]], [coord, and], [np, [var, 'M2']]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [var, 'M1']], [vp, [vbar, [v, talk]]]], '.']], '2008-07-10-10-47-14', '130.60.155.206', '').
text_drs_eval(0, 2814, '2 men X and Y wait. X sleep. Y drinks.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 2)-1, has_part(D, A)-1, predicate(B, wait, D)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 2)-1, predicate(E, sleep, A)-2, predicate(F, drink, C)-3]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [var, 'Y']]], [vp, [vbar, [v, wait]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sleep]]]], '.'], [specification, [s, [np, [var, 'Y']], [vp, [vbar, [v, drinks]]]], '.']], '2008-07-10-10-47-20', '130.60.155.206', '').
text_drs_eval(0, 2815, '2 men X and Y\'s dog wait. X sleep. Y drinks.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 2)-1, has_part(E, A)-1, predicate(B, wait, E)-1, object(C, something, dom, na, na, na)-1, relation(D, of, C)-1, object(D, dog, countable, na, eq, 1)-1, has_part(E, D)-1, object(E, na, countable, na, eq, 2)-1, predicate(F, sleep, A)-2, predicate(G, drink, C)-3]), [[specification, [s, [np_coord, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [poss_np, [var, 'Y'], [gen_marker, '\'s']], [nbar, [n, dog]]]], [vp, [vbar, [v, wait]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sleep]]]], '.'], [specification, [s, [np, [var, 'Y']], [vp, [vbar, [v, drinks]]]], '.']], '2008-07-10-10-47-26', '130.60.155.206', '').
text_drs_eval(1, 2816, 'p:= waits.', drs([A, B], [object(A, =, named, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [pname, [=]]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2007-12-29-19-07-34', '130.60.204.10', 'Is it ok to have special symbols overridden by prefixes to make them normal tokens.').
text_drs_eval(0, 2817, '% ; @  ^ ` | ~', drs([], []), [], '2007-12-29-19-10-50', '130.60.204.10', '').
text_drs_eval(0, 2818, '123man man123 123man123 man123man', drs([], []), [], '2008-03-28-17-49-10', '130.60.155.177', '').
text_drs_eval(0, 2819, 'John likes Õnne.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Õnne', named, na, eq, 1)-1, predicate(C, like, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [likes]], [np, [var, ['Õnne']]]]]], ['.']]], '2007-12-30-15-28-18', '130.60.204.44', '').
text_drs_eval(0, 2820, 'John knows that "Миша lives in СССР" holds.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, know, A, C)-1, C:drs([D], [predicate(D, hold, string('Миша lives in СССР'))-1])]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [knows]], [cp, ['_that_'], [s, [np, [string, ['Миша lives in СССР']]], [vp, [vbar, [v, [holds]]]]]]]]], ['.']]], '2008-01-07-00-48-47', '130.60.206.18', '').
text_drs_eval(0, 2821, 'Миша lives in СССР.', drs([], []), [], '2008-01-07-00-49-11', '130.60.206.18', '').
text_drs_eval(0, 2822, 'John reads "تراجيديا هاملت Hamlet واحدة من أهم مسرحيات شكسبير . كتبت في عام 1600".', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, read, A, string('تراجيديا هاملت Hamlet واحدة من أهم مسرحيات شكسبير . كتبت في عام 1600'))-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [reads]], [np, [string, ['تراجيديا هاملت Hamlet واحدة من أهم مسرحيات شكسبير . كتبت في عام 1600']]]]]], ['.']]], '2008-01-07-00-50-20', '130.60.206.18', '').
text_drs_eval(0, 2823, 'A card is manually taken by John.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, take, A, B)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]]]], [vp, [aux, [is], [[]]], [vbar, [adv, [manually]], [vbar, [v, [taken]], [by, [by]], [np, [pname, ['John']]]]]]], ['.']]], '2007-12-31-00-56-22', '130.60.204.25', '').
text_drs_eval(0, 2824, 'A card is taken by John manually.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, predicate(C, take, A, B)-1, modifier_adv(C, manually, pos)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [card]]]], [vp, [aux, [is], [[]]], [vbar, [vbar, [v, [taken]], [by, [by]], [np, [pname, ['John']]]], [adv, [manually]]]]], ['.']]], '2008-01-16-17-24-19', '130.60.155.177', '').
text_drs_eval(0, 2825, 'There are some men each of whose dogs barks.', drs([A, B], [object(A, man, countable, na, geq, 2)-1, object(B, dog, countable, na, geq, 2)-1, relation(B, of, A)-1, drs([C], [has_part(B, C)-1])=>drs([D], [predicate(D, bark, C)-1])]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [det, [some]], [nbar, [n, [men]], [rel_cl, [np, [quant, ['{each of}']], [np, [posspn, [whose]], [nbar, [n, [dogs]]]]], [vp, [vbar, [v, [barks]]]]]]]]], ['.']]], '2007-12-31-10-00-16', '130.60.204.31', '').
text_drs_eval(0, 2826, 'John is when in Paris?', drs([], [question(drs([A], [query(A, when)-1/3, predicate(A, be, named('John'))-1/2, modifier_pp(A, in, named('Paris'))-1/4]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [qpn, when]], [vmod, [pp, [prep, in], [np, [pname, 'Paris']]]]]]], ?], '.']], '2009-05-13-13-40-39', '130.60.155.193', '').
text_drs_eval(0, 2827, 'John is in Paris when?', drs([], [question(drs([A], [predicate(A, be, named('John'))-1/2, modifier_pp(A, in, named('Paris'))-1/3, query(A, when)-1/5]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [pp, [prep, in], [np, [pname, 'Paris']]]], [vmod, [qpn, when]]]]], ?], '.']], '2009-05-13-13-40-40', '130.60.155.193', '').
text_drs_eval(0, 2828, 'John is in Paris when with Mary?', drs([], [question(drs([A], [predicate(A, be, named('John'))-1/2, modifier_pp(A, in, named('Paris'))-1/3, modifier_pp(A, with, named('Mary'))-1/6, query(A, when)-1/5]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [pp, [prep, in], [np, [pname, 'Paris']]]], [vmod, [qpn, when], [pp, [prep, with], [np, [pname, 'Mary']]]]]]], ?], '.']], '2009-05-13-13-40-42', '130.60.155.193', '').
text_drs_eval(0, 2829, 'John is in Paris when where?', drs([], []), [], '2009-05-22-11-02-21', '130.60.155.193', '').
text_drs_eval(0, 2830, 'There are some men a dog of whose barks.', drs([], []), [], '2008-01-02-15-43-09', '130.60.206.59', '').
text_drs_eval(0, 2831, 'There are some men a dog of the men barks.', drs([], []), [], '2008-01-02-15-44-06', '130.60.206.59', '').
text_drs_eval(0, 2832, 'John is rich where?', drs([], [question(drs([A, B], [property(A, rich, pos)-1/3, predicate(B, be, named('John'), A)-1/2, query(B, where)-1/4]))]), [[sentence, [query, [question, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, rich]]]], [vmod, [qpn, where]]]]], ?], '.']], '2009-05-13-13-40-43', '130.60.155.193', '').
text_drs_eval(0, 2833, 'John is where where?', drs([], []), [], '2009-05-22-11-02-12', '130.60.155.193', '').
text_drs_eval(0, 2834, 'John is in a park in the park.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, park, countable, na, eq, 1)-1, predicate(C, be, A)-1, modifier_pp(C, in, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vbar, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [pp, [prep, in], [np, [det, the], [nbar, [n, park]]]]]]], '.']], '2008-08-12-17-17-13', '130.60.155.208', '').
text_drs_eval(0, 2835, 'John drinks p:õlu.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, õlu, named, na, eq, 1)-1, predicate(C, drink, A, B)-1]), [[specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [drinks]], [np, [pname, [õlu]]]]]], ['.']]], '2008-01-02-18-41-42', '130.60.206.59', '').
text_drs_eval(0, 2836, 'Can a book be written by a man?', drs([], [question(drs([A], [object(A, book, countable, na, eq, 1)-1/3, can(drs([B, C], [object(B, man, countable, na, eq, 1)-1/8, predicate(C, write, B, A)-1/5]))]))]), [[query, [question, can, [np, [det, a], [nbar, [n, book]]], [vp, [aux, be], [vbar, [vcompl, [v, written], by, [np, [det, a], [nbar, [n, man]]]]]]], ?]], '2010-10-27-09-32-27', '89.206.64.27', '').
text_drs_eval(0, 2837, 'It is false that there are a man and a woman and that the man waits.', drs([], [-drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, has_part(C, A)-1, object(B, woman, countable, na, eq, 1)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, predicate(D, wait, A)-1])]), [[specification, [neg_s, [sneg, ['{it is false}']], [cp, ['_that_'], [s_coord, [top_s, [topic, [quant, ['{there are}']], [np_coord, [np, [det, [a]], [nbar, [n, [man]]]], [coord, [and]], [np, [det, [a]], [nbar, [n, [woman]]]]]]], [coord, [and]], [cp, ['_that_'], [s, [np, [det, [the]], [nbar, [n, [man]]]], [vp, [vbar, [v, [waits]]]]]]]]], ['.']]], '2008-01-03-17-27-30', '130.60.206.88', '').
text_drs_eval(0, 2838, 'John who is larger than his own brother can work carefully in a year that is not 2006 and that is not in [1981, 1983, 1985].', drs([A, B, C], [relation(A, of, named('John'))-1/6, object(A, brother, countable, na, eq, 1)-1/8, property(B, large, comp_than, A)-1/4, predicate(C, be, named('John'), B)-1/3, can(drs([D, E], [object(D, year, countable, na, eq, 1)-1/14, -drs([F], [predicate(F, be, D, int(2006))-1/16]), -drs([G], [predicate(G, be, D)-1/21, modifier_pp(G, in, list([int(1981), int(1983), int(1985)]))-1/23]), predicate(E, work, named('John'))-1/10, modifier_pp(E, in, D)-1/12, modifier_adv(E, carefully, pos)-1/11]))]), [[specification, [s, [np, [pname, 'John'], [rel_cl, [np, [relpn, who]], [vp, [aux, is], [ap_coord, [ap, [adj, larger], [conj, than], [np, [posspn, 'his own'], [nbar, [n, brother]]]]]]]], [vp, [aux, can], [vbar, [vbar, [v, work]], [vmod, [adv, carefully], [pp, [prep, in], [np, [det, a], [nbar, [n, year], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is, not], [np, [int, 2006]]]], [coord, and], [rel_cl, [comp, that], [vp, [aux, is, not], [pp, [prep, in], [np, [list, [int, 1981], ',', [int, 1983], ',', [int, 1985]]]]]]]]]]]]]], '.']], '2010-10-27-09-32-36', '89.206.64.27', '').
text_drs_eval(0, 2839, 'If each of some men who are {John, Bill} gives a small text "abc" to a woman then John must buy 2 kg of food or knows that it is not provable that 2 km / (2.3 + 4) = X * 2.', drs([], [drs([A, B], [object(A, man, countable, na, geq, 2)-1/5, predicate(B, be, A, set([named('John'), named('Bill')]))-1/7, drs([C], [has_part(A, C)-1/2])=>drs([D, E, F], [object(D, text, countable, na, eq, 1)-1/16, property(D, small, pos)-1/15, object(E, woman, countable, na, eq, 1)-1/20, predicate(F, give, C, string(abc), D)-1/13, modifier_pp(F, to, E)-1/18])])=>drs([], [drs([], [must(drs([G, H], [object(G, food, mass, kg, eq, 2)-1/28, predicate(H, buy, named('John'), G)-1/24]))])v drs([I, J], [predicate(I, know, named('John'), J)-1/30, J:drs([], [~drs([K], [object(K, something, dom, na, na, na)-1/46, formula(expr(/, int(2, km), expr(+, real(2.3), int(4))), =, expr(*, K, int(2)))-1/45])])])])]), [[specification, [cond_s, if, [s, [np, [quant, 'each of'], [np, [det, some], [nbar, [n, men], [rel_cl, [np, [relpn, who]], [vp, [aux, are], [np, [set, [pname, 'John'], ',', [pname, 'Bill']]]]]]]], [vp, [vbar, [vcompl, [v, gives], [np, [det, a], [nbar, [adj, small], [nbar, [n, text]]]], [np, [string, '"abc"']]], [vmod, [pp, [prep, to], [np, [det, a], [nbar, [n, woman]]]]]]]], then, [s, [np, [pname, 'John']], [vp_coord, [vp, [aux, must], [vbar, [vcompl, [v, buy], [np, [meas_spec, [nump, 2], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, food]]]]]], [coord, or], [vp, [vbar, [cp, that, [s, [naf, 'it is not provable'], [cp, that, [formula, [expr, [meas_num, [int, 2], [meas_n, km]], [brackets, '(', [expr, [real, 2.3], [int, 4]], ')']], =, [expr, [var, 'X'], [int, 2]]]]]]]]]]], '.']], '2010-11-12-08-51-58', '89.206.69.32', '').
text_drs_eval(0, 2840, 'Who is mad-about John who is rich and who is as fond-of Mary as of Sue?', drs([], [question(drs([A, B, C, D, E, F, G], [query(A, who)-1/1, property(B, 'mad-about', pos, named('John'))-1/3, predicate(C, be, A, B)-1/2, property(D, rich, pos)-1/7, predicate(E, be, named('John'), D)-1/6, property(F, 'fond-of', named('Mary'), pos_as, obj, named('Sue'))-1/12, predicate(G, be, named('John'), F)-1/10]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, 'mad-about'], [np, [pname, 'John'], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, rich]]]]]]], [coord, and], [rel_cl, [np, [relpn, who]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, as, [adj, 'fond-of'], [np, [pname, 'Mary']], as, of, [np, [pname, 'Sue']]]]]]]]]]]]]]]], ?], '.']], '2009-05-13-13-40-49', '130.60.155.193', '').
text_drs_eval(0, 2841, 'At most 3 men own more than 5 cars. At most 5 cars are owned by more than 3 men.', drs([A, B, C, D, E, F], [[predicate(C, own, A, B)-1, object(B, car, countable, na, greater, 5)-1, object(A, man, countable, na, leq, 3)-1], [predicate(F, own, E, D)-2, object(E, man, countable, na, greater, 3)-2, object(D, car, countable, na, leq, 5)-2]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, own], [np, [nump, [genqu, 'more than'], 5], [nbar, [n, cars]]]]]]], '.'], [specification, [s, [np, [nump, [genqu, 'at most'], 5], [nbar, [n, cars]]], [vp, [aux, are], [vbar, [vcompl, [v, owned], by, [np, [nump, [genqu, 'more than'], 3], [nbar, [n, men]]]]]]], '.']], '2009-03-02-11-34-52', '130.60.155.206', '').
text_drs_eval(0, 2842, 'There are at most 3 men. The men wait.', drs([A, B], [[object(A, man, countable, na, leq, 3)-1], predicate(B, wait, A)-2]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], '.']], '2009-03-02-11-35-13', '130.60.155.206', '').
text_drs_eval(0, 2843, 'No man but John waits.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [predicate(B, wait, C)-1, object(C, man, countable, na, eq, 1)-1])=>drs([D], [predicate(D, be, C, A)-1])]), [[specification, [s, [np, [det, [np, [det, [no]], [nbar, [n, [man]]]], [but]], [pname, ['John']]], [vp, [vbar, [v, [waits]]]]], ['.']]], '2008-01-15-18-12-22', '130.60.155.177', '').
text_drs_eval(0, 2844, 'each of not at most 5 men owns each of not at most 8 cars.', drs([], []), [], '2008-08-19-19-58-52', '130.60.155.177', '').
text_drs_eval(0, 2845, 'each of at most 5 men owns each of less than 8 cars.', drs([A], [[drs([B], [has_part(A, B)-1])=>drs([C], [[drs([D], [has_part(C, D)-1])=>drs([E], [predicate(E, own, B, D)-1]), object(C, car, countable, na, less, 8)-1]]), object(A, man, countable, na, leq, 5)-1]]), [[specification, [s, [np, [quant, 'each of'], [np, [nump, [genqu, 'at most'], 5], [nbar, [n, men]]]], [vp, [vbar, [vcompl, [v, owns], [np, [quant, 'each of'], [np, [nump, [genqu, 'less than'], 8], [nbar, [n, cars]]]]]]]], '.']], '2009-03-02-11-35-30', '130.60.155.206', '').
text_drs_eval(0, 2846, 'every man owns each of at most 5 cars.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [[drs([C], [has_part(B, C)-1])=>drs([D], [predicate(D, own, A, C)-1]), object(B, car, countable, na, leq, 5)-1]])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, owns], [np, [quant, 'each of'], [np, [nump, [genqu, 'at most'], 5], [nbar, [n, cars]]]]]]]], '.']], '2009-03-02-11-35-55', '130.60.155.206', '').
text_drs_eval(0, 2847, 'at most 1 kg of water flows.', drs([A, B], [[predicate(B, flow, A)-1, object(A, water, mass, kg, leq, 1)-1]]), [[specification, [s, [np, [meas_spec, [nump, [genqu, 'at most'], 1], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, water]]], [vp, [vbar, [vbar, [v, flows]]]]], '.']], '2009-03-02-11-36-32', '130.60.155.206', '').
text_drs_eval(1, 2848, 'John sees nobody but Bill and Mary.', drs([], []), [], '2008-01-15-18-35-30', '130.60.155.177', 'Should we support this?').
text_drs_eval(0, 2849, 'A card manually is taken by John.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1/2, modifier_adv(C, manually, pos)-1/3, property(B, taken, pos)-1/5, predicate(C, be, A, B)-1/4, modifier_pp(C, by, named('John'))-1/6]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [vmod, [adv, manually]], [aux, is], [ap_coord, [ap, [adj, taken]]], [vmod, [pp, [prep, by], [np, [pname, 'John']]]]]], '.']], '2009-11-18-08-46-19', '130.60.155.164', '').
text_drs_eval(0, 2850, 'John is in a park manually.', drs([A, B], [object(A, park, countable, na, eq, 1)-1/5, predicate(B, be, named('John'))-1/2, modifier_pp(B, in, A)-1/3, modifier_adv(B, manually, pos)-1/6]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [vmod, [adv, manually]]]], '.']], '2009-05-19-17-21-52', '130.60.155.193', '').
text_drs_eval(0, 2851, '-0 /= -1.', drs([], []), [], '2008-01-18-11-29-57', '130.60.155.177', '').
text_drs_eval(0, 2852, '-0 = -1.', drs([], [formula(int(0), =, int(-1))-1]), [[specification, [formula, [int, 0], =, [int, -1]], '.']], '2008-07-30-14-43-34', '130.60.155.177', '').
text_drs_eval(0, 2853, '2l of water runs. It is clean.', drs([A, B, C, D], [object(A, water, mass, l, eq, 2)-1, predicate(B, run, A)-1, property(C, clean, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]]]]], [nbar, [n, [water]]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [pn, [it]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2008-02-14-18-39-06', '130.60.155.177', '').
text_drs_eval(0, 2854, 'Some water of John runs. The water of John is clean.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, water, mass, na, na, na)-1, relation(B, of, A)-1, predicate(C, run, B)-1, property(D, clean, pos)-2, predicate(E, be, B, D)-2]), [[specification, [s, [np, [det, [some]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2008-02-14-15-39-00', '130.60.155.177', '').
text_drs_eval(0, 2855, 'Some water of John runs. Some water of Mary flows. The water of John is clean.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-2, object(C, water, mass, na, na, na)-1, relation(C, of, A)-1, predicate(D, run, C)-1, object(E, water, mass, na, na, na)-2, relation(E, of, B)-2, predicate(F, flow, E)-2, property(G, clean, pos)-3, predicate(H, be, C, G)-3]), [[specification, [s, [np, [det, [some]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [det, [some]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]], [vp, [vbar, [v, [flows]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2008-02-14-15-39-37', '130.60.155.177', '').
text_drs_eval(0, 2856, '2l of water of John runs.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, water, mass, l, eq, 2)-1, relation(B, of, A)-1, predicate(C, run, B)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2008-02-14-15-41-05', '130.60.155.177', '').
text_drs_eval(0, 2857, '2l of water that every man drinks runs.', drs([A, B], [object(A, water, mass, l, eq, 2)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([D], [predicate(D, drink, C, A)-1]), predicate(B, run, A)-1]), [[specification, [s, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]], [nbar, [n, [water]], [rel_cl, [comp, [that]], [np, [det, [every]], [nbar, [n, [man]]]], [vp, [vbar, [v, [drinks]], [np, [[]]]]]]]]]], [vp, [vbar, [v, [runs]]]]], ['.']]], '2008-02-14-15-41-57', '130.60.155.177', '').
text_drs_eval(0, 2858, '2l of water of John runs. 2l of water of Mary flows. The water of John is clean.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-2, object(C, water, mass, l, eq, 2)-1, relation(C, of, A)-1, predicate(D, run, C)-1, object(E, water, mass, l, eq, 2)-2, relation(E, of, B)-2, predicate(F, flow, E)-2, property(G, clean, pos)-3, predicate(H, be, C, G)-3]), [[specification, [s, [np, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]]]]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]]]]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['Mary']]]]]], [vp, [vbar, [v, [flows]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [water]], [pp, [prep, [of]], [np, [pname, ['John']]]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [clean]]]]]]], ['.']]], '2008-02-14-21-47-55', '130.60.155.177', '').
text_drs_eval(0, 2859, '2 kg of water runs. The water is cold.', drs([A, B, C, D], [object(A, water, mass, kg, eq, 2)-1, predicate(B, run, A)-1, property(C, cold, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [measure_np, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [kg]], [pp, [prep, [of]]]]], [nbar, [n, [water]]]], [vp, [vbar, [v, [runs]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [n, [water]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [cold]]]]]]], ['.']]], '2008-02-14-21-47-00', '130.60.155.177', '').
text_drs_eval(0, 2860, '2l of warm water flows. 2l of cold water flows. The warm water boils.', drs([A, B, C, D, E], [object(A, water, mass, l, eq, 2)-1, property(A, warm, pos)-1, predicate(B, flow, A)-1, object(C, water, mass, l, eq, 2)-2, property(C, cold, pos)-2, predicate(D, flow, C)-2, predicate(E, boil, A)-3]), [[specification, [s, [np, [measure_spec, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]]]]], [nbar, [adj, [warm]], [nbar, [n, [water]]]]], [vp, [vbar, [v, [flows]]]]], ['.']], [specification, [s, [np, [measure_spec, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]]]]], [nbar, [adj, [cold]], [nbar, [n, [water]]]]], [vp, [vbar, [v, [flows]]]]], ['.']], [specification, [s, [np, [det, [the]], [nbar, [adj, [warm]], [nbar, [n, [water]]]]], [vp, [vbar, [v, [boils]]]]], ['.']]], '2008-02-18-16-06-17', '130.60.155.177', '').
text_drs_eval(0, 2861, 'If 2l of water boils and the water contains an egg then the water contains a boiled egg.', drs([], [drs([A, B, C, D], [object(A, water, mass, l, eq, 2)-1, predicate(B, boil, A)-1, object(C, egg, countable, na, eq, 1)-1, predicate(D, contain, A, C)-1])=>drs([E, F], [object(E, egg, countable, na, eq, 1)-1, property(E, boiled, pos)-1, predicate(F, contain, A, E)-1])]), [[specification, [cond_s, [if], [s_coord, [s, [np, [measure_spec, [numberp, [gen_quant, [[]]], [number, [2]]], [measure_nbar, [measure_noun, [l]], [pp, [prep, [of]]]]], [nbar, [n, [water]]]], [vp, [vbar, [v, [boils]]]]], [coord, [and]], [s, [np, [det, [the]], [nbar, [n, [water]]]], [vp, [vbar, [v, [contains]], [np, [det, [a]], [nbar, [n, [egg]]]]]]]], [then], [s, [np, [det, [the]], [nbar, [n, [water]]]], [vp, [vbar, [v, [contains]], [np, [det, [a]], [nbar, [adj, [boiled]], [nbar, [n, [egg]]]]]]]]], ['.']]], '2008-02-18-16-21-01', '130.60.155.177', '').
text_drs_eval(0, 2862, 'Every man is seen by his own dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [v, seen], by, [np, [posspn, 'his own'], [nbar, [n, dog]]]]]], '.']], '2008-10-23-15-01-26', '130.60.155.206', '').
text_drs_eval(0, 2863, 'The n:blahs wait.', drs([A, B], [predicate(A, wait, B)-1, object(B, blahs, countable, na, geq, 2)-1]), [[specification, [s, [np, [det, [the]], [nbar, [n, [blahs]]]], [vp, [vbar, [v, [wait]]]]], ['.']]], '2008-02-22-15-40-20', '130.60.155.177', '').
text_drs_eval(0, 2864, 'A number X is [X].', drs([A, B], [object(A, number, countable, na, eq, 1)-1, predicate(B, be, A, list([A]))-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [number]], [appos, [var, ['X']]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [np, [list, ['['], [var, ['X']], [']']]]]]], ['.']]], '2008-02-27-11-52-03', '130.60.204.18', '').
text_drs_eval(0, 2865, 'A number X is [X] and {X, X}.', drs([A, B, C], [object(A, number, countable, na, eq, 1)-1, has_part(C, list([A]))-1, predicate(B, be, A, C)-1, has_part(C, set([A, A]))-1, object(C, na, countable, na, eq, 2)-1]), [[specification, [s, [np, [det, [a]], [nbar, [n, [number]], [appos, [var, ['X']]]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [np_coord, [np, [list, ['['], [var, ['X']], [']']]], [coord, [and]], [np, [set, ['{'], [var, ['X']], [','], [var, ['X']], ['}']]]]]]], ['.']]], '2008-02-27-11-52-20', '130.60.204.18', '').
text_drs_eval(0, 2866, 'There is a number X. [X, X] is bigger than {X, X}.', drs([A, B, C], [object(A, number, countable, na, eq, 1)-1, property(B, big, comp_than, set([A, A]))-2, predicate(C, be, list([A, A]), B)-2]), [[specification, [top_s, [topic, [quant, ['{there is}']], [np, [det, [a]], [nbar, [n, [number]], [appos, [var, ['X']]]]]]], ['.']], [specification, [s, [np, [list, ['['], [var, ['X']], [','], [var, ['X']], [']']]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [ap_coord, [ap, [adj, [bigger]], [conj, [than]], [np, [set, ['{'], [var, ['X']], [','], [var, ['X']], ['}']]]]]]]], ['.']]], '2008-02-27-11-53-40', '130.60.204.18', '').
text_drs_eval(0, 2867, 'There are 3 men. There are who?', drs([A], [object(A, man, countable, na, eq, 3)-1/4, question(drs([B], [query(B, who)-2/3]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there are'], [np, [nump, 3], [nbar, [n, men]]]]], '.'], '.'], [sentence, [query, [question, [topic, [quant, 'there are'], [np, [qpn, who]]]], ?], '.']], '2009-05-13-13-40-51', '130.60.155.193', '').
text_drs_eval(0, 2868, 'Which men are there?', drs([], [question(drs([A], [query(A, which)-1/1, object(A, man, countable, na, geq, 2)-1/2]))]), [[sentence, [query, [question, [topic, [np, [qdet, which], [nbar, [n, men]]], [quant, 'are there']]], ?], '.']], '2009-05-13-13-40-52', '130.60.155.193', '').
text_drs_eval(0, 2869, 'Which dogs of a man are there?', drs([], [question(drs([A, B], [query(A, which)-1/1, object(A, dog, countable, na, geq, 2)-1/2, object(B, man, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3]))]), [[sentence, [query, [question, [topic, [np, [qdet, which], [nbar, [n, dogs], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [quant, 'are there']]], ?], '.']], '2009-05-13-13-40-54', '130.60.155.193', '').
text_drs_eval(0, 2870, 'There are which dogs of a man?', drs([], [question(drs([A, B], [query(A, which)-1/3, object(A, dog, countable, na, geq, 2)-1/4, object(B, man, countable, na, eq, 1)-1/7, relation(A, of, B)-1/5]))]), [[sentence, [query, [question, [topic, [quant, 'there are'], [np, [qdet, which], [nbar, [n, dogs], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]]]], ?], '.']], '2009-05-13-13-40-55', '130.60.155.193', '').
text_drs_eval(0, 2871, 'There are 3 men X. There are 4 men Y. John sees X. Mary sees Y. Bill sees X.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-3, object(B, 'Mary', named, na, eq, 1)-4, object(C, 'Bill', named, na, eq, 1)-5, object(D, man, countable, na, eq, 3)-1, object(E, man, countable, na, eq, 4)-2, predicate(F, see, A, D)-3, predicate(G, see, B, E)-4, predicate(H, see, C, D)-5]), [[specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [3]]], [nbar, [n, [men]], [appos, [var, ['X']]]]]]], ['.']], [specification, [top_s, [topic, [quant, ['{there are}']], [np, [numberp, [gen_quant, [[]]], [number, [4]]], [nbar, [n, [men]], [appos, [var, ['Y']]]]]]], ['.']], [specification, [s, [np, [pname, ['John']]], [vp, [vbar, [v, [sees]], [np, [var, ['X']]]]]], ['.']], [specification, [s, [np, [pname, ['Mary']]], [vp, [vbar, [v, [sees]], [np, [var, ['Y']]]]]], ['.']], [specification, [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [sees]], [np, [var, ['X']]]]]], ['.']]], '2008-02-27-18-25-37', '130.60.155.177', '').
text_drs_eval(0, 2872, 'John and Mary wait. Bill gives them them.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-2, has_part(E, A)-1, predicate(D, wait, E)-1, has_part(E, B)-1, object(E, na, countable, na, eq, 2)-1, predicate(F, give, C, E, E)-2]), [[specification, [s, [np_coord, [np, [pname, ['John']]], [coord, [and]], [np, [pname, ['Mary']]]], [vp, [vbar, [v, [wait]]]]], ['.']], [specification, [s, [np, [pname, ['Bill']]], [vp, [vbar, [v, [gives]], [np, [pn, [them]]], [np, [pn, [them]]]]]], ['.']]], '2008-02-27-18-49-17', '130.60.155.177', '').
text_drs_eval(0, 2873, '"abc" is "ab" & "c".', drs([A], [predicate(A, be, string(abc), expr(&, string(ab), string(c)))-1]), [[specification, [s, [np, [string, [abc]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [np, [expr, [string, [ab]], [&], [string, [c]]]]]]], ['.']]], '2008-02-27-20-00-17', '130.60.155.177', '').
text_drs_eval(0, 2874, '"abc" is "abc" & "" & "".', drs([A], [predicate(A, be, string(abc), expr(&, expr(&, string(abc), string('')), string('')))-1]), [[specification, [s, [np, [string, [abc]]], [vp, [aux, [is], [[]]], [vbar, [v, [[]]], [np, [expr, [expr, [string, [abc]], [&], [string, ['']]], [&], [string, ['']]]]]]], ['.']]], '2008-02-27-20-00-38', '130.60.155.177', '').
text_drs_eval(0, 2875, '"123" is "12" & "3".', drs([A], [predicate(A, be, string('123'), expr(&, string('12'), string('3')))-1/2]), [[specification, [s, [np, [string, '"123"']], [vp, [aux, is], [np, [expr, [string, '"12"'], [string, '"3"']]]]], '.']], '2010-11-12-09-14-33', '89.206.69.32', '').
text_drs_eval(1, 2876, 'Every continent overlaps-with no continent but itself.', drs([], []), [], '2008-03-06-10-20-31', '130.60.155.211', 'Feature request: I would be nice to support this, since there is no good alternative.').
text_drs_eval(1, 2877, 'Every dog is a something.', drs([], []), [], '2008-08-19-16-16-58', '130.60.155.208', 'wrong error message (token "a" is not repeated)').
text_drs_eval(0, 2878, 'human:Peeter owns a car. He drives.', drs([A, B, C, D], [object(A, 'Peeter', named, na, eq, 1)-1, object(B, car, countable, na, eq, 1)-1, predicate(C, own, A, B)-1, predicate(D, drive, A)-2]), [[specification, [s, [np, [pname, 'Peeter']], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, car]]]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [vbar, [v, drives]]]], '.']], '2008-06-26-17-42-29', '130.60.155.206', '').
text_drs_eval(0, 2879, 'A human:xxx sees a masc:yyy and verb:zzz him.', drs([A, B, C, D], [object(A, xxx, countable, na, eq, 1)-1, object(B, yyy, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, predicate(D, zzz, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, xxx]]], [vp_coord, [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, yyy]]]]], [coord, and], [vp, [vbar, [v, zzz], [np, [pn, him]]]]]], '.']], '2008-06-26-17-43-49', '130.60.155.206', '').
text_drs_eval(0, 2880, 'A human:xxx sees a masc:yyy and verb:zzz herself.', drs([A, B, C, D], [object(A, xxx, countable, na, eq, 1)-1, object(B, yyy, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, predicate(D, zzz, A, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, xxx]]], [vp_coord, [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, yyy]]]]], [coord, and], [vp, [vbar, [v, zzz], [np, [pn, herself]]]]]], '.']], '2008-06-26-17-43-59', '130.60.155.206', '').
text_drs_eval(0, 2881, '"\\" is a character.', drs([], []), [], '2010-01-23-18-56-55', '89.206.64.50', '').
text_drs_eval(0, 2882, '"\\\\" is a sequence of 2 characters.', drs([A, B, C], [object(A, sequence, countable, na, eq, 1)-1/4, object(B, character, countable, na, eq, 2)-1/7, relation(A, of, B)-1/5, predicate(C, be, string(\), A)-1/2]), [[specification, [s, [np, [string, '"\\"']], [vp, [aux, is], [np, [det, a], [nbar, [n, sequence], [pp, [prep, of], [np, [nump, 2], [nbar, [n, characters]]]]]]]], '.']], '2010-11-12-08-52-08', '89.206.69.32', '').
text_drs_eval(0, 2883, '"\\/\\/" looks like a letter.', drs([A, B], [object(A, letter, countable, na, eq, 1)-1/5, predicate(B, look, string(//))-1/2, modifier_pp(B, like, A)-1/3]), [[specification, [s, [np, [string, '"//"']], [vp, [vbar, [vbar, [v, looks]], [vmod, [pp, [prep, like], [np, [det, a], [nbar, [n, letter]]]]]]]], '.']], '2010-11-12-08-52-24', '89.206.69.32', '').
text_drs_eval(0, 2884, 'Every lady is somebody whose pet is an animal and who likes nothing but cats .', drs([], [drs([A], [object(A, lady, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(B, somebody, countable, na, eq, 1)-1, object(C, pet, countable, na, eq, 1)-1, relation(C, of, B)-1, object(D, animal, countable, na, eq, 1)-1, predicate(E, be, C, D)-1, drs([G, H], [predicate(G, like, B, H)-1, object(H, something, dom, na, na, na)-1])=>drs([I, J], [object(I, cat, countable, na, eq, 1)-1, predicate(J, be, H, I)-1]), predicate(F, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, lady]]], [vp, [aux, is], [vbar, [np, [pn, somebody], [rel_cl_coord, [rel_cl, [np, [posspn, whose], [nbar, [n, pet]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, animal]]]]]], [coord, and], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, likes], [np, [det, [np, [pn, nothing]], but], [nbar, [n, cats]]]]]]]]]]], '.']], '2008-07-02-00-39-10', '130.60.206.1', '').
text_drs_eval(0, 2885, 'Every man is an adult that is a male and that is a person.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D, E, F, G], [object(B, adult, countable, na, eq, 1)-1, object(C, male, countable, na, eq, 1)-1, predicate(D, be, B, C)-1, object(E, person, countable, na, eq, 1)-1, predicate(F, be, B, E)-1, predicate(G, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, adult], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, male]]]]]], [coord, and], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, person]]]]]]]]]]]], '.']], '2008-07-02-00-39-39', '130.60.206.1', '').
text_drs_eval(0, 2886, 'Every lady is a person whose pet is a cat.', drs([], [drs([A], [object(A, lady, countable, na, eq, 1)-1])=>drs([B, C, D, E, F], [object(B, person, countable, na, eq, 1)-1, object(C, pet, countable, na, eq, 1)-1, relation(C, of, B)-1, object(D, cat, countable, na, eq, 1)-1, predicate(E, be, C, D)-1, predicate(F, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, lady]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, person], [rel_cl, [np, [posspn, whose], [nbar, [n, pet]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]]]]]]], '.']], '2008-07-02-00-40-23', '130.60.206.1', '').
text_drs_eval(0, 2887, 'A customer enters a card X and a code Y. If Y is valid then SimpleMat accepts X. If Y is not valid then SimpleMat rejects X.', drs([A, B, C, D, E, F], [object(A, 'SimpleMat', named, na, eq, 1)-2, object(B, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, has_part(F, C)-1, predicate(D, enter, B, F)-1, object(E, code, countable, na, eq, 1)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1, drs([G, H], [property(G, valid, pos)-2, predicate(H, be, E, G)-2])=>drs([I], [predicate(I, accept, A, C)-2]), drs([], [-drs([J, K], [property(J, valid, pos)-3, predicate(K, be, E, J)-3])])=>drs([L], [predicate(L, reject, A, C)-3])]), [[specification, [s, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [v, enters], [np_coord, [np, [det, a], [nbar, [n, card], [appos, [var, 'X']]]], [coord, and], [np, [det, a], [nbar, [n, code], [appos, [var, 'Y']]]]]]]], '.'], [specification, [cond_s, if, [s, [np, [var, 'Y']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], then, [s, [np, [pname, 'SimpleMat']], [vp, [vbar, [v, accepts], [np, [var, 'X']]]]]], '.'], [specification, [cond_s, if, [s, [np, [var, 'Y']], [vp, [aux, is, not], [vbar, [ap_coord, [ap, [adj, valid]]]]]], then, [s, [np, [pname, 'SimpleMat']], [vp, [vbar, [v, rejects], [np, [var, 'X']]]]]], '.']], '2008-07-09-15-21-22', '130.60.155.206', '').
text_drs_eval(0, 2888, 'A customer enters a card X and a code Y. If the code Y is valid then SimpleMat accepts the card X. If the code Y is not valid then SimpleMat rejects the card X.', drs([A, B, C, D, E, F], [object(A, 'SimpleMat', named, na, eq, 1)-2, object(B, customer, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, has_part(F, C)-1, predicate(D, enter, B, F)-1, object(E, code, countable, na, eq, 1)-1, has_part(F, E)-1, object(F, na, countable, na, eq, 2)-1, drs([G, H], [property(G, valid, pos)-2, predicate(H, be, E, G)-2])=>drs([I], [predicate(I, accept, A, C)-2]), drs([], [-drs([J, K], [property(J, valid, pos)-3, predicate(K, be, E, J)-3])])=>drs([L], [predicate(L, reject, A, C)-3])]), [[specification, [s, [np, [det, a], [nbar, [n, customer]]], [vp, [vbar, [v, enters], [np_coord, [np, [det, a], [nbar, [n, card], [appos, [var, 'X']]]], [coord, and], [np, [det, a], [nbar, [n, code], [appos, [var, 'Y']]]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, the], [nbar, [n, code], [appos, [var, 'Y']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], then, [s, [np, [pname, 'SimpleMat']], [vp, [vbar, [v, accepts], [np, [det, the], [nbar, [n, card], [appos, [var, 'X']]]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, the], [nbar, [n, code], [appos, [var, 'Y']]]], [vp, [aux, is, not], [vbar, [ap_coord, [ap, [adj, valid]]]]]], then, [s, [np, [pname, 'SimpleMat']], [vp, [vbar, [v, rejects], [np, [det, the], [nbar, [n, card], [appos, [var, 'X']]]]]]]], '.']], '2008-07-09-15-21-44', '130.60.155.206', '').
text_drs_eval(0, 2889, 'A card C is green.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card], [appos, [var, 'C']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, green]]]]]], '.']], '2008-07-09-15-22-04', '130.60.155.206', '').
text_drs_eval(0, 2890, 'A card C1 is green.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card], [appos, [var, 'C1']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, green]]]]]], '.']], '2008-07-09-15-22-09', '130.60.155.206', '').
text_drs_eval(0, 2891, 'A card C11234234243 is green.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, property(B, green, pos)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card], [appos, [var, 'C11234234243']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, green]]]]]], '.']], '2008-07-09-15-22-14', '130.60.155.206', '').
text_drs_eval(0, 2892, 'A number N is a ratio of a circumference of a circle to its diameter.', drs([A, B, C, D, E, F], [object(A, number, countable, na, eq, 1)-1, relation(B, of, E)-1, object(B, diameter, countable, na, eq, 1)-1, object(C, ratio, countable, na, eq, 1)-1, object(D, circumference, countable, na, eq, 1)-1, object(E, circle, countable, na, eq, 1)-1, relation(D, of, E)-1, relation(C, of, D)-1, predicate(F, be, A, C)-1, modifier_pp(F, to, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, number], [appos, [var, 'N']]]], [vp, [aux, is], [vbar, [vbar, [np, [det, a], [nbar, [n, ratio], [pp, [prep, of], [np, [det, a], [nbar, [n, circumference], [pp, [prep, of], [np, [det, a], [nbar, [n, circle]]]]]]]]]], [pp, [prep, to], [np, [posspn, its], [nbar, [n, diameter]]]]]]], '.']], '2008-07-09-15-22-28', '130.60.155.206', '').
text_drs_eval(0, 2893, 'A man M1 waits.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'M1']]]], [vp, [vbar, [v, waits]]]], '.']], '2008-07-09-15-22-38', '130.60.155.206', '').
text_drs_eval(0, 2894, 'A man M1 waits. The man M1 is happy.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, property(C, happy, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'M1']]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'M1']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-07-09-15-22-51', '130.60.155.206', '').
text_drs_eval(0, 2895, 'A man M1 waits. M1 is happy.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, property(C, happy, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'M1']]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [var, 'M1']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-07-09-15-23-11', '130.60.155.206', '').
text_drs_eval(0, 2896, 'A dog D of a man is happy. A dog of a woman is sad. D barks.', drs([A, B, C, D, E, F, G, H, I], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, property(C, happy, pos)-1, predicate(D, be, A, C)-1, object(E, dog, countable, na, eq, 1)-2, object(F, woman, countable, na, eq, 1)-2, relation(E, of, F)-2, property(G, sad, pos)-2, predicate(H, be, E, G)-2, predicate(I, bark, A)-3]), [[specification, [s, [np, [det, a], [nbar, [n, dog], [appos, [var, 'D']], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, woman]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, sad]]]]]], '.'], [specification, [s, [np, [var, 'D']], [vp, [vbar, [v, barks]]]], '.']], '2008-07-09-15-23-25', '130.60.155.206', '').
text_drs_eval(0, 2897, 'A dog D of a man is happy. A dog of a woman is sad. The dog D barks.', drs([A, B, C, D, E, F, G, H, I], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, property(C, happy, pos)-1, predicate(D, be, A, C)-1, object(E, dog, countable, na, eq, 1)-2, object(F, woman, countable, na, eq, 1)-2, relation(E, of, F)-2, property(G, sad, pos)-2, predicate(H, be, E, G)-2, predicate(I, bark, A)-3]), [[specification, [s, [np, [det, a], [nbar, [n, dog], [appos, [var, 'D']], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, woman]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, sad]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog], [appos, [var, 'D']]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-15-20-35-02', '130.60.204.15', '').
text_drs_eval(0, 2898, 'There is a red card R. There is a blue card B. The red card R is valid.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, card, countable, na, eq, 1)-2, property(B, blue, pos)-2, property(C, valid, pos)-3, predicate(D, be, A, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-08-15-20-34-59', '130.60.204.15', '').
text_drs_eval(0, 2899, 'There is a red card R. There is a blue card B. The card R is valid.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, card, countable, na, eq, 1)-2, property(B, blue, pos)-2, property(C, valid, pos)-3, predicate(D, be, A, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, card], [appos, [var, 'R']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-08-15-20-35-45', '130.60.204.15', '').
text_drs_eval(0, 2900, 'There is a red card R. There is a blue card B. The card is valid.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, card, countable, na, eq, 1)-2, property(B, blue, pos)-2, property(C, valid, pos)-3, predicate(D, be, B, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, card]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-09-15-24-25', '130.60.155.206', '').
text_drs_eval(0, 2901, 'There is a red card R. There is a blue card B. The red card is valid.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, card, countable, na, eq, 1)-2, property(B, blue, pos)-2, property(C, valid, pos)-3, predicate(D, be, A, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, card]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-09-15-24-36', '130.60.155.206', '').
text_drs_eval(0, 2902, 'There is a red card R. There is a blue card B. R is valid.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, card, countable, na, eq, 1)-2, property(B, blue, pos)-2, property(C, valid, pos)-3, predicate(D, be, A, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]], '.'], [specification, [s, [np, [var, 'R']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-09-15-24-54', '130.60.155.206', '').
text_drs_eval(0, 2903, 'There are a red card R and a blue card B. R is valid.', drs([A, B, C, D, E], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, has_part(C, A)-1, object(B, card, countable, na, eq, 1)-1, property(B, blue, pos)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, property(D, valid, pos)-2, predicate(E, be, A, D)-2]), [[specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]], [coord, and], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]]], '.'], [specification, [s, [np, [var, 'R']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-09-15-25-06', '130.60.155.206', '').
text_drs_eval(0, 2904, 'There are a red card R and a blue card B. They are valid.', drs([A, B, C, D, E], [object(A, card, countable, na, eq, 1)-1, property(A, red, pos)-1, has_part(C, A)-1, object(B, card, countable, na, eq, 1)-1, property(B, blue, pos)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1, property(D, valid, pos)-2, predicate(E, be, C, D)-2]), [[specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [det, a], [nbar, [adj, red], [nbar, [n, card], [appos, [var, 'R']]]]], [coord, and], [np, [det, a], [nbar, [adj, blue], [nbar, [n, card], [appos, [var, 'B']]]]]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [aux, are], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-07-09-15-25-25', '130.60.155.206', '').
text_drs_eval(0, 2905, 'There are 3 men M3. M3 talk.', drs([A, B], [object(A, man, countable, na, eq, 3)-1, predicate(B, talk, A)-2]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, [num, 3]], [nbar, [n, men], [appos, [var, 'M3']]]]]], '.'], [specification, [s, [np, [var, 'M3']], [vp, [vbar, [v, talk]]]], '.']], '2008-07-09-15-25-39', '130.60.155.206', '').
text_drs_eval(1, 2906, 'Each of some men who own the dog D owns D.', drs([A, B, C], [object(A, man, countable, na, geq, 2)-1, predicate(B, own, A, C)-1, object(C, dog, countable, na, eq, 1)-1, drs([D], [has_part(A, D)-1])=>drs([E], [predicate(E, own, D, C)-1])]), [[specification, [s, [np, [quant, 'each of'], [np, [det, some], [nbar, [n, men], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, own], [np, [det, the], [nbar, [n, dog], [appos, [var, 'D']]]]]]]]]], [vp, [vbar, [v, owns], [np, [var, 'D']]]]], '.']], '2008-10-27-11-01-27', '84.74.167.232', 'Missing paraphrase.').
text_drs_eval(0, 2907, 'There is a dog D. Each of some men who own D owns D.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, geq, 2)-2, predicate(C, own, B, A)-2, drs([D], [has_part(B, D)-2])=>drs([E], [predicate(E, own, D, A)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [appos, [var, 'D']]]]]], '.'], [specification, [s, [np, [quant, 'each of'], [np, [det, some], [nbar, [n, men], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, own], [np, [var, 'D']]]]]]]], [vp, [vbar, [v, owns], [np, [var, 'D']]]]], '.']], '2008-07-21-14-41-37', '130.60.155.177', '').
text_drs_eval(0, 2908, 'A child C1 of a child C2 of a man M waits.', drs([A, B, C, D], [object(A, child, countable, na, eq, 1)-1, object(B, child, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-1, relation(B, of, C)-1, relation(A, of, B)-1, predicate(D, wait, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, child], [appos, [var, 'C1']], [pp, [prep, of], [np, [det, a], [nbar, [n, child], [appos, [var, 'C2']], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [appos, [var, 'M']]]]]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-39-00', '130.60.204.15', '').
text_drs_eval(0, 2909, '2 men M drink. They eat.', drs([A, B, C], [object(A, man, countable, na, eq, 2)-1, predicate(B, drink, A)-1, predicate(C, eat, A)-2]), [[specification, [s, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'M']]]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [vbar, [v, eat]]]], '.']], '2008-07-09-15-26-46', '130.60.155.206', '').
text_drs_eval(0, 2910, '2 men M drink. M talk. They eat.', drs([A, B, C, D], [object(A, man, countable, na, eq, 2)-1, predicate(B, drink, A)-1, predicate(C, talk, A)-2, predicate(D, eat, A)-3]), [[specification, [s, [np, [nump, [num, 2]], [nbar, [n, men], [appos, [var, 'M']]]], [vp, [vbar, [v, drink]]]], '.'], [specification, [s, [np, [var, 'M']], [vp, [vbar, [v, talk]]]], '.'], [specification, [s, [np, [pn, they]], [vp, [vbar, [v, eat]]]], '.']], '2008-07-09-15-26-55', '130.60.155.206', '').
text_drs_eval(0, 2911, 'There is a long zip-code Z.', drs([A], [object(A, 'zip-code', countable, na, eq, 1)-1, property(A, long, pos)-1]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, long], [nbar, [n, 'zip-code'], [appos, [var, 'Z']]]]]]], '.']], '2008-07-09-15-27-04', '130.60.155.206', '').
text_drs_eval(0, 2912, 'If John works in a bank then he does not commute.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [object(B, bank, countable, na, eq, 1)-1, predicate(C, work, A)-1, modifier_pp(C, in, B)-1])=>drs([], [-drs([D], [predicate(D, commute, A)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, works]], [pp, [prep, in], [np, [det, a], [nbar, [n, bank]]]]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [v, commute]]]]], '.']], '2008-07-09-18-16-43', '130.60.155.177', '').
text_drs_eval(0, 2913, 'If John works then John does not work in his own house.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C, D], [relation(C, of, A)-1, object(C, house, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vbar, [v, work]], [pp, [prep, in], [np, [posspn, 'his own'], [nbar, [n, house]]]]]]]], '.']], '2008-07-09-18-18-29', '130.60.155.177', '').
text_drs_eval(0, 2914, 'If John works then he does not work in his own house.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C, D], [relation(C, of, A)-1, object(C, house, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [vbar, [v, work]], [pp, [prep, in], [np, [posspn, 'his own'], [nbar, [n, house]]]]]]]], '.']], '2008-07-30-01-17-42', '130.60.204.7', '').
text_drs_eval(0, 2915, 'If John works then he does not work.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C], [predicate(C, work, A)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [v, work]]]]], '.']], '2008-07-09-18-19-04', '130.60.155.177', '').
text_drs_eval(0, 2916, 'If John works then John does not work in John\'s house.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C, D], [relation(C, of, A)-1, object(C, house, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vbar, [v, work]], [pp, [prep, in], [np, [poss_np, [pname, 'John'], [gen_marker, '\'s']], [nbar, [n, house]]]]]]]], '.']], '2008-07-09-18-19-34', '130.60.155.177', '').
text_drs_eval(0, 2917, 'If John works then he does not work in John\'s house.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C, D], [relation(C, of, A)-1, object(C, house, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [vbar, [v, work]], [pp, [prep, in], [np, [poss_np, [pname, 'John'], [gen_marker, '\'s']], [nbar, [n, house]]]]]]]], '.']], '2008-07-30-01-18-35', '130.60.204.7', '').
text_drs_eval(0, 2918, 'If John works then he does not work in a house.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C, D], [object(C, house, countable, na, eq, 1)-1, predicate(D, work, A)-1, modifier_pp(D, in, C)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [vbar, [v, work]], [pp, [prep, in], [np, [det, a], [nbar, [n, house]]]]]]]], '.']], '2008-07-09-18-20-44', '130.60.155.177', '').
text_drs_eval(0, 2919, 'If John works then he does not see himself.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [predicate(B, work, A)-1])=>drs([], [-drs([C], [predicate(C, see, A, A)-1])])]), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [v, see], [np, [pn, himself]]]]]], '.']], '2008-07-09-18-21-04', '130.60.155.177', '').
text_drs_eval(0, 2920, 'If John works then he does not feed his dog.', drs([], []), [[specification, [cond_s, if, [s, [np, [pname, 'John']], [vp, [vbar, [v, works]]]], then, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [v, feed], [np, [posspn, his], [nbar, [n, dog]]]]]]], '.']], '2008-07-09-18-21-31', '130.60.155.177', '').
text_drs_eval(0, 2921, 'Mary sees John. He does not work in John\'s house.', drs([A, B, C], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, see, A, B)-1, -drs([D, E], [relation(D, of, B)-2, object(D, house, countable, na, eq, 1)-2, predicate(E, work, B)-2, modifier_pp(E, in, D)-2])]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, sees], [np, [pname, 'John']]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [aux, does, not], [vbar, [vbar, [v, work]], [pp, [prep, in], [np, [poss_np, [pname, 'John'], [gen_marker, '\'s']], [nbar, [n, house]]]]]]], '.']], '2008-07-09-18-24-58', '130.60.155.177', '').
text_drs_eval(0, 2922, 'X sees a man X. X sleeps.', drs([], []), [[specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sleeps]]]], '.']], '2008-07-12-00-31-27', '130.60.204.28', '').
text_drs_eval(0, 2923, 'John knows the Abcdef.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Abcdef', named, na, eq, 1)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [pname, 'Abcdef']]]]], '.']], '2008-07-10-11-49-37', '130.60.155.206', '').
text_drs_eval(0, 2924, 'John knows Abcdef.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Abcdef', named, na, eq, 1)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [pname, 'Abcdef']]]]], '.']], '2008-07-10-11-49-43', '130.60.155.206', '').
text_drs_eval(0, 2925, 'John knows Sun.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Sun', named, na, eq, 1)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [pname, 'Sun']]]]], '.']], '2008-07-10-11-49-52', '130.60.155.206', '').
text_drs_eval(0, 2926, 'John knows the Sun.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Sun', named, na, eq, 1)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [pname, the, 'Sun']]]]], '.']], '2008-07-10-11-49-57', '130.60.155.206', '').
text_drs_eval(0, 2927, 'John knows Mary.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [pname, 'Mary']]]]], '.']], '2008-07-10-11-50-05', '130.60.155.206', '').
text_drs_eval(0, 2928, 'John knows the Mary.', drs([], []), [], '2008-07-10-11-50-10', '130.60.155.206', '').
text_drs_eval(0, 2929, 'John knows United-Nations.', drs([], []), [], '2008-07-10-11-50-20', '130.60.155.206', '').
text_drs_eval(0, 2930, 'John knows the United-Nations.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'United-Nations', named, na, geq, 2)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [pname, theWordForm]]]]], '.']], '2008-07-10-11-50-24', '130.60.155.206', '').
text_drs_eval(0, 2931, 'X sees X.', drs([A, B], [object(A, something, dom, na, na, na)-1, predicate(B, see, A, A)-1]), [[specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sees], [np, [var, 'X']]]]], '.']], '2008-07-12-00-27-00', '130.60.204.28', '').
text_drs_eval(0, 2932, 'A man spends his own vacation in a warm country. Where does he spend the vacation?', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, country, countable, na, eq, 1)-1/10, property(B, warm, pos)-1/9, relation(C, of, A)-1/4, object(C, vacation, countable, na, eq, 1)-1/6, predicate(D, spend, A, C)-1/3, modifier_pp(D, in, B)-1/7, question(drs([E], [predicate(E, spend, A, C)-2/4, query(E, where)-2/1]))]), [[sentence, [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, spends], [np, [posspn, 'his own'], [nbar, [n, vacation]]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [adj, warm], [nbar, [n, country]]]]]]]]], '.'], '.'], [sentence, [query, [question, [qpn, where], does, [np, [pn, he]], [vp, [vbar, [vcompl, [v, spend], [np, [det, the], [nbar, [n, vacation]]]]]]], ?], '.']], '2009-05-13-13-40-56', '130.60.155.193', '').
text_drs_eval(0, 2933, 'If a group is {John, Bill} then John is X.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, drs([C, D], [object(C, group, countable, na, eq, 1)-1, predicate(D, be, C, set([A, B]))-1])=>drs([E, F], [object(E, something, dom, na, na, na)-1, predicate(F, be, A, E)-1])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, group]]], [vp, [aux, is], [vbar, [np, [set, [pname, 'John'], ',', [pname, 'Bill']]]]]], then, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [var, 'X']]]]]], '.']], '2008-07-14-09-06-16', '130.60.155.206', '').
text_drs_eval(0, 2934, 'John knows X.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, know, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [var, 'X']]]]], '.']], '2008-07-14-09-06-24', '130.60.155.206', '').
text_drs_eval(0, 2935, 'John sees Every woman.', drs([], []), [], '2008-07-14-13-45-00', '130.60.155.206', '').
text_drs_eval(0, 2936, 'John sees A dog.', drs([], []), [], '2008-07-14-13-46-08', '130.60.155.206', '').
text_drs_eval(0, 2937, 'John Is a man.', drs([], []), [], '2008-07-14-13-46-20', '130.60.155.206', '').
text_drs_eval(0, 2938, 'There is some toxicity. The toxicity is high.', drs([A, B, C], [object(A, toxicity, mass, na, na, na)-1, property(B, high, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, some], [nbar, [n, toxicity]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, toxicity]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, high]]]]]], '.']], '2008-07-18-16-38-07', '130.60.155.206', '').
text_drs_eval(0, 2939, 'There is some water. The water is wet.', drs([A, B, C], [object(A, water, mass, na, na, na)-1, property(B, wet, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, some], [nbar, [n, water]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, water]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, wet]]]]]], '.']], '2008-07-18-16-41-21', '130.60.155.206', '').
text_drs_eval(0, 2940, 'There is a water. The water is wet.', drs([A, B, C], [object(A, water, countable, na, eq, 1)-1, property(B, wet, pos)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, water]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, water]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, wet]]]]]], '.']], '2008-07-18-16-41-24', '130.60.155.206', '').
text_drs_eval(0, 2941, 'There is some water. There is a water. The water is wet.', drs([A, B, C, D], [object(A, water, mass, na, na, na)-1, object(B, water, countable, na, eq, 1)-2, property(C, wet, pos)-3, predicate(D, be, B, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, some], [nbar, [n, water]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, water]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, water]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, wet]]]]]], '.']], '2008-07-18-16-41-58', '130.60.155.206', '').
text_drs_eval(0, 2942, 'There is a water. There is some water. The water is wet.', drs([A, B, C, D], [object(A, water, countable, na, eq, 1)-1, object(B, water, mass, na, na, na)-2, property(C, wet, pos)-3, predicate(D, be, B, C)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, water]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, some], [nbar, [n, water]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, water]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, wet]]]]]], '.']], '2008-07-18-16-41-59', '130.60.155.206', '').
text_drs_eval(0, 2943, 'It is false that there is X.', drs([], [-drs([A], [object(A, something, dom, na, na, na)-1])]), [[specification, [s, [neg, 'it is false'], [cp, that, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]]]], '.']], '2009-01-05-14-43-08', '130.60.155.206', '').
text_drs_eval(0, 2944, 'If there is X then there is Y.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B], [object(B, something, dom, na, na, na)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], then, [top_s, [topic, [quant, 'there is'], [np, [var, 'Y']]]]], '.']], '2009-01-05-14-43-15', '130.60.155.206', '').
text_drs_eval(0, 2945, 'It is false that there is something X.', drs([], [-drs([A], [object(A, something, dom, na, na, na)-1])]), [[specification, [s, [neg, 'it is false'], [cp, that, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X']]]]]]], '.']], '2009-01-05-14-43-27', '130.60.155.206', '').
text_drs_eval(0, 2946, 'If there is something X then there is something Y.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1])=>drs([B], [object(B, something, dom, na, na, na)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X']]]]], then, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'Y']]]]]], '.']], '2009-01-05-14-43-42', '130.60.155.206', '').
text_drs_eval(0, 2947, 'If there is something X then there is X.', drs([], []), [], '2008-07-21-14-47-34', '130.60.155.177', '').
text_drs_eval(0, 2948, 'If there is something X then there is something X.', drs([], []), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X']]]]], then, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X']]]]]], '.']], '2008-07-21-14-47-44', '130.60.155.177', '').
text_drs_eval(0, 2949, 'If X\'s pet is Y then X likes Y.', drs([], [drs([A, B, C, D], [object(A, something, dom, na, na, na)-1, relation(B, of, A)-1, object(B, pet, countable, na, eq, 1)-1, object(C, something, dom, na, na, na)-1, predicate(D, be, B, C)-1])=>drs([E], [predicate(E, like, A, C)-1])]), [[specification, [cond_s, if, [s, [np, [poss_np, [var, 'X'], [gen_marker, '\'s']], [nbar, [n, pet]]], [vp, [aux, is], [vbar, [np, [var, 'Y']]]]], then, [s, [np, [var, 'X']], [vp, [vbar, [v, likes], [np, [var, 'Y']]]]]], '.']], '2008-07-22-22-34-03', '77.57.2.2', '').
text_drs_eval(0, 2950, 'John works at at least 3 banks.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, bank, countable, na, geq, 3)-1, predicate(C, work, A)-1, modifier_pp(C, at, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, works]], [pp, [prep, at], [np, [nump, [genqu, 'at least'], [num, 3]], [nbar, [n, banks]]]]]]], '.']], '2008-07-25-14-23-18', '130.60.155.177', '').
text_drs_eval(0, 2951, 'John looks at at least 4 men at least 3 dogs of who bark.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, geq, 4)-1, object(C, dog, countable, na, geq, 3)-1, relation(C, of, B)-1, predicate(D, bark, C)-1, predicate(E, look, A)-1, modifier_pp(E, at, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, looks]], [pp, [prep, at], [np, [nump, [genqu, 'at least'], [num, 4]], [nbar, [n, men], [rel_cl, [np, [nump, [genqu, 'at least'], [num, 3]], [nbar, [n, dogs], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [vbar, [v, bark]]]]]]]]]], '.']], '2008-07-25-14-27-23', '130.60.155.177', '').
text_drs_eval(0, 2952, 'John sees a man who sleeps in a bed in a morning.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, C)-1, modifier_pp(E, in, D)-1, predicate(F, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]]], '.']], '2008-07-26-23-03-54', '77.57.2.2', '').
text_drs_eval(0, 2953, 'John sees a man who sleeps soundly in a bed in a morning.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, C)-1, modifier_pp(E, in, D)-1, modifier_adv(E, soundly, pos)-1, predicate(F, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]]], '.']], '2008-09-23-11-34-59', '130.60.155.206', '').
text_drs_eval(0, 2954, 'There is a man who does not sleep soundly in a bed in a morning.', drs([A], [object(A, man, countable, na, eq, 1)-1, -drs([B, C, D], [object(B, morning, countable, na, eq, 1)-1, object(C, bed, countable, na, eq, 1)-1, predicate(D, sleep, A)-1, modifier_pp(D, in, B)-1, modifier_pp(D, in, C)-1, modifier_adv(D, soundly, pos)-1])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]], '.']], '2008-07-26-23-16-38', '77.57.2.2', '').
text_drs_eval(0, 2955, 'John sees a man who does not sleep soundly in a bed in a morning.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E, F], [object(D, morning, countable, na, eq, 1)-1, object(E, bed, countable, na, eq, 1)-1, predicate(F, sleep, B)-1, modifier_pp(F, in, D)-1, modifier_pp(F, in, E)-1, modifier_adv(F, soundly, pos)-1]), predicate(C, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]]], '.']], '2008-09-23-11-28-17', '130.60.155.206', '').
text_drs_eval(0, 2956, 'John soundly sees a man who sleeps in a bed in a morning.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, morning, countable, na, eq, 1)-1, object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, C)-1, modifier_pp(E, in, D)-1, predicate(F, see, A, B)-1, modifier_adv(F, soundly, pos)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, soundly], [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]]]], '.']], '2008-07-26-23-19-25', '77.57.2.2', '').
text_drs_eval(0, 2957, 'John soundly sees a man in a bed in a morning. The man sleeps.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1, object(B, morning, countable, na, eq, 1)-1, object(C, bed, countable, na, eq, 1)-1, object(D, man, countable, na, eq, 1)-1, predicate(E, see, A, D)-1, modifier_adv(E, soundly, pos)-1, modifier_pp(E, in, B)-1, modifier_pp(E, in, C)-1, predicate(F, sleep, D)-2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, soundly], [vbar, [vbar, [v, sees], [np, [det, a], [nbar, [n, man]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, sleeps]]]], '.']], '2008-07-26-23-20-20', '77.57.2.2', '').
text_drs_eval(0, 2958, 'A customer who manually in a bank enters a card types a code.', drs([A, B, C, D, E, F], [object(A, customer, countable, na, eq, 1)-1/2, object(B, bank, countable, na, eq, 1)-1/7, object(C, card, countable, na, eq, 1)-1/10, predicate(D, enter, A, C)-1/8, modifier_pp(D, in, B)-1/5, modifier_adv(D, manually, pos)-1/4, object(E, code, countable, na, eq, 1)-1/13, predicate(F, type, A, E)-1/11]), [[specification, [s, [np, [det, a], [nbar, [n, customer], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vmod, [adv, manually], [pp, [prep, in], [np, [det, a], [nbar, [n, bank]]]]], [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]]]]]]], [vp, [vbar, [vcompl, [v, types], [np, [det, a], [nbar, [n, code]]]]]]], '.']], '2009-04-02-15-21-42', '130.60.155.206', '').
text_drs_eval(0, 2959, 'There is a man who does not sleep. There is a woman who does not wait. John sees the man who does not sleep.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, -drs([E], [predicate(E, sleep, B)-1]), object(C, woman, countable, na, eq, 1)-2, -drs([F], [predicate(F, wait, C)-2]), predicate(D, see, A, B)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-07-27-01-59-07', '130.60.206.2', '').
text_drs_eval(0, 2960, 'There is a man who does not sleep. John sees the man.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, -drs([D], [predicate(D, sleep, B)-1]), predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]], '.']], '2008-07-27-02-42-10', '77.57.2.2', '').
text_drs_eval(0, 2961, 'John sees soundly in a bed in a morning _that_ a man sleeps.', drs([], []), [], '2009-04-02-13-16-50', '130.60.155.206', '').
text_drs_eval(0, 2962, 'John sees a man who does not sleep soundly in a bed.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, D)-1, modifier_adv(E, soundly, pos)-1]), predicate(C, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]]]]]], '.']], '2008-09-23-11-35-20', '130.60.155.206', '').
text_drs_eval(0, 2963, 'John soundly sees a man who does not sleep in a bed.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, D)-1]), predicate(C, see, A, B)-1, modifier_adv(C, soundly, pos)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, soundly], [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]]]]]]], '.']], '2008-07-27-14-03-33', '77.57.2.2', '').
text_drs_eval(0, 2964, 'John soundly and quickly sees a man who does not sleep in a bed.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, D)-1]), predicate(C, see, A, B)-1, modifier_adv(C, quickly, pos)-1, modifier_adv(C, soundly, pos)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv_coord, [adv, soundly], [coord, and], [adv, quickly]], [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]]]]]]], '.']], '2008-07-27-14-04-50', '77.57.2.2', '').
text_drs_eval(0, 2965, 'John sees a man who does not sleep in a bed soundly.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_adv(E, soundly, pos)-1, modifier_pp(E, in, D)-1]), predicate(C, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [adv, soundly]]]]]]]]], '.']], '2008-07-27-14-05-36', '77.57.2.2', '').
text_drs_eval(0, 2966, 'John sees a man who does not sleep in a bed soundly and quickly.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_adv(E, quickly, pos)-1, modifier_adv(E, soundly, pos)-1, modifier_pp(E, in, D)-1]), predicate(C, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [adv_coord, [adv, soundly], [coord, and], [adv, quickly]]]]]]]]]], '.']], '2008-07-27-14-05-47', '77.57.2.2', '').
text_drs_eval(0, 2967, 'John sees a man who does not sleep soundly and quickly in a bed.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D, E], [object(D, bed, countable, na, eq, 1)-1, predicate(E, sleep, B)-1, modifier_pp(E, in, D)-1, modifier_adv(E, quickly, pos)-1, modifier_adv(E, soundly, pos)-1]), predicate(C, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [adv_coord, [adv, soundly], [coord, and], [adv, quickly]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]]]]]], '.']], '2008-09-23-11-35-37', '130.60.155.206', '').
text_drs_eval(0, 2968, 'John sees a man who sleeps in a bed soundly.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, bed, countable, na, eq, 1)-1, predicate(D, sleep, B)-1, modifier_adv(D, soundly, pos)-1, modifier_pp(D, in, C)-1, predicate(E, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [adv, soundly]]]]]]]]], '.']], '2008-07-27-14-09-03', '77.57.2.2', '').
text_drs_eval(0, 2969, 'There is a man. John sees the man. The man does not sleep.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, see, A, B)-2, -drs([D], [predicate(D, sleep, B)-3])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, sleep]]]], '.']], '2008-07-29-01-30-59', '130.60.204.21', '').
text_drs_eval(0, 2970, 'If there is a man who does not sleep and John sees the man then a dog barks.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C], [object(B, man, countable, na, eq, 1)-1, -drs([D], [predicate(D, sleep, B)-1]), predicate(C, see, A, B)-1])=>drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, bark, E)-1])]), [[specification, [cond_s, if, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], [coord, and], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]], then, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]]], '.']], '2008-07-29-01-32-46', '130.60.204.21', '').
text_drs_eval(0, 2971, 'John is as a:richrich as Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, property(C, richrich, pos_as, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [ap_coord, [ap, as, [adj, richrich], as, [np, [pname, 'Mary']]]]]]], '.']], '2008-07-29-16-42-40', '130.60.155.177', '').
text_drs_eval(0, 2972, 'John is as a:fondfond-of Mary as Bill.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Bill', named, na, eq, 1)-1, property(D, 'fondfond-of', B, pos_as, subj, C)-1, predicate(E, be, A, D)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [ap_coord, [ap, as, [adj, 'fondfond-of'], [np, [pname, 'Mary']], as, [np, [pname, 'Bill']]]]]]], '.']], '2008-07-29-17-01-18', '130.60.155.177', '').
text_drs_eval(0, 2973, 'There is a man who does not sleep and John sees the man.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, -drs([D], [predicate(D, sleep, B)-1]), predicate(C, see, A, B)-1]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], [coord, and], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]], '.']], '2008-07-29-17-17-35', '130.60.155.177', '').
text_drs_eval(0, 2974, 'There is a man who does not sleep or John sees the man.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1, -drs([C], [predicate(C, sleep, B)-1])])v drs([D], [predicate(D, see, A, B)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], [coord, or], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]], '.']], '2008-07-29-17-51-08', '130.60.155.177', '').
text_drs_eval(0, 2975, 'There is a man or the man does not sleep or John sees the man.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])v drs([], [drs([], [-drs([C], [predicate(C, sleep, B)-1])])v drs([D], [predicate(D, see, A, B)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, sleep]]]], [coord, or], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]], '.']], '2008-07-29-17-52-10', '130.60.155.177', '').
text_drs_eval(0, 2976, 'There is a man or the man does not sleep and John sees the man.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, man, countable, na, eq, 1)-1])v drs([C], [-drs([D], [predicate(D, sleep, B)-1]), predicate(C, see, A, B)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, sleep]]]], [coord, and], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]], '.']], '2008-07-29-17-53-18', '130.60.155.177', '').
text_drs_eval(0, 2977, 'There is a man or the man does not sleep, and John sees the man.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, drs([D], [object(D, man, countable, na, eq, 1)-1])v drs([], [-drs([E], [predicate(E, sleep, D)-1])]), predicate(B, see, A, C)-1, object(C, man, countable, na, eq, 1)-1]), [[specification, [s_coord, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, sleep]]]]], [coord, ', and'], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]], '.']], '2008-07-29-17-54-14', '130.60.155.177', '').
text_drs_eval(0, 2978, 'There is a man or the man sleeps.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([B], [predicate(B, sleep, A)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, sleeps]]]]], '.']], '2008-07-29-17-54-41', '130.60.155.177', '').
text_drs_eval(0, 2979, 'X is Y.', drs([A, B, C], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [np, [var, 'Y']]]]], '.']], '2008-07-29-18-08-39', '130.60.155.177', '').
text_drs_eval(0, 2980, 'X is X.', drs([A, B], [object(A, something, dom, na, na, na)-1, predicate(B, be, A, A)-1]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [np, [var, 'X']]]]], '.']], '2008-07-29-18-08-42', '130.60.155.177', '').
text_drs_eval(0, 2981, 'X is not X.', drs([A], [object(A, something, dom, na, na, na)-1, -drs([B], [predicate(B, be, A, A)-1])]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is, not], [vbar, [np, [var, 'X']]]]], '.']], '2008-07-29-18-09-02', '130.60.155.177', '').
text_drs_eval(0, 2982, 'X is not Y.', drs([A], [object(A, something, dom, na, na, na)-1, -drs([B, C], [object(B, something, dom, na, na, na)-1, predicate(C, be, A, B)-1])]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is, not], [vbar, [np, [var, 'Y']]]]], '.']], '2008-07-29-18-09-24', '130.60.155.177', '').
text_drs_eval(0, 2983, 'A man likes Mary. Sue likes the man that likes Mary.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'Sue', named, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, predicate(D, like, C, A)-1, predicate(E, like, B, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, likes], [np, [pname, 'Mary']]]]], '.'], [specification, [s, [np, [pname, 'Sue']], [vp, [vbar, [v, likes], [np, [det, the], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [v, likes], [np, [pname, 'Mary']]]]]]]]]], '.']], '2008-08-20-22-09-02', '130.60.206.93', '').
text_drs_eval(0, 2984, 'There is a man that must feed every dog. There is a man that must feed every cat. The man that must feed every dog feeds himself.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, must(drs([], [drs([D], [object(D, dog, countable, na, eq, 1)-1/9])=>drs([E], [predicate(E, feed, A, D)-1/7])])), object(B, man, countable, na, eq, 1)-2/4, must(drs([], [drs([F], [object(F, cat, countable, na, eq, 1)-2/9])=>drs([G], [predicate(G, feed, B, F)-2/7])])), predicate(C, feed, A, A)-3/8]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [aux, must], [vbar, [vcompl, [v, feed], [np, [det, every], [nbar, [n, dog]]]]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [aux, must], [vbar, [vcompl, [v, feed], [np, [det, every], [nbar, [n, cat]]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [comp, that], [vp, [aux, must], [vbar, [vcompl, [v, feed], [np, [det, every], [nbar, [n, dog]]]]]]]]], [vp, [vbar, [vcompl, [v, feeds], [np, [pn, himself]]]]]], '.']], '2010-10-27-09-32-53', '89.206.64.27', '').
text_drs_eval(0, 2985, 'There is a dog. A man sees the dog and likes it.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, predicate(C, see, B, A)-2, predicate(D, like, B, A)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, dog]]]]], [coord, and], [vp, [vbar, [v, likes], [np, [pn, it]]]]]], '.']], '2008-07-30-14-34-44', '130.60.155.177', '').
text_drs_eval(0, 2986, 'There is a boy. A man sees his cat and a dog.', drs([A, B, C, D, E, F], [object(A, boy, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-2, relation(C, of, A)-2, object(C, cat, countable, na, eq, 1)-2, has_part(F, C)-2, predicate(D, see, B, F)-2, object(E, dog, countable, na, eq, 1)-2, has_part(F, E)-2, object(F, na, countable, na, eq, 2)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, boy]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np_coord, [np, [posspn, his], [nbar, [n, cat]]], [coord, and], [np, [det, a], [nbar, [n, dog]]]]]]], '.']], '2008-07-30-14-35-59', '130.60.155.177', '').
text_drs_eval(0, 2987, 'If there is an animal that is a dog or that is a cat then John sees the animal that is a dog or that is a cat.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, animal, countable, na, eq, 1)-1, drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])v drs([E, F], [object(E, cat, countable, na, eq, 1)-1, predicate(F, be, B, E)-1])])=>drs([G], [predicate(G, see, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, animal], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]]]]]]]]], '.']], '2008-07-30-14-50-34', '130.60.155.177', '').
text_drs_eval(0, 2988, 'If there is an animal that is not a dog or that is a cat then John sees the animal that is not a dog or that is a cat.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, animal, countable, na, eq, 1)-1, drs([], [-drs([C, D], [object(C, dog, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])])v drs([E, F], [object(E, cat, countable, na, eq, 1)-1, predicate(F, be, B, E)-1])])=>drs([G], [predicate(G, see, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is, not], [vbar, [np, [det, a], [nbar, [n, dog]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, animal], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is, not], [vbar, [np, [det, a], [nbar, [n, dog]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]]]]]]]]], '.']], '2008-07-30-14-51-09', '130.60.155.177', '').
text_drs_eval(0, 2989, 'If there is an animal that is a cat or that is a dog then John sees the animal that is a dog or that is a cat.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, animal, countable, na, eq, 1)-1, drs([C, D], [object(C, cat, countable, na, eq, 1)-1, predicate(D, be, B, C)-1])v drs([E, F], [object(E, dog, countable, na, eq, 1)-1, predicate(F, be, B, E)-1])])=>drs([G], [predicate(G, see, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog]]]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, animal], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, cat]]]]]]]]]]]]], '.']], '2008-07-30-14-52-13', '130.60.155.177', '').
text_drs_eval(0, 2990, 'If there is an animal that eats every food then John sees the animal that eats every food.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, animal, countable, na, eq, 1)-1, drs([C], [object(C, food, countable, na, eq, 1)-1])=>drs([D], [predicate(D, eat, B, C)-1])])=>drs([E], [predicate(E, see, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [rel_cl, [comp, that], [vp, [vbar, [v, eats], [np, [det, every], [nbar, [n, food]]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, animal], [rel_cl, [comp, that], [vp, [vbar, [v, eats], [np, [det, every], [nbar, [n, food]]]]]]]]]]]], '.']], '2008-07-30-14-53-06', '130.60.155.177', '').
text_drs_eval(0, 2991, 'If there is an animal that believes that John is its own owner then John sees the animal.', drs([], []), [], '2008-10-23-15-00-06', '130.60.155.206', '').
text_drs_eval(0, 2992, 'If there is an animal that believes that John is its own owner then John sees the animal that believes that John is its own owner.', drs([], []), [], '2008-10-06-14-51-13', '130.60.155.206', '').
text_drs_eval(0, 2993, 'John is his own owner.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, owner, countable, na, eq, 1)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, 'his own'], [nbar, [n, owner]]]]]], '.']], '2008-07-30-14-55-29', '130.60.155.177', '').
text_drs_eval(0, 2994, 'John is his owner.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, his], [nbar, [n, owner]]]]]], '.']], '2008-07-30-14-55-37', '130.60.155.177', '').
text_drs_eval(0, 2995, 'Bill knows that John is his own owner.', drs([A, B, C, D], [object(A, 'Bill', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, know, A, D)-1, D:drs([E, F], [relation(E, of, B)-1, object(E, owner, countable, na, eq, 1)-1, predicate(F, be, B, E)-1])]), [[specification, [s, [np, [pname, 'Bill']], [vp, [vbar, [v, knows], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, 'his own'], [nbar, [n, owner]]]]]]]]]], '.']], '2008-07-30-14-56-13', '130.60.155.177', '').
text_drs_eval(0, 2996, 'Bill knows that John is his owner.', drs([A, B, C, D], [object(A, 'Bill', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-1, predicate(C, know, A, D)-1, D:drs([E, F], [relation(E, of, A)-1, object(E, owner, countable, na, eq, 1)-1, predicate(F, be, B, E)-1])]), [[specification, [s, [np, [pname, 'Bill']], [vp, [vbar, [v, knows], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, his], [nbar, [n, owner]]]]]]]]]], '.']], '2008-10-23-14-51-47', '130.60.155.177', '').
text_drs_eval(0, 2997, 'John sees a man. Mary knows the man that John sees.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-2, object(C, man, countable, na, eq, 1)-1, predicate(D, see, A, C)-1, predicate(E, know, B, C)-2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, man], [rel_cl, [comp, that], [np, [pname, 'John']], [vp, [vbar, [v, sees]]]]]]]]], '.']], '2008-08-20-22-09-49', '130.60.206.93', '').
text_drs_eval(0, 2998, 'A man sees a woman. Mary knows the woman that the man sees.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, woman, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, know, A, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, woman]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, woman], [rel_cl, [comp, that], [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, sees]]]]]]]]], '.']], '2008-07-30-15-01-03', '130.60.155.177', '').
text_drs_eval(0, 2999, 'A man sees a woman. Mary knows the woman that a man sees.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, woman, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, know, A, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, woman]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, woman], [rel_cl, [comp, that], [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees]]]]]]]]], '.']], '2008-07-30-15-01-15', '130.60.155.177', '').
text_drs_eval(0, 3000, 'A man sees a woman. Mary knows the man that sees the woman.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, woman, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, know, A, B)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, woman]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, woman]]]]]]]]]]], '.']], '2008-07-30-15-01-36', '130.60.155.177', '').
text_drs_eval(0, 3001, 'A man sees a woman. Mary knows the man that sees a woman.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, woman, countable, na, eq, 1)-1, predicate(D, see, B, C)-1, predicate(E, know, A, B)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, woman]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, woman]]]]]]]]]]], '.']], '2008-07-30-15-01-46', '130.60.155.177', '').
text_drs_eval(0, 3002, 'A man X and Y\'s dog can wait.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, has_part(D, A)-1/'', can(drs([E], [predicate(E, wait, D)-1/10])), object(B, something, dom, na, na, na)-1/5, relation(C, of, B)-1/6, object(C, dog, countable, na, eq, 1)-1/8, has_part(D, C)-1/'', object(D, na, countable, na, eq, 2)-1/'']), [[specification, [s, [np_coord, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [coord, and], [np, [poss_np, [var, 'Y'], [gen_marker, '\'s']], [nbar, [n, dog]]]], [vp, [aux, can], [vbar, [vbar, [v, wait]]]]], '.']], '2010-10-27-09-32-58', '89.206.64.27', '').
text_drs_eval(0, 3003, 'There are a man and a dog of something. It is possible that they wait.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, has_part(D, A)-1/'', object(B, dog, countable, na, eq, 1)-1/7, object(C, something, dom, na, na, na)-1/10, relation(B, of, C)-1/8, has_part(D, B)-1/'', object(D, na, countable, na, eq, 2)-1/'', can(drs([E], [predicate(E, wait, D)-2/6]))]), [[specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [pn, something]]]]]]]], '.'], [specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pn, they]], [vp, [vbar, [vbar, [v, wait]]]]]]], '.']], '2010-10-27-09-33-03', '89.206.64.27', '').
text_drs_eval(0, 3004, 'There is a machine. It controls itself.', drs([A, B], [object(A, machine, countable, na, eq, 1)-1, predicate(B, control, A, A)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, machine]]]]], '.'], [specification, [s, [np, [pn, it]], [vp, [vbar, [v, controls], [np, [pn, itself]]]]], '.']], '2008-08-09-10-02-40', '84.74.167.232', '').
text_drs_eval(0, 3005, 'There is a machine. It controls it.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, machine]]]]], '.'], [specification, [s, [np, [pn, it]], [vp, [vbar, [v, controls], [np, [pn, it]]]]], '.']], '2008-08-09-10-01-46', '84.74.167.232', '').
text_drs_eval(0, 3006, 'There is a black man. There is a man who sees himself. John knows the man. John encounters the black man. John watches the man who sees himself.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, property(B, black, pos)-1, object(C, man, countable, na, eq, 1)-2, predicate(D, see, C, C)-2, predicate(E, know, A, C)-3, predicate(F, encounter, A, B)-4, predicate(G, watch, A, C)-5]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, black], [nbar, [n, man]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, man]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, encounters], [np, [det, the], [nbar, [adj, black], [nbar, [n, man]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]]], '.']], '2008-08-17-11-38-55', '84.74.167.232', '').
text_drs_eval(0, 3007, 'There is a black woman. There is a woman who sees herself. John knows the woman. John encounters the black woman. John watches the woman who sees herself.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-3, object(B, woman, countable, na, eq, 1)-1, property(B, black, pos)-1, object(C, woman, countable, na, eq, 1)-2, predicate(D, see, C, C)-2, predicate(E, know, A, C)-3, predicate(F, encounter, A, B)-4, predicate(G, watch, A, C)-5]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, black], [nbar, [n, woman]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, herself]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, woman]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, encounters], [np, [det, the], [nbar, [adj, black], [nbar, [n, woman]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, herself]]]]]]]]]], '.']], '2008-08-17-11-37-30', '84.74.167.232', '').
text_drs_eval(0, 3008, 'There is a black woman. There is a woman who sees herself. John knows the woman. John encounters the black woman.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-3, object(B, woman, countable, na, eq, 1)-1, property(B, black, pos)-1, object(C, woman, countable, na, eq, 1)-2, predicate(D, see, C, C)-2, predicate(E, know, A, C)-3, predicate(F, encounter, A, B)-4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, black], [nbar, [n, woman]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, herself]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, knows], [np, [det, the], [nbar, [n, woman]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, encounters], [np, [det, the], [nbar, [adj, black], [nbar, [n, woman]]]]]]], '.']], '2008-07-30-18-03-20', '130.60.155.177', '').
text_drs_eval(0, 3009, 'Somebody M is the mother of a child C1. Somebody H is the husband of M. H\'s child is C2. C1 is not C2. Who is C1?', drs([A, B, C, D, E, F, G, H, I, J], [object(A, somebody, countable, na, eq, 1)-1/2, predicate(B, be, A, C)-1/4, relation(C, of, D)-1/7, object(D, child, countable, na, eq, 1)-1/9, object(C, mother, countable, na, eq, 1)-1/6, object(E, somebody, countable, na, eq, 1)-2/2, predicate(F, be, E, G)-2/4, relation(G, of, A)-2/7, object(G, husband, countable, na, eq, 1)-2/6, relation(H, of, E)-3/2, object(H, child, countable, na, eq, 1)-3/4, object(I, something, dom, na, na, na)-3/6, predicate(J, be, H, I)-3/5, -drs([K], [predicate(K, be, D, I)-4/2]), question(drs([L, M], [query(L, who)-5/1, predicate(M, be, L, D)-5/2]))]), [[specification, [s, [np, [pn, somebody], [appos, [var, 'M']]], [vp, [aux, is], [np, [det, the], [nbar, [n, mother], [pp, [prep, of], [np, [det, a], [nbar, [n, child], [appos, [var, 'C1']]]]]]]]], '.'], [specification, [s, [np, [pn, somebody], [appos, [var, 'H']]], [vp, [aux, is], [np, [det, the], [nbar, [n, husband], [pp, [prep, of], [np, [var, 'M']]]]]]], '.'], [specification, [s, [np, [poss_np, [var, 'H'], [gen_marker, '\'s']], [nbar, [n, child]]], [vp, [aux, is], [np, [var, 'C2']]]], '.'], [specification, [s, [np, [var, 'C1']], [vp, [aux, is, not], [np, [var, 'C2']]]], '.'], [query, [question, [np, [qpn, who]], [vp, [aux, is], [np, [var, 'C1']]]], ?]], '2009-05-26-07-57-31', '130.60.155.193', '').
text_drs_eval(0, 3010, 'John should wait.', drs([A], [object(A, 'John', named, na, eq, 1)-1, should(drs([B], [predicate(B, wait, A)-1]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should], [vbar, [v, wait]]]], '.']], '2008-07-31-09-48-05', '130.60.155.206', '').
text_drs_eval(0, 3011, 'John should wait and can swim and must drink.', drs([], [should(drs([A], [predicate(A, wait, named('John'))-1/3])), can(drs([B], [predicate(B, swim, named('John'))-1/6])), must(drs([C], [predicate(C, drink, named('John'))-1/9]))]), [[specification, [s, [np, [pname, 'John']], [vp_coord, [vp, [aux, should], [vbar, [vbar, [v, wait]]]], [coord, and], [vp, [aux, can], [vbar, [vbar, [v, swim]]]], [coord, and], [vp, [aux, must], [vbar, [vbar, [v, drink]]]]]], '.']], '2010-10-27-09-33-09', '89.206.64.27', '').
text_drs_eval(0, 3012, 'A man should wait and can swim and must drink.', drs([A], [object(A, man, countable, na, eq, 1)-1/2, should(drs([B], [predicate(B, wait, A)-1/4])), can(drs([C], [predicate(C, swim, A)-1/7])), must(drs([D], [predicate(D, drink, A)-1/10]))]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [aux, should], [vbar, [vbar, [v, wait]]]], [coord, and], [vp, [aux, can], [vbar, [vbar, [v, swim]]]], [coord, and], [vp, [aux, must], [vbar, [vbar, [v, drink]]]]]], '.']], '2010-10-27-09-33-13', '89.206.64.27', '').
text_drs_eval(0, 3013, 'Every man should drink.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [should(drs([B], [predicate(B, drink, A)-1]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, should], [vbar, [v, drink]]]], '.']], '2008-07-31-09-48-47', '130.60.155.206', '').
text_drs_eval(0, 3014, 'Every man should love every woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [should(drs([], [drs([B], [object(B, woman, countable, na, eq, 1)-1])=>drs([C], [predicate(C, love, A, B)-1])]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, should], [vbar, [v, love], [np, [det, every], [nbar, [n, woman]]]]]], '.']], '2008-07-31-09-49-04', '130.60.155.206', '').
text_drs_eval(0, 3015, 'It is recommended that a man drinks.', drs([], [should(drs([A, B], [predicate(A, drink, B)-1, object(B, man, countable, na, eq, 1)-1]))]), [[specification, [s, [recommendation, 'it is recommended'], [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, drinks]]]]]], '.']], '2008-07-31-09-49-46', '130.60.155.206', '').
text_drs_eval(0, 3016, 'It is not recommended that every man drinks.', drs([], [-drs([], [should(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B], [predicate(B, drink, A)-1])]))])]), [[specification, [s, [recommendation, 'it is not recommended'], [cp, that, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [v, drinks]]]]]], '.']], '2008-07-31-09-50-08', '130.60.155.206', '').
text_drs_eval(0, 3017, 'Every person should be important.', drs([], [drs([A], [object(A, person, countable, na, eq, 1)-1])=>drs([], [should(drs([B, C], [predicate(B, be, A, C)-1, property(C, important, pos)-1]))])]), [[specification, [s, [np, [det, every], [nbar, [n, person]]], [vp, [aux, should, be], [vbar, [ap_coord, [ap, [adj, important]]]]]], '.']], '2008-07-31-09-52-21', '130.60.155.206', '').
text_drs_eval(0, 3018, 'Every person should not kill someone.', drs([], [drs([A], [object(A, person, countable, na, eq, 1)-1])=>drs([], [-drs([], [should(drs([B, C], [predicate(B, kill, A, C)-1, object(C, somebody, countable, na, eq, 1)-1]))])])]), [[specification, [s, [np, [det, every], [nbar, [n, person]]], [vp, [aux, should, not], [vbar, [v, kill], [np, [pn, someone]]]]], '.']], '2008-07-31-09-52-39', '130.60.155.206', '').
text_drs_eval(0, 3019, 'Every person should not be rich.', drs([], [drs([A], [object(A, person, countable, na, eq, 1)-1])=>drs([], [-drs([], [should(drs([B, C], [predicate(B, be, A, C)-1, property(C, rich, pos)-1]))])])]), [[specification, [s, [np, [det, every], [nbar, [n, person]]], [vp, [aux, should, 'not be'], [vbar, [ap_coord, [ap, [adj, rich]]]]]], '.']], '2008-07-31-09-52-54', '130.60.155.206', '').
text_drs_eval(0, 3020, 'Every person shouldn\'t be rich.', drs([], [drs([A], [object(A, person, countable, na, eq, 1)-1])=>drs([], [-drs([], [should(drs([B, C], [predicate(B, be, A, C)-1, property(C, rich, pos)-1]))])])]), [[specification, [s, [np, [det, every], [nbar, [n, person]]], [vp, [aux, should, 'not be'], [vbar, [ap_coord, [ap, [adj, rich]]]]]], '.']], '2008-07-31-09-54-56', '130.60.155.206', '').
text_drs_eval(0, 3021, 'Every person shouldn\'t kill someone.', drs([], [drs([A], [object(A, person, countable, na, eq, 1)-1])=>drs([], [-drs([], [should(drs([B, C], [predicate(B, kill, A, C)-1, object(C, somebody, countable, na, eq, 1)-1]))])])]), [[specification, [s, [np, [det, every], [nbar, [n, person]]], [vp, [aux, should, not], [vbar, [v, kill], [np, [pn, someone]]]]], '.']], '2008-07-31-09-55-04', '130.60.155.206', '').
text_drs_eval(0, 3022, 'It is recommended that it is possible that it is necessary that every person does not provably not wait.', drs([], [should(drs([], [can(drs([], [must(drs([], [drs([A], [object(A, person, countable, na, eq, 1)-1/14])=>drs([], [~drs([], [-drs([B], [predicate(B, wait, A)-1/19])])])]))]))]))]), [[specification, [s, [recommendation, 'it is recommended'], [cp, that, [s, [poss, 'it is possible'], [cp, that, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [det, every], [nbar, [n, person]]], [vp, [aux, does, 'not provably not'], [vbar, [vbar, [v, wait]]]]]]]]]]], '.']], '2010-10-27-09-33-18', '89.206.64.27', '').
text_drs_eval(0, 3023, 'It is recommended that John can swim.', drs([], [should(drs([], [can(drs([A], [predicate(A, swim, named('John'))-1/7]))]))]), [[specification, [s, [recommendation, 'it is recommended'], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, can], [vbar, [vbar, [v, swim]]]]]]], '.']], '2010-10-27-09-33-23', '89.206.64.27', '').
text_drs_eval(0, 3024, 'It is possible that John should swim.', drs([], [can(drs([], [should(drs([A], [predicate(A, swim, named('John'))-1/7]))]))]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, should], [vbar, [vbar, [v, swim]]]]]]], '.']], '2010-10-27-09-33-29', '89.206.64.27', '').
text_drs_eval(0, 3025, 'John should give a present to Mary.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, should(drs([C, D], [predicate(C, give, A, D, B)-1, object(D, present, countable, na, eq, 1)-1]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should], [vbar, [v, give], [np, [det, a], [nbar, [n, present]]], [pp, [prep, to], [np, [pname, 'Mary']]]]]], '.']], '2008-07-31-09-57-20', '130.60.155.206', '').
text_drs_eval(0, 3026, 'John shouldn\'t be more fond-of Mary than of Sue.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, 'Sue', named, na, eq, 1)-1, -drs([], [should(drs([D, E], [predicate(D, be, A, E)-1, property(E, 'fond-of', B, comp_than, obj, C)-1]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should, 'not be'], [vbar, [ap_coord, [ap, [adj, more, 'fond-of'], [np, [pname, 'Mary']], than, of, [np, [pname, 'Sue']]]]]]], '.']], '2008-07-31-09-57-47', '130.60.155.206', '').
text_drs_eval(0, 3027, 'John should not swim.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([], [should(drs([B], [predicate(B, swim, A)-1]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should, not], [vbar, [v, swim]]]], '.']], '2008-07-31-09-58-10', '130.60.155.206', '').
text_drs_eval(0, 3028, 'Should John wait?', drs([], [question(drs([], [should(drs([A], [predicate(A, wait, named('John'))-1/3]))]))]), [[sentence, [query, [question, should, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, wait]]]]], ?], '.']], '2009-05-13-13-41-00', '130.60.155.193', '').
text_drs_eval(0, 3029, 'What is nothing?', drs([], [question(drs([A], [query(A, what)-1/1, drs([B], [object(B, something, dom, na, na, na)-1/4])=>drs([], [-drs([C], [predicate(C, be, A, B)-1/2])])]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, nothing]]]]]], ?], '.']], '2009-05-13-13-41-01', '130.60.155.193', '').
text_drs_eval(0, 3030, 'What is something that is not something?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, object(B, something, dom, na, na, na)-1/4, -drs([D, E], [object(D, something, dom, na, na, na)-1/9, predicate(E, be, B, D)-1/6]), predicate(C, be, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, what]], [vp, [aux, is], [vbar, [vcompl, [np, [pn, something], [rel_cl, [comp, that], [vp, [aux, is, not], [vbar, [vcompl, [np, [pn, something]]]]]]]]]]], ?], '.']], '2009-05-13-13-41-04', '130.60.155.193', '').
text_drs_eval(0, 3031, 'Mary invites Sue for a visit and she tells her that she must go and must work.', drs([], []), [], '2008-09-23-11-31-29', '130.60.155.206', '').
text_drs_eval(0, 3032, 'Sue sees Mary that she that sees her that she sees sees.', drs([], []), [], '2008-09-23-11-31-50', '130.60.155.206', '').
text_drs_eval(0, 3033, 'If a city overlaps-with something X then X is the city or X is not a city .', drs([], [drs([A, B, C], [object(A, city, countable, na, eq, 1)-1, object(B, something, dom, na, na, na)-1, predicate(C, 'overlap-with', A, B)-1])=>drs([], [drs([D], [predicate(D, be, B, A)-1])v drs([], [-drs([E, F], [object(E, city, countable, na, eq, 1)-1, predicate(F, be, B, E)-1])])])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, city]]], [vp, [vbar, [v, 'overlaps-with'], [np, [pn, something], [appos, [var, 'X']]]]]], then, [s_coord, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [np, [det, the], [nbar, [n, city]]]]]], [coord, or], [s, [np, [var, 'X']], [vp, [aux, is, not], [vbar, [np, [det, a], [nbar, [n, city]]]]]]]], '.']], '2008-08-04-18-32-22', '130.60.155.177', '').
text_drs_eval(0, 3034, 'Every city overlaps-with itself or does not overlap-with a city.', drs([], [drs([A], [object(A, city, countable, na, eq, 1)-1])=>drs([], [drs([B], [predicate(B, 'overlap-with', A, A)-1])v drs([], [-drs([C, D], [object(C, city, countable, na, eq, 1)-1, predicate(D, 'overlap-with', A, C)-1])])])]), [[specification, [s, [np, [det, every], [nbar, [n, city]]], [vp_coord, [vp, [vbar, [v, 'overlaps-with'], [np, [pn, itself]]]], [coord, or], [vp, [aux, does, not], [vbar, [v, 'overlap-with'], [np, [det, a], [nbar, [n, city]]]]]]], '.']], '2008-08-04-18-34-44', '130.60.155.177', '').
text_drs_eval(0, 3035, 'Every man who owns a car that likes a cat is a dog that is hated by a bike or that likes itself.', drs([], [drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, car, countable, na, eq, 1)-1, object(C, cat, countable, na, eq, 1)-1, predicate(D, like, B, C)-1, predicate(E, own, A, B)-1])=>drs([F, G], [object(F, dog, countable, na, eq, 1)-1, drs([H, I], [object(H, bike, countable, na, eq, 1)-1, predicate(I, hate, H, F)-1])v drs([J], [predicate(J, like, F, F)-1]), predicate(G, be, A, F)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, car], [rel_cl, [comp, that], [vp, [vbar, [v, likes], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [v, hated], by, [np, [det, a], [nbar, [n, bike]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [vbar, [v, likes], [np, [pn, itself]]]]]]]]]]], '.']], '2008-08-04-18-44-01', '130.60.155.177', '').
text_drs_eval(0, 3036, 'Every man who owns a car is a dog that is hated by a bike or that likes itself.', drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, object(B, car, countable, na, eq, 1)-1, predicate(C, own, A, B)-1])=>drs([D, E], [object(D, dog, countable, na, eq, 1)-1, drs([F, G], [object(F, bike, countable, na, eq, 1)-1, predicate(G, hate, F, D)-1])v drs([H], [predicate(H, like, D, D)-1]), predicate(E, be, A, D)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, car]]]]]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [v, hated], by, [np, [det, a], [nbar, [n, bike]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [vbar, [v, likes], [np, [pn, itself]]]]]]]]]]], '.']], '2008-08-04-18-44-58', '130.60.155.177', '').
text_drs_eval(0, 3037, 'Every man is a dog that is hated by a bike or that likes itself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, drs([D, E], [object(D, bike, countable, na, eq, 1)-1, predicate(E, hate, D, B)-1])v drs([F], [predicate(F, like, B, B)-1]), predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [v, hated], by, [np, [det, a], [nbar, [n, bike]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [vbar, [v, likes], [np, [pn, itself]]]]]]]]]]], '.']], '2008-08-04-18-45-44', '130.60.155.177', '').
text_drs_eval(0, 3038, 'Every man is a dog that hates a bike or that likes itself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [object(B, dog, countable, na, eq, 1)-1, drs([D, E], [object(D, bike, countable, na, eq, 1)-1, predicate(E, hate, B, D)-1])v drs([F], [predicate(F, like, B, B)-1]), predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [v, hates], [np, [det, a], [nbar, [n, bike]]]]]], [coord, or], [rel_cl, [comp, that], [vp, [vbar, [v, likes], [np, [pn, itself]]]]]]]]]]], '.']], '2008-08-04-18-46-22', '130.60.155.177', '').
text_drs_eval(0, 3039, 'There is a red man and there is a blue man.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, man, countable, na, eq, 1)-1, property(B, blue, pos)-1]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, man]]]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, man]]]]]]], '.']], '2008-08-05-11-45-29', '77.57.2.2', '').
text_drs_eval(0, 3040, 'There is a red man and there is a blue man and the man feeds a dog.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, man, countable, na, eq, 1)-1, property(B, blue, pos)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, feed, B, C)-1]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, man]]]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, man]]]]]], [coord, and], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, feeds], [np, [det, a], [nbar, [n, dog]]]]]]], '.']], '2008-08-05-11-45-53', '77.57.2.2', '').
text_drs_eval(0, 3041, 'There is a red man and there is a blue man and the man feeds a dog and the dog that the blue man feeds barks.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, property(A, red, pos)-1, object(B, man, countable, na, eq, 1)-1, property(B, blue, pos)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, feed, B, C)-1, predicate(E, bark, C)-1]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, man]]]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, man]]]]]], [coord, and], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, feeds], [np, [det, a], [nbar, [n, dog]]]]]], [coord, and], [s, [np, [det, the], [nbar, [n, dog], [rel_cl, [comp, that], [np, [det, the], [nbar, [adj, blue], [nbar, [n, man]]]], [vp, [vbar, [v, feeds]]]]]], [vp, [vbar, [v, barks]]]]], '.']], '2008-08-05-11-48-27', '77.57.2.2', '').
text_drs_eval(0, 3042, 'There is a red man and there is a blue man and the man feeds a dog and the dog that the red man feeds barks.', drs([A, B, C, D, E, F, G], [object(B, man, countable, na, eq, 1)-1, property(B, blue, pos)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, feed, B, C)-1, predicate(E, bark, F)-1, property(A, red, pos)-1, predicate(G, feed, A, F)-1, object(F, dog, countable, na, eq, 1)-1, object(A, man, countable, na, eq, 1)-1]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, red], [nbar, [n, man]]]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [adj, blue], [nbar, [n, man]]]]]], [coord, and], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, feeds], [np, [det, a], [nbar, [n, dog]]]]]], [coord, and], [s, [np, [det, the], [nbar, [n, dog], [rel_cl, [comp, that], [np, [det, the], [nbar, [adj, red], [nbar, [n, man]]]], [vp, [vbar, [v, feeds]]]]]], [vp, [vbar, [v, barks]]]]], '.']], '2008-08-12-17-36-38', '130.60.155.208', '').
text_drs_eval(0, 3043, 'No analysis confirms X and excludes X.', drs([], [drs([A], [object(A, analysis, countable, na, eq, 1)-1])=>drs([], [-drs([B, C, D], [object(B, something, dom, na, na, na)-1, predicate(C, confirm, A, B)-1, predicate(D, exclude, A, B)-1])])]), [[specification, [s, [np, [det, no], [nbar, [n, analysis]]], [vp_coord, [vp, [vbar, [v, confirms], [np, [var, 'X']]]], [coord, and], [vp, [vbar, [v, excludes], [np, [var, 'X']]]]]], '.']], '2008-08-07-18-33-20', '130.60.155.177', '').
text_drs_eval(0, 3044, 'X sees a man X.', drs([], []), [[specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]]], '.']], '2008-08-15-20-23-59', '130.60.204.15', '').
text_drs_eval(0, 3045, 'X sees the man X.', drs([], []), [[specification, [s, [np, [var, 'X']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]]]]], '.']], '2008-08-15-20-24-16', '130.60.204.15', '').
text_drs_eval(0, 3046, 'A man X waits. A man X is tired.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, tired]]]]]], '.']], '2008-08-15-20-24-38', '130.60.204.15', '').
text_drs_eval(0, 3047, 'A man X waits. The man X is tired.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, property(C, tired, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, tired]]]]]], '.']], '2008-08-15-20-30-31', '130.60.204.15', '').
text_drs_eval(0, 3048, 'The man X is tired. The man X waits.', drs([A, B, C, D], [property(A, tired, pos)-1, predicate(B, be, C, A)-1, object(C, man, countable, na, eq, 1)-1, predicate(D, wait, C)-2]), [[specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, tired]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-30-44', '130.60.204.15', '').
text_drs_eval(0, 3049, 'A man X waits. X is tired.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, property(C, tired, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, tired]]]]]], '.']], '2008-08-15-20-31-01', '130.60.204.15', '').
text_drs_eval(0, 3050, 'The man X waits. X is tired.', drs([A, B, C, D], [predicate(A, wait, B)-1, object(B, man, countable, na, eq, 1)-1, property(C, tired, pos)-2, predicate(D, be, B, C)-2]), [[specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, tired]]]]]], '.']], '2008-08-15-20-31-14', '130.60.204.15', '').
text_drs_eval(0, 3051, 'X is tired. X waits.', drs([A, B, C, D], [object(A, something, dom, na, na, na)-1, property(B, tired, pos)-1, predicate(C, be, A, B)-1, predicate(D, wait, A)-2]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, tired]]]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-31-25', '130.60.204.15', '').
text_drs_eval(0, 3052, 'Somebody M sleeps. A man is a husband of M.', drs([A, B, C, D, E], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, sleep, A)-1, object(C, man, countable, na, eq, 1)-2, object(D, husband, countable, na, eq, 1)-2, relation(D, of, A)-2, predicate(E, be, C, D)-2]), [[specification, [s, [np, [pn, somebody], [appos, [var, 'M']]], [vp, [vbar, [v, sleeps]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, husband], [pp, [prep, of], [np, [var, 'M']]]]]]]], '.']], '2008-08-15-20-31-58', '130.60.204.15', '').
text_drs_eval(0, 3053, 'Somebody M sleeps. A man is the husband of M.', drs([A, B, C, D, E], [object(A, somebody, countable, na, eq, 1)-1, predicate(B, sleep, A)-1, object(C, man, countable, na, eq, 1)-2, predicate(D, be, C, E)-2, relation(E, of, A)-2, object(E, husband, countable, na, eq, 1)-2]), [[specification, [s, [np, [pn, somebody], [appos, [var, 'M']]], [vp, [vbar, [v, sleeps]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, is], [vbar, [np, [det, the], [nbar, [n, husband], [pp, [prep, of], [np, [var, 'M']]]]]]]], '.']], '2008-08-15-20-31-47', '130.60.204.15', '').
text_drs_eval(0, 3054, 'There is a price of a resource. The price of the resource is high. The resource is valid.', drs([A, B, C, D, E, F], [object(A, price, countable, na, eq, 1)-1, object(B, resource, countable, na, eq, 1)-1, relation(A, of, B)-1, property(C, high, pos)-2, predicate(D, be, A, C)-2, property(E, valid, pos)-3, predicate(F, be, B, E)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, price], [pp, [prep, of], [np, [det, a], [nbar, [n, resource]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, price], [pp, [prep, of], [np, [det, the], [nbar, [n, resource]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, high]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, resource]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-08-12-10-31-49', '130.60.206.55', '').
text_drs_eval(0, 3055, 'A man owns a dog. John sees the man who owns a dog. The dog barks.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, predicate(E, see, A, B)-2, predicate(F, bark, C)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-12-10-06-52', '130.60.206.55', '').
text_drs_eval(0, 3056, 'A man owns a dog. John sees the man who owns the dog. The dog barks.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, predicate(E, see, A, B)-2, predicate(F, bark, C)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, the], [nbar, [n, dog]]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-12-10-07-27', '130.60.206.55', '').
text_drs_eval(0, 3057, 'A card of a man is valid. Which man\'s card is valid?', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, object(B, man, countable, na, eq, 1)-1/5, relation(A, of, B)-1/3, property(C, valid, pos)-1/7, predicate(D, be, A, C)-1/6, question(drs([E, F, G, H], [query(E, which)-2/1, object(E, man, countable, na, eq, 1)-2/2, relation(F, of, E)-2/3, object(F, card, countable, na, eq, 1)-2/5, property(G, valid, pos)-2/7, predicate(H, be, F, G)-2/6]))]), [[sentence, [specification, [s, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], '.'], '.'], [sentence, [query, [question, [np, [poss_np, [qdet, which], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-13-41-05', '130.60.155.193', '').
text_drs_eval(0, 3058, 'A card of a man X is valid. The card of which man X is valid?', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.'], [query, [question, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man], [appos, [var, 'X']]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], ?]], '2008-08-15-20-28-24', '130.60.204.15', '').
text_drs_eval(0, 3059, 'John beats a donkey of his own wife\'s brother.', drs([], []), [], '2008-08-12-10-10-13', '130.60.206.55', '').
text_drs_eval(0, 3060, 'John beats the donkey of a brother of his own wife.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, predicate(B, beat, A, C)-1, relation(C, of, D)-1, relation(D, of, E)-1, object(E, wife, countable, na, eq, 1)-1, relation(E, of, A)-1, object(C, donkey, countable, na, eq, 1)-1, object(D, brother, countable, na, eq, 1)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, beats], [np, [det, the], [nbar, [n, donkey], [pp, [prep, of], [np, [det, a], [nbar, [n, brother], [pp, [prep, of], [np, [posspn, 'his own'], [nbar, [n, wife]]]]]]]]]]]], '.']], '2008-08-12-10-10-30', '130.60.206.55', '').
text_drs_eval(0, 3061, 'John beats a donkey of the brother of his own wife.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, donkey, countable, na, eq, 1)-1, relation(B, of, C)-1, relation(C, of, D)-1, object(D, wife, countable, na, eq, 1)-1, relation(D, of, A)-1, object(C, brother, countable, na, eq, 1)-1, predicate(E, beat, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, beats], [np, [det, a], [nbar, [n, donkey], [pp, [prep, of], [np, [det, the], [nbar, [n, brother], [pp, [prep, of], [np, [posspn, 'his own'], [nbar, [n, wife]]]]]]]]]]]], '.']], '2008-08-12-10-10-51', '130.60.206.55', '').
text_drs_eval(0, 3062, 'John beats the donkey of the brother of his own wife.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, predicate(B, beat, A, C)-1, relation(C, of, D)-1, object(C, donkey, countable, na, eq, 1)-1, relation(D, of, E)-1, object(E, wife, countable, na, eq, 1)-1, relation(E, of, A)-1, object(D, brother, countable, na, eq, 1)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, beats], [np, [det, the], [nbar, [n, donkey], [pp, [prep, of], [np, [det, the], [nbar, [n, brother], [pp, [prep, of], [np, [posspn, 'his own'], [nbar, [n, wife]]]]]]]]]]]], '.']], '2008-08-12-10-11-10', '130.60.206.55', '').
text_drs_eval(0, 3063, 'There is a man who sleeps in the morning in a bed. John sees the man who sleeps in a bed in the morning.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, bed, countable, na, eq, 1)-1, predicate(D, sleep, B)-1, modifier_pp(D, in, C)-1, modifier_pp(D, in, E)-1, object(E, morning, countable, na, eq, 1)-1, predicate(F, see, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]]]]]]]]], '.']], '2008-08-12-10-11-33', '130.60.206.55', '').
text_drs_eval(0, 3064, 'A man owns a dog. John sees the man who owns a dog.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, predicate(E, see, A, B)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]], '.']], '2008-08-12-10-24-31', '130.60.206.55', '').
text_drs_eval(0, 3065, 'A man owns a dog. A man owns a cat. A girl sees the man who owns a dog.', drs([A, B, C, D, E, F, G, H], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, own, A, B)-1, object(D, man, countable, na, eq, 1)-2, object(E, cat, countable, na, eq, 1)-2, predicate(F, own, D, E)-2, object(G, girl, countable, na, eq, 1)-3, predicate(H, see, G, A)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]], '.']], '2008-08-12-10-24-50', '130.60.206.55', '').
text_drs_eval(0, 3066, 'A man X owns a dog. A man Y owns a cat. John sees the man X.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, object(E, man, countable, na, eq, 1)-2, object(F, cat, countable, na, eq, 1)-2, predicate(G, own, E, F)-2, predicate(H, see, A, B)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'Y']]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]]]]], '.']], '2008-08-15-20-36-03', '130.60.204.15', '').
text_drs_eval(0, 3067, 'A man X owns a dog. A man Y owns a cat. John sees X.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, object(E, man, countable, na, eq, 1)-2, object(F, cat, countable, na, eq, 1)-2, predicate(G, own, E, F)-2, predicate(H, see, A, B)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'Y']]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [var, 'X']]]]], '.']], '2008-08-12-10-25-30', '130.60.206.55', '').
text_drs_eval(0, 3068, 'A red man owns a dog. A red man owns a cat. John sees the red man who owns a dog.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, property(B, red, pos)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, object(E, man, countable, na, eq, 1)-2, property(E, red, pos)-2, object(F, cat, countable, na, eq, 1)-2, predicate(G, own, E, F)-2, predicate(H, see, A, B)-3]), [[specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man]]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man]]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]]], '.']], '2008-08-12-10-25-53', '130.60.206.55', '').
text_drs_eval(0, 3069, 'A man is red and owns a dog. A man is red and owns a cat. John sees the man who is red and who owns a dog.', drs([A, B, C, D, E, F, G, H, I, J, K, L], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, property(C, red, pos)-1, predicate(D, be, B, C)-1, object(E, dog, countable, na, eq, 1)-1, predicate(F, own, B, E)-1, object(G, man, countable, na, eq, 1)-2, property(H, red, pos)-2, predicate(I, be, G, H)-2, object(J, cat, countable, na, eq, 1)-2, predicate(K, own, G, J)-2, predicate(L, see, A, B)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]], [coord, and], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]], [coord, and], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]]], [coord, and], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]]], '.']], '2008-08-12-10-26-11', '130.60.206.55', '').
text_drs_eval(0, 3070, 'There is a man who does not sleep. John sees the man who does not sleep.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, -drs([D], [predicate(D, sleep, B)-1]), predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-08-12-10-26-27', '130.60.206.55', '').
text_drs_eval(0, 3071, 'There is a man who does not sleep. There is a man who sleeps. John sees the man who does not sleep.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, -drs([F], [predicate(F, sleep, B)-1]), object(C, man, countable, na, eq, 1)-2, predicate(D, sleep, C)-2, predicate(E, see, A, B)-3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sleeps]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-08-12-10-26-41', '130.60.206.55', '').
text_drs_eval(0, 3072, 'A man can not sleep. John sees the man who can not sleep.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([C], [predicate(C, sleep, A)-1/5]))]), predicate(B, see, named('John'), A)-2/2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vbar, [v, sleep]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can, not], [vbar, [vbar, [v, sleep]]]]]]]]]]], '.']], '2010-10-27-09-33-40', '89.206.64.27', '').
text_drs_eval(0, 3073, 'A man can not sleep. A man can sleep. John sees the man who can not sleep.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, -drs([], [can(drs([D], [predicate(D, sleep, A)-1/5]))]), object(B, man, countable, na, eq, 1)-2/2, can(drs([E], [predicate(E, sleep, B)-2/4])), predicate(C, see, named('John'), A)-3/2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can, not], [vbar, [vbar, [v, sleep]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, can], [vbar, [vbar, [v, sleep]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can, not], [vbar, [vbar, [v, sleep]]]]]]]]]]], '.']], '2010-10-27-09-33-45', '89.206.64.27', '').
text_drs_eval(0, 3074, 'There is a man who must wait patiently. There is a man who can sleep. John sees the man who must wait. Mary expects the man who can sleep.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/4, must(drs([F], [predicate(F, wait, A)-1/7, modifier_adv(F, patiently, pos)-1/8])), object(B, man, countable, na, eq, 1)-2/4, can(drs([G], [predicate(G, sleep, B)-2/7])), must(drs([H], [predicate(H, wait, D)-3/7])), object(D, man, countable, na, eq, 1)-3/4, predicate(C, see, named('John'), D)-3/2, predicate(E, expect, named('Mary'), B)-4/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, must], [vbar, [vbar, [v, wait]], [vmod, [adv, patiently]]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, sleep]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]]]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, expects], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, sleep]]]]]]]]]]], '.']], '2010-10-27-09-33-51', '89.206.64.27', '').
text_drs_eval(0, 3075, 'A man X must wait. A man Y can sleep. John sees the man X. Mary expects the man Y.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, must(drs([E], [predicate(E, wait, A)-1/5])), object(B, man, countable, na, eq, 1)-2/2, can(drs([F], [predicate(F, sleep, B)-2/5])), predicate(C, see, named('John'), A)-3/2, predicate(D, expect, named('Mary'), B)-4/2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'Y']]]], [vp, [aux, can], [vbar, [vbar, [v, sleep]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, expects], [np, [det, the], [nbar, [n, man], [appos, [var, 'Y']]]]]]]], '.']], '2010-10-27-09-33-55', '89.206.64.27', '').
text_drs_eval(0, 3076, 'There is a man who must wait patiently. John sees the man who must wait.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, must(drs([D], [predicate(D, wait, A)-1/7, modifier_adv(D, patiently, pos)-1/8])), must(drs([E], [predicate(E, wait, C)-2/7])), object(C, man, countable, na, eq, 1)-2/4, predicate(B, see, named('John'), C)-2/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, must], [vbar, [vbar, [v, wait]], [vmod, [adv, patiently]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]]]]]]]], '.']], '2010-10-27-09-34-01', '89.206.64.27', '').
text_drs_eval(0, 3077, 'There is a man who cannot wait patiently. John sees the man who cannot wait.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, -drs([], [can(drs([D], [predicate(D, wait, A)-1/8, modifier_adv(D, patiently, pos)-1/9]))]), -drs([], [can(drs([E], [predicate(E, wait, C)-2/8]))]), object(C, man, countable, na, eq, 1)-2/4, predicate(B, see, named('John'), C)-2/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]], [vmod, [adv, patiently]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]]]]]]]], '.']], '2010-10-27-09-34-06', '89.206.64.27', '').
text_drs_eval(0, 3078, 'There is a man who does not wait patiently. There is a man who does not sleep. John sees the man who does not wait. Mary expects the man who does not sleep.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-3, object(B, 'Mary', named, na, eq, 1)-4, object(C, man, countable, na, eq, 1)-1, -drs([H], [predicate(H, wait, C)-1, modifier_adv(H, patiently, pos)-1]), object(D, man, countable, na, eq, 1)-2, -drs([I], [predicate(I, sleep, D)-2]), predicate(E, see, A, F)-3, -drs([J], [predicate(J, wait, F)-3]), object(F, man, countable, na, eq, 1)-3, predicate(G, expect, B, D)-4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]], [adv, patiently]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, expects], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-08-12-10-29-10', '130.60.206.55', '').
text_drs_eval(0, 3079, 'A man does not wait patiently. A man does not sleep. John sees the man who does not wait. Mary expects the man who does not sleep.', drs([A, B, C, D, E, F, G], [object(A, 'John', named, na, eq, 1)-3, object(B, 'Mary', named, na, eq, 1)-4, object(C, man, countable, na, eq, 1)-1, -drs([H], [predicate(H, wait, C)-1, modifier_adv(H, patiently, pos)-1]), object(D, man, countable, na, eq, 1)-2, -drs([I], [predicate(I, sleep, D)-2]), predicate(E, see, A, F)-3, -drs([J], [predicate(J, wait, F)-3]), object(F, man, countable, na, eq, 1)-3, predicate(G, expect, B, D)-4]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]], [adv, patiently]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, sleep]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, expects], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-08-12-10-29-31', '130.60.206.55', '').
text_drs_eval(0, 3080, 'A red man who can sleep must wait. A red man who can sleep must work. The man who must wait is tired.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/3, property(A, red, pos)-1/2, can(drs([E], [predicate(E, sleep, A)-1/6])), must(drs([F], [predicate(F, wait, A)-1/8])), object(B, man, countable, na, eq, 1)-2/3, property(B, red, pos)-2/2, can(drs([G], [predicate(G, sleep, B)-2/6])), must(drs([H], [predicate(H, work, B)-2/8])), property(C, tired, pos)-3/7, predicate(D, be, A, C)-3/6]), [[specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, sleep]]]]]]]], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can], [vbar, [vbar, [v, sleep]]]]]]]], [vp, [aux, must], [vbar, [vbar, [v, work]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, must], [vbar, [vbar, [v, wait]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, tired]]]]], '.']], '2010-10-27-09-34-15', '89.206.64.27', '').
text_drs_eval(0, 3081, 'A man owns a dog. A girl sees the man who owns a dog. The dog barks.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(C, own, A, B)-1, object(D, girl, countable, na, eq, 1)-2, predicate(E, see, D, A)-2, predicate(F, bark, B)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-12-10-30-32', '130.60.206.55', '').
text_drs_eval(0, 3082, 'The man sleeps. There is a man.', drs([A, B, C], [predicate(A, sleep, B)-1, object(B, man, countable, na, eq, 1)-1, object(C, man, countable, na, eq, 1)-2]), [[specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, sleeps]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.']], '2008-08-12-10-30-51', '130.60.206.55', '').
text_drs_eval(0, 3083, 'The man owns the dog. The dog barks. The dog is red. The man who owns the dog that barks and that is red is happy.', drs([A, B, C, D, E, F, G, H], [predicate(A, own, C, B)-1, object(C, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, predicate(D, bark, B)-2, property(E, red, pos)-3, predicate(F, be, B, E)-3, property(G, happy, pos)-4, predicate(H, be, C, G)-4]), [[specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [v, owns], [np, [det, the], [nbar, [n, dog]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, dog]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, the], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [v, barks]]]], [coord, and], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]]]]]]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, happy]]]]]], '.']], '2008-08-12-10-31-22', '130.60.206.55', '').
text_drs_eval(0, 3084, 'A man does not wait patiently. A man does not sleep. A girl sees the man who does not wait. A boy expects the man who does not sleep.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, -drs([H], [predicate(H, wait, A)-1, modifier_adv(H, patiently, pos)-1]), object(B, man, countable, na, eq, 1)-2, -drs([I], [predicate(I, sleep, B)-2]), object(C, girl, countable, na, eq, 1)-3, predicate(D, see, C, E)-3, -drs([J], [predicate(J, wait, E)-3]), object(E, man, countable, na, eq, 1)-3, object(F, boy, countable, na, eq, 1)-4, predicate(G, expect, F, B)-4]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]], [adv, patiently]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, sleep]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, boy]]], [vp, [vbar, [v, expects], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-08-12-10-32-31', '130.60.206.55', '').
text_drs_eval(0, 3085, 'A man does not wait patiently. A girl sees the man who does not wait.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, -drs([E], [predicate(E, wait, A)-1, modifier_adv(E, patiently, pos)-1]), object(B, girl, countable, na, eq, 1)-2, predicate(C, see, B, D)-2, -drs([F], [predicate(F, wait, D)-2]), object(D, man, countable, na, eq, 1)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]], [adv, patiently]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.']], '2008-08-12-10-32-49', '130.60.206.55', '').
text_drs_eval(0, 3086, 'A man does not wait. A girl sees the man who does not wait.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, -drs([D], [predicate(D, wait, A)-1]), object(B, girl, countable, na, eq, 1)-2, predicate(C, see, B, A)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [v, wait]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.']], '2008-08-12-10-33-15', '130.60.206.55', '').
text_drs_eval(0, 3087, 'There is a man who does not wait patiently. There is a man who does not sleep. A girl sees the man who does not wait. A boy expects the man who does not sleep.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1, -drs([H], [predicate(H, wait, A)-1, modifier_adv(H, patiently, pos)-1]), object(B, man, countable, na, eq, 1)-2, -drs([I], [predicate(I, sleep, B)-2]), object(C, girl, countable, na, eq, 1)-3, predicate(D, see, C, E)-3, -drs([J], [predicate(J, wait, E)-3]), object(E, man, countable, na, eq, 1)-3, object(F, boy, countable, na, eq, 1)-4, predicate(G, expect, F, B)-4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]], [adv, patiently]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, boy]]], [vp, [vbar, [v, expects], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, sleep]]]]]]]]], '.']], '2008-08-12-10-33-54', '130.60.206.55', '').
text_drs_eval(0, 3088, 'There is a man who does not wait patiently. A girl sees the man who does not wait.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, -drs([E], [predicate(E, wait, A)-1, modifier_adv(E, patiently, pos)-1]), object(B, girl, countable, na, eq, 1)-2, predicate(C, see, B, D)-2, -drs([F], [predicate(F, wait, D)-2]), object(D, man, countable, na, eq, 1)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, wait]], [adv, patiently]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.']], '2008-08-12-10-34-11', '130.60.206.55', '').
text_drs_eval(0, 3089, 'There is a man who does not wait. A girl sees the man who does not wait.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, -drs([D], [predicate(D, wait, A)-1]), object(B, girl, countable, na, eq, 1)-2, predicate(C, see, B, A)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [v, wait]]]]]]]]], '.']], '2008-08-12-10-34-25', '130.60.206.55', '').
text_drs_eval(0, 3090, 'There is a man who cannot wait patiently. A girl sees the man who cannot wait.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, -drs([], [can(drs([E], [predicate(E, wait, A)-1/8, modifier_adv(E, patiently, pos)-1/9]))]), object(B, girl, countable, na, eq, 1)-2/2, -drs([], [can(drs([F], [predicate(F, wait, D)-2/9]))]), object(D, man, countable, na, eq, 1)-2/5, predicate(C, see, B, D)-2/3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]], [vmod, [adv, patiently]]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, girl]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, can, not], [vbar, [vbar, [v, wait]]]]]]]]]]], '.']], '2010-10-27-09-34-19', '89.206.64.27', '').
text_drs_eval(0, 3091, 'A man is red. The red man sleeps.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, property(B, red, pos)-1, predicate(C, be, A, B)-1, predicate(D, sleep, E)-2, property(E, red, pos)-2, object(E, man, countable, na, eq, 1)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man]]]], [vp, [vbar, [v, sleeps]]]], '.']], '2008-08-12-10-34-54', '130.60.206.55', '').
text_drs_eval(0, 3092, 'A man is red and owns a dog. A man is red and owns a cat. John sees the red man who owns a dog.', drs([A, B, C, D, E, F, G, H, I, J, K, L, M, N, O], [object(A, 'John', named, na, eq, 1)-3, object(B, man, countable, na, eq, 1)-1, property(C, red, pos)-1, predicate(D, be, B, C)-1, object(E, dog, countable, na, eq, 1)-1, predicate(F, own, B, E)-1, object(G, man, countable, na, eq, 1)-2, property(H, red, pos)-2, predicate(I, be, G, H)-2, object(J, cat, countable, na, eq, 1)-2, predicate(K, own, G, J)-2, predicate(L, see, A, M)-3, predicate(O, own, M, N)-3, object(N, dog, countable, na, eq, 1)-3, property(M, red, pos)-3, object(M, man, countable, na, eq, 1)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]], [coord, and], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, red]]]]], [coord, and], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]]]], '.']], '2008-08-12-10-35-15', '130.60.206.55', '').
text_drs_eval(0, 3093, 'A man waits or sleeps. John sees the man who sleeps or who waits.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, drs([D], [predicate(D, wait, B)-1])v drs([E], [predicate(E, sleep, B)-1]), predicate(C, see, A, B)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [vbar, [v, waits]]], [coord, or], [vp, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sleeps]]]], [coord, or], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, waits]]]]]]]]]], '.']], '2008-08-12-10-35-32', '130.60.206.55', '').
text_drs_eval(0, 3094, 'A man waits or sleeps. John sees the man who sleeps.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, drs([F], [predicate(F, wait, B)-1])v drs([G], [predicate(G, sleep, B)-1]), predicate(C, see, A, D)-2, predicate(E, sleep, D)-2, object(D, man, countable, na, eq, 1)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp_coord, [vp, [vbar, [v, waits]]], [coord, or], [vp, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sleeps]]]]]]]]], '.']], '2008-08-12-10-35-55', '130.60.206.55', '').
text_drs_eval(0, 3095, 'A man waits. John sees the man who sleeps or who waits.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, wait, B)-1, predicate(D, see, A, E)-2, drs([F], [predicate(F, sleep, E)-2])v drs([G], [predicate(G, wait, E)-2]), object(E, man, countable, na, eq, 1)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl_coord, [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sleeps]]]], [coord, or], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, waits]]]]]]]]]], '.']], '2008-08-12-10-36-09', '130.60.206.55', '').
text_drs_eval(0, 3096, 'There is 1kg of n:laundry.', drs([A], [object(A, laundry, countable, kg, eq, 1)-1]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [meas_spec, [nump, [num, 1]], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, laundry]]]]], '.']], '2008-08-19-16-23-44', '130.60.155.208', '').
text_drs_eval(0, 3097, '3.141592653611111 approximates Pi.', drs([A], [predicate(A, approximate, real(3.141592653611111), named('Pi'))-1/2]), [[specification, [s, [np, [real, 3.141592653611111]], [vp, [vbar, [vcompl, [v, approximates], [np, [pname, 'Pi']]]]]], '.']], '2012-09-12-17-59-32', '89.206.103.116', '').
text_drs_eval(0, 3098, 'A man visits a town Zürich.', drs([], []), [], '2008-08-12-15-14-29', '130.60.155.208', '').
text_drs_eval(0, 3099, 'There is a man who does not sleep soundly in a bed in a morning. John sees the man who does not sleep soundly in a bed in a morning.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, -drs([D, E, F], [object(D, morning, countable, na, eq, 1)-1, object(E, bed, countable, na, eq, 1)-1, predicate(F, sleep, B)-1, modifier_pp(F, in, D)-1, modifier_pp(F, in, E)-1, modifier_adv(F, soundly, pos)-1]), predicate(C, see, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]]]]]], '.']], '2008-09-23-11-28-41', '130.60.155.206', '').
text_drs_eval(0, 3100, 'At most 3 men X wait. X are tired.', drs([A, B, C, D], [[predicate(B, wait, A)-1, object(A, man, countable, na, leq, 3)-1], property(C, tired, pos)-2, predicate(D, be, A, C)-2]), [[specification, [s, [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men], [appos, [var, 'X']]]], [vp, [vbar, [vbar, [v, wait]]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, are], [vbar, [vcompl, [ap_coord, [ap, [adj, tired]]]]]]], '.']], '2009-03-02-11-37-18', '130.60.155.206', '').
text_drs_eval(0, 3101, 'There is X who sleeps.', drs([], []), [], '2008-09-23-11-32-24', '130.60.155.206', '').
text_drs_eval(0, 3102, 'If there is an animal that believes that John is its owner then John sees the animal that believes that John is its owner.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, animal, countable, na, eq, 1)-1, predicate(C, believe, B, D)-1, D:drs([E, F], [relation(E, of, B)-1, object(E, owner, countable, na, eq, 1)-1, predicate(F, be, A, E)-1])])=>drs([G], [predicate(G, see, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [rel_cl, [comp, that], [vp, [vbar, [v, believes], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, its], [nbar, [n, owner]]]]]]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, animal], [rel_cl, [comp, that], [vp, [vbar, [v, believes], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, its], [nbar, [n, owner]]]]]]]]]]]]]]]], '.']], '2008-10-23-14-52-40', '130.60.155.177', '').
text_drs_eval(0, 3103, 'A man X which runs is happy.', drs([], []), [], '2008-08-14-15-55-36', '130.60.155.177', '').
text_drs_eval(0, 3104, 'A man X eats. X who drinks waits.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, eats]]]], '.']], '2008-09-23-08-52-32', '130.60.155.206', '').
text_drs_eval(0, 3105, 'A man X eats. The man X who drinks waits.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, drinks]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-19-16-26-00', '130.60.155.208', '').
text_drs_eval(0, 3106, 'A man X eats. The man X who eats waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1, predicate(B, eat, A)-1, predicate(C, wait, A)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, eats]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, eats]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-14-16-07-03', '130.60.155.177', '').
text_drs_eval(0, 3107, 'A man X eats. X who eats waits.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, eats]]]], '.']], '2008-09-23-11-32-39', '130.60.155.206', '').
text_drs_eval(0, 3108, 'There is a man X1 that owns a dog and there is a man X2 that owns a cat and John sees X1.', drs([A, B, C, D, E, F, G, H], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, dog, countable, na, eq, 1)-1, predicate(D, own, B, C)-1, object(E, man, countable, na, eq, 1)-1, object(F, cat, countable, na, eq, 1)-1, predicate(G, own, E, F)-1, predicate(H, see, A, B)-1]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X1']], [rel_cl, [comp, that], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, dog]]]]]]]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X2']], [rel_cl, [comp, that], [vp, [vbar, [v, owns], [np, [det, a], [nbar, [n, cat]]]]]]]]]], [coord, and], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [var, 'X1']]]]]], '.']], '2008-08-14-19-17-19', '130.60.155.177', '').
text_drs_eval(0, 3109, 'A man X sees a cat Y. A woman X observes a dog Y.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, cat], [appos, [var, 'Y']]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]], [vp, [vbar, [v, observes], [np, [det, a], [nbar, [n, dog], [appos, [var, 'Y']]]]]]], '.']], '2008-08-15-20-24-58', '130.60.204.15', '').
text_drs_eval(0, 3110, 'A man X walks. A woman X talks.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, walks]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]], [vp, [vbar, [v, talks]]]], '.']], '2008-08-15-20-25-49', '130.60.204.15', '').
text_drs_eval(0, 3111, 'A man X walks. The woman X talks.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, walks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, woman], [appos, [var, 'X']]]], [vp, [vbar, [v, talks]]]], '.']], '2008-08-15-20-26-01', '130.60.204.15', '').
text_drs_eval(0, 3112, 'The man X walks. A woman X talks.', drs([], []), [[specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, walks]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]], [vp, [vbar, [v, talks]]]], '.']], '2008-08-15-20-26-17', '130.60.204.15', '').
text_drs_eval(0, 3113, 'A man X walks. The red man X talks.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, walks]]]], '.'], [specification, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, talks]]]], '.']], '2008-08-15-20-26-43', '130.60.204.15', '').
text_drs_eval(0, 3114, 'There is a man X. The man X of a woman waits.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X']], [pp, [prep, of], [np, [det, a], [nbar, [n, woman]]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-26-58', '130.60.204.15', '').
text_drs_eval(0, 3115, 'A red man X waits. If a red man X waits then the red man is a customer.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [cond_s, if, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], then, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]]], '.']], '2008-08-15-20-27-53', '130.60.204.15', '').
text_drs_eval(0, 3116, 'Someone X waits. If someone X waits then X is a customer.', drs([], []), [[specification, [s, [np, [pn, someone], [appos, [var, 'X']]], [vp, [vbar, [v, waits]]]], '.'], [specification, [cond_s, if, [s, [np, [pn, someone], [appos, [var, 'X']]], [vp, [vbar, [v, waits]]]], then, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]]], '.']], '2008-08-15-20-27-56', '130.60.204.15', '').
text_drs_eval(0, 3117, 'A red man X waits. If the red man X waits then the red man X is a customer.', drs([A, B], [object(A, man, countable, na, eq, 1)-1, property(A, red, pos)-1, predicate(B, wait, A)-1, drs([C], [predicate(C, wait, A)-2])=>drs([D, E], [object(D, customer, countable, na, eq, 1)-2, predicate(E, be, A, D)-2])]), [[specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [cond_s, if, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], then, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]]], '.']], '2008-08-15-20-32-14', '130.60.204.15', '').
text_drs_eval(0, 3118, 'The red man X waits. If the red man X waits then the red man X is a customer.', drs([A, B], [predicate(A, wait, B)-1, property(B, red, pos)-1, object(B, man, countable, na, eq, 1)-1, drs([C], [predicate(C, wait, B)-2])=>drs([D, E], [object(D, customer, countable, na, eq, 1)-2, predicate(E, be, B, D)-2])]), [[specification, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [cond_s, if, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], then, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]]], '.']], '2008-08-15-20-32-27', '130.60.204.15', '').
text_drs_eval(0, 3119, 'If the red man X waits then the red man is a customer. A red man X waits.', drs([A, B], [drs([C, D], [predicate(C, wait, D)-1, property(D, red, pos)-1, object(D, man, countable, na, eq, 1)-1])=>drs([E, F], [object(E, customer, countable, na, eq, 1)-1, predicate(F, be, D, E)-1]), object(A, man, countable, na, eq, 1)-2, property(A, red, pos)-2, predicate(B, wait, A)-2]), [[specification, [cond_s, if, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], then, [s, [np, [det, the], [nbar, [adj, red], [nbar, [n, man]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, customer]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [adj, red], [nbar, [n, man], [appos, [var, 'X']]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-15-20-32-44', '130.60.204.15', '').
text_drs_eval(0, 3120, 'John watches the man who sees himself.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, predicate(B, watch, A, C)-1, predicate(D, see, C, C)-1, object(C, man, countable, na, eq, 1)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]]], '.']], '2008-08-17-10-45-30', '84.74.167.232', '').
text_drs_eval(0, 3121, 'There is a man who sees himself. John watches the man who sees himself.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-2, object(B, man, countable, na, eq, 1)-1, predicate(C, see, B, B)-1, predicate(D, watch, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, watches], [np, [det, the], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, sees], [np, [pn, himself]]]]]]]]]], '.']], '2008-08-17-10-45-59', '84.74.167.232', '').
text_drs_eval(0, 3122, 'A child of a child X is the child X.', drs([A, B, C], [object(A, child, countable, na, eq, 1)-1, object(B, child, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, child], [pp, [prep, of], [np, [det, a], [nbar, [n, child], [appos, [var, 'X']]]]]]], [vp, [aux, is], [vbar, [np, [det, the], [nbar, [n, child], [appos, [var, 'X']]]]]]], '.']], '2008-08-18-20-01-59', '130.60.206.84', '').
text_drs_eval(0, 3123, 'There is a child X whose child is the child X.', drs([A, B, C], [object(A, child, countable, na, eq, 1)-1, object(B, child, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, be, B, A)-1]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, child], [appos, [var, 'X']], [rel_cl, [np, [posspn, whose], [nbar, [n, child]]], [vp, [aux, is], [vbar, [np, [det, the], [nbar, [n, child], [appos, [var, 'X']]]]]]]]]]], '.']], '2008-08-18-20-02-38', '130.60.206.84', '').
text_drs_eval(0, 3124, 'There is a child X whose child is not the child X.', drs([A, B], [object(A, child, countable, na, eq, 1)-1, object(B, child, countable, na, eq, 1)-1, relation(B, of, A)-1, -drs([C], [predicate(C, be, B, A)-1])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, child], [appos, [var, 'X']], [rel_cl, [np, [posspn, whose], [nbar, [n, child]]], [vp, [aux, is, not], [vbar, [np, [det, the], [nbar, [n, child], [appos, [var, 'X']]]]]]]]]]], '.']], '2008-08-18-20-03-20', '130.60.206.84', '').
text_drs_eval(0, 3125, 'There is a man X and there is a man X.', drs([], []), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]]], '.']], '2008-08-18-19-17-05', '130.60.155.177', '').
text_drs_eval(0, 3126, 'Every man X waits and there is a man X.', drs([A], [drs([B], [object(B, man, countable, na, eq, 1)-1])=>drs([C], [predicate(C, wait, B)-1]), object(A, man, countable, na, eq, 1)-1]), [[specification, [s_coord, [s, [np, [det, every], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]], [coord, and], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]]], '.']], '2008-08-18-19-17-33', '130.60.155.177', '').
text_drs_eval(0, 3127, 'There is a man X and every man X waits.', drs([], []), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], [coord, and], [s, [np, [det, every], [nbar, [n, man], [appos, [var, 'X']]]], [vp, [vbar, [v, waits]]]]], '.']], '2008-08-19-16-30-40', '130.60.155.208', '').
text_drs_eval(0, 3128, 'A child of a child X is not the child X.', drs([A, B], [object(A, child, countable, na, eq, 1)-1, object(B, child, countable, na, eq, 1)-1, relation(A, of, B)-1, -drs([C], [predicate(C, be, A, B)-1])]), [[specification, [s, [np, [det, a], [nbar, [n, child], [pp, [prep, of], [np, [det, a], [nbar, [n, child], [appos, [var, 'X']]]]]]], [vp, [aux, is, not], [vbar, [np, [det, the], [nbar, [n, child], [appos, [var, 'X']]]]]]], '.']], '2008-08-18-20-02-15', '130.60.206.84', '').
text_drs_eval(0, 3129, 'Who is a child X whose child is not the child X?', drs([], [question(drs([A, B, C, D], [query(A, who)-1/1, object(B, child, countable, na, eq, 1)-1/4, object(C, child, countable, na, eq, 1)-1/7, relation(C, of, B)-1/6, -drs([E], [predicate(E, be, C, B)-1/8]), predicate(D, be, A, B)-1/2]))]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, child], [appos, [var, 'X']], [rel_cl, [np, [posspn, whose], [nbar, [n, child]]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, the], [nbar, [n, child], [appos, [var, 'X']]]]]]]]]]]]]], ?], '.']], '2009-05-13-13-41-07', '130.60.155.193', '').
text_drs_eval(0, 3130, 'There is a man or there is a dog or there is a cat that sees it and him.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B], [object(B, dog, countable, na, eq, 1)-1])v drs([C, D, E], [object(C, cat, countable, na, eq, 1)-1, has_part(E, B)-1, predicate(D, see, C, E)-1, has_part(E, A)-1, object(E, na, countable, na, eq, 2)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np_coord, [np, [pn, it]], [coord, and], [np, [pn, him]]]]]]]]]]], '.']], '2008-08-18-20-04-39', '130.60.206.84', '').
text_drs_eval(0, 3131, 'There is a man or there is a dog that sees him or there is a cat that sees him.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, A)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [pn, him]]]]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [pn, him]]]]]]]]]], '.']], '2008-08-18-20-04-54', '130.60.206.84', '').
text_drs_eval(0, 3132, 'There is a dog that sees the man or there is a cat that sees it.', drs([], [drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, predicate(B, see, A, C)-1, object(C, man, countable, na, eq, 1)-1])v drs([D, E], [object(D, cat, countable, na, eq, 1)-1, predicate(E, see, D, A)-1])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [pn, it]]]]]]]]]], '.']], '2008-08-18-20-05-14', '130.60.206.84', '').
text_drs_eval(0, 3133, 'There is a man or there is a dog that sees the man or there is a cat that sees it and the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])v drs([], [drs([B, C], [object(B, dog, countable, na, eq, 1)-1, predicate(C, see, B, A)-1])v drs([D, E, F], [object(D, cat, countable, na, eq, 1)-1, has_part(F, B)-1, predicate(E, see, D, F)-1, has_part(F, A)-1, object(F, na, countable, na, eq, 2)-1])])]), [[specification, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, man]]]]]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [v, sees], [np_coord, [np, [pn, it]], [coord, and], [np, [det, the], [nbar, [n, man]]]]]]]]]]]], '.']], '2008-08-18-20-05-42', '130.60.206.84', '').
text_drs_eval(0, 3134, 'A dog sees a man and a cat sees it and him.', drs([A, B, C, D, E, F], [object(A, dog, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, predicate(C, see, A, B)-1, object(D, cat, countable, na, eq, 1)-1, has_part(F, A)-1, predicate(E, see, D, F)-1, has_part(F, B)-1, object(F, na, countable, na, eq, 2)-1]), [[specification, [s_coord, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man]]]]]], [coord, and], [s, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [v, sees], [np_coord, [np, [pn, it]], [coord, and], [np, [pn, him]]]]]]], '.']], '2008-08-18-20-05-59', '130.60.206.84', '').
text_drs_eval(0, 3135, 'A man comes in a day A1. A boy reads in the day A2 that follows A1. A book is red in the day that follows A2.', drs([A, B, C, D, E, F, G, H, I, J, K, L], [object(A, man, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-1, predicate(C, come, A)-1, modifier_pp(C, in, B)-1, object(D, boy, countable, na, eq, 1)-2, predicate(E, read, D)-2, modifier_pp(E, in, F)-2, predicate(G, follow, F, B)-2, object(F, day, countable, na, eq, 1)-2, object(H, book, countable, na, eq, 1)-3, property(I, red, pos)-3, predicate(J, be, H, I)-3, modifier_pp(J, in, K)-3, predicate(L, follow, K, F)-3, object(K, day, countable, na, eq, 1)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, comes]], [pp, [prep, in], [np, [det, a], [nbar, [n, day], [appos, [var, 'A1']]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, boy]]], [vp, [vbar, [vbar, [v, reads]], [pp, [prep, in], [np, [det, the], [nbar, [n, day], [appos, [var, 'A2']], [rel_cl, [comp, that], [vp, [vbar, [v, follows], [np, [var, 'A1']]]]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, book]]], [vp, [aux, is], [vbar, [vbar, [ap_coord, [ap, [adj, red]]]], [pp, [prep, in], [np, [det, the], [nbar, [n, day], [rel_cl, [comp, that], [vp, [vbar, [v, follows], [np, [var, 'A2']]]]]]]]]]], '.']], '2008-08-18-20-07-12', '130.60.206.84', '').
text_drs_eval(0, 3136, 'A man comes in a day A1. A boy reads in a day A2 that follows A1. A book is red in a day that follows A2.', drs([A, B, C, D, E, F, G, H, I, J, K, L], [object(A, man, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-1, predicate(C, come, A)-1, modifier_pp(C, in, B)-1, object(D, boy, countable, na, eq, 1)-2, object(E, day, countable, na, eq, 1)-2, predicate(F, follow, E, B)-2, predicate(G, read, D)-2, modifier_pp(G, in, E)-2, object(H, book, countable, na, eq, 1)-3, object(I, day, countable, na, eq, 1)-3, predicate(J, follow, I, E)-3, property(K, red, pos)-3, predicate(L, be, H, K)-3, modifier_pp(L, in, I)-3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, comes]], [pp, [prep, in], [np, [det, a], [nbar, [n, day], [appos, [var, 'A1']]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, boy]]], [vp, [vbar, [vbar, [v, reads]], [pp, [prep, in], [np, [det, a], [nbar, [n, day], [appos, [var, 'A2']], [rel_cl, [comp, that], [vp, [vbar, [v, follows], [np, [var, 'A1']]]]]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, book]]], [vp, [aux, is], [vbar, [vbar, [ap_coord, [ap, [adj, red]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, day], [rel_cl, [comp, that], [vp, [vbar, [v, follows], [np, [var, 'A2']]]]]]]]]]], '.']], '2008-08-18-20-07-44', '130.60.206.84', '').
text_drs_eval(0, 3137, 'There is a day A1. A day A2 follows A1.', drs([A, B, C], [object(A, day, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-2, predicate(C, follow, B, A)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, day], [appos, [var, 'A1']]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, day], [appos, [var, 'A2']]]], [vp, [vbar, [v, follows], [np, [var, 'A1']]]]], '.']], '2008-08-18-20-07-58', '130.60.206.84', '').
text_drs_eval(0, 3138, 'There is a day A1. A day A2 follows the day.', drs([A, B, C], [object(A, day, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-2, predicate(C, follow, B, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, day], [appos, [var, 'A1']]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, day], [appos, [var, 'A2']]]], [vp, [vbar, [v, follows], [np, [det, the], [nbar, [n, day]]]]]], '.']], '2008-08-18-20-08-26', '130.60.206.84', '').
text_drs_eval(0, 3139, 'There is a day. A day follows the day.', drs([A, B, C], [object(A, day, countable, na, eq, 1)-1, object(B, day, countable, na, eq, 1)-2, predicate(C, follow, B, B)-2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, day]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, day]]], [vp, [vbar, [v, follows], [np, [det, the], [nbar, [n, day]]]]]], '.']], '2008-08-18-20-08-41', '130.60.206.84', '').
text_drs_eval(0, 3140, 'Somebody M is the mother of a child C1. Somebody H is the husband of M. H has a child C2. C1 is not C2. Who is C1?', drs([A, B, C, D, E, F, G, H, I], [object(A, somebody, countable, na, eq, 1)-1/2, predicate(B, be, A, C)-1/4, relation(C, of, D)-1/7, object(D, child, countable, na, eq, 1)-1/9, object(C, mother, countable, na, eq, 1)-1/6, object(E, somebody, countable, na, eq, 1)-2/2, predicate(F, be, E, G)-2/4, relation(G, of, A)-2/7, object(G, husband, countable, na, eq, 1)-2/6, object(H, child, countable, na, eq, 1)-3/4, predicate(I, have, E, H)-3/2, -drs([J], [predicate(J, be, D, H)-4/2]), question(drs([K, L], [query(K, who)-5/1, predicate(L, be, K, D)-5/2]))]), [[sentence, [specification, [s, [np, [pn, somebody], [appos, [var, 'M']]], [vp, [aux, is], [vbar, [vcompl, [np, [det, the], [nbar, [n, mother], [pp, [prep, of], [np, [det, a], [nbar, [n, child], [appos, [var, 'C1']]]]]]]]]]], '.'], '.'], [sentence, [specification, [s, [np, [pn, somebody], [appos, [var, 'H']]], [vp, [aux, is], [vbar, [vcompl, [np, [det, the], [nbar, [n, husband], [pp, [prep, of], [np, [var, 'M']]]]]]]]], '.'], '.'], [sentence, [specification, [s, [np, [var, 'H']], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, child], [appos, [var, 'C2']]]]]]]], '.'], '.'], [sentence, [specification, [s, [np, [var, 'C1']], [vp, [aux, is, not], [vbar, [vcompl, [np, [var, 'C2']]]]]], '.'], '.'], [sentence, [query, [question, [np, [qpn, who]], [vp, [aux, is], [vbar, [vcompl, [np, [var, 'C1']]]]]], ?], '.']], '2009-05-13-13-41-09', '130.60.155.193', '').
text_drs_eval(0, 3141, 'A card of a man a card of who is valid is valid.', drs([A, B, C, D, E, F, G], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, relation(C, of, B)-1, property(D, valid, pos)-1, predicate(E, be, C, D)-1, relation(A, of, B)-1, property(F, valid, pos)-1, predicate(G, be, A, F)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-08-19-11-38-19', '130.60.204.40', '').
text_drs_eval(0, 3142, 'A card of a man the card of who is valid is valid.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, property(C, valid, pos)-1, predicate(D, be, A, C)-1, relation(A, of, B)-1, property(E, valid, pos)-1, predicate(F, be, A, E)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]]]]]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], '.']], '2008-08-19-11-38-31', '130.60.204.40', '').
text_drs_eval(0, 3143, 'A card of which man the card of who is valid is valid?', drs([], [question(drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, man, countable, na, eq, 1)-1/5, property(C, valid, pos)-1/11, predicate(D, be, A, C)-1/10, relation(A, of, B)-1/3, property(E, valid, pos)-1/13, predicate(F, be, A, E)-1/12]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]]]]]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-13-41-11', '130.60.155.193', '').
text_drs_eval(0, 3144, 'A man waits. His dog barks.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1, predicate(B, wait, A)-1, relation(C, of, A)-2, object(C, dog, countable, na, eq, 1)-2, predicate(D, bark, C)-2]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, waits]]]], '.'], [specification, [s, [np, [posspn, his], [nbar, [n, dog]]], [vp, [vbar, [v, barks]]]], '.']], '2008-08-19-12-22-43', '130.60.204.40', '').
text_drs_eval(0, 3145, 'A man waits. His own dog barks.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, waits]]]], '.']], '2008-08-19-12-24-05', '130.60.204.40', '').
text_drs_eval(0, 3146, 'Every man is seen by his dog.', drs([], []), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [v, seen], by, [np, [posspn, his], [nbar, [n, dog]]]]]], '.']], '2008-10-23-15-01-33', '130.60.155.206', '').
text_drs_eval(0, 3147, 'There is nothing.', drs([], [-drs([A], [object(A, something, dom, na, na, na)-1])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [pn, nothing]]]], '.']], '2008-08-19-16-20-29', '130.60.155.208', '').
text_drs_eval(0, 3148, 'Mary sleeps. John sees himself and her.', drs([A, B, C, D, E], [object(A, 'Mary', named, na, eq, 1)-1, object(B, 'John', named, na, eq, 1)-2, predicate(C, sleep, A)-1, has_part(E, B)-2, predicate(D, see, B, E)-2, has_part(E, A)-2, object(E, na, countable, na, eq, 2)-2]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, sleeps]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np_coord, [np, [pn, himself]], [coord, and], [np, [pn, her]]]]]], '.']], '2008-08-19-18-40-48', '130.60.155.177', '').
text_drs_eval(0, 3149, 'Mary sleeps. John sees herself.', drs([], []), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, sleeps]]]], '.']], '2008-10-02-14-51-55', '130.60.155.206', '').
text_drs_eval(0, 3150, 'Mary sleeps. John sees himself and herself.', drs([], []), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, sleeps]]]], '.']], '2008-10-02-14-52-14', '130.60.155.206', '').
text_drs_eval(0, 3151, 'Mary sleeps and John sees herself.', drs([], []), [[specification, [s_coord, [s, [np, [pname, 'Mary']], [vp, [vbar, [v, sleeps]]]], [coord, and], [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [pn, herself]]]]]], '.']], '2008-08-19-18-42-50', '130.60.155.177', '').
text_drs_eval(0, 3152, 'Mary sleeps and John sees herself and himself.', drs([], []), [], '2008-10-02-14-52-24', '130.60.155.206', '').
text_drs_eval(0, 3153, 'Mary sleeps and John sees himself and herself.', drs([], []), [], '2008-10-02-14-52-33', '130.60.155.206', '').
text_drs_eval(0, 3154, 'If a card X1 is a card of the card X1 then John enters the card X1.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, card, countable, na, eq, 1)-1, object(C, card, countable, na, eq, 1)-1, relation(C, of, B)-1, predicate(D, be, B, C)-1])=>drs([E], [predicate(E, enter, A, B)-1])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, card], [appos, [var, 'X1']]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [det, the], [nbar, [n, card], [appos, [var, 'X1']]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, enters], [np, [det, the], [nbar, [n, card], [appos, [var, 'X1']]]]]]]], '.']], '2008-10-27-12-06-03', '84.74.167.232', '').
text_drs_eval(0, 3155, 'Not 5 men wait.', drs([], []), [], '2008-08-20-17-15-48', '130.60.155.177', '').
text_drs_eval(0, 3156, 'A man owns not two cars.', drs([], []), [], '2008-08-20-17-16-12', '130.60.155.177', '').
text_drs_eval(0, 3157, 'There are some men each of who who is tired sleeps.', drs([], []), [], '2008-08-21-18-28-42', '130.60.206.13', '').
text_drs_eval(0, 3158, 'There are some men. Each of the men who is tired sleeps.', drs([], []), [[specification, [top_s, [topic, [quant, 'there are'], [np, [det, some], [nbar, [n, men]]]]], '.']], '2008-08-21-18-30-41', '130.60.206.13', '').
text_drs_eval(0, 3159, 'Every friend of JohnX is JohnY or it is rich.', drs([A, B], [object(A, 'JohnX', named, na, eq, 1)-1, object(B, 'JohnY', named, na, eq, 1)-1, drs([], [drs([C], [object(C, friend, countable, na, eq, 1)-1, relation(C, of, A)-1])=>drs([D], [predicate(D, be, C, B)-1])])v drs([E, F], [property(E, rich, pos)-1, predicate(F, be, B, E)-1])]), [[specification, [s_coord, [s, [np, [det, every], [nbar, [n, friend], [pp, [prep, of], [np, [pname, 'JohnX']]]]], [vp, [aux, is], [vbar, [np, [pname, 'JohnY']]]]], [coord, or], [s, [np, [pn, it]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, rich]]]]]]], '.']], '2008-09-02-15-04-20', '130.60.155.177', '').
text_drs_eval(0, 3160, 'JohnX is JohnY or it is rich.', drs([A, B], [object(A, 'JohnX', named, na, eq, 1)-1, object(B, 'JohnY', named, na, eq, 1)-1, drs([C], [predicate(C, be, A, B)-1])v drs([D, E], [property(D, rich, pos)-1, predicate(E, be, B, D)-1])]), [[specification, [s_coord, [s, [np, [pname, 'JohnX']], [vp, [aux, is], [vbar, [np, [pname, 'JohnY']]]]], [coord, or], [s, [np, [pn, it]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, rich]]]]]]], '.']], '2008-09-01-22-06-03', '130.60.155.177', '').
text_drs_eval(0, 3161, 'Which thing which is good does a man enter?', drs([], [question(drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/8, query(B, which)-1/1, object(B, thing, countable, na, eq, 1)-1/2, property(C, good, pos)-1/5, predicate(D, be, B, C)-1/4, predicate(E, enter, A, B)-1/9]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, thing], [rel_cl, [np, [relpn, which]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, good]]]]]]]]], does, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, enter]]]]], ?], '.']], '2009-05-13-13-41-14', '130.60.155.193', '').
text_drs_eval(0, 3162, 'Every man sees a dog X that sees a cat that sees the dog X that sees a rat that sees a mouse.', drs([], []), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, dog], [appos, [var, 'X']], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, dog], [appos, [var, 'X']], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, rat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, mouse]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]], '.']], '2009-11-10-23-18-28', '89.206.64.19', '').
text_drs_eval(0, 3163, 'Which thing which succeeds exists?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, thing, countable, na, eq, 1)-1/2, predicate(B, succeed, A)-1/4, predicate(C, exist, A)-1/5]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, thing], [rel_cl, [np, [relpn, which]], [vp, [vbar, [vbar, [v, succeeds]]]]]]], [vp, [vbar, [vbar, [v, exists]]]]], ?], '.']], '2009-05-13-13-41-15', '130.60.155.193', '').
text_drs_eval(0, 3164, 'John sees a man who sleeps soundly in a bed.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, man, countable, na, eq, 1)-1, object(C, bed, countable, na, eq, 1)-1, predicate(D, sleep, B)-1, modifier_pp(D, in, C)-1, modifier_adv(D, soundly, pos)-1, predicate(E, see, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, sleeps]], [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]]]]]], '.']], '2008-09-23-11-29-01', '130.60.155.206', '').
text_drs_eval(0, 3165, 'Every customer has at least 2 cards and their associated codes. If a customer C approaches an automatic teller and a card of her is valid and she inserts the card carefully into a slot and types a correct code of the card then the automatic teller accepts the card and displays "Card accepted" and C is happy. No card that does not have a correct code is accepted. It is false that a customer\'s card is valid, and is expired or is cancelled. If a card is not provably invalid then it is accepted. If a customer owns a card and can prove that it is lost then a bank must replace it.', drs([], [drs([A], [object(A, customer, countable, na, eq, 1)-1/2])=>drs([B, C, D, E], [object(B, card, countable, na, geq, 2)-1/7, has_part(E, B)-1/'', predicate(C, have, A, E)-1/3, relation(D, of, B)-1/9, object(D, code, countable, na, geq, 2)-1/11, property(D, associated, pos)-1/10, has_part(E, D)-1/'', object(E, na, countable, na, eq, 2)-1/'']), drs([F, G, H, I, J, K, L, M, N, O], [object(F, customer, countable, na, eq, 1)-2/3, object(G, teller, countable, na, eq, 1)-2/8, property(G, automatic, pos)-2/7, predicate(H, approach, F, G)-2/5, object(I, card, countable, na, eq, 1)-2/11, relation(I, of, G)-2/12, property(J, valid, pos)-2/15, predicate(K, be, I, J)-2/14, object(L, slot, countable, na, eq, 1)-2/24, predicate(M, insert, G, I)-2/18, modifier_pp(M, into, L)-2/22, modifier_adv(M, carefully, pos)-2/21, object(N, code, countable, na, eq, 1)-2/29, property(N, correct, pos)-2/28, relation(N, of, I)-2/30, predicate(O, type, G, N)-2/26])=>drs([P, Q, R, S], [predicate(P, accept, G, I)-2/37, predicate(Q, display, G, string('Card accepted'))-2/41, property(R, happy, pos)-2/46, predicate(S, be, F, R)-2/45]), drs([T], [object(T, card, countable, na, eq, 1)-3/2, -drs([U, V], [object(U, code, countable, na, eq, 1)-3/9, property(U, correct, pos)-3/8, predicate(V, have, T, U)-3/6])])=>drs([], [-drs([W, X], [property(W, accepted, pos)-3/11, predicate(X, be, T, W)-3/10])]), -drs([Y, Z, A1, B1], [object(Y, customer, countable, na, eq, 1)-4/6, relation(Z, of, Y)-4/7, object(Z, card, countable, na, eq, 1)-4/9, property(A1, valid, pos)-4/11, predicate(B1, be, Z, A1)-4/10, drs([C1, D1], [property(C1, expired, pos)-4/15, predicate(D1, be, Z, C1)-4/14])v drs([E1, F1], [property(E1, cancelled, pos)-4/18, predicate(F1, be, Z, E1)-4/17])]), drs([G1], [object(G1, card, countable, na, eq, 1)-5/3, ~drs([H1, I1], [property(H1, invalid, pos)-5/7, predicate(I1, be, G1, H1)-5/4])])=>drs([J1, K1], [property(J1, accepted, pos)-5/11, predicate(K1, be, G1, J1)-5/10]), drs([L1, M1, N1], [object(L1, customer, countable, na, eq, 1)-6/3, object(M1, card, countable, na, eq, 1)-6/6, predicate(N1, own, L1, M1)-6/4, can(drs([O1, P1], [predicate(O1, prove, L1, P1)-6/9, P1:drs([Q1, R1], [property(Q1, lost, pos)-6/13, predicate(R1, be, M1, Q1)-6/12])]))])=>drs([S1], [object(S1, bank, countable, na, eq, 1)-6/16, must(drs([T1], [predicate(T1, replace, S1, M1)-6/18]))])]), [[specification, [s, [np, [det, every], [nbar, [n, customer]]], [vp, [vbar, [vcompl, [v, has], [np_coord, [np, [nump, [genqu, 'at least'], 2], [nbar, [n, cards]]], [coord, and], [np, [posspn, their], [nbar, [adj, associated], [nbar, [n, codes]]]]]]]]], '.'], [specification, [cond_s, if, [s_coord, [s, [np, [det, a], [nbar, [n, customer], [appos, [var, 'C']]]], [vp, [vbar, [vcompl, [v, approaches], [np, [det, an], [nbar, [adj, automatic], [nbar, [n, teller]]]]]]]], [coord, and], [s, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [pn, her]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], [coord, and], [s, [np, [pn, she]], [vp_coord, [vp, [vbar, [vcompl, [v, inserts], [np, [det, the], [nbar, [n, card]]]], [vmod, [adv, carefully], [pp, [prep, into], [np, [det, a], [nbar, [n, slot]]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, types], [np, [det, a], [nbar, [adj, correct], [nbar, [n, code], [pp, [prep, of], [np, [det, the], [nbar, [n, card]]]]]]]]]]]]], then, [s_coord, [s, [np, [det, the], [nbar, [adj, automatic], [nbar, [n, teller]]]], [vp_coord, [vp, [vbar, [vcompl, [v, accepts], [np, [det, the], [nbar, [n, card]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, displays], [np, [string, '"Card accepted"']]]]]]], [coord, and], [s, [np, [var, 'C']], [vp, [aux, is], [ap_coord, [ap, [adj, happy]]]]]]], '.'], [specification, [s, [np, [det, no], [nbar, [n, card], [rel_cl, [comp, that], [vp, [aux, does, not], [vbar, [vcompl, [v, have], [np, [det, a], [nbar, [adj, correct], [nbar, [n, code]]]]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, accepted]]]]], '.'], [specification, [s, [neg, 'it is false'], [cp, that, [s, [np, [poss_np, [det, a], [nbar, [n, customer]], [gen_marker, '\'s']], [nbar, [n, card]]], [vp_coord, [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]], [coord, ', and'], [vp, [aux, is], [ap_coord, [ap, [adj, expired]]]], [coord, or], [vp, [aux, is], [ap_coord, [ap, [adj, cancelled]]]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is, 'not provably'], [ap_coord, [ap, [adj, invalid]]]]], then, [s, [np, [pn, it]], [vp, [aux, is], [ap_coord, [ap, [adj, accepted]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, a], [nbar, [n, customer]]], [vp_coord, [vp, [vbar, [vcompl, [v, owns], [np, [det, a], [nbar, [n, card]]]]]], [coord, and], [vp, [aux, can], [vbar, [cp, that, [s, [np, [pn, it]], [vp, [aux, is], [ap_coord, [ap, [adj, lost]]]]]]]]]], then, [s, [np, [det, a], [nbar, [n, bank]]], [vp, [aux, must], [vbar, [vcompl, [v, replace], [np, [pn, it]]]]]]], '.']], '2010-11-12-08-52-44', '89.206.69.32', '').
text_drs_eval(0, 3166, 'A man hits a dog which runs fast in a park.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, park, countable, na, eq, 1)-1, predicate(D, run, B)-1, modifier_pp(D, in, C)-1, modifier_adv(D, fast, pos)-1, predicate(E, hit, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, hits], [np, [det, a], [nbar, [n, dog], [rel_cl, [np, [relpn, which]], [vp, [vbar, [vbar, [v, runs]], [adv, fast], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]]]]]]]]], '.']], '2008-10-06-15-32-27', '130.60.155.206', '').
text_drs_eval(0, 3167, 'A man hits a dog which runs fast in a park quickly.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1, object(B, dog, countable, na, eq, 1)-1, object(C, park, countable, na, eq, 1)-1, predicate(D, run, B)-1, modifier_adv(D, quickly, pos)-1, modifier_pp(D, in, C)-1, modifier_adv(D, fast, pos)-1, predicate(E, hit, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [v, hits], [np, [det, a], [nbar, [n, dog], [rel_cl, [np, [relpn, which]], [vp, [vbar, [vbar, [v, runs]], [adv, fast], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [adv, quickly]]]]]]]]], '.']], '2008-10-06-15-32-42', '130.60.155.206', '').
text_drs_eval(0, 3168, 'Mary inserts her own card that is valid carefully into a slot.', drs([A, B, C, D, E], [relation(A, of, named('Mary'))-1/3, object(A, card, countable, na, eq, 1)-1/5, object(B, slot, countable, na, eq, 1)-1/12, property(C, valid, pos)-1/8, predicate(D, be, A, C)-1/7, modifier_pp(D, into, B)-1/10, modifier_adv(D, carefully, pos)-1/9, predicate(E, insert, named('Mary'), A)-1/2]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, inserts], [np, [posspn, 'her own'], [nbar, [n, card], [rel_cl, [comp, that], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]], [vmod, [adv, carefully], [pp, [prep, into], [np, [det, a], [nbar, [n, slot]]]]]]]]]]]]], '.']], '2009-05-19-17-22-03', '130.60.155.193', '').
text_drs_eval(0, 3169, 'Mary\'s card is valid and she inserts the card carefully into a slot.', drs([A, B, C, D, E, F], [object(A, 'Mary', named, na, eq, 1)-1, relation(B, of, A)-1, object(B, card, countable, na, eq, 1)-1, property(C, valid, pos)-1, predicate(D, be, B, C)-1, object(E, slot, countable, na, eq, 1)-1, predicate(F, insert, A, B)-1, modifier_pp(F, into, E)-1, modifier_adv(F, carefully, pos)-1]), [[specification, [s_coord, [s, [np, [poss_np, [pname, 'Mary'], [gen_marker, '\'s']], [nbar, [n, card]]], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, valid]]]]]], [coord, and], [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, inserts], [np, [det, the], [nbar, [n, card]]]], [adv, carefully], [pp, [prep, into], [np, [det, a], [nbar, [n, slot]]]]]]]], '.']], '2008-10-06-15-33-46', '130.60.155.206', '').
text_drs_eval(0, 3170, 'A card is valid in a slot.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1, object(B, slot, countable, na, eq, 1)-1, property(C, valid, pos)-1, predicate(D, be, A, C)-1, modifier_pp(D, in, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vbar, [ap_coord, [ap, [adj, valid]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, slot]]]]]]], '.']], '2008-10-06-15-34-02', '130.60.155.206', '').
text_drs_eval(0, 3171, 'A card is valid in a slot carefully.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, object(B, slot, countable, na, eq, 1)-1/7, property(C, valid, pos)-1/4, predicate(D, be, A, C)-1/3, modifier_adv(D, carefully, pos)-1/8, modifier_pp(D, in, B)-1/5]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, slot]]]], [adv, carefully]]]], '.']], '2009-05-19-17-22-11', '130.60.155.193', '').
text_drs_eval(0, 3172, 'A card is valid carefully in a slot.', drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, object(B, slot, countable, na, eq, 1)-1/8, property(C, valid, pos)-1/4, predicate(D, be, A, C)-1/3, modifier_pp(D, in, B)-1/6, modifier_adv(D, carefully, pos)-1/5]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]], [vmod, [adv, carefully], [pp, [prep, in], [np, [det, a], [nbar, [n, slot]]]]]]], '.']], '2009-05-19-17-22-19', '130.60.155.193', '').
text_drs_eval(0, 3173, 'A card is valid carefully.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1/2, property(B, valid, pos)-1/4, predicate(C, be, A, B)-1/3, modifier_adv(C, carefully, pos)-1/5]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]], [vmod, [adv, carefully]]]], '.']], '2009-05-19-17-22-27', '130.60.155.193', '').
text_drs_eval(0, 3174, 'A card is valid in a slot in a bank.', drs([A, B, C, D, E], [object(A, card, countable, na, eq, 1)-1, object(B, bank, countable, na, eq, 1)-1, object(C, slot, countable, na, eq, 1)-1, property(D, valid, pos)-1, predicate(E, be, A, D)-1, modifier_pp(E, in, B)-1, modifier_pp(E, in, C)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vbar, [ap_coord, [ap, [adj, valid]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, slot]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, bank]]]]]]], '.']], '2008-10-06-15-34-38', '130.60.155.206', '').
text_drs_eval(0, 3175, 'Everybody X of X\'s dog waits.', drs([], [drs([A, B], [object(A, somebody, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, dog, countable, na, eq, 1)-1, relation(A, of, B)-1])=>drs([C], [predicate(C, wait, A)-1])]), [[specification, [s, [np, [pn, everybody], [appos, [var, 'X']], [pp, [prep, of], [np, [poss_np, [var, 'X'], [gen_marker, '\'s']], [nbar, [n, dog]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-07-17-22-12', '130.60.155.177', '').
text_drs_eval(0, 3176, 'There is a boy. A man of his own group waits.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, boy]]]]], '.']], '2008-10-23-14-56-55', '130.60.155.177', '').
text_drs_eval(0, 3177, 'Every mother of someone is a parent of it.', drs([], []), [[specification, [s, [np, [det, every], [nbar, [n, mother], [pp, [prep, of], [np, [pn, someone]]]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, parent], [pp, [prep, of], [np, [pn, it]]]]]]]], '.']], '2008-10-23-14-57-29', '130.60.155.177', '').
text_drs_eval(0, 3178, 'Every man\'s car contains some instructions that code its development.', drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, car, countable, na, eq, 1)-1])=>drs([C, D, E, F], [object(C, instruction, countable, na, geq, 2)-1, relation(D, of, B)-1, object(D, development, countable, na, eq, 1)-1, predicate(E, code, C, D)-1, predicate(F, contain, B, C)-1])]), [[specification, [s, [np, [poss_np, [det, every], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, car]]], [vp, [vbar, [v, contains], [np, [det, some], [nbar, [n, instructions], [rel_cl, [comp, that], [vp, [vbar, [v, code], [np, [posspn, its], [nbar, [n, development]]]]]]]]]]], '.']], '2008-10-23-14-59-49', '130.60.155.206', '').
text_drs_eval(0, 3179, 'Everybody of its dog waits.', drs([], []), [[specification, [s, [np, [pn, everybody], [pp, [prep, of], [np, [posspn, its], [nbar, [n, dog]]]]], [vp, [vbar, [v, waits]]]], '.']], '2008-10-23-14-59-51', '130.60.155.177', '').
text_drs_eval(0, 3180, 'If there is an animal that believes that John is its owner then John sees the animal.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B, C, D], [object(B, animal, countable, na, eq, 1)-1, predicate(C, believe, B, D)-1, D:drs([E, F], [relation(E, of, B)-1, object(E, owner, countable, na, eq, 1)-1, predicate(F, be, A, E)-1])])=>drs([G], [predicate(G, see, A, B)-1])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, animal], [rel_cl, [comp, that], [vp, [vbar, [v, believes], [cp, that, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [np, [posspn, its], [nbar, [n, owner]]]]]]]]]]]]]], then, [s, [np, [pname, 'John']], [vp, [vbar, [v, sees], [np, [det, the], [nbar, [n, animal]]]]]]], '.']], '2008-10-23-15-00-33', '130.60.155.206', '').
text_drs_eval(0, 3181, 'A dog of its man barks.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1, relation(B, of, A)-1, object(B, man, countable, na, eq, 1)-1, relation(A, of, B)-1, predicate(C, bark, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [posspn, its], [nbar, [n, man]]]]]], [vp, [vbar, [v, barks]]]], '.']], '2008-10-23-15-00-58', '130.60.155.206', '').
text_drs_eval(0, 3182, 'A card X1 is a card of the card X1.', drs([A, B, C], [object(A, card, countable, na, eq, 1)-1, object(B, card, countable, na, eq, 1)-1, relation(B, of, A)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [det, a], [nbar, [n, card], [appos, [var, 'X1']]]], [vp, [aux, is], [vbar, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [det, the], [nbar, [n, card], [appos, [var, 'X1']]]]]]]]]], '.']], '2008-10-27-12-06-35', '84.74.167.232', '').
text_drs_eval(0, 3183, 'What does John not see?', drs([], [question(drs([], [-drs([A, B], [query(A, what)-1/1, predicate(B, see, named('John'), A)-1/5])]))]), [[query, [question, [np, [qpn, what]], does, [np, [pname, 'John']], [vp, [aux, not], [vbar, [vcompl, [v, see]]]]], ?]], '2009-11-18-08-48-00', '130.60.155.164', '').
text_drs_eval(0, 3184, 'Switzerland borders 4 countries that border Germany.', drs([A, B, C, D, E], [object(A, 'Switzerland', named, na, eq, 1)-1, object(B, 'Germany', named, na, eq, 1)-1, object(C, country, countable, na, eq, 4)-1, predicate(D, border, C, B)-1, predicate(E, border, A, C)-1]), [[specification, [s, [np, [pname, 'Switzerland']], [vp, [vbar, [v, borders], [np, [nump, [num, 4]], [nbar, [n, countries], [rel_cl, [comp, that], [vp, [vbar, [v, border], [np, [pname, 'Germany']]]]]]]]]], '.']], '2008-11-11-17-28-00', '130.60.155.203', '').
text_drs_eval(0, 3185, 'Switzerland borders each of 4 countries that border Germany.', drs([A, B], [object(A, country, countable, na, eq, 4)-1/6, predicate(B, border, A, named('Germany'))-1/8, drs([C], [has_part(A, C)-1/3])=>drs([D], [predicate(D, border, named('Switzerland'), C)-1/2])]), [[specification, [s, [np, [pname, 'Switzerland']], [vp, [vbar, [vcompl, [v, borders], [np, [quant, 'each of'], [np, [nump, 4], [nbar, [n, countries], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, border], [np, [pname, 'Germany']]]]]]]]]]]]], '.']], '2009-11-18-08-48-34', '130.60.155.164', '').
text_drs_eval(0, 3186, 'John has 0 kg of apples.', drs([A, B], [object(A, apple, countable, kg, eq, 0)-1/6, predicate(B, have, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [meas_spec, [nump, 0], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, apples]]]]]]], '.']], '2010-01-18-11-14-51', '89.206.64.72', '').
text_drs_eval(0, 3187, 'John wants to run.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, want, A, C)-1, C:drs([D], [predicate(D, run, A)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, wants], to, [vp, [vbar, [vbar, [v, run]]]]]]], '.']], '2009-01-06-10-43-09', '130.60.155.206', '').
text_drs_eval(0, 3188, 'John has 1.83 apples.', drs([], []), [], '2009-01-05-12-12-37', '130.60.155.206', '').
text_drs_eval(0, 3189, 'A dog that every man who waits has barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, drs([C, D], [object(C, man, countable, na, eq, 1)-1, predicate(D, wait, C)-1])=>drs([E], [predicate(E, have, C, A)-1]), predicate(B, bark, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [np, [det, every], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, waits]]]]]], [vp, [vbar, [v, has]]]]]], [vp, [vbar, [v, barks]]]], '.']], '2008-12-09-17-05-17', '130.60.155.177', '').
text_drs_eval(0, 3190, 'A dog of every man who waits barks.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, drs([C, D], [object(C, man, countable, na, eq, 1)-1, predicate(D, wait, C)-1])=>drs([], [relation(A, of, C)-1]), predicate(B, bark, A)-1]), [[specification, [s, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, every], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, waits]]]]]]]]], [vp, [vbar, [v, barks]]]], '.']], '2008-12-09-17-05-26', '130.60.155.177', '').
text_drs_eval(0, 3191, 'There is a dog of every man. There is a cat of every woman.', drs([A, B], [object(A, dog, countable, na, eq, 1)-1, drs([C], [object(C, man, countable, na, eq, 1)-1])=>drs([], [relation(A, of, C)-1]), object(B, cat, countable, na, eq, 1)-2, drs([D], [object(D, woman, countable, na, eq, 1)-2])=>drs([], [relation(B, of, D)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, every], [nbar, [n, man]]]]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [pp, [prep, of], [np, [det, every], [nbar, [n, woman]]]]]]]], '.']], '2008-12-09-17-35-40', '130.60.155.177', '').
text_drs_eval(0, 3192, 'An apple is v:given toooo John by Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, given, B, C, A)-1]), [[specification, [s, [np, [det, an], [nbar, [n, apple]]], [vp, [aux, is], [vbar, [v, given], toooo, [np, [pname, 'John']], by, [np, [pname, 'Mary']]]]], '.']], '2009-01-05-11-08-16', '130.60.155.206', '').
text_drs_eval(0, 3193, 'John v:gives an apple to Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, gives, A, C, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, gives], [np, [det, an], [nbar, [n, apple]]], to, [np, [pname, 'Mary']]]]], '.']], '2009-01-05-11-08-58', '130.60.155.206', '').
text_drs_eval(0, 3194, 'John v:gives Mary an apple.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, gives, A, C, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, gives], [np, [pname, 'Mary']], [np, [det, an], [nbar, [n, apple]]]]]], '.']], '2009-01-05-11-09-06', '130.60.155.206', '').
text_drs_eval(0, 3195, 'John v:gives an apple toooo Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, gives, A, C, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, gives], [np, [det, an], [nbar, [n, apple]]], toooo, [np, [pname, 'Mary']]]]], '.']], '2009-01-05-11-09-20', '130.60.155.206', '').
text_drs_eval(0, 3196, 'John v:xxx an apple yyy Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, object(C, apple, countable, na, eq, 1)-1, predicate(D, xxx, A, C, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, xxx], [np, [det, an], [nbar, [n, apple]]], yyy, [np, [pname, 'Mary']]]]], '.']], '2009-01-05-11-09-55', '130.60.155.206', '').
text_drs_eval(0, 3197, 'John is as a:rrich as Bill.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, property(C, rrich, pos_as, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [ap_coord, [ap, as, [adj, rrich], as, [np, [pname, 'Bill']]]]]]], '.']], '2009-01-05-11-10-35', '130.60.155.206', '').
text_drs_eval(0, 3198, 'John is a:rricher than Bill.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, property(C, rricher, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, rricher], [conj, than], [np, [pname, 'Bill']]]]]]], '.']], '2009-01-05-11-10-56', '130.60.155.206', '').
text_drs_eval(0, 3199, 'John is more a:rrich than Bill.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Bill', named, na, eq, 1)-1, property(C, rrich, comp_than, B)-1, predicate(D, be, A, C)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, more, rrich], [conj, than], [np, [pname, 'Bill']]]]]]], '.']], '2009-01-05-11-11-07', '130.60.155.206', '').
text_drs_eval(0, 3200, 'John is most a:rrich.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, property(B, rrich, sup)-1, predicate(C, be, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [ap_coord, [ap, [adj, most, rrich]]]]]], '.']], '2009-01-05-11-12-04', '130.60.155.206', '').
text_drs_eval(0, 3201, 'John runs a:ffast.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, ffast, pos)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, runs]], [adv, ffast]]]], '.']], '2009-01-05-11-12-20', '130.60.155.206', '').
text_drs_eval(0, 3202, 'John runs more a:ffast.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, ffast, comp)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, runs]], [adv, more, ffast]]]], '.']], '2009-01-05-11-12-28', '130.60.155.206', '').
text_drs_eval(0, 3203, 'John runs most a:ffast.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, predicate(B, run, A)-1, modifier_adv(B, ffast, sup)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, runs]], [adv, most, ffast]]]], '.']], '2009-01-05-11-12-33', '130.60.155.206', '').
text_drs_eval(0, 3204, 'John has 1.83 kg of apples.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, apple, countable, kg, eq, 1.83)-1, predicate(C, have, A, B)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, has], [np, [meas_spec, [nump, 1.83], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, apples]]]]]], '.']], '2009-01-05-12-13-11', '130.60.155.206', '').
text_drs_eval(0, 3205, 'John has 0 apples.', drs([A, B], [object(A, apple, countable, na, eq, 0)-1/4, predicate(B, have, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [nump, 0], [nbar, [n, apples]]]]]]], '.']], '2010-01-18-11-14-59', '89.206.64.72', '').
text_drs_eval(0, 3206, 'John has -2 apples.', drs([], []), [], '2009-01-05-12-22-01', '130.60.155.206', '').
text_drs_eval(0, 3207, 'John has -2 kg of apples.', drs([], []), [], '2009-01-05-12-22-07', '130.60.155.206', '').
text_drs_eval(0, 3208, 'There are at most 2 men X and something Y and something Z.', drs([A, B, C, D], [[has_part(D, A)-1, object(A, man, countable, na, leq, 2)-1], object(B, something, dom, na, na, na)-1, has_part(D, B)-1, object(C, something, dom, na, na, na)-1, has_part(D, C)-1, object(D, na, countable, na, eq, 3)-1]), [[specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men], [appos, [var, 'X']]]], [coord, and], [np, [pn, something], [appos, [var, 'Y']]], [coord, and], [np, [pn, something], [appos, [var, 'Z']]]]]], '.']], '2009-03-02-11-37-26', '130.60.155.206', '').
text_drs_eval(0, 3209, 'There is X. There is X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.']], '2010-12-27-16-03-02', '82.131.73.12', '').
text_drs_eval(0, 3210, 'There is a man X. There is X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.']], '2009-01-05-14-44-32', '130.60.155.206', '').
text_drs_eval(0, 3211, 'There is something X. There is X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X']]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.']], '2009-01-05-14-44-41', '130.60.155.206', '').
text_drs_eval(0, 3212, 'There are X. There is X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there are'], [np, [var, 'X']]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.']], '2009-01-05-14-44-52', '130.60.155.206', '').
text_drs_eval(0, 3213, 'There are X. X are some men.', drs([A, B, C], [object(A, something, dom, na, na, na)-1, object(B, man, countable, na, geq, 2)-2, predicate(C, be, A, B)-2]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [var, 'X']]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, are], [vbar, [np, [det, some], [nbar, [n, men]]]]]], '.']], '2009-01-05-14-45-35', '130.60.155.206', '').
text_drs_eval(0, 3214, 'There are X. X is some men.', drs([], []), [[specification, [top_s, [topic, [quant, 'there are'], [np, [var, 'X']]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [np, [det, some], [nbar, [n, men]]]]]], '.']], '2009-01-05-14-45-36', '130.60.155.206', '').
text_drs_eval(0, 3215, 'There is X. There is a man X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.']], '2009-01-05-14-45-48', '130.60.155.206', '').
text_drs_eval(0, 3216, 'If there is X then there is X.', drs([], []), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], then, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]]], '.']], '2009-01-05-14-45-57', '130.60.155.206', '').
text_drs_eval(0, 3217, 'There are X and Y.', drs([A, B, C], [object(A, something, dom, na, na, na)-1, has_part(C, A)-1, object(B, something, dom, na, na, na)-1, has_part(C, B)-1, object(C, na, countable, na, eq, 2)-1]), [[specification, [top_s, [topic, [quant, 'there are'], [np_coord, [np, [var, 'X']], [coord, and], [np, [var, 'Y']]]]], '.']], '2009-01-05-14-46-07', '130.60.155.206', '').
text_drs_eval(0, 3218, 'John says "', drs([], []), [], '2009-01-05-15-22-53', '130.60.155.206', '').
text_drs_eval(0, 3219, 'John, can swim!', drs([], []), [], '2009-01-05-16-13-20', '130.60.155.206', '').
text_drs_eval(0, 3220, 'John, must wait!', drs([], []), [], '2009-01-05-16-13-28', '130.60.155.206', '').
text_drs_eval(0, 3221, 'John, do not provably sleep!', drs([], []), [], '2009-01-05-16-15-22', '130.60.155.206', '').
text_drs_eval(0, 3222, 'John tries to hurry and runs.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, predicate(B, try, A, C)-1, C:drs([E], [predicate(E, hurry, A)-1]), predicate(D, run, A)-1]), [[specification, [s, [np, [pname, 'John']], [vp_coord, [vp, [vbar, [v, tries], to, [vp, [vbar, [vbar, [v, hurry]]]]]], [coord, and], [vp, [vbar, [vbar, [v, runs]]]]]], '.']], '2009-01-06-10-43-01', '130.60.155.206', '').
text_drs_eval(0, 3223, 'Every manager manages to manage.', drs([], [drs([A], [object(A, manager, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, manage, A, C)-1, C:drs([D], [predicate(D, manage, A)-1])])]), [[specification, [s, [np, [det, every], [nbar, [n, manager]]], [vp, [vbar, [v, manages], to, [vp, [vbar, [vbar, [v, manage]]]]]]], '.']], '2009-01-06-10-44-02', '130.60.155.206', '').
text_drs_eval(0, 3224, 'Every manager manages to manage something.', drs([], [drs([A], [object(A, manager, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, manage, A, C)-1, C:drs([D, E], [object(D, something, dom, na, na, na)-1, predicate(E, manage, A, D)-1])])]), [[specification, [s, [np, [det, every], [nbar, [n, manager]]], [vp, [vbar, [v, manages], to, [vp, [vbar, [vcompl, [v, manage], [np, [pn, something]]]]]]]], '.']], '2009-01-06-10-44-14', '130.60.155.206', '').
text_drs_eval(0, 3225, 'John stops to smoke and starts to drink.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, predicate(B, stop, A, C)-1, C:drs([F], [predicate(F, smoke, A)-1]), predicate(D, start, A, E)-1, E:drs([G], [predicate(G, drink, A)-1])]), [[specification, [s, [np, [pname, 'John']], [vp_coord, [vp, [vbar, [v, stops], to, [vp, [vbar, [vbar, [v, smoke]]]]]], [coord, and], [vp, [vbar, [v, starts], to, [vp, [vbar, [vbar, [v, drink]]]]]]]], '.']], '2009-01-06-10-45-29', '130.60.155.206', '').
text_drs_eval(0, 3226, 'John strongly desires a beer.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, object(B, beer, countable, na, eq, 1)-1, predicate(C, desire, A, B)-1, modifier_adv(C, strongly, pos)-1]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, strongly], [vcompl, [v, desires], [np, [det, a], [nbar, [n, beer]]]]]]], '.']], '2009-01-06-10-45-52', '130.60.155.206', '').
text_drs_eval(0, 3227, 'John strongly desires to drink a beer.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, predicate(B, desire, A, C)-1, modifier_adv(B, strongly, pos)-1, C:drs([D, E], [object(D, beer, countable, na, eq, 1)-1, predicate(E, drink, A, D)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, strongly], [v, desires], to, [vp, [vbar, [vcompl, [v, drink], [np, [det, a], [nbar, [n, beer]]]]]]]]], '.']], '2009-01-06-10-46-14', '130.60.155.206', '').
text_drs_eval(0, 3228, 'John wants to be loved by Mary.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, predicate(C, want, A, D)-1, D:drs([E], [predicate(E, love, B, A)-1])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, wants], to, [vp, [aux, be], [vbar, [vcompl, [v, loved], by, [np, [pname, 'Mary']]]]]]]], '.']], '2009-01-06-11-41-43', '130.60.155.206', '').
text_drs_eval(0, 3229, 'Every man wants to be loved by a woman who wants to be protected by the man.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C], [predicate(B, want, A, C)-1, C:drs([D, E, F, G], [object(D, woman, countable, na, eq, 1)-1, predicate(E, want, D, F)-1, F:drs([H], [predicate(H, protect, A, D)-1]), predicate(G, love, D, A)-1])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [v, wants], to, [vp, [aux, be], [vbar, [vcompl, [v, loved], by, [np, [det, a], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [vbar, [v, wants], to, [vp, [aux, be], [vbar, [vcompl, [v, protected], by, [np, [det, the], [nbar, [n, man]]]]]]]]]]]]]]]]], '.']], '2009-01-06-11-42-37', '130.60.155.206', '').
text_drs_eval(0, 3230, 'Every man can want to love a woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [can(drs([B, C], [predicate(B, want, A, C)-1/4, C:drs([D, E], [object(D, woman, countable, na, eq, 1)-1/8, predicate(E, love, A, D)-1/6])]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, can], [vbar, [v, want], to, [vp, [vbar, [vcompl, [v, love], [np, [det, a], [nbar, [n, woman]]]]]]]]], '.']], '2010-10-27-09-34-41', '89.206.64.27', '').
text_drs_eval(0, 3231, 'Every man can want to attempt to try to love a woman.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [can(drs([B, C], [predicate(B, want, A, C)-1/4, C:drs([D, E], [predicate(D, attempt, A, E)-1/6, E:drs([F, G], [predicate(F, try, A, G)-1/8, G:drs([H, I], [object(H, woman, countable, na, eq, 1)-1/12, predicate(I, love, A, H)-1/10])])])]))])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, can], [vbar, [v, want], to, [vp, [vbar, [v, attempt], to, [vp, [vbar, [v, try], to, [vp, [vbar, [vcompl, [v, love], [np, [det, a], [nbar, [n, woman]]]]]]]]]]]]], '.']], '2010-10-27-09-34-47', '89.206.64.27', '').
text_drs_eval(0, 3232, 'John wants to can swim.', drs([], []), [], '2009-01-06-11-45-10', '130.60.155.206', '').
text_drs_eval(0, 3233, 'John wants to must swim.', drs([], []), [], '2009-01-06-11-45-17', '130.60.155.206', '').
text_drs_eval(0, 3234, 'John wants to have to swim.', drs([], []), [], '2009-01-06-11-45-22', '130.60.155.206', '').
text_drs_eval(0, 3235, 'John wants to not swim.', drs([], []), [], '2009-01-06-11-45-29', '130.60.155.206', '').
text_drs_eval(0, 3236, 'John should swim.', drs([A], [object(A, 'John', named, na, eq, 1)-1, should(drs([B], [predicate(B, swim, A)-1]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should], [vbar, [vbar, [v, swim]]]]], '.']], '2009-01-06-11-47-59', '130.60.155.206', '').
text_drs_eval(0, 3237, 'John wants to should swim.', drs([], []), [], '2009-01-06-11-48-04', '130.60.155.206', '').
text_drs_eval(0, 3238, 'John wants to do not swim.', drs([], []), [], '2009-01-06-12-06-57', '130.60.155.206', '').
text_drs_eval(0, 3239, 'John wants to swims.', drs([], []), [], '2009-01-06-12-07-09', '130.60.155.206', '').
text_drs_eval(0, 3240, 'There is a case. It is not the case that John sees.', drs([A, B], [object(A, 'John', named, na, eq, 1)-2, object(B, case, countable, na, eq, 1)-1, -drs([C, D, E], [predicate(C, be, B, D)-2, predicate(E, see, A, D)-2, object(D, case, countable, na, eq, 1)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, case]]]]], '.'], [specification, [s, [np, [pn, it]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, the], [nbar, [n, case], [rel_cl, [comp, that], [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees]]]]]]]]]]], '.']], '2009-01-12-20-11-14', '130.60.155.177', '').
text_drs_eval(0, 3241, 'There is a case. It is not the case.', drs([A], [object(A, case, countable, na, eq, 1)-1, -drs([B], [predicate(B, be, A, A)-2])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, case]]]]], '.'], [specification, [s, [np, [pn, it]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, the], [nbar, [n, case]]]]]]], '.']], '2009-01-12-20-11-56', '130.60.155.177', '').
text_drs_eval(0, 3242, 'When can a card be valid?', drs([], [question(drs([A], [object(A, card, countable, na, eq, 1)-1/4, can(drs([B, C], [property(B, valid, pos)-1/6, predicate(C, be, A, B)-1/2, query(C, when)-1/1]))]))]), [[query, [question, [qpn, when], can, [np, [det, a], [nbar, [n, card]]], [vp, [aux, be], [ap_coord, [ap, [adj, valid]]]]], ?]], '2010-10-27-09-34-51', '89.206.64.27', '').
text_drs_eval(0, 3243, 'How can a car be fastest and more reliable?', drs([], [question(drs([A], [object(A, car, countable, na, eq, 1)-1/4, can(drs([B, C], [property(B, fast, sup)-1/6, property(B, reliable, comp)-1/9, predicate(C, be, A, B)-1/2, query(C, how)-1/1]))]))]), [[query, [question, [qpn, how], can, [np, [det, a], [nbar, [n, car]]], [vp, [aux, be], [ap_coord, [ap, [adj, fastest]], [coord, and], [ap, [adj, more, reliable]]]]], ?]], '2010-10-27-09-34-56', '89.206.64.27', '').
text_drs_eval(0, 3244, 'How must John be polite?', drs([], [question(drs([], [must(drs([A, B], [property(A, polite, pos)-1/5, predicate(B, be, named('John'), A)-1/2, query(B, how)-1/1]))]))]), [[query, [question, [qpn, how], must, [np, [pname, 'John']], [vp, [aux, be], [ap_coord, [ap, [adj, polite]]]]], ?]], '2010-10-27-09-35-01', '89.206.64.27', '').
text_drs_eval(0, 3245, 'Where can an escaped prisoner be?', drs([], [question(drs([A], [object(A, prisoner, countable, na, eq, 1)-1/5, property(A, escaped, pos)-1/4, can(drs([B], [predicate(B, be, A)-1/2, query(B, where)-1/1]))]))]), [[query, [question, [qpn, where], can, [np, [det, an], [nbar, [adj, escaped], [nbar, [n, prisoner]]]], [vp, [aux, be]]], ?]], '2010-10-27-09-35-06', '89.206.64.27', '').
text_drs_eval(0, 3246, 'Where can an escaped prisoner be rich?', drs([], [question(drs([A], [object(A, prisoner, countable, na, eq, 1)-1/5, property(A, escaped, pos)-1/4, can(drs([B, C], [property(B, rich, pos)-1/7, predicate(C, be, A, B)-1/2, query(C, where)-1/1]))]))]), [[query, [question, [qpn, where], can, [np, [det, an], [nbar, [adj, escaped], [nbar, [n, prisoner]]]], [vp, [aux, be], [ap_coord, [ap, [adj, rich]]]]], ?]], '2010-10-27-09-35-11', '89.206.64.27', '').
text_drs_eval(0, 3247, 'How can a man can be rich?', drs([], []), [], '2009-01-16-09-54-34', '130.60.155.206', '').
text_drs_eval(0, 3248, 'How does a man works?', drs([], []), [], '2009-01-16-09-54-52', '130.60.155.206', '').
text_drs_eval(0, 3249, 'when can some cards be valid?', drs([], [question(drs([A], [object(A, card, countable, na, geq, 2)-1/4, can(drs([B, C], [property(B, valid, pos)-1/6, predicate(C, be, A, B)-1/2, query(C, when)-1/1]))]))]), [[query, [question, [qpn, when], can, [np, [det, some], [nbar, [n, cards]]], [vp, [aux, be], [ap_coord, [ap, [adj, valid]]]]], ?]], '2010-10-27-09-36-36', '89.206.64.27', '').
text_drs_eval(0, 3250, 'when can some cards is valid?', drs([], []), [], '2009-01-16-14-07-46', '130.60.155.206', '').
text_drs_eval(0, 3251, 'when can some cards must be valid?', drs([], []), [], '2009-01-16-14-07-58', '130.60.155.206', '').
text_drs_eval(0, 3252, 'When are some cards valid?', drs([], [question(drs([A, B, C], [object(A, card, countable, na, geq, 2)-1/4, property(B, valid, pos)-1/5, predicate(C, be, A, B)-1/2, query(C, when)-1/1]))]), [[sentence, [query, [question, [qpn, when], are, [np, [det, some], [nbar, [n, cards]]], [vp, [vbar, [vcompl, [ap_coord, [ap, [adj, valid]]]]]]], ?], '.']], '2009-05-13-13-41-28', '130.60.155.193', '').
text_drs_eval(0, 3253, 'John lives in a city that exists always always.', drs([], []), [], '2009-01-16-15-10-06', '130.60.155.206', '').
text_drs_eval(0, 3254, 'If X=X then X=X.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1/2, formula(A, =, A)-1/3])=>drs([], [formula(A, =, A)-1/7])]), [[specification, [cond_s, if, [formula, [var, 'X'], =, [var, 'X']], then, [formula, [var, 'X'], =, [var, 'X']]], '.']], '2009-05-26-07-57-45', '130.60.155.193', '').
text_drs_eval(0, 3255, 'If X=Y then X=X.', drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1/2, object(B, something, dom, na, na, na)-1/4, formula(A, =, B)-1/3])=>drs([], [formula(A, =, A)-1/7])]), [[specification, [cond_s, if, [formula, [var, 'X'], =, [var, 'Y']], then, [formula, [var, 'X'], =, [var, 'X']]], '.']], '2009-05-26-07-58-42', '130.60.155.193', '').
text_drs_eval(0, 3256, 'If X=Y then X=Y.', drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1/2, object(B, something, dom, na, na, na)-1/4, formula(A, =, B)-1/3])=>drs([], [formula(A, =, B)-1/7])]), [[specification, [cond_s, if, [formula, [var, 'X'], =, [var, 'Y']], then, [formula, [var, 'X'], =, [var, 'Y']]], '.']], '2009-05-26-07-57-56', '130.60.155.193', '').
text_drs_eval(0, 3257, 'If X=Y then Y=X.', drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1, object(B, something, dom, na, na, na)-1, formula(A, =, B)-1])=>drs([], [formula(B, =, A)-1])]), [[specification, [cond_s, if, [formula, [var, 'X'], =, [var, 'Y']], then, [formula, [var, 'Y'], =, [var, 'X']]], '.']], '2009-02-04-21-41-04', '130.60.155.177', '').
text_drs_eval(1, 3258, 'If X=X then it is false that X=X.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1, formula(A, =, A)-1])=>drs([], [-drs([], [formula(A, =, A)-1])])]), [[specification, [cond_s, if, [formula, [var, 'X'], =, [var, 'X']], then, [s, [neg, 'it is false'], [cp, that, [formula, [var, 'X'], =, [var, 'X']]]]], '.']], '2009-02-04-21-42-24', '130.60.155.177', 'DRS is OK, but Core ACE paraphrase is buggy.').
text_drs_eval(0, 3259, 'If it is false that X=X then it is false that X=X.', drs([], [drs([], [-drs([A], [object(A, something, dom, na, na, na)-1, formula(A, =, A)-1])])=>drs([], [-drs([B], [object(B, something, dom, na, na, na)-1, formula(B, =, B)-1])])]), [[specification, [cond_s, if, [s, [neg, 'it is false'], [cp, that, [formula, [var, 'X'], =, [var, 'X']]]], then, [s, [neg, 'it is false'], [cp, that, [formula, [var, 'X'], =, [var, 'X']]]]], '.']], '2009-02-04-21-43-29', '130.60.155.177', '').
text_drs_eval(0, 3260, 'If it is false that there is something X1 and that X1 = X1 then it is false that there is something X2 and that X2 = X2.', drs([], [drs([], [-drs([A], [object(A, something, dom, na, na, na)-1, formula(A, =, A)-1])])=>drs([], [-drs([B], [object(B, something, dom, na, na, na)-1, formula(B, =, B)-1])])]), [[specification, [cond_s, if, [s, [neg, 'it is false'], [cp, that, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X1']]]]], [coord, and], [cp, that, [formula, [var, 'X1'], =, [var, 'X1']]]]]], then, [s, [neg, 'it is false'], [cp, that, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X2']]]]], [coord, and], [cp, that, [formula, [var, 'X2'], =, [var, 'X2']]]]]]], '.']], '2009-02-04-21-43-38', '130.60.155.177', '').
text_drs_eval(0, 3261, 'If it is false that X=X then X=X.', drs([], [drs([], [-drs([A], [object(A, something, dom, na, na, na)-1, formula(A, =, A)-1])])=>drs([B], [object(B, something, dom, na, na, na)-1, formula(B, =, B)-1])]), [[specification, [cond_s, if, [s, [neg, 'it is false'], [cp, that, [formula, [var, 'X'], =, [var, 'X']]]], then, [formula, [var, 'X'], =, [var, 'X']]], '.']], '2009-02-04-21-44-03', '130.60.155.177', '').
text_drs_eval(0, 3262, 'If John=X then it is false that John=X.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([B], [object(B, something, dom, na, na, na)-1, formula(A, =, B)-1])=>drs([], [-drs([], [formula(A, =, B)-1])])]), [[specification, [cond_s, if, [formula, [pname, 'John'], =, [var, 'X']], then, [s, [neg, 'it is false'], [cp, that, [formula, [pname, 'John'], =, [var, 'X']]]]], '.']], '2009-02-04-21-47-27', '130.60.155.177', '').
text_drs_eval(0, 3263, 'If John=John then it is false that John=John.', drs([A], [object(A, 'John', named, na, eq, 1)-1, drs([], [formula(A, =, A)-1])=>drs([], [-drs([], [formula(A, =, A)-1])])]), [[specification, [cond_s, if, [formula, [pname, 'John'], =, [pname, 'John']], then, [s, [neg, 'it is false'], [cp, that, [formula, [pname, 'John'], =, [pname, 'John']]]]], '.']], '2009-02-04-21-47-53', '130.60.155.177', '').
text_drs_eval(0, 3264, 'If John=John then John=John.', drs([], [drs([], [formula(named('John'), =, named('John'))-1/3])=>drs([], [formula(named('John'), =, named('John'))-1/7])]), [[sentence, [specification, [cond_s, if, [formula, [pname, 'John'], =, [pname, 'John']], then, [formula, [pname, 'John'], =, [pname, 'John']]], '.'], '.']], '2009-05-15-08-22-45', '130.60.155.193', '').
text_drs_eval(0, 3265, 'If John=John then John=Mary.', drs([], [drs([], [formula(named('John'), =, named('John'))-1/3])=>drs([], [formula(named('John'), =, named('Mary'))-1/7])]), [[specification, [cond_s, if, [formula, [pname, 'John'], =, [pname, 'John']], then, [formula, [pname, 'John'], =, [pname, 'Mary']]], '.']], '2009-06-03-01-18-32', '89.206.68.11', '').
text_drs_eval(0, 3266, 'If John=Mary then Mary=John.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-1, drs([], [formula(A, =, B)-1])=>drs([], [formula(B, =, A)-1])]), [[specification, [cond_s, if, [formula, [pname, 'John'], =, [pname, 'Mary']], then, [formula, [pname, 'Mary'], =, [pname, 'John']]], '.']], '2009-02-04-21-49-56', '130.60.155.177', '').
text_drs_eval(0, 3267, 'No man gives no woman no apple.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([B], [object(B, woman, countable, na, eq, 1)-1])=>drs([], [-drs([], [drs([C], [object(C, apple, countable, na, eq, 1)-1])=>drs([], [-drs([D], [predicate(D, give, A, C, B)-1])])])])])])]), [[specification, [s, [np, [det, no], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, gives], [np, [det, no], [nbar, [n, woman]]], [np, [det, no], [nbar, [n, apple]]]]]]], '.']], '2009-02-08-15-56-07', '130.60.155.177', '').
text_drs_eval(0, 3268, 'At least 2 men give at least 3 women at least 4 apples.', drs([A, B, C, D], [object(A, man, countable, na, geq, 2)-1, object(B, woman, countable, na, geq, 3)-1, object(C, apple, countable, na, geq, 4)-1, predicate(D, give, A, C, B)-1]), [[specification, [s, [np, [nump, [genqu, 'at least'], 2], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, give], [np, [nump, [genqu, 'at least'], 3], [nbar, [n, women]]], [np, [nump, [genqu, 'at least'], 4], [nbar, [n, apples]]]]]]], '.']], '2009-02-08-16-18-47', '130.60.155.177', '').
text_drs_eval(0, 3269, 'At most 2 men give at most 3 women at most 4 apples.', drs([A, B, C, D], [[[[predicate(D, give, A, C, B)-1, object(C, apple, countable, na, leq, 4)-1], object(B, woman, countable, na, leq, 3)-1], object(A, man, countable, na, leq, 2)-1]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, give], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, women]]], [np, [nump, [genqu, 'at most'], 4], [nbar, [n, apples]]]]]]], '.']], '2009-03-02-11-37-42', '130.60.155.206', '').
text_drs_eval(0, 3270, 'At most 2 men give themselves at most 4 apples.', drs([A, B, C], [[[predicate(C, give, A, B, A)-1, object(B, apple, countable, na, leq, 4)-1], object(A, man, countable, na, leq, 2)-1]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, give], [np, [pn, themselves]], [np, [nump, [genqu, 'at most'], 4], [nbar, [n, apples]]]]]]], '.']], '2009-03-02-11-37-50', '130.60.155.206', '').
text_drs_eval(0, 3271, 'At most 2 men give themselves themselves.', drs([A, B], [[predicate(B, give, A, A, A)-1, object(A, man, countable, na, leq, 2)-1]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, give], [np, [pn, themselves]], [np, [pn, themselves]]]]]], '.']], '2009-03-02-11-37-58', '130.60.155.206', '').
text_drs_eval(0, 3272, 'every man owns each of at most 5 cars that are expensive.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1])=>drs([B, C, D], [[drs([E], [has_part(B, E)-1])=>drs([F], [predicate(F, own, A, E)-1]), predicate(D, be, B, C)-1, property(C, expensive, pos)-1, object(B, car, countable, na, leq, 5)-1]])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, owns], [np, [quant, 'each of'], [np, [nump, [genqu, 'at most'], 5], [nbar, [n, cars], [rel_cl, [comp, that], [vp, [aux, are], [vbar, [vcompl, [ap_coord, [ap, [adj, expensive]]]]]]]]]]]]]], '.']], '2009-03-02-11-36-15', '130.60.155.206', '').
text_drs_eval(0, 3273, 'John has at most 3 cars. Mary loves them.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1, object(B, 'Mary', named, na, eq, 1)-2, [object(C, car, countable, na, leq, 3)-1, predicate(D, have, A, C)-1], predicate(E, love, B, C)-2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, cars]]]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, loves], [np, [pn, them]]]]]], '.']], '2009-03-02-11-42-44', '130.60.155.206', '').
text_drs_eval(0, 3274, 'John owns at most 3 cars that do not start.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1, [object(B, car, countable, na, leq, 3)-1, -drs([D], [predicate(D, start, B)-1]), predicate(C, own, A, B)-1]]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, owns], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, cars], [rel_cl, [comp, that], [vp, [aux, do, not], [vbar, [vbar, [v, start]]]]]]]]]]], '.']], '2009-03-11-22-02-58', '130.60.155.177', '').
text_drs_eval(0, 3275, 'John owns at most 3 cars that have at most 3 wheels.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1/1, [object(B, car, countable, na, leq, 3)-1/6, [object(C, wheel, countable, na, leq, 3)-1/12, predicate(D, have, B, C)-1/8], predicate(E, own, A, B)-1/2]]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, owns], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, cars], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, have], [np, [nump, [genqu, 'at most'], 3], [nbar, [n, wheels]]]]]]]]]]]]], '.']], '2009-03-13-15-55-30', '130.60.155.177', '').
text_drs_eval(0, 3276, 'John quickly knows that Mary sleeps.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/5, predicate(C, know, A, D)-1/3, modifier_adv(C, quickly, pos)-1/2, D:drs([E], [predicate(E, sleep, B)-1/6])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, quickly], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2009-04-02-15-22-54', '130.60.155.206', '').
text_drs_eval(0, 3277, 'John quickly knows that Mary quickly sleeps.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/5, predicate(C, know, A, D)-1/3, modifier_adv(C, quickly, pos)-1/2, D:drs([E], [predicate(E, sleep, B)-1/7, modifier_adv(E, quickly, pos)-1/6])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [adv, quickly], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vmod, [adv, quickly]], [vbar, [v, sleeps]]]]]]]]], '.']], '2009-04-02-15-23-20', '130.60.155.206', '').
text_drs_eval(0, 3278, 'John sees a girl in every park.', drs([A], [object(A, girl, countable, na, eq, 1)-1/4, drs([B], [object(B, park, countable, na, eq, 1)-1/7])=>drs([C], [predicate(C, see, named('John'), A)-1/2, modifier_pp(C, in, B)-1/5])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, girl]]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]]]]], '.']], '2009-06-22-15-17-41', '130.60.155.209', '').
text_drs_eval(0, 3279, 'John in every park sees a girl.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, drs([B], [object(B, park, countable, na, eq, 1)-1/4])=>drs([C, D], [object(C, girl, countable, na, eq, 1)-1/7, predicate(D, see, A, C)-1/5, modifier_pp(D, in, B)-1/2])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [vcompl, [v, sees], [np, [det, a], [nbar, [n, girl]]]]]]], '.']], '2009-04-02-15-27-28', '130.60.155.206', '').
text_drs_eval(0, 3280, 'John in every park sees a girl with every telescope.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([B], [object(B, girl, countable, na, eq, 1)-1/7, drs([C], [object(C, telescope, countable, na, eq, 1)-1/10])=>drs([D], [modifier_pp(D, in, A)-1/2, predicate(D, see, named('John'), B)-1/5, modifier_pp(D, with, C)-1/8])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [vcompl, [v, sees], [np, [det, a], [nbar, [n, girl]]]], [vmod, [pp, [prep, with], [np, [det, every], [nbar, [n, telescope]]]]]]]], '.']], '2009-06-22-15-18-16', '130.60.155.209', '').
text_drs_eval(0, 3281, 'John in a park sees that Mary sleeps.', drs([A, B, C, D, E], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/7, object(C, park, countable, na, eq, 1)-1/4, predicate(D, see, A, E)-1/5, modifier_pp(D, in, C)-1/2, E:drs([F], [predicate(F, sleep, B)-1/8])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2009-04-02-15-38-11', '130.60.155.206', '').
text_drs_eval(0, 3282, 'John in every park sees that Mary sleeps.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/7, drs([C], [object(C, park, countable, na, eq, 1)-1/4])=>drs([D, E], [predicate(D, see, A, E)-1/5, modifier_pp(D, in, C)-1/2, E:drs([F], [predicate(F, sleep, B)-1/8])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2009-04-02-15-42-51', '130.60.155.206', '').
text_drs_eval(0, 3283, 'John in no park sees that Mary sleeps.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/7, drs([C], [object(C, park, countable, na, eq, 1)-1/4])=>drs([], [-drs([D, E], [predicate(D, see, A, E)-1/5, modifier_pp(D, in, C)-1/2, E:drs([F], [predicate(F, sleep, B)-1/8])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, no], [nbar, [n, park]]]]], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2009-04-02-15-42-59', '130.60.155.206', '').
text_drs_eval(0, 3284, 'John in every park for no reason sees that Mary sleeps.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1/1, object(B, 'Mary', named, na, eq, 1)-1/10, drs([C], [object(C, park, countable, na, eq, 1)-1/4])=>drs([], [drs([D], [object(D, reason, countable, na, eq, 1)-1/7])=>drs([], [-drs([E, F], [predicate(E, see, A, F)-1/8, modifier_pp(E, for, D)-1/5, modifier_pp(E, in, C)-1/2, F:drs([G], [predicate(G, sleep, B)-1/11])])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], '.']], '2009-04-02-16-09-56', '130.60.155.206', '').
text_drs_eval(0, 3285, 'John in every park sees a girl with no telescope.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([B], [object(B, girl, countable, na, eq, 1)-1/7, drs([C], [object(C, telescope, countable, na, eq, 1)-1/10])=>drs([], [-drs([D], [modifier_pp(D, in, A)-1/2, predicate(D, see, named('John'), B)-1/5, modifier_pp(D, with, C)-1/8])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [vcompl, [v, sees], [np, [det, a], [nbar, [n, girl]]]], [vmod, [pp, [prep, with], [np, [det, no], [nbar, [n, telescope]]]]]]]], '.']], '2009-06-22-15-18-44', '130.60.155.209', '').
text_drs_eval(0, 3286, 'John in every park intentionally sees a girl manually with no telescope.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([B], [object(B, girl, countable, na, eq, 1)-1/8, drs([C], [object(C, telescope, countable, na, eq, 1)-1/12])=>drs([], [-drs([D], [modifier_adv(D, intentionally, pos)-1/5, modifier_pp(D, in, A)-1/2, predicate(D, see, named('John'), B)-1/6, modifier_pp(D, with, C)-1/10, modifier_adv(D, manually, pos)-1/9])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [adv, intentionally]], [vcompl, [v, sees], [np, [det, a], [nbar, [n, girl]]]], [vmod, [adv, manually], [pp, [prep, with], [np, [det, no], [nbar, [n, telescope]]]]]]]], '.']], '2009-06-22-15-19-33', '130.60.155.209', '').
text_drs_eval(0, 3287, 'John believes that a dog barks and it is false that a cat sleeps.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, predicate(B, believe, A, C)-1/2, C:drs([D, E], [object(D, dog, countable, na, eq, 1)-1/5, predicate(E, bark, D)-1/6]), -drs([F, G], [object(F, cat, countable, na, eq, 1)-1/13, predicate(G, sleep, F)-1/14])]), [[specification, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]], [coord, and], [s, [neg, 'it is false'], [cp, that, [s, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [vbar, [v, sleeps]]]]]]]], '.']], '2009-04-02-15-47-47', '130.60.155.206', '').
text_drs_eval(0, 3288, 'John sees soundly in a bed in a morning that a man sleeps.', drs([A, B, C, D, E, F], [object(A, 'John', named, na, eq, 1)-1/1, object(B, morning, countable, na, eq, 1)-1/9, object(C, man, countable, na, eq, 1)-1/12, predicate(D, sleep, C, B)-1/13, object(E, bed, countable, na, eq, 1)-1/6, predicate(F, see, A)-1/2, modifier_pp(F, in, B)-1/7, modifier_pp(F, in, E)-1/4, modifier_adv(F, soundly, pos)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, sees]], [vmod, [adv, soundly], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning], [rel_cl, [comp, that], [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, sleeps]]]]]]]]]]]], '.']], '2009-04-02-15-48-50', '130.60.155.206', '').
text_drs_eval(0, 3289, 'John in every morning wants to swim.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, drs([B], [object(B, morning, countable, na, eq, 1)-1/4])=>drs([C, D], [predicate(C, want, A, D)-1/5, modifier_pp(C, in, B)-1/2, D:drs([E], [predicate(E, swim, A)-1/7])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]], [v, wants], to, [vp, [vbar, [vbar, [v, swim]]]]]]], '.']], '2009-04-02-15-54-21', '130.60.155.206', '').
text_drs_eval(0, 3290, 'John in every morning wants to swim intentionally for no reason.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, drs([B], [object(B, morning, countable, na, eq, 1)-1/4])=>drs([C, D], [predicate(C, want, A, D)-1/5, modifier_pp(C, in, B)-1/2, D:drs([], [drs([E], [object(E, reason, countable, na, eq, 1)-1/11])=>drs([], [-drs([F], [predicate(F, swim, A)-1/7, modifier_pp(F, for, E)-1/9, modifier_adv(F, intentionally, pos)-1/8])])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]], [v, wants], to, [vp, [vbar, [vbar, [v, swim]], [vmod, [adv, intentionally], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]]]]]]], '.']], '2009-04-02-15-54-57', '130.60.155.206', '').
text_drs_eval(0, 3291, 'John in a bar wants to drink a beer.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, bar, countable, na, eq, 1)-1/4, predicate(C, want, A, D)-1/5, modifier_pp(C, in, B)-1/2, D:drs([E, F], [object(E, beer, countable, na, eq, 1)-1/9, predicate(F, drink, A, E)-1/7])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, bar]]]]], [v, wants], to, [vp, [vbar, [vcompl, [v, drink], [np, [det, a], [nbar, [n, beer]]]]]]]]], '.']], '2009-04-02-15-55-24', '130.60.155.206', '').
text_drs_eval(0, 3292, 'John wants to drink a beer in a bar.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, predicate(B, want, A, C)-1/2, C:drs([D, E, F], [object(D, bar, countable, na, eq, 1)-1/9, object(E, beer, countable, na, eq, 1)-1/6, predicate(F, drink, A, E)-1/4, modifier_pp(F, in, D)-1/7])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [v, wants], to, [vp, [vbar, [vcompl, [v, drink], [np, [det, a], [nbar, [n, beer]]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, bar]]]]]]]]]], '.']], '2009-04-02-15-55-35', '130.60.155.206', '').
text_drs_eval(0, 3293, 'John in the morning wants to swim in the evening.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, predicate(B, want, A, C)-1/5, modifier_pp(B, in, D)-1/2, C:drs([E, F], [predicate(E, swim, A)-1/7, modifier_pp(E, in, F)-1/8, object(F, evening, countable, na, eq, 1)-1/10]), object(D, morning, countable, na, eq, 1)-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]], [v, wants], to, [vp, [vbar, [vbar, [v, swim]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, evening]]]]]]]]]], '.']], '2009-04-02-15-55-54', '130.60.155.206', '').
text_drs_eval(0, 3294, 'Every man in the morning wants to in the evening say that he likes the day completely.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C, D], [predicate(B, want, A, C)-1/6, modifier_pp(B, in, D)-1/3, C:drs([E, F, G], [predicate(E, say, A, F)-1/11, modifier_pp(E, in, G)-1/8, F:drs([H, I], [predicate(H, like, A, I)-1/14, modifier_adv(H, completely, pos)-1/17, object(I, day, countable, na, eq, 1)-1/16]), object(G, evening, countable, na, eq, 1)-1/10]), object(D, morning, countable, na, eq, 1)-1/5])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]], [v, wants], to, [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, evening]]]]], [cp, that, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, day]]]], [vmod, [adv, completely]]]]]]]]]]], '.']], '2009-04-02-15-57-36', '130.60.155.206', '').
text_drs_eval(0, 3295, 'Every man for no reason in every location meets a woman between two houses after no search.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [drs([C], [object(C, location, countable, na, eq, 1)-1/8])=>drs([D, E], [object(D, woman, countable, na, eq, 1)-1/11, object(E, house, countable, na, eq, 2)-1/14, drs([F], [object(F, search, countable, na, eq, 1)-1/17])=>drs([], [-drs([G], [modifier_pp(G, in, C)-1/6, modifier_pp(G, for, B)-1/3, predicate(G, meet, A, D)-1/9, modifier_pp(G, after, F)-1/15, modifier_pp(G, between, E)-1/12])])])])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, location]]]]], [vcompl, [v, meets], [np, [det, a], [nbar, [n, woman]]]], [vmod, [pp, [prep, between], [np, [nump, two], [nbar, [n, houses]]]], [pp, [prep, after], [np, [det, no], [nbar, [n, search]]]]]]]], '.']], '2009-06-22-15-19-47', '130.60.155.209', '').
text_drs_eval(0, 3296, 'Every man for no reason at every time wants to swim.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [drs([C], [object(C, time, countable, na, eq, 1)-1/8])=>drs([D, E], [predicate(D, want, A, E)-1/9, modifier_pp(D, at, C)-1/6, modifier_pp(D, for, B)-1/3, E:drs([F], [predicate(F, swim, A)-1/11])])])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]], [pp, [prep, at], [np, [det, every], [nbar, [n, time]]]]], [v, wants], to, [vp, [vbar, [vbar, [v, swim]]]]]]], '.']], '2009-04-02-16-12-37', '130.60.155.206', '').
text_drs_eval(0, 3297, 'Every man for no reason at every time intentionally wants to swim in every lake.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [drs([C], [object(C, time, countable, na, eq, 1)-1/8])=>drs([D, E], [predicate(D, want, A, E)-1/10, modifier_adv(D, intentionally, pos)-1/9, modifier_pp(D, at, C)-1/6, modifier_pp(D, for, B)-1/3, E:drs([], [drs([F], [object(F, lake, countable, na, eq, 1)-1/15])=>drs([G], [predicate(G, swim, A)-1/12, modifier_pp(G, in, F)-1/13])])])])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]], [pp, [prep, at], [np, [det, every], [nbar, [n, time]]]], [adv, intentionally]], [v, wants], to, [vp, [vbar, [vbar, [v, swim]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, lake]]]]]]]]]], '.']], '2009-04-02-16-12-59', '130.60.155.206', '').
text_drs_eval(0, 3298, 'Every man for no reason at every time intentionally knows that no woman swims in every lake.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [drs([C], [object(C, time, countable, na, eq, 1)-1/8])=>drs([D, E], [predicate(D, know, A, E)-1/10, modifier_adv(D, intentionally, pos)-1/9, modifier_pp(D, at, C)-1/6, modifier_pp(D, for, B)-1/3, E:drs([], [drs([F], [object(F, woman, countable, na, eq, 1)-1/13])=>drs([], [-drs([], [drs([G], [object(G, lake, countable, na, eq, 1)-1/17])=>drs([H], [predicate(H, swim, F)-1/14, modifier_pp(H, in, G)-1/15])])])])])])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]], [pp, [prep, at], [np, [det, every], [nbar, [n, time]]]], [adv, intentionally]], [cp, that, [s, [np, [det, no], [nbar, [n, woman]]], [vp, [vbar, [vbar, [v, swims]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, lake]]]]]]]]]]]], '.']], '2009-04-02-16-13-38', '130.60.155.206', '').
text_drs_eval(0, 3299, 'Every man for no reason knows that every woman for no reason wants to for no reason swim in every lake.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/5])=>drs([], [-drs([C, D], [predicate(C, know, A, D)-1/6, modifier_pp(C, for, B)-1/3, D:drs([], [drs([E], [object(E, woman, countable, na, eq, 1)-1/9])=>drs([], [drs([F], [object(F, reason, countable, na, eq, 1)-1/12])=>drs([], [-drs([G, H], [predicate(G, want, E, H)-1/13, modifier_pp(G, for, F)-1/10, H:drs([], [drs([I], [object(I, reason, countable, na, eq, 1)-1/17])=>drs([], [-drs([], [drs([J], [object(J, lake, countable, na, eq, 1)-1/21])=>drs([K], [predicate(K, swim, E)-1/18, modifier_pp(K, for, I)-1/15, modifier_pp(K, in, J)-1/19])])])])])])])])])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [cp, that, [s, [np, [det, every], [nbar, [n, woman]]], [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [v, wants], to, [vp, [vbar, [vmod, [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [vbar, [v, swim]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, lake]]]]]]]]]]]]]], '.']], '2009-04-02-16-14-32', '130.60.155.206', '').
text_drs_eval(0, 3300, 'John sees a girl in every park with no telescope.', drs([A], [object(A, girl, countable, na, eq, 1)-1/4, drs([B], [object(B, park, countable, na, eq, 1)-1/7])=>drs([], [drs([C], [object(C, telescope, countable, na, eq, 1)-1/10])=>drs([], [-drs([D], [predicate(D, see, named('John'), A)-1/2, modifier_pp(D, with, C)-1/8, modifier_pp(D, in, B)-1/5])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, girl]]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [pp, [prep, with], [np, [det, no], [nbar, [n, telescope]]]]]]]], '.']], '2009-06-22-15-19-55', '130.60.155.209', '').
text_drs_eval(0, 3301, 'John is with no telescope in every park seen by a girl.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, drs([B], [object(B, telescope, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [drs([C], [object(C, park, countable, na, eq, 1)-1/8])=>drs([D, E], [object(D, girl, countable, na, eq, 1)-1/12, predicate(E, see, D, A)-1/9, modifier_pp(E, in, C)-1/6, modifier_pp(E, with, B)-1/3])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vmod, [pp, [prep, with], [np, [det, no], [nbar, [n, telescope]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [vcompl, [v, seen], by, [np, [det, a], [nbar, [n, girl]]]]]]], '.']], '2009-04-02-16-41-19', '130.60.155.177', '').
text_drs_eval(0, 3302, 'John is with no telescope fast and quickly in every park seen by a girl.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, drs([B], [object(B, telescope, countable, na, eq, 1)-1/5])=>drs([], [-drs([], [drs([C], [object(C, park, countable, na, eq, 1)-1/11])=>drs([D, E], [object(D, girl, countable, na, eq, 1)-1/15, predicate(E, see, D, A)-1/12, modifier_pp(E, in, C)-1/9, modifier_adv(E, quickly, pos)-1/8, modifier_adv(E, fast, pos)-1/6, modifier_pp(E, with, B)-1/3])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vmod, [pp, [prep, with], [np, [det, no], [nbar, [n, telescope]]]], [adv_coord, [adv, fast], [coord, and], [adv, quickly]], [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [vcompl, [v, seen], by, [np, [det, a], [nbar, [n, girl]]]]]]], '.']], '2009-04-02-16-42-07', '130.60.155.177', '').
text_drs_eval(0, 3303, 'John does not in a park sleep.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, -drs([B, C], [object(B, park, countable, na, eq, 1)-1/6, predicate(C, sleep, A)-1/7, modifier_pp(C, in, B)-1/4])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [vbar, [v, sleep]]]]], '.']], '2009-04-02-16-45-16', '130.60.155.206', '').
text_drs_eval(0, 3304, 'John does not intentionally in a park sleep in the night.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, -drs([B, C, D], [object(B, park, countable, na, eq, 1)-1/7, predicate(C, sleep, A)-1/8, modifier_pp(C, in, B)-1/5, modifier_adv(C, intentionally, pos)-1/4, modifier_pp(C, in, D)-1/9, object(D, night, countable, na, eq, 1)-1/11])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, not], [vbar, [vmod, [adv, intentionally], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [vbar, [v, sleep]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, night]]]]]]]], '.']], '2009-04-02-16-45-31', '130.60.155.206', '').
text_drs_eval(0, 3305, 'John can travel from Rome to Zurich.', drs([], [can(drs([A], [predicate(A, travel, named('John'))-1/3, modifier_pp(A, to, named('Zurich'))-1/6, modifier_pp(A, from, named('Rome'))-1/4]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can], [vbar, [vbar, [v, travel]], [vmod, [pp, [prep, from], [np, [pname, 'Rome']]], [pp, [prep, to], [np, [pname, 'Zurich']]]]]]], '.']], '2010-10-27-09-36-41', '89.206.64.27', '').
text_drs_eval(0, 3306, 'John can from Rome to Zurich travel.', drs([], [can(drs([A], [modifier_pp(A, to, named('Zurich'))-1/5, modifier_pp(A, from, named('Rome'))-1/3, predicate(A, travel, named('John'))-1/7]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, can], [vbar, [vmod, [pp, [prep, from], [np, [pname, 'Rome']]], [pp, [prep, to], [np, [pname, 'Zurich']]]], [vbar, [v, travel]]]]], '.']], '2010-10-27-09-36-51', '89.206.64.27', '').
text_drs_eval(0, 3307, 'John is in a park hit by a ball.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, park, countable, na, eq, 1)-1/5, object(C, ball, countable, na, eq, 1)-1/9, predicate(D, hit, C, A)-1/6, modifier_pp(D, in, B)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [vcompl, [v, hit], by, [np, [det, a], [nbar, [n, ball]]]]]]], '.']], '2009-04-02-16-46-32', '130.60.155.206', '').
text_drs_eval(0, 3308, 'A ball in a park hits John.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/7, object(B, ball, countable, na, eq, 1)-1/2, object(C, park, countable, na, eq, 1)-1/5, predicate(D, hit, B, A)-1/6, modifier_pp(D, in, C)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, ball]]], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [vcompl, [v, hits], [np, [pname, 'John']]]]]], '.']], '2009-04-02-16-46-44', '130.60.155.206', '').
text_drs_eval(0, 3309, 'A ball where hits John?', drs([], [question(drs([A, B], [object(A, ball, countable, na, eq, 1)-1/2, predicate(B, hit, A, named('John'))-1/4, query(B, where)-1/3]))]), [[sentence, [query, [question, [np, [det, a], [nbar, [n, ball]]], [vp, [vbar, [vmod, [qpn, where]], [vcompl, [v, hits], [np, [pname, 'John']]]]]], ?], '.']], '2009-05-13-13-41-29', '130.60.155.193', '').
text_drs_eval(0, 3310, 'Where does a ball in a park hit John?', drs([], [question(drs([A, B, C], [object(A, ball, countable, na, eq, 1)-1/4, object(B, park, countable, na, eq, 1)-1/7, predicate(C, hit, A, named('John'))-1/8, modifier_pp(C, in, B)-1/5, query(C, where)-1/1]))]), [[sentence, [query, [question, [qpn, where], does, [np, [det, a], [nbar, [n, ball]]], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [vcompl, [v, hit], [np, [pname, 'John']]]]]], ?], '.']], '2009-05-13-13-41-31', '130.60.155.193', '').
text_drs_eval(0, 3311, 'John does not provably mostly swim.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, ~drs([B], [predicate(B, swim, A)-1/6, modifier_adv(B, mostly, pos)-1/5])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'not provably'], [vbar, [vmod, [adv, mostly]], [vbar, [v, swim]]]]], '.']], '2009-04-02-16-48-40', '130.60.155.206', '').
text_drs_eval(0, 3312, 'John does not provably in a park talk-to a girl.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, ~drs([B, C, D], [object(B, park, countable, na, eq, 1)-1/7, object(C, girl, countable, na, eq, 1)-1/10, predicate(D, 'talk-to', A, C)-1/8, modifier_pp(D, in, B)-1/5])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, does, 'not provably'], [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]], [vcompl, [v, 'talk-to'], [np, [det, a], [nbar, [n, girl]]]]]]], '.']], '2009-04-02-16-49-08', '130.60.155.206', '').
text_drs_eval(0, 3313, 'John must manually hit a button.', drs([], [must(drs([A, B], [object(A, button, countable, na, eq, 1)-1/6, modifier_adv(B, manually, pos)-1/3, predicate(B, hit, named('John'), A)-1/4]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, must], [vbar, [vmod, [adv, manually]], [vcompl, [v, hit], [np, [det, a], [nbar, [n, button]]]]]]], '.']], '2010-10-27-09-36-56', '89.206.64.27', '').
text_drs_eval(0, 3314, 'John must manually hit every button in every case.', drs([], [must(drs([], [drs([A], [object(A, button, countable, na, eq, 1)-1/6])=>drs([], [drs([B], [object(B, case, countable, na, eq, 1)-1/9])=>drs([C], [modifier_adv(C, manually, pos)-1/3, predicate(C, hit, named('John'), A)-1/4, modifier_pp(C, in, B)-1/7])])]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, must], [vbar, [vmod, [adv, manually]], [vcompl, [v, hit], [np, [det, every], [nbar, [n, button]]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, case]]]]]]]], '.']], '2010-10-27-09-37-01', '89.206.64.27', '').
text_drs_eval(0, 3315, 'John must manually in every case for no reason hit every button.', drs([], [must(drs([], [drs([A], [object(A, case, countable, na, eq, 1)-1/6])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/9])=>drs([], [-drs([], [drs([C], [object(C, button, countable, na, eq, 1)-1/12])=>drs([D], [modifier_pp(D, for, B)-1/7, modifier_pp(D, in, A)-1/4, modifier_adv(D, manually, pos)-1/3, predicate(D, hit, named('John'), C)-1/10])])])])]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, must], [vbar, [vmod, [adv, manually], [pp, [prep, in], [np, [det, every], [nbar, [n, case]]]], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [vcompl, [v, hit], [np, [det, every], [nbar, [n, button]]]]]]], '.']], '2010-10-27-09-37-06', '89.206.64.27', '').
text_drs_eval(0, 3316, 'A man who in a park that in a city exists walks waits.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/6, object(C, city, countable, na, eq, 1)-1/10, predicate(D, exist, B)-1/11, modifier_pp(D, in, C)-1/8, predicate(E, walk, A)-1/12, modifier_pp(E, in, B)-1/4, predicate(F, wait, A)-1/13]), [[specification, [s, [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park], [rel_cl, [comp, that], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, city]]]]], [vbar, [v, exists]]]]]]]]], [vbar, [v, walks]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-04-02-16-50-49', '130.60.155.206', '').
text_drs_eval(0, 3317, 'Every man who in every park that in no city exists walks waits.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2, drs([B], [object(B, park, countable, na, eq, 1)-1/6, drs([C], [object(C, city, countable, na, eq, 1)-1/10])=>drs([], [-drs([D], [predicate(D, exist, B)-1/11, modifier_pp(D, in, C)-1/8])])])=>drs([E], [predicate(E, walk, A)-1/12, modifier_pp(E, in, B)-1/4])])=>drs([F], [predicate(F, wait, A)-1/13])]), [[specification, [s, [np, [det, every], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park], [rel_cl, [comp, that], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, no], [nbar, [n, city]]]]], [vbar, [v, exists]]]]]]]]], [vbar, [v, walks]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-04-02-16-51-34', '130.60.155.206', '').
text_drs_eval(1, 3318, 'If there is a dog X1 then the dog X1 is an animal or there is a man.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1/5])=>drs([], [drs([B, C], [object(B, animal, countable, na, eq, 1)-1/13, predicate(C, be, A, B)-1/11])v drs([D], [object(D, man, countable, na, eq, 1)-1/18])])]), [[specification, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [appos, [var, 'X1']]]]]], then, [s_coord, [s, [np, [det, the], [nbar, [n, dog], [appos, [var, 'X1']]]], [vp, [aux, is], [vbar, [vcompl, [np, [det, an], [nbar, [n, animal]]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]]]], '.']], '2009-04-04-20-39-07', '130.60.155.177', 'Wrong NP ACE paraphrase.').
text_drs_eval(0, 3319, '{ Christmases, the United-Nations } > 2.', drs([A, B], [object(A, 'Christmas', named, na, geq, 2)-1/2, object(B, 'United-Nations', named, na, geq, 2)-1/5, formula(set([A, B]), >, int(2))-1/7]), [[specification, [formula, [set, [pname, 'Christmases'], ',', [pname, theWordForm]], >, [int, 2]], '.']], '2009-04-08-15-13-01', '130.60.155.177', '').
text_drs_eval(0, 3320, 'Everybody sees the United-Nations that wait.', drs([A], [object(A, 'United-Nations', named, na, geq, 2)-1/5, drs([B], [object(B, somebody, countable, na, eq, 1)-1/2])=>drs([C, D], [predicate(C, see, B, A)-1/3, predicate(D, wait, A)-1/7])]), [[specification, [s, [np, [pn, everybody]], [vp, [vbar, [vcompl, [v, sees], [np, [pname, theWordForm], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, wait]]]]]]]]]], '.']], '2009-04-08-20-39-21', '130.60.155.177', '').
text_drs_eval(0, 3321, 'Everybody sees the United-Nations.', drs([A], [object(A, 'United-Nations', named, na, geq, 2)-1/5, drs([B], [object(B, somebody, countable, na, eq, 1)-1/2])=>drs([C], [predicate(C, see, B, A)-1/3])]), [[specification, [s, [np, [pn, everybody]], [vp, [vbar, [vcompl, [v, sees], [np, [pname, theWordForm]]]]]], '.']], '2009-04-08-20-39-33', '130.60.155.177', '').
text_drs_eval(0, 3322, 'Everybody sees Christmases that wait.', drs([A], [object(A, 'Christmas', named, na, geq, 2)-1/4, drs([B], [object(B, somebody, countable, na, eq, 1)-1/2])=>drs([C, D], [predicate(C, see, B, A)-1/3, predicate(D, wait, A)-1/6])]), [[specification, [s, [np, [pn, everybody]], [vp, [vbar, [vcompl, [v, sees], [np, [pname, 'Christmases'], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, wait]]]]]]]]]], '.']], '2009-04-08-20-39-53', '130.60.155.177', '').
text_drs_eval(0, 3323, 'Everybody sees Christmases.', drs([A], [object(A, 'Christmas', named, na, geq, 2)-1/4, drs([B], [object(B, somebody, countable, na, eq, 1)-1/2])=>drs([C], [predicate(C, see, B, A)-1/3])]), [[specification, [s, [np, [pn, everybody]], [vp, [vbar, [vcompl, [v, sees], [np, [pname, 'Christmases']]]]]], '.']], '2009-04-08-20-40-11', '130.60.155.177', '').
text_drs_eval(0, 3324, 'The United-Nations see the United-Nations.', drs([A, B], [object(A, 'United-Nations', named, na, geq, 2)-1/2, predicate(B, see, A, A)-1/3]), [[specification, [s, [np, [pname, theWordForm]], [vp, [vbar, [vcompl, [v, see], [np, [pname, theWordForm]]]]]], '.']], '2009-04-09-01-23-55', '89.206.64.20', '').
text_drs_eval(0, 3325, 'John sees the United-Nations and the United-Nations.', drs([], []), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np_coord, [np, [pname, theWordForm]], [coord, and], [np, [pname, theWordForm]]]]]]], '.']], '2009-04-10-17-13-24', '84.75.137.96', '').
text_drs_eval(0, 3326, '{ the United-Nations, the United-Nations} waits.', drs([A, B], [object(A, 'United-Nations', named, na, geq, 2)-1/3, predicate(B, wait, set([A, A]))-1/8]), [[specification, [s, [np, [set, [pname, theWordForm], ',', [pname, theWordForm]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-04-09-01-23-40', '89.206.64.20', '').
text_drs_eval(0, 3327, 'He sleeps.', drs([], []), [[specification, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.']], '2009-04-09-07-47-40', '89.206.64.27', '').
text_drs_eval(0, 3328, 'He sees himself.', drs([], []), [[specification, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, sees], [np, [pn, himself]]]]]], '.']], '2009-04-09-07-47-52', '89.206.64.27', '').
text_drs_eval(0, 3329, 'A woman sees himself.', drs([], []), [], '2009-04-09-07-48-05', '89.206.64.27', '').
text_drs_eval(0, 3330, 'A number X sees the number X.', drs([A, B], [object(A, number, countable, na, eq, 1)-1/2, predicate(B, see, A, A)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, number], [appos, [var, 'X']]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, number], [appos, [var, 'X']]]]]]]], '.']], '2009-04-09-07-48-13', '89.206.64.27', '').
text_drs_eval(0, 3331, 'A number X sees the man X.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, number], [appos, [var, 'X']]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, man], [appos, [var, 'X']]]]]]]], '.']], '2009-04-09-07-48-19', '89.206.64.27', '').
text_drs_eval(0, 3332, 'A number X sees a man X.', drs([], []), [[specification, [s, [np, [det, a], [nbar, [n, number], [appos, [var, 'X']]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]]]], '.']], '2009-04-09-07-48-30', '89.206.64.27', '').
text_drs_eval(0, 3333, 'The water flows.', drs([A, B], [predicate(A, flow, B)-1/3, object(B, water, countable, na, eq, 1)-1/2]), [[specification, [s, [np, [det, the], [nbar, [n, water]]], [vp, [vbar, [vbar, [v, flows]]]]], '.']], '2009-04-09-07-48-36', '89.206.64.27', '').
text_drs_eval(0, 3334, 'John patiently waits.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1/1, predicate(B, wait, A)-1/3, modifier_adv(B, patiently, pos)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, patiently]], [vbar, [v, waits]]]]], '.']], '2009-04-09-14-51-11', '84.74.163.25', '').
text_drs_eval(0, 3335, 'John waits patiently.', drs([A, B], [object(A, 'John', named, na, eq, 1)-1/1, predicate(B, wait, A)-1/2, modifier_adv(B, patiently, pos)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]], [vmod, [adv, patiently]]]]], '.']], '2009-04-09-14-51-49', '84.74.163.25', '').
text_drs_eval(0, 3336, 'John in a kitchen waits.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/4, predicate(C, wait, A)-1/5, modifier_pp(C, in, B)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]], [vbar, [v, waits]]]]], '.']], '2009-04-09-14-51-53', '84.74.163.25', '').
text_drs_eval(0, 3337, 'John waits in a kitchen.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/5, predicate(C, wait, A)-1/2, modifier_pp(C, in, B)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]]]]], '.']], '2009-04-09-14-52-07', '84.74.163.25', '').
text_drs_eval(0, 3338, 'John patiently waits in a kitchen.', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/6, predicate(C, wait, A)-1/3, modifier_adv(C, patiently, pos)-1/2, modifier_pp(C, in, B)-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, patiently]], [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]]]]], '.']], '2009-04-09-14-52-22', '84.74.163.25', '').
text_drs_eval(0, 3339, 'John patiently in a kitchen waits .', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/5, predicate(C, wait, A)-1/6, modifier_pp(C, in, B)-1/3, modifier_adv(C, patiently, pos)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, patiently], [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]], [vbar, [v, waits]]]]], '.']], '2009-04-09-14-52-41', '84.74.163.25', '').
text_drs_eval(0, 3340, 'John in a kitchen patiently waits .', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/4, predicate(C, wait, A)-1/6, modifier_adv(C, patiently, pos)-1/5, modifier_pp(C, in, B)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]], [adv, patiently]], [vbar, [v, waits]]]]], '.']], '2009-04-09-14-52-56', '84.74.163.25', '').
text_drs_eval(0, 3341, 'John waits in a kitchen patiently .', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/5, predicate(C, wait, A)-1/2, modifier_adv(C, patiently, pos)-1/6, modifier_pp(C, in, B)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]], [adv, patiently]]]]], '.']], '2009-04-09-14-53-12', '84.74.163.25', '').
text_drs_eval(0, 3342, 'John waits patiently in a kitchen .', drs([A, B, C], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/6, predicate(C, wait, A)-1/2, modifier_pp(C, in, B)-1/4, modifier_adv(C, patiently, pos)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]], [vmod, [adv, patiently], [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]]]]], '.']], '2009-04-09-14-53-24', '84.74.163.25', '').
text_drs_eval(0, 3343, 'John patiently in a kitchen wants to wait.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/5, predicate(C, want, A, D)-1/6, modifier_pp(C, in, B)-1/3, modifier_adv(C, patiently, pos)-1/2, D:drs([E], [predicate(E, wait, A)-1/8])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, patiently], [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]], [v, wants], to, [vp, [vbar, [vbar, [v, wait]]]]]]], '.']], '2009-04-09-14-54-34', '84.74.163.25', '').
text_drs_eval(0, 3344, 'John in a kitchen patiently wants to wait.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/4, predicate(C, want, A, D)-1/6, modifier_adv(C, patiently, pos)-1/5, modifier_pp(C, in, B)-1/2, D:drs([E], [predicate(E, wait, A)-1/8])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]], [adv, patiently]], [v, wants], to, [vp, [vbar, [vbar, [v, wait]]]]]]], '.']], '2009-04-09-14-56-16', '84.74.163.25', '').
text_drs_eval(0, 3345, 'John wants in a kitchen patiently to wait.', drs([], []), [], '2009-04-09-14-55-04', '84.74.163.25', '').
text_drs_eval(0, 3346, 'John wants patiently in a kitchen to wait.', drs([], []), [], '2009-04-09-14-55-23', '84.74.163.25', '').
text_drs_eval(0, 3347, 'John in a kitchen patiently wants that he waits.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/4, predicate(C, want, A, D)-1/6, modifier_adv(C, patiently, pos)-1/5, modifier_pp(C, in, B)-1/2, D:drs([E], [predicate(E, wait, A)-1/9])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]], [adv, patiently]], [cp, that, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, waits]]]]]]]]], '.']], '2009-04-09-14-56-43', '84.74.163.25', '').
text_drs_eval(0, 3348, 'John patiently in a kitchen wants that he waits.', drs([A, B, C, D], [object(A, 'John', named, na, eq, 1)-1/1, object(B, kitchen, countable, na, eq, 1)-1/5, predicate(C, want, A, D)-1/6, modifier_pp(C, in, B)-1/3, modifier_adv(C, patiently, pos)-1/2, D:drs([E], [predicate(E, wait, A)-1/9])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, patiently], [pp, [prep, in], [np, [det, a], [nbar, [n, kitchen]]]]], [cp, that, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, waits]]]]]]]]], '.']], '2009-04-09-14-57-06', '84.74.163.25', '').
text_drs_eval(0, 3349, 'John wants patiently in a kitchen that he waits.', drs([], []), [], '2009-04-09-14-57-23', '84.74.163.25', '').
text_drs_eval(0, 3350, 'John wants patiently that he waits.', drs([], []), [], '2009-04-09-14-57-32', '84.74.163.25', '').
text_drs_eval(0, 3351, 'There is a dog. A cat sees what?', drs([A], [object(A, dog, countable, na, eq, 1)-1/4, question(drs([B, C, D], [object(B, cat, countable, na, eq, 1)-2/2, query(C, what)-2/4, predicate(D, see, B, C)-2/3]))]), [[sentence, [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], '.'], '.'], [sentence, [query, [question, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [vcompl, [v, sees], [np, [qpn, what]]]]]], ?], '.']], '2009-05-13-13-41-32', '130.60.155.193', '').
text_drs_eval(0, 3352, 'There is a dog and a cat sees what?', drs([], []), [], '2009-11-18-08-49-26', '130.60.155.164', '').
text_drs_eval(0, 3353, 'Whose child is Mary and is nothing but Mary?', drs([], [question(drs([A, B, C], [query(A, what)-1/1, relation(B, of, A)-1/1, object(B, child, countable, na, eq, 1)-1/2, predicate(C, be, B, named('Mary'))-1/3, drs([D, E], [predicate(D, be, B, E)-1/6, object(E, something, dom, na, na, na)-1/8])=>drs([F], [predicate(F, be, E, named('Mary'))-1/''])]))]), [[sentence, [query, [question, [np, [qdet, whose], [nbar, [n, child]]], [vp_coord, [vp, [aux, is], [vbar, [vcompl, [np, [pname, 'Mary']]]]], [coord, and], [vp, [aux, is], [vbar, [vcompl, [np, [det, [np, [pn, nothing]], but], [pname, 'Mary']]]]]]], ?], '.']], '2009-05-13-13-41-33', '130.60.155.193', '').
text_drs_eval(0, 3354, 'Who sleeps? John waits.', drs([A], [question(drs([B, C], [query(B, who)-1/1, predicate(C, sleep, B)-1/2])), predicate(A, wait, named('John'))-2/2]), [[sentence, [query, [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, sleeps]]]]], ?], '.'], [sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], '.']], '2009-05-15-08-21-55', '130.60.155.193', '').
text_drs_eval(0, 3355, 'John may wait.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, may(drs([B], [predicate(B, wait, A)-1/3]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, may], [vbar, [vbar, [v, wait]]]]], '.']], '2009-05-11-09-30-21', '130.60.155.193', '').
text_drs_eval(0, 3356, 'John may not sleep.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, -drs([], [may(drs([B], [predicate(B, sleep, A)-1/4]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, may, not], [vbar, [vbar, [v, sleep]]]]], '.']], '2009-05-11-09-30-47', '130.60.155.193', '').
text_drs_eval(0, 3357, 'John may be rich.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, may(drs([B, C], [property(B, rich, pos)-1/4, predicate(C, be, A, B)-1/2]))]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, may, be], [vbar, [vcompl, [ap_coord, [ap, [adj, rich]]]]]]], '.']], '2009-05-11-09-31-25', '130.60.155.193', '').
text_drs_eval(0, 3358, 'John may not be important.', drs([A], [object(A, 'John', named, na, eq, 1)-1/1, -drs([], [may(drs([B, C], [property(B, important, pos)-1/5, predicate(C, be, A, B)-1/2]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, may, 'not be'], [vbar, [vcompl, [ap_coord, [ap, [adj, important]]]]]]], '.']], '2009-05-11-09-32-15', '130.60.155.193', '').
text_drs_eval(0, 3359, 'If a young child has a fever then the doctor may treat the child.', drs([], [drs([A, B, C], [object(A, child, countable, na, eq, 1)-1/4, property(A, young, pos)-1/3, object(B, fever, countable, na, eq, 1)-1/7, predicate(C, have, A, B)-1/5])=>drs([D], [may(drs([E], [predicate(E, treat, D, A)-1/12])), object(D, doctor, countable, na, eq, 1)-1/10])]), [[specification, [cond_s, if, [s, [np, [det, a], [nbar, [adj, young], [nbar, [n, child]]]], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, fever]]]]]]], then, [s, [np, [det, the], [nbar, [n, doctor]]], [vp, [aux, may], [vbar, [vcompl, [v, treat], [np, [det, the], [nbar, [n, child]]]]]]]], '.']], '2009-05-11-09-33-19', '130.60.155.193', '').
text_drs_eval(0, 3360, 'If Socrates is a man and every man is mortal then Socrates is mortal.', drs([A], [object(A, 'Socrates', named, na, eq, 1)-1/2, drs([B, C], [object(B, man, countable, na, eq, 1)-1/5, predicate(C, be, A, B)-1/3, drs([D], [object(D, man, countable, na, eq, 1)-1/8])=>drs([E, F], [property(E, mortal, pos)-1/10, predicate(F, be, D, E)-1/9])])=>drs([G, H], [property(G, mortal, pos)-1/14, predicate(H, be, A, G)-1/13])]), [[specification, [cond_s, if, [s_coord, [s, [np, [pname, 'Socrates']], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, man]]]]]]], [coord, and], [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, mortal]]]]]]]], then, [s, [np, [pname, 'Socrates']], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, mortal]]]]]]]], '.']], '2009-05-11-10-34-42', '130.60.155.193', '').
text_drs_eval(0, 3361, 'JJ1 waits. JJ2 waits. She sleeps. He eats.', drs([A, B, C, D], [predicate(A, wait, named('JJ1'))-1/2, predicate(B, wait, named('JJ2'))-2/2, predicate(C, sleep, named('JJ2'))-3/2, predicate(D, eat, named('JJ1'))-4/2]), [[specification, [s, [np, [pname, 'JJ1']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'JJ2']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, eats]]]]], '.']], '2011-07-21-00-03-35', '89.206.71.199', '').
text_drs_eval(0, 3362, 'If Iokaste makes Oedipus, and Iokaste makes Polyneikes, and Oedipus makes Polyneikes, and Polyneikes makes Thersandros and Oedipus is a patricide, and Thersandros is not a patricide then Iokaste makes a patricide that makes somebody who is not a patricide.', drs([A, B, C, D], [object(A, 'Iokaste', named, na, eq, 1)-1/2, object(B, 'Oedipus', named, na, eq, 1)-1/4, object(C, 'Polyneikes', named, na, eq, 1)-1/9, object(D, 'Thersandros', named, na, eq, 1)-1/19, drs([E, F, G, H, I, J], [predicate(E, make, A, B)-1/3, predicate(F, make, A, C)-1/8, predicate(G, make, B, C)-1/13, predicate(H, make, C, D)-1/18, object(I, patricide, countable, na, eq, 1)-1/24, predicate(J, be, B, I)-1/22, -drs([K, L], [object(K, patricide, countable, na, eq, 1)-1/31, predicate(L, be, D, K)-1/28])])=>drs([M, N, O, P], [object(M, patricide, countable, na, eq, 1)-1/36, object(N, somebody, countable, na, eq, 1)-1/40, -drs([Q, R], [object(Q, patricide, countable, na, eq, 1)-1/45, predicate(R, be, N, Q)-1/42]), predicate(O, make, M, N)-1/38, predicate(P, make, A, M)-1/34])]), [[specification, [cond_s, if, [s_coord, [s, [np, [pname, 'Iokaste']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Oedipus']]]]]], [coord, ', and'], [s, [np, [pname, 'Iokaste']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Polyneikes']]]]]], [coord, ', and'], [s, [np, [pname, 'Oedipus']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Polyneikes']]]]]], [coord, ', and'], [s_coord, [s, [np, [pname, 'Polyneikes']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Thersandros']]]]]], [coord, and], [s, [np, [pname, 'Oedipus']], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]]], [coord, ', and'], [s, [np, [pname, 'Thersandros']], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]]], then, [s, [np, [pname, 'Iokaste']], [vp, [vbar, [vcompl, [v, makes], [np, [det, a], [nbar, [n, patricide], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, makes], [np, [pn, somebody], [rel_cl, [np, [relpn, who]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]]]]]]]]]]]]]], '.']], '2009-05-11-12-41-18', '130.60.155.177', '').
text_drs_eval(0, 3363, 'If Iokaste makes Oedipus, and Iokaste makes Polyneikes, and Oedipus makes Polyneikes, and Polyneikes makes Thersandros and Oedipus is a patricide, and Thersandros is not a patricide, and everybody that makes a patricide that makes somebody who is not a patricide is an answer then Iokaste is an answer.', drs([A, B, C, D], [object(A, 'Iokaste', named, na, eq, 1)-1/2, object(B, 'Oedipus', named, na, eq, 1)-1/4, object(C, 'Polyneikes', named, na, eq, 1)-1/9, object(D, 'Thersandros', named, na, eq, 1)-1/19, drs([E, F, G, H, I, J], [predicate(E, make, A, B)-1/3, predicate(F, make, A, C)-1/8, predicate(G, make, B, C)-1/13, predicate(H, make, C, D)-1/18, object(I, patricide, countable, na, eq, 1)-1/24, predicate(J, be, B, I)-1/22, -drs([K, L], [object(K, patricide, countable, na, eq, 1)-1/31, predicate(L, be, D, K)-1/28]), drs([M, N, O, P, Q], [object(M, somebody, countable, na, eq, 1)-1/35, object(N, patricide, countable, na, eq, 1)-1/39, object(O, somebody, countable, na, eq, 1)-1/43, -drs([R, S], [object(R, patricide, countable, na, eq, 1)-1/48, predicate(S, be, O, R)-1/45]), predicate(P, make, N, O)-1/41, predicate(Q, make, M, N)-1/37])=>drs([T, U], [object(T, answer, countable, na, eq, 1)-1/51, predicate(U, be, M, T)-1/49])])=>drs([V, W], [object(V, answer, countable, na, eq, 1)-1/56, predicate(W, be, A, V)-1/54])]), [[specification, [cond_s, if, [s_coord, [s, [np, [pname, 'Iokaste']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Oedipus']]]]]], [coord, ', and'], [s, [np, [pname, 'Iokaste']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Polyneikes']]]]]], [coord, ', and'], [s, [np, [pname, 'Oedipus']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Polyneikes']]]]]], [coord, ', and'], [s_coord, [s, [np, [pname, 'Polyneikes']], [vp, [vbar, [vcompl, [v, makes], [np, [pname, 'Thersandros']]]]]], [coord, and], [s, [np, [pname, 'Oedipus']], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]]], [coord, ', and'], [s, [np, [pname, 'Thersandros']], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]], [coord, ', and'], [s, [np, [pn, everybody], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, makes], [np, [det, a], [nbar, [n, patricide], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, makes], [np, [pn, somebody], [rel_cl, [np, [relpn, who]], [vp, [aux, is, not], [vbar, [vcompl, [np, [det, a], [nbar, [n, patricide]]]]]]]]]]]]]]]]]]], [vp, [aux, is], [vbar, [vcompl, [np, [det, an], [nbar, [n, answer]]]]]]]], then, [s, [np, [pname, 'Iokaste']], [vp, [aux, is], [vbar, [vcompl, [np, [det, an], [nbar, [n, answer]]]]]]]], '.']], '2009-05-11-12-43-21', '130.60.155.177', '').
text_drs_eval(0, 3364, '"a" & "a" makes "aa".', drs([A], [predicate(A, make, expr(&, string(a), string(a)), string(aa))-1/4]), [[specification, [s, [np, [expr, [string, '"a"'], [string, '"a"']]], [vp, [vbar, [vcompl, [v, makes], [np, [string, '"aa"']]]]]], '.']], '2010-11-12-08-53-01', '89.206.69.32', '').
text_drs_eval(0, 3365, 'All men sleep. They are tired.', drs([], []), [[sentence, [specification, [s, [np, [det, all], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, sleep]]]]], '.'], '.'], [sentence, [specification, [s, [np, [pn, they]], [vp, [aux, are], [vbar, [vcompl, [ap_coord, [ap, [adj, tired]]]]]]], '.'], '.']], '2009-05-15-10-19-15', '80.219.71.81', '').
text_drs_eval(0, 3366, 'John, sell his own car!', drs([], []), [], '2009-05-15-08-49-57', '130.60.155.193', '').
text_drs_eval(0, 3367, 'John, buy a dog that likes him!', drs([], []), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, him]]]]]]]]]]]], !], '.']], '2009-05-15-08-50-17', '130.60.155.193', '').
text_drs_eval(0, 3368, 'John hits himself.', drs([A], [predicate(A, hit, named('John'), named('John'))-1/2]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, hits], [np, [pn, himself]]]]]], '.'], '.']], '2009-05-15-08-50-42', '130.60.155.193', '').
text_drs_eval(0, 3369, 'John hits yourself.', drs([], []), [], '2009-05-15-09-14-31', '130.60.155.193', '').
text_drs_eval(0, 3370, 'John and Mary, buy a dog!', drs([], [command(drs([A, B, C], [has_part(C, named('John'))-1/'', object(A, dog, countable, na, eq, 1)-1/7, predicate(B, buy, C, A)-1/5, has_part(C, named('Mary'))-1/'', object(C, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog]]]]]]], !], '.']], '2009-05-15-09-14-51', '130.60.155.193', '').
text_drs_eval(0, 3371, 'John and Mary, hit yourselves!', drs([], [command(drs([A, B], [has_part(B, named('John'))-1/'', predicate(A, hit, B, B)-1/5, has_part(B, named('Mary'))-1/'', object(B, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], ',', [vp, [vbar, [vcompl, [v, hit], [np, [pn, yourselves]]]]]], !], '.']], '2009-05-15-09-15-08', '130.60.155.193', '').
text_drs_eval(0, 3372, 'John and Mary, hit yourself!', drs([], []), [], '2009-05-15-09-15-16', '130.60.155.193', '').
text_drs_eval(0, 3373, 'John and Mary hit yourselves.', drs([], []), [], '2009-05-15-09-15-31', '130.60.155.193', '').
text_drs_eval(0, 3374, 'John and Mary hit themselves.', drs([A, B], [has_part(B, named('John'))-1/'', predicate(A, hit, B, B)-1/4, has_part(B, named('Mary'))-1/'', object(B, na, countable, na, eq, 2)-1/'']), [[sentence, [specification, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], [vp, [vbar, [vcompl, [v, hit], [np, [pn, themselves]]]]]], '.'], '.']], '2009-05-15-09-15-40', '130.60.155.193', '').
text_drs_eval(0, 3375, 'John sells his own car.', drs([A, B], [relation(A, of, named('John'))-1/3, object(A, car, countable, na, eq, 1)-1/5, predicate(B, sell, named('John'), A)-1/2]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sells], [np, [posspn, 'his own'], [nbar, [n, car]]]]]]], '.'], '.']], '2009-05-15-09-16-43', '130.60.155.193', '').
text_drs_eval(0, 3376, 'John sells your own car.', drs([], []), [], '2009-05-15-09-16-53', '130.60.155.193', '').
text_drs_eval(0, 3377, 'You, buy a car!', drs([], []), [[sentence, [command, [s, [np, [pn, you]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, car]]]]]]], !], '.']], '2009-05-15-09-17-11', '130.60.155.193', '').
text_drs_eval(0, 3378, 'John, you wait!', drs([], []), [], '2009-05-15-09-17-39', '130.60.155.193', '').
text_drs_eval(0, 3379, 'John and Mary, sell your own car!', drs([], [command(drs([A, B, C], [has_part(C, named('John'))-1/'', relation(A, of, C)-1/6, object(A, car, countable, na, eq, 1)-1/8, predicate(B, sell, C, A)-1/5, has_part(C, named('Mary'))-1/'', object(C, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], ',', [vp, [vbar, [vcompl, [v, sell], [np, [posspn, 'your own'], [nbar, [n, car]]]]]]], !], '.']], '2009-05-15-09-18-03', '130.60.155.193', '').
text_drs_eval(0, 3380, 'John and Mary, buy a dog that likes you!', drs([], [command(drs([A, B, C, D], [has_part(D, named('John'))-1/'', object(A, dog, countable, na, eq, 1)-1/7, predicate(B, like, A, D)-1/9, predicate(C, buy, D, A)-1/5, has_part(D, named('Mary'))-1/'', object(D, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]], !], '.']], '2009-05-15-09-18-20', '130.60.155.193', '').
text_drs_eval(0, 3381, 'John and Mary, buy a dog that is owned by Bill and that likes you!', drs([], [command(drs([A, B, C, D, E], [has_part(E, named('John'))-1/'', object(A, dog, countable, na, eq, 1)-1/7, predicate(B, own, named('Bill'), A)-1/10, predicate(C, like, A, E)-1/15, predicate(D, buy, E, A)-1/5, has_part(E, named('Mary'))-1/'', object(E, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pname, 'Mary']]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]]], !], '.']], '2009-05-15-09-18-37', '130.60.155.193', '').
text_drs_eval(0, 3382, 'A man, hit himself!', drs([], []), [], '2009-05-15-09-18-51', '130.60.155.193', '').
text_drs_eval(0, 3383, 'A man, hit yourself!', drs([], [command(drs([A, B], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, hit, A, A)-1/4]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, hit], [np, [pn, yourself]]]]]], !], '.']], '2009-05-15-09-18-56', '130.60.155.193', '').
text_drs_eval(0, 3384, 'A man, hit yourselves!', drs([], []), [], '2009-05-15-09-19-02', '130.60.155.193', '').
text_drs_eval(0, 3385, 'A man, sell your own car!', drs([], [command(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, relation(B, of, A)-1/5, object(B, car, countable, na, eq, 1)-1/7, predicate(C, sell, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, sell], [np, [posspn, 'your own'], [nbar, [n, car]]]]]]], !], '.']], '2009-05-15-09-19-16', '130.60.155.193', '').
text_drs_eval(0, 3386, 'A man, sell his own car!', drs([], []), [], '2009-05-15-09-19-21', '130.60.155.193', '').
text_drs_eval(0, 3387, 'A man, buy a dog that likes you!', drs([], [command(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, dog, countable, na, eq, 1)-1/6, predicate(C, like, B, A)-1/8, predicate(D, buy, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]], !], '.']], '2009-05-15-09-19-33', '130.60.155.193', '').
text_drs_eval(0, 3388, 'A man, buy a dog that likes him!', drs([], []), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, him]]]]]]]]]]]], !], '.']], '2009-05-15-09-19-38', '130.60.155.193', '').
text_drs_eval(0, 3389, 'A man, buy a dog that is owned by Bill and that likes him!', drs([], [command(drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/2, object(B, dog, countable, na, eq, 1)-1/6, predicate(C, own, named('Bill'), B)-1/9, predicate(D, like, B, named('Bill'))-1/14, predicate(E, buy, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, him]]]]]]]]]]]]], !], '.']], '2009-05-15-09-19-51', '130.60.155.193', '').
text_drs_eval(0, 3390, 'A man, buy a dog that is owned by Bill and that likes you!', drs([], [command(drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/2, object(B, dog, countable, na, eq, 1)-1/6, predicate(C, own, named('Bill'), B)-1/9, predicate(D, like, B, A)-1/14, predicate(E, buy, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, a], [nbar, [n, man]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]]], !], '.']], '2009-05-15-09-20-03', '130.60.155.193', '').
text_drs_eval(0, 3391, 'Some men, buy a dog that is owned by Bill and that likes you!', drs([], [command(drs([A, B, C, D, E], [object(A, man, countable, na, geq, 2)-1/2, object(B, dog, countable, na, eq, 1)-1/6, predicate(C, own, named('Bill'), B)-1/9, predicate(D, like, B, A)-1/14, predicate(E, buy, A, B)-1/4]))]), [[sentence, [command, [s, [np, [det, some], [nbar, [n, men]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]]], !], '.']], '2009-05-15-09-20-12', '130.60.155.193', '').
text_drs_eval(0, 3392, 'At least 5 men, buy a dog that is owned by Bill and that likes you!', drs([], [command(drs([A, B, C, D, E], [object(A, man, countable, na, geq, 5)-1/4, object(B, dog, countable, na, eq, 1)-1/8, predicate(C, own, named('Bill'), B)-1/11, predicate(D, like, B, A)-1/16, predicate(E, buy, A, B)-1/6]))]), [[sentence, [command, [s, [np, [nump, [genqu, 'at least'], 5], [nbar, [n, men]]], ',', [vp, [vbar, [vcompl, [v, buy], [np, [det, a], [nbar, [n, dog], [rel_cl_coord, [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, owned], by, [np, [pname, 'Bill']]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, you]]]]]]]]]]]]], !], '.']], '2009-05-15-09-20-21', '130.60.155.193', '').
text_drs_eval(0, 3393, 'John and you, wait!', drs([], []), [[sentence, [command, [s, [np_coord, [np, [pname, 'John']], [coord, and], [np, [pn, you]]], ',', [vp, [vbar, [vbar, [v, wait]]]]], !], '.']], '2009-05-15-09-20-38', '130.60.155.193', '').
text_drs_eval(0, 3394, 'John, trust a woman and yourself!', drs([], [command(drs([A, B, C], [object(A, woman, countable, na, eq, 1)-1/5, has_part(C, A)-1/'', predicate(B, trust, named('John'), C)-1/3, has_part(C, named('John'))-1/'', object(C, na, countable, na, eq, 2)-1/'']))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, trust], [np_coord, [np, [det, a], [nbar, [n, woman]]], [coord, and], [np, [pn, yourself]]]]]]], !], '.']], '2009-05-15-09-22-58', '130.60.155.193', '').
text_drs_eval(0, 3395, 'All men see a dog that likes them.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C, D], [object(B, dog, countable, na, eq, 1)-1/5, predicate(C, like, B, A)-1/7, predicate(D, see, A, B)-1/3])]), [[sentence, [specification, [s, [np, [det, all], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [pn, them]]]]]]]]]]]], '.'], '.']], '2009-05-15-10-18-50', '80.219.71.81', '').
text_drs_eval(0, 3396, 'All men see their own dog.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C], [relation(B, of, A)-1/4, object(B, dog, countable, na, eq, 1)-1/6, predicate(C, see, A, B)-1/3])]), [[sentence, [specification, [s, [np, [det, all], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, see], [np, [posspn, 'their own'], [nbar, [n, dog]]]]]]], '.'], '.']], '2009-05-15-10-18-57', '80.219.71.81', '').
text_drs_eval(0, 3397, 'All men sleep and he is tired.', drs([], []), [[sentence, [specification, [s_coord, [s, [np, [det, all], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, sleep]]]]], [coord, and], [s, [np, [pn, he]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, tired]]]]]]]], '.'], '.']], '2009-05-15-10-19-03', '80.219.71.81', '').
text_drs_eval(0, 3398, 'All men sleep and they are tired.', drs([], []), [[sentence, [specification, [s_coord, [s, [np, [det, all], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, sleep]]]]], [coord, and], [s, [np, [pn, they]], [vp, [aux, are], [vbar, [vcompl, [ap_coord, [ap, [adj, tired]]]]]]]], '.'], '.']], '2009-05-15-10-19-10', '80.219.71.81', '').
text_drs_eval(0, 3399, 'All men sleep.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, sleep, A)-1/3])]), [[sentence, [specification, [s, [np, [det, all], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, sleep]]]]], '.'], '.']], '2009-05-15-10-19-20', '80.219.71.81', '').
text_drs_eval(0, 3400, 'Christmases, help yourselves!', drs([], [command(drs([A], [predicate(A, help, named('Christmas'), named('Christmas'))-1/3]))]), [[sentence, [command, [s, [np, [pname, 'Christmases']], ',', [vp, [vbar, [vcompl, [v, help], [np, [pn, yourselves]]]]]], !], '.']], '2009-05-15-10-19-33', '80.219.71.81', '').
text_drs_eval(0, 3401, 'John, see yourself!', drs([], [command(drs([A], [predicate(A, see, named('John'), named('John'))-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, see], [np, [pn, yourself]]]]]], !], '.']], '2009-05-15-10-19-43', '80.219.71.81', '').
text_drs_eval(0, 3402, 'John, enter your own card!', drs([], [command(drs([A, B], [relation(A, of, named('John'))-1/4, object(A, card, countable, na, eq, 1)-1/6, predicate(B, enter, named('John'), A)-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, enter], [np, [posspn, 'your own'], [nbar, [n, card]]]]]]], !], '.']], '2009-05-15-10-19-46', '80.219.71.81', '').
text_drs_eval(0, 3403, 'John, enter your own card and see yourself!', drs([], []), [], '2009-05-15-10-20-04', '80.219.71.81', '').
text_drs_eval(0, 3404, 'Every man likes who?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C], [query(B, who)-1/4, predicate(C, like, A, B)-1/3])]))]), [[sentence, [query, [question, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, likes], [np, [qpn, who]]]]]], ?], '.']], '2009-05-15-13-44-52', '130.60.155.177', '').
text_drs_eval(0, 3405, 'Which man likes who?', drs([], [question(drs([A, B, C], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, query(B, who)-1/4, predicate(C, like, A, B)-1/3]))]), [[sentence, [query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, likes], [np, [qpn, who]]]]]], ?], '.']], '2009-05-15-13-45-07', '130.60.155.177', '').
text_drs_eval(0, 3406, 'Is it true that a man does not eat or that the man does not drink?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/6, -drs([B], [predicate(B, eat, A)-1/9])])v drs([], [-drs([C], [predicate(C, drink, A)-1/16])])]))]), [[sentence, [query, [question, [truth, 'is it true'], [s_coord, [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [vbar, [v, eat]]]]]], [coord, or], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [aux, does, not], [vbar, [vbar, [v, drink]]]]]]]], ?], '.']], '2009-05-15-13-46-58', '130.60.155.177', '').
text_drs_eval(0, 3407, 'Is it true that it is false that if there is a man X1 then the man X1 is a human?', drs([], [question(drs([], [-drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/13])=>drs([B, C], [object(B, human, countable, na, eq, 1)-1/21, predicate(C, be, A, B)-1/19])])]))]), [[sentence, [query, [question, [truth, 'is it true'], [cp, that, [s, [neg, 'it is false'], [cp, that, [cond_s, if, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X1']]]]]], then, [s, [np, [det, the], [nbar, [n, man], [appos, [var, 'X1']]]], [vp, [aux, is], [vbar, [vcompl, [np, [det, a], [nbar, [n, human]]]]]]]]]]]], ?], '.']], '2009-05-15-13-48-28', '130.60.155.177', '').
text_drs_eval(0, 3408, 'John in the morning is rich.', drs([A, B, C], [property(A, rich, pos)-1/6, predicate(B, be, named('John'), A)-1/5, modifier_pp(B, in, C)-1/2, object(C, morning, countable, na, eq, 1)-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]], [aux, is], [ap_coord, [ap, [adj, rich]]]]], '.']], '2009-05-21-10-40-54', '89.206.64.31', '').
text_drs_eval(0, 3409, 'A one-armed bandit has an hour.', drs([A, B, C], [object(A, bandit, countable, na, eq, 1)-1/3, property(A, 'one-armed', pos)-1/2, object(B, hour, countable, na, eq, 1)-1/6, predicate(C, have, A, B)-1/4]), [[sentence, [specification, [s, [np, [det, a], [nbar, [adj, 'one-armed'], [nbar, [n, bandit]]]], [vp, [vbar, [vcompl, [v, has], [np, [det, an], [nbar, [n, hour]]]]]]], '.'], '.']], '2009-05-16-18-14-13', '130.60.155.177', '').
text_drs_eval(0, 3410, 'John waits usually.', drs([A], [predicate(A, wait, named('John'))-1/2, modifier_adv(A, usually, pos)-1/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]], [vmod, [adv, usually]]]]], '.']], '2009-05-18-10-15-36', '130.60.155.177', '').
text_drs_eval(0, 3411, 'John is rich in the morning.', drs([A, B, C], [property(A, rich, pos)-1/3, predicate(B, be, named('John'), A)-1/2, modifier_pp(B, in, C)-1/4, object(C, morning, countable, na, eq, 1)-1/6]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, rich]]]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]]]]], '.'], '.']], '2009-05-17-11-38-06', '80.219.71.81', '').
text_drs_eval(0, 3412, 'Not every card is correct.', drs([], [-drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1/3])=>drs([B, C], [property(B, correct, pos)-1/5, predicate(C, be, A, B)-1/4])])]), [[sentence, [specification, [s, [np, [det, 'not every'], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, correct]]]]]]], '.'], '.']], '2009-05-17-11-38-48', '80.219.71.81', '').
text_drs_eval(0, 3413, 'No card is correct.', drs([], [drs([A], [object(A, card, countable, na, eq, 1)-1/2])=>drs([], [-drs([B, C], [property(B, correct, pos)-1/4, predicate(C, be, A, B)-1/3])])]), [[sentence, [specification, [s, [np, [det, no], [nbar, [n, card]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, correct]]]]]]], '.'], '.']], '2009-05-17-11-38-50', '80.219.71.81', '').
text_drs_eval(0, 3414, 'the United-Nations wait.', drs([A], [predicate(A, wait, named('United-Nations'))-1/3]), [[sentence, [specification, [s, [np, [pname, theWordForm]], [vp, [vbar, [vbar, [v, wait]]]]], '.'], '.']], '2009-05-17-11-38-53', '80.219.71.81', '').
text_drs_eval(0, 3415, 'No one sleeps.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/2])=>drs([], [-drs([B], [predicate(B, sleep, A)-1/3])])]), [[sentence, [specification, [s, [np, [pn, noone]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.'], '.']], '2009-05-17-11-38-56', '80.219.71.81', '').
text_drs_eval(0, 3416, 'John has not at least 2 cards.', drs([], []), [], '2009-05-17-11-39-02', '80.219.71.81', '').
text_drs_eval(0, 3417, 'John has at least 2 cards.', drs([A, B], [object(A, card, countable, na, geq, 2)-1/6, predicate(B, have, named('John'), A)-1/2]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [nump, [genqu, 'at least'], 2], [nbar, [n, cards]]]]]]], '.'], '.']], '2009-05-17-11-39-06', '80.219.71.81', '').
text_drs_eval(0, 3418, 'John has not more than 3 cards.', drs([], []), [], '2009-05-17-11-39-10', '80.219.71.81', '').
text_drs_eval(0, 3419, 'John has not exactly 3 cards.', drs([], []), [], '2009-05-17-11-39-13', '80.219.71.81', '').
text_drs_eval(0, 3420, 'John has each of less than 3 cards.', drs([A], [[object(A, card, countable, na, less, 3)-1/8, drs([B], [has_part(A, B)-1/3])=>drs([C], [predicate(C, have, named('John'), B)-1/2])]]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [quant, 'each of'], [np, [nump, [genqu, 'less than'], 3], [nbar, [n, cards]]]]]]]], '.'], '.']], '2009-05-17-11-39-17', '80.219.71.81', '').
text_drs_eval(0, 3421, 'John has each of exactly 3 cards.', drs([A], [[object(A, card, countable, na, exactly, 3)-1/7, drs([B], [has_part(A, B)-1/3])=>drs([C], [predicate(C, have, named('John'), B)-1/2])]]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [quant, 'each of'], [np, [nump, [genqu, exactly], 3], [nbar, [n, cards]]]]]]]], '.'], '.']], '2009-05-17-11-39-20', '80.219.71.81', '').
text_drs_eval(0, 3422, '3 kg of apples are heavy.', drs([A, B, C], [object(A, apple, countable, kg, eq, 3)-1/4, property(B, heavy, pos)-1/6, predicate(C, be, A, B)-1/5]), [[sentence, [specification, [s, [np, [meas_spec, [nump, 3], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, apples]]], [vp, [aux, are], [vbar, [vcompl, [ap_coord, [ap, [adj, heavy]]]]]]], '.'], '.']], '2009-05-17-11-39-23', '80.219.71.81', '').
text_drs_eval(0, 3423, '3 kg of apples is heavy.', drs([A, B, C], [object(A, apple, countable, kg, eq, 3)-1/4, property(B, heavy, pos)-1/6, predicate(C, be, A, B)-1/5]), [[sentence, [specification, [s, [np, [meas_spec, [nump, 3], [meas_nbar, [meas_n, kg], [pp, [prep, of]]]], [nbar, [n, apples]]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, heavy]]]]]]], '.'], '.']], '2009-05-17-11-39-25', '80.219.71.81', '').
text_drs_eval(0, 3424, 'X weighs 300 kg. X is heavy.', drs([A, B, C, D], [object(A, something, dom, na, na, na)-1/1, predicate(B, weigh, A, int(300, kg))-1/2, property(C, heavy, pos)-2/3, predicate(D, be, A, C)-2/2]), [[specification, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, weighs], [np, [meas_num, [int, 300], [meas_n, kg]]]]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [ap_coord, [ap, [adj, heavy]]]]], '.']], '2009-05-26-07-59-05', '130.60.155.193', '').
text_drs_eval(0, 3425, 'John should not work.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([], [should(drs([B], [predicate(B, work, A)-1]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should, not], [vbar, [v, work]]]], '.']], '2009-05-17-11-39-47', '80.219.71.81', '').
text_drs_eval(0, 3426, 'John shouldn\'t work.', drs([A], [object(A, 'John', named, na, eq, 1)-1, -drs([], [should(drs([B], [predicate(B, work, A)-1]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, should, not], [vbar, [v, work]]]], '.']], '2009-05-17-11-39-55', '80.219.71.81', '').
text_drs_eval(0, 3427, 'John may not work.', drs([], [-drs([], [may(drs([A], [predicate(A, work, named('John'))-1/4]))])]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [aux, may, not], [vbar, [vbar, [v, work]]]]], '.'], '.']], '2009-05-17-11-40-04', '80.219.71.81', '').
text_drs_eval(0, 3428, 'John rarely sleeps.', drs([A], [predicate(A, sleep, named('John'))-1/3, modifier_adv(A, rarely, pos)-1/2]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, rarely]], [vbar, [v, sleeps]]]]], '.'], '.']], '2009-05-17-11-40-14', '80.219.71.81', '').
text_drs_eval(0, 3429, 'John never sleeps.', drs([A], [predicate(A, sleep, named('John'))-1/3, modifier_adv(A, never, pos)-1/2]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, never]], [vbar, [v, sleeps]]]]], '.'], '.']], '2009-05-17-11-40-19', '80.219.71.81', '').
text_drs_eval(0, 3430, 'John mostly sleeps.', drs([A], [predicate(A, sleep, named('John'))-1/3, modifier_adv(A, mostly, pos)-1/2]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv, mostly]], [vbar, [v, sleeps]]]]], '.'], '.']], '2009-05-17-11-40-22', '80.219.71.81', '').
text_drs_eval(0, 3431, 'It is false that John sleeps.', drs([], [-drs([A], [predicate(A, sleep, named('John'))-1/6])]), [[sentence, [specification, [s, [neg, 'it is false'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, sleeps]]]]]]], '.'], '.']], '2009-05-17-11-40-35', '80.219.71.81', '').
text_drs_eval(0, 3432, 'It is not true that John sleeps.', drs([], [-drs([A], [predicate(A, sleep, named('John'))-1/7])]), [[sentence, [specification, [s, [neg, 'it is not true'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, sleeps]]]]]]], '.'], '.']], '2009-05-17-11-40-39', '80.219.71.81', '').
text_drs_eval(0, 3433, 'It is true that John sleeps.', drs([A], [predicate(A, sleep, named('John'))-1/6]), [[sentence, [specification, [s, [truth, 'it is true'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, sleeps]]]]]]], '.'], '.']], '2009-05-17-11-40-42', '80.219.71.81', '').
text_drs_eval(0, 3434, 'It is possible that John waits. It is not necessary that John enters a card and that he types a code. It is recommended that the surgeon operates the patient. It is not admissible that the patient takes his/her own medicine.', drs([], [can(drs([A], [predicate(A, wait, named('John'))-1/6])), -drs([], [must(drs([B, C, D, E], [object(B, card, countable, na, eq, 1)-2/9, predicate(C, enter, named('John'), B)-2/7, object(D, code, countable, na, eq, 1)-2/15, predicate(E, type, named('John'), D)-2/13]))]), should(drs([F, G, H], [object(H, surgeon, countable, na, eq, 1)-3/6, object(G, patient, countable, na, eq, 1)-3/9, predicate(F, operate, H, G)-3/7])), -drs([], [may(drs([I, J, K], [object(K, patient, countable, na, eq, 1)-4/7, relation(I, of, K)-4/9, object(I, medicine, countable, na, eq, 1)-4/13, predicate(J, take, K, I)-4/8]))])]), [[specification, [s, [poss, 'it is possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.'], [specification, [s, [unnecessity, 'it is not necessary'], [cp, that, [s_coord, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]]]]], [coord, and], [cp, that, [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, types], [np, [det, a], [nbar, [n, code]]]]]]]]]]], '.'], [specification, [s, [recommendation, 'it is recommended'], [cp, that, [s, [np, [det, the], [nbar, [n, surgeon]]], [vp, [vbar, [vcompl, [v, operates], [np, [det, the], [nbar, [n, patient]]]]]]]]], '.'], [specification, [s, [admissibility, 'it is not admissible'], [cp, that, [s, [np, [det, the], [nbar, [n, patient]]], [vp, [vbar, [vcompl, [v, takes], [np, [posspn, 'his/her own'], [nbar, [n, medicine]]]]]]]]], '.']], '2010-10-27-09-37-15', '89.206.64.27', '').
text_drs_eval(0, 3435, 'John eats. It is necessary that John waits.', drs([A], [predicate(A, eat, named('John'))-1/2, must(drs([B], [predicate(B, wait, named('John'))-2/6]))]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]], '.'], [specification, [s, [necessity, 'it is necessary'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-37-23', '89.206.64.27', '').
text_drs_eval(0, 3436, 'John eats. It is false that John waits.', drs([A], [predicate(A, eat, named('John'))-1/2, -drs([B], [predicate(B, wait, named('John'))-2/6])]), [[sentence, [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]], '.'], '.'], [sentence, [specification, [s, [neg, 'it is false'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.'], '.']], '2009-05-17-20-18-28', '130.60.155.177', '').
text_drs_eval(0, 3437, 'John eats. It is not possible that John waits.', drs([A], [predicate(A, eat, named('John'))-1/2, -drs([], [can(drs([B], [predicate(B, wait, named('John'))-2/7]))])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]], '.'], [specification, [s, [impossibility, 'it is not possible'], [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]]]], '.']], '2010-10-27-09-37-29', '89.206.64.27', '').
text_drs_eval(0, 3438, 'John, wait yourself!', drs([], [command(drs([A], [predicate(A, wait, named('John'), named('John'))-1/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, wait], [np, [pn, yourself]]]]]], !], '.']], '2009-05-17-20-29-47', '130.60.155.177', '').
text_drs_eval(0, 3439, 'John, wait Mary! Does John wait Mary?', drs([], [command(drs([A], [predicate(A, wait, named('John'), named('Mary'))-1/3])), question(drs([B], [predicate(B, wait, named('John'), named('Mary'))-2/3]))]), [[sentence, [command, [s, [np, [pname, 'John']], ',', [vp, [vbar, [vcompl, [v, wait], [np, [pname, 'Mary']]]]]], !], '.'], [sentence, [query, [question, does, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, wait], [np, [pname, 'Mary']]]]]], ?], '.']], '2009-05-17-20-30-21', '130.60.155.177', '').
text_drs_eval(0, 3440, 'John is in every park.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/5])=>drs([B], [predicate(B, be, named('John'))-1/2, modifier_pp(B, in, A)-1/3])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]]]]], '.']], '2009-05-18-11-22-57', '130.60.155.193', '').
text_drs_eval(0, 3441, 'John is in every park in every morning.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/5])=>drs([], [drs([B], [object(B, morning, countable, na, eq, 1)-1/8])=>drs([C], [predicate(C, be, named('John'))-1/2, modifier_pp(C, in, B)-1/6, modifier_pp(C, in, A)-1/3])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]]], '.']], '2009-05-21-10-52-38', '84.74.95.228', '').
text_drs_eval(0, 3442, 'John is in no park.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/5])=>drs([], [-drs([B], [predicate(B, be, named('John'))-1/2, modifier_pp(B, in, A)-1/3])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [vbar, [vcompl, [pp, [prep, in], [np, [det, no], [nbar, [n, park]]]]]]]], '.']], '2009-05-18-11-25-46', '130.60.155.193', '').
text_drs_eval(0, 3443, 'XJohn waits. It is happy.', drs([A, B, C], [predicate(A, wait, named('XJohn'))-1/2, property(B, happy, pos)-2/3, predicate(C, be, named('XJohn'), B)-2/2]), [[specification, [s, [np, [pname, 'XJohn']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pn, it]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, happy]]]]]]], '.']], '2009-05-19-13-37-59', '130.60.155.177', '').
text_drs_eval(0, 3444, 'XJohn waits. He is happy.', drs([A, B, C], [predicate(A, wait, named('XJohn'))-1/2, property(B, happy, pos)-2/3, predicate(C, be, named('XJohn'), B)-2/2]), [[specification, [s, [np, [pname, 'XJohn']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, happy]]]]]]], '.']], '2009-05-19-13-39-26', '130.60.155.177', '').
text_drs_eval(0, 3445, 'XJohn waits. She is happy.', drs([A, B, C], [predicate(A, wait, named('XJohn'))-1/2, property(B, happy, pos)-2/3, predicate(C, be, named('XJohn'), B)-2/2]), [[specification, [s, [np, [pname, 'XJohn']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [aux, is], [vbar, [vcompl, [ap_coord, [ap, [adj, happy]]]]]]], '.']], '2009-05-19-13-39-38', '130.60.155.177', '').
text_drs_eval(0, 3446, 'XJohn sees herself.', drs([A], [predicate(A, see, named('XJohn'), named('XJohn'))-1/2]), [[specification, [s, [np, [pname, 'XJohn']], [vp, [vbar, [vcompl, [v, sees], [np, [pn, herself]]]]]], '.']], '2009-05-19-13-39-46', '130.60.155.177', '').
text_drs_eval(0, 3447, 'Mary waits. XJohn waits. Bill sees her.', drs([A, B, C], [predicate(A, wait, named('Mary'))-1/2, predicate(B, wait, named('XJohn'))-2/2, predicate(C, see, named('Bill'), named('XJohn'))-3/2]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'XJohn']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, sees], [np, [pn, her]]]]]], '.']], '2009-05-19-13-40-44', '130.60.155.177', '').
text_drs_eval(0, 3448, 'Mary waits. XJohn waits. He waits. Bill sees her.', drs([A, B, C, D], [predicate(A, wait, named('Mary'))-1/2, predicate(B, wait, named('XJohn'))-2/2, predicate(C, wait, named('XJohn'))-3/2, predicate(D, see, named('Bill'), named('Mary'))-4/2]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'XJohn']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, sees], [np, [pn, her]]]]]], '.']], '2009-05-19-13-41-19', '130.60.155.177', '').
text_drs_eval(0, 3449, 'A man manually enters a card.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, card, countable, na, eq, 1)-1/6, predicate(C, enter, A, B)-1/4, modifier_adv(C, manually, pos)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vmod, [adv, manually]], [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]]]]], '.']], '2009-05-19-17-22-38', '130.60.155.193', '').
text_drs_eval(0, 3450, 'A man manually enters a card usually.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, card, countable, na, eq, 1)-1/6, predicate(C, enter, A, B)-1/4, modifier_adv(C, manually, pos)-1/3, modifier_adv(C, usually, pos)-1/7]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vmod, [adv, manually]], [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]], [vmod, [adv, usually]]]]], '.']], '2009-05-19-17-22-50', '130.60.155.193', '').
text_drs_eval(0, 3451, 'A man manually in a bank enters a card usually in a morning.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/2, object(B, bank, countable, na, eq, 1)-1/6, object(C, morning, countable, na, eq, 1)-1/13, object(D, card, countable, na, eq, 1)-1/9, predicate(E, enter, A, D)-1/7, modifier_pp(E, in, B)-1/4, modifier_adv(E, manually, pos)-1/3, modifier_pp(E, in, C)-1/11, modifier_adv(E, usually, pos)-1/10]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vmod, [adv, manually], [pp, [prep, in], [np, [det, a], [nbar, [n, bank]]]]], [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]], [vmod, [adv, usually], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]]], '.']], '2009-05-19-17-23-14', '130.60.155.193', '').
text_drs_eval(0, 3452, 'A man in a morning manually and usually in a bank enters a card.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/2, object(B, morning, countable, na, eq, 1)-1/5, object(C, bank, countable, na, eq, 1)-1/11, object(D, card, countable, na, eq, 1)-1/14, predicate(E, enter, A, D)-1/12, modifier_pp(E, in, C)-1/9, modifier_adv(E, usually, pos)-1/8, modifier_adv(E, manually, pos)-1/6, modifier_pp(E, in, B)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [adv_coord, [adv, manually], [coord, and], [adv, usually]], [pp, [prep, in], [np, [det, a], [nbar, [n, bank]]]]], [vcompl, [v, enters], [np, [det, a], [nbar, [n, card]]]]]]], '.']], '2009-05-19-17-23-34', '130.60.155.193', '').
text_drs_eval(0, 3453, 'A man in a morning manually usually in a bank enters a card.', drs([], []), [], '2009-05-19-17-23-46', '130.60.155.193', '').
text_drs_eval(0, 3454, 'A man usually is rich.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, property(B, rich, pos)-1/5, predicate(C, be, A, B)-1/4, modifier_adv(C, usually, pos)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, usually]], [aux, is], [ap_coord, [ap, [adj, rich]]]]], '.']], '2009-05-19-17-24-04', '130.60.155.193', '').
text_drs_eval(0, 3455, 'A man usually is rich fast.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, property(B, rich, pos)-1/5, predicate(C, be, A, B)-1/4, modifier_adv(C, usually, pos)-1/3, modifier_adv(C, fast, pos)-1/6]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, usually]], [aux, is], [ap_coord, [ap, [adj, rich]]], [vmod, [adv, fast]]]], '.']], '2009-05-19-17-24-15', '130.60.155.193', '').
text_drs_eval(0, 3456, 'A man usually in a morning is rich fast.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, morning, countable, na, eq, 1)-1/6, property(C, rich, pos)-1/8, predicate(D, be, A, C)-1/7, modifier_pp(D, in, B)-1/4, modifier_adv(D, usually, pos)-1/3, modifier_adv(D, fast, pos)-1/9]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, usually], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]], [aux, is], [ap_coord, [ap, [adj, rich]]], [vmod, [adv, fast]]]], '.']], '2009-05-19-17-24-27', '130.60.155.193', '').
text_drs_eval(0, 3457, 'A man usually is in a park.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/7, predicate(C, be, A)-1/4, modifier_pp(C, in, B)-1/5, modifier_adv(C, usually, pos)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, usually]], [aux, is], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]]], '.']], '2009-05-19-17-24-46', '130.60.155.193', '').
text_drs_eval(0, 3458, 'A man usually is in a park fast.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/7, predicate(C, be, A)-1/4, modifier_pp(C, in, B)-1/5, modifier_adv(C, usually, pos)-1/3, modifier_adv(C, fast, pos)-1/8]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, usually]], [aux, is], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [vmod, [adv, fast]]]], '.']], '2009-05-19-17-24-51', '130.60.155.193', '').
text_drs_eval(0, 3459, 'A man usually is fast in a park.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, park, countable, na, eq, 1)-1/8, property(C, fast, pos)-1/5, predicate(D, be, A, C)-1/4, modifier_adv(D, usually, pos)-1/3, modifier_pp(D, in, B)-1/6]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vmod, [adv, usually]], [aux, is], [ap_coord, [ap, [adj, fast]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]]]]], '.']], '2009-05-19-17-25-01', '130.60.155.193', '').
text_drs_eval(0, 3460, 'John in every park usually for no reason waits.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/8])=>drs([], [-drs([C], [predicate(C, wait, named('John'))-1/9, modifier_pp(C, for, B)-1/6, modifier_adv(C, usually, pos)-1/5, modifier_pp(C, in, A)-1/2])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [adv, usually], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [vbar, [v, waits]]]]], '.']], '2009-05-20-07-41-43', '130.60.155.193', '').
text_drs_eval(0, 3461, 'John in no park usually for every reason waits.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [-drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/8])=>drs([C], [predicate(C, wait, named('John'))-1/9, modifier_pp(C, for, B)-1/6, modifier_adv(C, usually, pos)-1/5, modifier_pp(C, in, A)-1/2])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, no], [nbar, [n, park]]]], [adv, usually], [pp, [prep, for], [np, [det, every], [nbar, [n, reason]]]]], [vbar, [v, waits]]]]], '.']], '2009-05-20-07-41-52', '130.60.155.193', '').
text_drs_eval(0, 3462, 'John in every park usually for no reason waits in every morning.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/8])=>drs([], [-drs([], [drs([C], [object(C, morning, countable, na, eq, 1)-1/12])=>drs([D], [predicate(D, wait, named('John'))-1/9, modifier_pp(D, for, B)-1/6, modifier_adv(D, usually, pos)-1/5, modifier_pp(D, in, A)-1/2, modifier_pp(D, in, C)-1/10])])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [adv, usually], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]]]], '.']], '2009-05-20-07-42-07', '130.60.155.193', '').
text_drs_eval(0, 3463, 'John in every park usually for no reason waits in every morning at every condition.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, reason, countable, na, eq, 1)-1/8])=>drs([], [-drs([], [drs([C], [object(C, morning, countable, na, eq, 1)-1/12])=>drs([], [drs([D], [object(D, condition, countable, na, eq, 1)-1/15])=>drs([E], [predicate(E, wait, named('John'))-1/9, modifier_pp(E, for, B)-1/6, modifier_adv(E, usually, pos)-1/5, modifier_pp(E, in, A)-1/2, modifier_pp(E, at, D)-1/13, modifier_pp(E, in, C)-1/10])])])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [adv, usually], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]], [vbar, [v, waits]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]], [pp, [prep, at], [np, [det, every], [nbar, [n, condition]]]]]]]], '.']], '2009-05-20-07-42-46', '130.60.155.193', '').
text_drs_eval(0, 3464, 'John is in a park in a morning.', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/8, object(B, park, countable, na, eq, 1)-1/5, predicate(C, be, named('John'))-1/2, modifier_pp(C, in, B)-1/3, modifier_pp(C, in, A)-1/6]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-11-40-31', '84.74.95.228', '').
text_drs_eval(0, 3465, 'John usually is in a park in a morning .', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/9, object(B, park, countable, na, eq, 1)-1/6, predicate(C, be, named('John'))-1/3, modifier_pp(C, in, B)-1/4, modifier_adv(C, usually, pos)-1/2, modifier_pp(C, in, A)-1/7]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [adv, usually]], [aux, is], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-11-40-47', '84.74.95.228', '').
text_drs_eval(0, 3466, 'John is rich usually in a morning .', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/7, property(B, rich, pos)-1/3, predicate(C, be, named('John'), B)-1/2, modifier_pp(C, in, A)-1/5, modifier_adv(C, usually, pos)-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [ap_coord, [ap, [adj, rich]]], [vmod, [adv, usually], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-11-41-05', '84.74.95.228', '').
text_drs_eval(0, 3467, 'John is in a park in a morning usually.', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/8, object(B, park, countable, na, eq, 1)-1/5, predicate(C, be, named('John'))-1/2, modifier_pp(C, in, B)-1/3, modifier_adv(C, usually, pos)-1/9, modifier_pp(C, in, A)-1/6]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [pp, [prep, in], [np, [det, a], [nbar, [n, park]]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [adv, usually]]]], '.']], '2009-05-20-11-41-53', '84.74.95.228', '').
text_drs_eval(0, 3468, 'John is a manager usually in a morning .', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/8, object(B, manager, countable, na, eq, 1)-1/4, predicate(C, be, named('John'), B)-1/2, modifier_pp(C, in, A)-1/6, modifier_adv(C, usually, pos)-1/5]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, manager]]], [vmod, [adv, usually], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-11-42-50', '84.74.95.228', '').
text_drs_eval(0, 3469, 'John usually is a manager in a morning .', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/8, object(B, manager, countable, na, eq, 1)-1/5, predicate(C, be, named('John'), B)-1/3, modifier_adv(C, usually, pos)-1/2, modifier_pp(C, in, A)-1/6]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [adv, usually]], [aux, is], [np, [det, a], [nbar, [n, manager]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-11-42-54', '84.74.95.228', '').
text_drs_eval(0, 3470, 'John often and usually is a manager in a morning .', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/10, object(B, manager, countable, na, eq, 1)-1/7, predicate(C, be, named('John'), B)-1/5, modifier_adv(C, usually, pos)-1/4, modifier_adv(C, often, pos)-1/2, modifier_pp(C, in, A)-1/8]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [adv_coord, [adv, often], [coord, and], [adv, usually]]], [aux, is], [np, [det, a], [nbar, [n, manager]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-11-42-58', '84.74.95.228', '').
text_drs_eval(0, 3471, 'John often and usually is a manager in a morning early.', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/10, object(B, manager, countable, na, eq, 1)-1/7, predicate(C, be, named('John'), B)-1/5, modifier_adv(C, usually, pos)-1/4, modifier_adv(C, often, pos)-1/2, modifier_adv(C, early, pos)-1/11, modifier_pp(C, in, A)-1/8]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [adv_coord, [adv, often], [coord, and], [adv, usually]]], [aux, is], [np, [det, a], [nbar, [n, manager]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [adv, early]]]], '.']], '2009-05-20-11-43-29', '84.74.95.228', '').
text_drs_eval(0, 3472, 'John in the beginning in a morning early and often and usually is a manager.', drs([A, B, C, D], [object(A, morning, countable, na, eq, 1)-1/7, object(B, manager, countable, na, eq, 1)-1/15, predicate(C, be, named('John'), B)-1/13, modifier_adv(C, usually, pos)-1/12, modifier_adv(C, often, pos)-1/10, modifier_adv(C, early, pos)-1/8, modifier_pp(C, in, A)-1/5, modifier_pp(C, in, D)-1/2, object(D, beginning, countable, na, eq, 1)-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, beginning]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [adv_coord, [adv, early], [coord, and], [adv_coord, [adv, often], [coord, and], [adv, usually]]]], [aux, is], [np, [det, a], [nbar, [n, manager]]]]], '.']], '2009-05-20-11-44-09', '84.74.95.228', '').
text_drs_eval(0, 3473, 'John in a morning early and often and usually is a manager.', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/4, object(B, manager, countable, na, eq, 1)-1/12, predicate(C, be, named('John'), B)-1/10, modifier_adv(C, usually, pos)-1/9, modifier_adv(C, often, pos)-1/7, modifier_adv(C, early, pos)-1/5, modifier_pp(C, in, A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [adv_coord, [adv, early], [coord, and], [adv_coord, [adv, often], [coord, and], [adv, usually]]]], [aux, is], [np, [det, a], [nbar, [n, manager]]]]], '.']], '2009-05-20-11-44-13', '84.74.95.228', '').
text_drs_eval(0, 3474, 'John is rich in a morning usually.', drs([A, B, C], [object(A, morning, countable, na, eq, 1)-1/6, property(B, rich, pos)-1/3, predicate(C, be, named('John'), B)-1/2, modifier_adv(C, usually, pos)-1/7, modifier_pp(C, in, A)-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [ap_coord, [ap, [adj, rich]]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, morning]]]], [adv, usually]]]], '.']], '2009-05-20-11-44-25', '84.74.95.228', '').
text_drs_eval(0, 3475, 'John usually is a manager in every morning .', drs([A], [object(A, manager, countable, na, eq, 1)-1/5, drs([B], [object(B, morning, countable, na, eq, 1)-1/8])=>drs([C], [modifier_adv(C, usually, pos)-1/2, predicate(C, be, named('John'), A)-1/3, modifier_pp(C, in, B)-1/6])]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [adv, usually]], [aux, is], [np, [det, a], [nbar, [n, manager]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]]], '.']], '2009-06-22-17-15-01', '130.60.155.209', '').
text_drs_eval(0, 3476, 'John is in each of 3 parks.', drs([A], [object(A, park, countable, na, eq, 3)-1/7, drs([B], [has_part(A, B)-1/4])=>drs([C], [predicate(C, be, named('John'))-1/2, modifier_pp(C, in, B)-1/3])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [pp, [prep, in], [np, [quant, 'each of'], [np, [nump, 3], [nbar, [n, parks]]]]]]], '.']], '2009-05-20-15-22-41', '130.60.155.193', '').
text_drs_eval(0, 3477, 'John is happy in each of 3 parks.', drs([A], [object(A, park, countable, na, eq, 3)-1/8, drs([B], [has_part(A, B)-1/5])=>drs([C, D], [property(C, happy, pos)-1/3, predicate(D, be, named('John'), C)-1/2, modifier_pp(D, in, B)-1/4])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [ap_coord, [ap, [adj, happy]]], [vmod, [pp, [prep, in], [np, [quant, 'each of'], [np, [nump, 3], [nbar, [n, parks]]]]]]]], '.']], '2009-05-20-15-22-53', '130.60.155.193', '').
text_drs_eval(0, 3478, 'John is happy in each of 3 parks in every morning.', drs([A], [object(A, park, countable, na, eq, 3)-1/8, drs([B], [has_part(A, B)-1/5])=>drs([], [drs([C], [object(C, morning, countable, na, eq, 1)-1/11])=>drs([D, E], [property(D, happy, pos)-1/3, predicate(E, be, named('John'), D)-1/2, modifier_pp(E, in, C)-1/9, modifier_pp(E, in, B)-1/4])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [ap_coord, [ap, [adj, happy]]], [vmod, [pp, [prep, in], [np, [quant, 'each of'], [np, [nump, 3], [nbar, [n, parks]]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]]], '.']], '2009-05-20-15-23-03', '130.60.155.193', '').
text_drs_eval(0, 3479, 'John is happy in every morning in each of 3 parks.', drs([], [drs([A], [object(A, morning, countable, na, eq, 1)-1/6])=>drs([B], [object(B, park, countable, na, eq, 3)-1/11, drs([C], [has_part(B, C)-1/8])=>drs([D, E], [property(D, happy, pos)-1/3, predicate(E, be, named('John'), D)-1/2, modifier_pp(E, in, C)-1/7, modifier_pp(E, in, A)-1/4])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [ap_coord, [ap, [adj, happy]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]], [pp, [prep, in], [np, [quant, 'each of'], [np, [nump, 3], [nbar, [n, parks]]]]]]]], '.']], '2009-05-20-15-23-28', '130.60.155.193', '').
text_drs_eval(0, 3480, 'XYZ is tired. He sleeps.', drs([A, B, C], [property(A, tired, pos)-1/3, predicate(B, be, named('XYZ'), A)-1/2, predicate(C, sleep, named('XYZ'))-2/2]), [[specification, [s, [np, [pname, 'XYZ']], [vp, [aux, is], [ap_coord, [ap, [adj, tired]]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.']], '2009-05-20-18-51-47', '84.74.95.228', '').
text_drs_eval(0, 3481, 'XYZ is tired. He sleeps. She waits.', drs([], []), [[specification, [s, [np, [pname, 'XYZ']], [vp, [aux, is], [ap_coord, [ap, [adj, tired]]]]], '.'], [specification, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-20-18-51-51', '84.74.95.228', '').
text_drs_eval(0, 3482, 'XYZ is tired. she sleeps. She waits.', drs([A, B, C, D], [property(A, tired, pos)-1/3, predicate(B, be, named('XYZ'), A)-1/2, predicate(C, sleep, named('XYZ'))-2/2, predicate(D, wait, named('XYZ'))-3/2]), [[specification, [s, [np, [pname, 'XYZ']], [vp, [aux, is], [ap_coord, [ap, [adj, tired]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-20-18-51-58', '84.74.95.228', '').
text_drs_eval(0, 3483, 'XYZ is tired. she sleeps. It waits.', drs([], []), [[specification, [s, [np, [pname, 'XYZ']], [vp, [aux, is], [ap_coord, [ap, [adj, tired]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [pn, it]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-20-18-52-02', '84.74.95.228', '').
text_drs_eval(0, 3484, 'XYZ is tired. she sleeps. Its dog waits.', drs([], []), [[specification, [s, [np, [pname, 'XYZ']], [vp, [aux, is], [ap_coord, [ap, [adj, tired]]]]], '.'], [specification, [s, [np, [pn, she]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.'], [specification, [s, [np, [posspn, its], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-20-18-52-10', '84.74.95.228', '').
text_drs_eval(0, 3485, 'A message is from someone from who John awaits a delivery usually.', drs([A, B, C, D, E], [object(A, message, countable, na, eq, 1)-1/2, object(B, somebody, countable, na, eq, 1)-1/6, object(C, delivery, countable, na, eq, 1)-1/12, predicate(D, await, named('John'), C)-1/10, modifier_adv(D, usually, pos)-1/13, modifier_pp(D, from, B)-1/7, predicate(E, be, A)-1/3, modifier_pp(E, from, B)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, message]]], [vp, [aux, is], [pp, [prep, from], [np, [pn, someone], [rel_cl, [pp, [prep, from], [np, [relpn, who]]], [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, awaits], [np, [det, a], [nbar, [n, delivery]]]], [vmod, [adv, usually]]]]]]]]], '.']], '2009-05-21-10-42-25', '89.206.64.31', '').
text_drs_eval(0, 3486, 'A message is from someone from who John awaits a delivery usually manually.', drs([], []), [], '2009-05-21-10-42-33', '89.206.64.31', '').
text_drs_eval(0, 3487, 'A message is from someone from who John awaits a delivery usually and manually.', drs([A, B, C, D, E], [object(A, message, countable, na, eq, 1)-1/2, object(B, somebody, countable, na, eq, 1)-1/6, object(C, delivery, countable, na, eq, 1)-1/12, predicate(D, await, named('John'), C)-1/10, modifier_adv(D, manually, pos)-1/15, modifier_adv(D, usually, pos)-1/13, modifier_pp(D, from, B)-1/7, predicate(E, be, A)-1/3, modifier_pp(E, from, B)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, message]]], [vp, [aux, is], [pp, [prep, from], [np, [pn, someone], [rel_cl, [pp, [prep, from], [np, [relpn, who]]], [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, awaits], [np, [det, a], [nbar, [n, delivery]]]], [vmod, [adv_coord, [adv, usually], [coord, and], [adv, manually]]]]]]]]]], '.']], '2009-05-21-10-42-42', '89.206.64.31', '').
text_drs_eval(0, 3488, 'Every man is in every park in every morning for no reason.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, park, countable, na, eq, 1)-1/6])=>drs([], [drs([C], [object(C, morning, countable, na, eq, 1)-1/9])=>drs([], [drs([D], [object(D, reason, countable, na, eq, 1)-1/12])=>drs([], [-drs([E], [predicate(E, be, A)-1/3, modifier_pp(E, for, D)-1/10, modifier_pp(E, in, C)-1/7, modifier_pp(E, in, B)-1/4])])])])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]], [pp, [prep, for], [np, [det, no], [nbar, [n, reason]]]]]]], '.']], '2009-05-21-10-43-13', '89.206.64.31', '').
text_drs_eval(0, 3489, 'Every man is fast in every park.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([], [drs([B], [object(B, park, countable, na, eq, 1)-1/7])=>drs([C, D], [property(C, fast, pos)-1/4, predicate(D, be, A, C)-1/3, modifier_pp(D, in, B)-1/5])])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [ap_coord, [ap, [adj, fast]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]]]], '.']], '2009-05-21-10-43-38', '89.206.64.31', '').
text_drs_eval(0, 3490, 'Every man is who in every park?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B], [query(B, who)-1/4, drs([C], [object(C, park, countable, na, eq, 1)-1/7])=>drs([D], [predicate(D, be, A, B)-1/3, modifier_pp(D, in, C)-1/5])])]))]), [[query, [question, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [np, [qpn, who]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]]]], ?]], '2009-06-22-17-15-08', '130.60.155.209', '').
text_drs_eval(0, 3491, 'Every man is where in the morning?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C], [query(B, where)-1/4, predicate(B, be, A)-1/3, modifier_pp(B, in, C)-1/5, object(C, morning, countable, na, eq, 1)-1/7])]))]), [[query, [question, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [qpn, where], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]]]], ?]], '2009-05-21-10-44-15', '89.206.64.31', '').
text_drs_eval(0, 3492, 'Every man is in the morning where?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C], [predicate(B, be, A)-1/3, query(B, where)-1/7, modifier_pp(B, in, C)-1/4, object(C, morning, countable, na, eq, 1)-1/6])]))]), [[query, [question, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]], [vmod, [qpn, where]]]], ?]], '2009-05-21-10-44-36', '89.206.64.31', '').
text_drs_eval(0, 3493, 'Every man is rich in the morning where?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C, D], [property(B, rich, pos)-1/4, predicate(C, be, A, B)-1/3, query(C, where)-1/8, modifier_pp(C, in, D)-1/5, object(D, morning, countable, na, eq, 1)-1/7])]))]), [[query, [question, [np, [det, every], [nbar, [n, man]]], [vp, [aux, is], [ap_coord, [ap, [adj, rich]]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]], [qpn, where]]]], ?]], '2009-05-21-10-44-44', '89.206.64.31', '').
text_drs_eval(0, 3494, 'John in every park is in every morning.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, morning, countable, na, eq, 1)-1/8])=>drs([C], [predicate(C, be, named('John'))-1/5, modifier_pp(C, in, A)-1/2, modifier_pp(C, in, B)-1/6])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]], [aux, is], [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]]], '.']], '2009-05-21-10-53-27', '84.74.95.228', '').
text_drs_eval(0, 3495, 'John in every park in every morning is in every bank.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, morning, countable, na, eq, 1)-1/7])=>drs([], [drs([C], [object(C, bank, countable, na, eq, 1)-1/11])=>drs([D], [predicate(D, be, named('John'))-1/8, modifier_pp(D, in, B)-1/5, modifier_pp(D, in, A)-1/2, modifier_pp(D, in, C)-1/9])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]], [aux, is], [pp, [prep, in], [np, [det, every], [nbar, [n, bank]]]]]], '.']], '2009-05-21-10-54-33', '84.74.95.228', '').
text_drs_eval(0, 3496, 'John in every park in every morning is in every bank at every time.', drs([], [drs([A], [object(A, park, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, morning, countable, na, eq, 1)-1/7])=>drs([], [drs([C], [object(C, bank, countable, na, eq, 1)-1/11])=>drs([], [drs([D], [object(D, time, countable, na, eq, 1)-1/14])=>drs([E], [predicate(E, be, named('John'))-1/8, modifier_pp(E, in, B)-1/5, modifier_pp(E, in, A)-1/2, modifier_pp(E, at, D)-1/12, modifier_pp(E, in, C)-1/9])])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]], [pp, [prep, in], [np, [det, every], [nbar, [n, morning]]]]], [aux, is], [pp, [prep, in], [np, [det, every], [nbar, [n, bank]]]], [vmod, [pp, [prep, at], [np, [det, every], [nbar, [n, time]]]]]]], '.']], '2009-05-21-10-55-06', '84.74.95.228', '').
text_drs_eval(0, 3497, 'John likes Mary.\n\nMary likes John.', drs([A, B], [predicate(A, like, named('John'), named('Mary'))-1/2, predicate(B, like, named('Mary'), named('John'))-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'John']]]]]], '.']], '2009-05-21-12-21-58', '130.60.155.177', '').
text_drs_eval(0, 3498, 'John likes Mary.\n \nMary likes John.', drs([A, B], [predicate(A, like, named('John'), named('Mary'))-1/2, predicate(B, like, named('Mary'), named('John'))-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'John']]]]]], '.']], '2009-05-21-12-33-30', '130.60.155.177', '').
text_drs_eval(0, 3499, '#This is a comment.\nThere is a comment.', drs([A], [object(A, comment, countable, na, eq, 1)-1/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, comment]]]]], '.']], '2009-06-03-01-17-21', '89.206.68.11', '').
text_drs_eval(0, 3500, '#This is a comment.\n\nThere is a paragraph.\n\nThere is a paragraph.', drs([A, B], [object(A, paragraph, countable, na, eq, 1)-1/4, object(B, paragraph, countable, na, eq, 1)-2/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, paragraph]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, paragraph]]]]], '.']], '2009-06-03-01-17-07', '89.206.68.11', '').
text_drs_eval(0, 3501, 'There is a man X.\nThere is a woman X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-14-19-27', '89.206.64.31', '').
text_drs_eval(0, 3502, 'There is a man X.\n\nThere is a woman X.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, object(B, woman, countable, na, eq, 1)-2/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-14-19-33', '89.206.64.31', '').
text_drs_eval(0, 3503, 'There is a man X.\n \nThere is a woman X.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, object(B, woman, countable, na, eq, 1)-2/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-14-19-42', '89.206.64.31', '').
text_drs_eval(0, 3504, 'There is a man X.\n# comment\nThere is a woman X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-14-38-56', '89.206.64.31', '').
text_drs_eval(0, 3505, 'There is a man X.\n/*\n\n\n*/\nThere is a woman X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-14-39-34', '89.206.64.31', '').
text_drs_eval(0, 3506, 'There is a man X.\n/* comment */\nThere is a woman X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-14-39-46', '89.206.64.31', '').
text_drs_eval(0, 3507, 'John sees a man.\n\nThe man waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, see, named('John'), A)-1/2, predicate(C, wait, D)-2/3, object(D, man, countable, na, eq, 1)-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, man]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-21-14-40-19', '89.206.64.31', '').
text_drs_eval(0, 3508, 'John sees a man.\n# comment.\nThe man waits.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, see, named('John'), A)-1/2, predicate(C, wait, A)-2/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, man]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-21-14-40-43', '89.206.64.31', '').
text_drs_eval(0, 3509, 'X is Y.\nY is X.', drs([A, B, C, D], [object(A, something, dom, na, na, na)-1/1, object(B, something, dom, na, na, na)-1/3, predicate(C, be, A, B)-1/2, predicate(D, be, B, A)-2/2]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is], [np, [var, 'Y']]]], '.'], [specification, [s, [np, [var, 'Y']], [vp, [aux, is], [np, [var, 'X']]]], '.']], '2009-05-26-08-00-14', '130.60.155.193', '').
text_drs_eval(0, 3510, 'X is Y.\n\nY is X.', drs([A, B, C, D, E, F], [object(A, something, dom, na, na, na)-1/1, object(B, something, dom, na, na, na)-1/3, predicate(C, be, A, B)-1/2, object(D, something, dom, na, na, na)-2/1, object(E, something, dom, na, na, na)-2/3, predicate(F, be, D, E)-2/2]), [[specification, [s, [np, [var, 'X']], [vp, [aux, is], [np, [var, 'Y']]]], '.'], [specification, [s, [np, [var, 'Y']], [vp, [aux, is], [np, [var, 'X']]]], '.']], '2009-05-26-08-00-24', '130.60.155.193', '').
text_drs_eval(0, 3511, 'John waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.\n\nJohn waits.', drs([A, B, C, D, E, F, G, H, I, J], [predicate(A, wait, named('John'))-1/2, predicate(B, wait, named('John'))-2/2, predicate(C, wait, named('John'))-3/2, predicate(D, wait, named('John'))-4/2, predicate(E, wait, named('John'))-5/2, predicate(F, wait, named('John'))-6/2, predicate(G, wait, named('John'))-7/2, predicate(H, wait, named('John'))-8/2, predicate(I, wait, named('John'))-9/2, predicate(J, wait, named('John'))-10/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-21-15-08-06', '89.206.64.31', '').
text_drs_eval(0, 3512, 'There is a man X. There is a woman X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-20-15-43', '84.74.95.228', '').
text_drs_eval(0, 3513, 'There is a man X. \nThere is a woman X.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-20-15-45', '84.74.95.228', '').
text_drs_eval(0, 3514, 'There is a man X. \n\nThere is a woman X.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, object(B, woman, countable, na, eq, 1)-2/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, woman], [appos, [var, 'X']]]]]], '.']], '2009-05-21-20-15-47', '84.74.95.228', '').
text_drs_eval(0, 3515, 'John is a man.\n\n# comment\n\nMary is a woman.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, be, named('John'), A)-1/2, object(C, woman, countable, na, eq, 1)-2/4, predicate(D, be, named('Mary'), C)-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [aux, is], [np, [det, a], [nbar, [n, woman]]]]], '.']], '2009-05-22-08-00-58', '130.60.155.193', '').
text_drs_eval(0, 3516, 'John is a man.\n# comment\n\nMary is a woman.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, be, named('John'), A)-1/2, object(C, woman, countable, na, eq, 1)-2/4, predicate(D, be, named('Mary'), C)-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [aux, is], [np, [det, a], [nbar, [n, woman]]]]], '.']], '2009-05-22-08-01-02', '130.60.155.193', '').
text_drs_eval(0, 3517, 'John is a man.\n\n# comment\nMary is a woman.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, be, named('John'), A)-1/2, object(C, woman, countable, na, eq, 1)-2/4, predicate(D, be, named('Mary'), C)-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [aux, is], [np, [det, a], [nbar, [n, woman]]]]], '.']], '2009-05-22-08-01-07', '130.60.155.193', '').
text_drs_eval(0, 3518, 'John is a man.\n\nMary is a woman. Bill knows the woman.\n\nThe woman waits.', drs([A, B, C, D, E, F, G], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, be, named('John'), A)-1/2, object(C, woman, countable, na, eq, 1)-2/4, predicate(D, be, named('Mary'), C)-2/2, predicate(E, know, named('Bill'), C)-3/2, predicate(F, wait, G)-4/3, object(G, woman, countable, na, eq, 1)-4/2]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'Mary']], [vp, [aux, is], [np, [det, a], [nbar, [n, woman]]]]], '.'], [specification, [s, [np, [pname, 'Bill']], [vp, [vbar, [vcompl, [v, knows], [np, [det, the], [nbar, [n, woman]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, woman]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-05-22-08-01-35', '130.60.155.193', '').
text_drs_eval(0, 3519, 'John sees a man. A customer is him.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, see, named('John'), A)-1/2, object(C, customer, countable, na, eq, 1)-2/2, predicate(D, be, C, A)-2/3]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, man]]]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, customer]]], [vp, [aux, is], [np, [pn, him]]]], '.']], '2009-05-22-09-04-59', '130.60.155.193', '').
text_drs_eval(0, 3520, 'John is where and when?', drs([], [question(drs([A], [predicate(A, be, named('John'))-1/2, query(A, when)-1/5, query(A, where)-1/3]))]), [[query, [question, [np, [pname, 'John']], [vp, [aux, is], [adv_coord, [qpn, where], [coord, and], [qpn, when]]]], ?]], '2009-05-22-11-36-09', '130.60.155.193', '').
text_drs_eval(0, 3521, 'John is in Paris when and where?', drs([], [question(drs([A], [predicate(A, be, named('John'))-1/2, query(A, where)-1/7, query(A, when)-1/5, modifier_pp(A, in, named('Paris'))-1/3]))]), [[query, [question, [np, [pname, 'John']], [vp, [aux, is], [pp, [prep, in], [np, [pname, 'Paris']]], [vmod, [adv_coord, [qpn, when], [coord, and], [qpn, where]]]]], ?]], '2009-05-22-11-36-17', '130.60.155.193', '').
text_drs_eval(0, 3522, 'Every man sleeps where and when and how?', drs([], [question(drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, sleep, A)-1/3, query(B, how)-1/8, query(B, when)-1/6, query(B, where)-1/4])]))]), [[query, [question, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, sleeps]], [vmod, [adv_coord, [qpn, where], [coord, and], [adv_coord, [qpn, when], [coord, and], [qpn, how]]]]]]], ?]], '2009-05-22-11-36-21', '130.60.155.193', '').
text_drs_eval(0, 3523, 'John sleeps where and where?', drs([], [question(drs([A], [predicate(A, sleep, named('John'))-1/2, query(A, where)-1/3]))]), [[query, [question, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, sleeps]], [vmod, [adv_coord, [qpn, where], [coord, and], [qpn, where]]]]]], ?]], '2009-05-22-11-36-34', '130.60.155.193', '').
text_drs_eval(0, 3524, '-007 likes -002.200.', drs([A], [predicate(A, like, int(-7), real(-2.2))-1/3]), [[specification, [s, [np, [int, -7]], [vp, [vbar, [vcompl, [v, likes], [np, [real, -2.2]]]]]], '.']], '2009-05-24-21-42-00', '84.74.95.228', '').
text_drs_eval(0, 3525, 'John likes (Mary + 1).', drs([A], [predicate(A, like, named('John'), expr(+, named('Mary'), int(1)))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [brackets, '(', [expr, [pname, 'Mary'], [int, 1]], ')']]]]]], '.']], '2009-06-02-01-50-14', '89.206.64.20', '').
text_drs_eval(0, 3526, 'John likes 1 + Mary.', drs([A], [predicate(A, like, named('John'), expr(+, int(1), named('Mary')))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [expr, [int, 1], [pname, 'Mary']]]]]]], '.']], '2009-06-02-01-50-36', '89.206.64.20', '').
text_drs_eval(0, 3527, 'John likes Mary + 1.', drs([A], [predicate(A, like, named('John'), expr(+, named('Mary'), int(1)))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [expr, [pname, 'Mary'], [int, 1]]]]]]], '.']], '2009-06-03-01-16-45', '89.206.68.11', '').
text_drs_eval(0, 3528, 'There is a car that John buys for himself.', drs([A, B], [object(A, car, countable, na, eq, 1)-1/4, predicate(B, buy, named('John'), A)-1/7, modifier_pp(B, for, named('John'))-1/8]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, car], [rel_cl, [comp, that], [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, buys]], [vmod, [pp, [prep, for], [np, [pn, himself]]]]]]]]]]], '.']], '2009-06-22-14-11-39', '130.60.155.209', '').
text_drs_eval(0, 3529, 'Mary is as young as who?', drs([], [question(drs([A, B, C], [query(A, who)-1/6, property(B, young, pos_as, A)-1/4, predicate(C, be, named('Mary'), B)-1/2]))]), [[query, [question, [np, [pname, 'Mary']], [vp, [aux, is], [ap_coord, [ap, as, [adj, young], as, [np, [qpn, who]]]]]], ?]], '2009-06-19-10-15-24', '130.60.155.209', '').
text_drs_eval(0, 3530, 'Mary asks everybody X for X.', drs([], [drs([A], [object(A, somebody, countable, na, eq, 1)-1/4])=>drs([B], [predicate(B, ask, named('Mary'), A)-1/2, modifier_pp(B, for, A)-1/6])]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, asks], [np, [pn, everybody], [appos, [var, 'X']]]], [vmod, [pp, [prep, for], [np, [var, 'X']]]]]]], '.']], '2009-06-22-15-16-36', '130.60.155.209', '').
text_drs_eval(0, 3531, 'There is a car that John buys for herself.', drs([], []), [], '2009-06-22-14-11-51', '130.60.155.209', '').
text_drs_eval(0, 3532, 'There is a car that John buys for him.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, car], [rel_cl, [comp, that], [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, buys]], [vmod, [pp, [prep, for], [np, [pn, him]]]]]]]]]]], '.']], '2009-06-22-14-12-00', '130.60.155.209', '').
text_drs_eval(0, 3533, 'John sees every woman in every park.', drs([], [drs([A], [object(A, woman, countable, na, eq, 1)-1/4])=>drs([], [drs([B], [object(B, park, countable, na, eq, 1)-1/7])=>drs([C], [predicate(C, see, named('John'), A)-1/2, modifier_pp(C, in, B)-1/5])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, every], [nbar, [n, woman]]]], [vmod, [pp, [prep, in], [np, [det, every], [nbar, [n, park]]]]]]]], '.']], '2009-06-22-15-16-24', '130.60.155.209', '').
text_drs_eval(0, 3534, 'John is no hero at every time.', drs([], [drs([A], [object(A, hero, countable, na, eq, 1)-1/4])=>drs([], [-drs([], [drs([B], [object(B, time, countable, na, eq, 1)-1/7])=>drs([C], [predicate(C, be, named('John'), A)-1/2, modifier_pp(C, at, B)-1/5])])])]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, no], [nbar, [n, hero]]], [vmod, [pp, [prep, at], [np, [det, every], [nbar, [n, time]]]]]]], '.']], '2009-06-22-17-14-47', '130.60.155.209', '').
text_drs_eval(0, 3535, 'There is X. X is fast. John shows X to a man.', drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1/3, property(B, fast, pos)-2/3, predicate(C, be, A, B)-2/2, object(D, man, countable, na, eq, 1)-3/6, predicate(E, show, named('John'), A, D)-3/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [ap_coord, [ap, [adj, fast]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, shows], [np, [var, 'X']], to, [np, [det, a], [nbar, [n, man]]]]]]], '.']], '2009-07-03-10-21-44', '82.131.73.174', '').
text_drs_eval(0, 3536, 'There is X. X is fast. A man is shown X by John.', drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1/3, property(B, fast, pos)-2/3, predicate(C, be, A, B)-2/2, object(D, man, countable, na, eq, 1)-3/2, predicate(E, show, named('John'), A, D)-3/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [ap_coord, [ap, [adj, fast]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [aux, is], [vbar, [vcompl, [v, shown], [np, [var, 'X']], by, [np, [pname, 'John']]]]]], '.']], '2009-07-03-14-14-01', '89.206.64.52', '').
text_drs_eval(0, 3537, 'There is X. X is fast. X is shown to a man by John.', drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1/3, property(B, fast, pos)-2/3, predicate(C, be, A, B)-2/2, object(D, man, countable, na, eq, 1)-3/6, predicate(E, show, named('John'), A, D)-3/3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [var, 'X']]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [ap_coord, [ap, [adj, fast]]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [aux, is], [vbar, [vcompl, [v, shown], to, [np, [det, a], [nbar, [n, man]]], by, [np, [pname, 'John']]]]]], '.']], '2009-07-03-14-15-40', '89.206.64.52', '').
text_drs_eval(0, 3538, 'There is something X1.\nX1 is fast.\nJohn shows X1 a man.', drs([A, B, C, D, E], [object(A, something, dom, na, na, na)-1/4, property(B, fast, pos)-2/3, predicate(C, be, A, B)-2/2, object(D, man, countable, na, eq, 1)-3/5, predicate(E, show, named('John'), D, A)-3/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [pn, something], [appos, [var, 'X1']]]]], '.'], [specification, [s, [np, [var, 'X1']], [vp, [aux, is], [ap_coord, [ap, [adj, fast]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, shows], [np, [var, 'X1']], [np, [det, a], [nbar, [n, man]]]]]]], '.']], '2009-07-03-14-16-33', '89.206.64.52', '').
text_drs_eval(0, 3539, 'At most 2 men give at most 4 apples to at most 3 women.', drs([A, B, C, D], [[object(A, man, countable, na, leq, 2)-1/4, [object(B, apple, countable, na, leq, 4)-1/9, [object(C, woman, countable, na, leq, 3)-1/14, predicate(D, give, A, B, C)-1/5]]]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men]]], [vp, [vbar, [vcompl, [v, give], [np, [nump, [genqu, 'at most'], 4], [nbar, [n, apples]]], to, [np, [nump, [genqu, 'at most'], 3], [nbar, [n, women]]]]]]], '.']], '2009-07-03-16-02-47', '89.206.64.52', '').
text_drs_eval(0, 3540, 'Mary asks John who asks who.', drs([], []), [], '2009-07-06-09-40-07', '130.60.155.150', '').
text_drs_eval(0, 3541, 'Mary asks John who asks who?', drs([], [question(drs([A, B, C], [predicate(A, ask, named('Mary'), named('John'))-1/2, query(B, who)-1/6, predicate(C, ask, named('John'), B)-1/5]))]), [[query, [question, [np, [pname, 'Mary']], [vp, [vbar, [vcompl, [v, asks], [np, [pname, 'John'], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, asks], [np, [qpn, who]]]]]]]]]]], ?]], '2009-07-06-09-40-18', '130.60.155.150', '').
text_drs_eval(0, 3542, 'For every woman the woman does not ask her.', drs([], []), [[specification, [top_s, [topic, [quant, for], [np, [det, every], [nbar, [n, woman]]]], [s, [np, [det, the], [nbar, [n, woman]]], [vp, [aux, does, not], [vbar, [vcompl, [v, ask], [np, [pn, her]]]]]]], '.']], '2009-07-07-11-54-02', '130.60.155.150', '').
text_drs_eval(0, 3543, 'For every woman the woman asks her.', drs([], []), [[specification, [top_s, [topic, [quant, for], [np, [det, every], [nbar, [n, woman]]]], [s, [np, [det, the], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, asks], [np, [pn, her]]]]]]], '.']], '2009-07-07-11-54-08', '130.60.155.150', '').
text_drs_eval(0, 3544, 'Mary who sees Bill who does not see her asks X.', drs([A, B, C], [-drs([D], [predicate(D, see, named('Bill'), named('Mary'))-1/8]), predicate(A, see, named('Mary'), named('Bill'))-1/3, object(B, something, dom, na, na, na)-1/11, predicate(C, ask, named('Mary'), B)-1/10]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [pname, 'Bill'], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vcompl, [v, see], [np, [pn, her]]]]]]]]]]]], [vp, [vbar, [vcompl, [v, asks], [np, [var, 'X']]]]]], '.']], '2009-09-21-08-25-19', '130.60.155.174', '').
text_drs_eval(0, 3545, 'Mary who X asks does not ask her .', drs([A, B], [object(A, something, dom, na, na, na)-1/3, predicate(B, ask, A, named('Mary'))-1/4, -drs([C], [predicate(C, ask, named('Mary'), A)-1/7])]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [np, [var, 'X']], [vp, [vbar, [vcompl, [v, asks]]]]]], [vp, [aux, does, not], [vbar, [vcompl, [v, ask], [np, [pn, her]]]]]], '.']], '2009-09-21-08-25-26', '130.60.155.174', '').
text_drs_eval(0, 3546, 'Mary who asks X is not her .', drs([A, B], [object(A, something, dom, na, na, na)-1/4, predicate(B, ask, named('Mary'), A)-1/3, -drs([C], [predicate(C, be, named('Mary'), A)-1/5])]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, asks], [np, [var, 'X']]]]]]], [vp, [aux, is, not], [np, [pn, her]]]], '.']], '2009-09-21-08-25-41', '130.60.155.174', '').
text_drs_eval(0, 3547, 'Mary who asks everybody X asks X .', drs([A, B], [drs([C], [object(C, somebody, countable, na, eq, 1)-1/5])=>drs([D], [predicate(D, ask, named('Mary'), C)-1/3]), object(A, something, dom, na, na, na)-1/8, predicate(B, ask, named('Mary'), A)-1/7]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, asks], [np, [pn, everybody], [appos, [var, 'X']]]]]]]], [vp, [vbar, [vcompl, [v, asks], [np, [var, 'X']]]]]], '.']], '2009-09-21-08-25-57', '130.60.155.174', '').
text_drs_eval(0, 3548, 'Mary who does not ask X is X .', drs([A, B], [-drs([C, D], [object(C, something, dom, na, na, na)-1/6, predicate(D, ask, named('Mary'), C)-1/5]), object(A, something, dom, na, na, na)-1/8, predicate(B, be, named('Mary'), A)-1/7]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [vp, [aux, does, not], [vbar, [vcompl, [v, ask], [np, [var, 'X']]]]]]], [vp, [aux, is], [np, [var, 'X']]]], '.']], '2009-09-21-08-26-05', '130.60.155.174', '').
text_drs_eval(0, 3549, 'Mary who everybody X asks asks X .', drs([A, B], [drs([C], [object(C, somebody, countable, na, eq, 1)-1/4])=>drs([D], [predicate(D, ask, C, named('Mary'))-1/6]), object(A, something, dom, na, na, na)-1/8, predicate(B, ask, named('Mary'), A)-1/7]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [np, [pn, everybody], [appos, [var, 'X']]], [vp, [vbar, [vcompl, [v, asks]]]]]], [vp, [vbar, [vcompl, [v, asks], [np, [var, 'X']]]]]], '.']], '2009-09-21-08-26-15', '130.60.155.174', '').
text_drs_eval(0, 3550, 'Mary who is X is not her .', drs([A, B], [object(A, something, dom, na, na, na)-1/4, predicate(B, be, named('Mary'), A)-1/3, -drs([C], [predicate(C, be, named('Mary'), A)-1/5])]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [vp, [aux, is], [np, [var, 'X']]]]], [vp, [aux, is, not], [np, [pn, her]]]], '.']], '2009-09-21-08-26-23', '130.60.155.174', '').
text_drs_eval(0, 3551, 'Mary who is not X asks X .', drs([A, B], [-drs([C, D], [object(C, something, dom, na, na, na)-1/5, predicate(D, be, named('Mary'), C)-1/3]), object(A, something, dom, na, na, na)-1/7, predicate(B, ask, named('Mary'), A)-1/6]), [[specification, [s, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [vp, [aux, is, not], [np, [var, 'X']]]]], [vp, [vbar, [vcompl, [v, asks], [np, [var, 'X']]]]]], '.']], '2009-09-21-08-26-31', '130.60.155.174', '').
text_drs_eval(0, 3552, 'Mary who which women ask for her waits ?', drs([], [question(drs([A, B, C], [query(A, which)-1/3, object(A, woman, countable, na, geq, 2)-1/4, predicate(B, ask, A, named('Mary'))-1/5, modifier_pp(B, for, named('Mary'))-1/6, predicate(C, wait, named('Mary'))-1/8]))]), [[query, [question, [np, [pname, 'Mary'], [rel_cl, [np, [relpn, who]], [np, [qdet, which], [nbar, [n, women]]], [vp, [vbar, [vcompl, [v, ask]], [vmod, [pp, [prep, for], [np, [pn, her]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?]], '2009-09-21-09-40-31', '130.60.155.174', '').
text_drs_eval(0, 3553, 'a man who a woman asks for him waits.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, woman, countable, na, eq, 1)-1/5, predicate(C, ask, B, A)-1/6, modifier_pp(C, for, A)-1/7, predicate(D, wait, A)-1/9]), [[specification, [s, [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [np, [det, a], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, asks]], [vmod, [pp, [prep, for], [np, [pn, him]]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-09-21-09-41-16', '130.60.155.174', '').
text_drs_eval(0, 3554, 'everybody who which women ask for her waits?', drs([], [question(drs([], [drs([A, B, C], [object(A, somebody, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, woman, countable, na, geq, 2)-1/5, predicate(C, ask, B, A)-1/6, modifier_pp(C, for, A)-1/7])=>drs([D], [predicate(D, wait, A)-1/9])]))]), [[query, [question, [np, [pn, everybody], [rel_cl, [np, [relpn, who]], [np, [qdet, which], [nbar, [n, women]]], [vp, [vbar, [vcompl, [v, ask]], [vmod, [pp, [prep, for], [np, [pn, her]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?]], '2009-09-21-09-45-28', '130.60.155.174', '').
text_drs_eval(0, 3555, 'a woman carries the woman from who to her?', drs([], [question(drs([A, B, C], [object(A, woman, countable, na, eq, 1)-1/2, query(B, who)-1/7, predicate(C, carry, A, A)-1/3, modifier_pp(C, to, B)-1/8, modifier_pp(C, from, B)-1/6]))]), [[query, [question, [np, [det, a], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, carries], [np, [det, the], [nbar, [n, woman]]]], [vmod, [pp, [prep, from], [np, [qpn, who]]], [pp, [prep, to], [np, [pn, her]]]]]]], ?]], '2009-09-21-10-47-48', '130.60.155.174', '').
text_drs_eval(0, 3556, 'exactly 1 woman who sees a man who loves her waits.', drs([A, B, C, D, E], [[object(A, woman, countable, na, exactly, 1)-1/3, object(B, man, countable, na, eq, 1)-1/7, predicate(C, love, B, A)-1/9, predicate(D, see, A, B)-1/5, predicate(E, wait, A)-1/11]]), [[specification, [s, [np, [nump, [genqu, exactly], 1], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, loves], [np, [pn, her]]]]]]]]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2009-09-21-15-57-10', '130.60.155.174', '').
text_drs_eval(0, 3557, 'exactly 1 woman asks a woman of her.', drs([A, B, C], [[object(A, woman, countable, na, exactly, 1)-1/3, object(B, woman, countable, na, eq, 1)-1/6, relation(B, of, B)-1/7, predicate(C, ask, A, B)-1/4]]), [[specification, [s, [np, [nump, [genqu, exactly], 1], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, asks], [np, [det, a], [nbar, [n, woman], [pp, [prep, of], [np, [pn, her]]]]]]]]], '.']], '2009-09-21-15-57-42', '130.60.155.174', '').
text_drs_eval(0, 3558, 'John sees a cat that likes the cat that smiles.', drs([A, B, C, D, E], [object(A, cat, countable, na, eq, 1)-1/4, predicate(D, smile, C)-1/10, object(C, cat, countable, na, eq, 1)-1/8, predicate(B, like, A, C)-1/6, predicate(E, see, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]]], '.']], '2009-11-13-00-01-32', '84.74.139.220', '').
text_drs_eval(0, 3559, 'There is a cat that smiles. John sees a cat that likes the cat that smiles.', drs([A, B, C, D, E], [object(A, cat, countable, na, eq, 1)-1/4, predicate(B, smile, A)-1/6, object(C, cat, countable, na, eq, 1)-2/4, predicate(D, like, C, A)-2/6, predicate(E, see, named('John'), C)-2/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]]], '.']], '2009-11-10-23-13-29', '89.206.64.19', '').
text_drs_eval(0, 3560, 'There is a cat that likes the cat that smiles.', drs([A, B, C, D], [object(A, cat, countable, na, eq, 1)-1/4, predicate(D, smile, C)-1/10, object(C, cat, countable, na, eq, 1)-1/8, predicate(B, like, A, C)-1/6]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]], '.']], '2009-11-10-23-14-10', '89.206.64.19', '').
text_drs_eval(0, 3561, 'There is a cat that smiles and that likes the cat that smiles.', drs([A, B, C], [object(A, cat, countable, na, eq, 1)-1/4, predicate(B, smile, A)-1/6, predicate(C, like, A, A)-1/9]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]], '.']], '2009-10-25-12-33-24', '82.131.106.42', '').
text_drs_eval(0, 3562, 'There is a cat that smiles or that likes the cat that smiles.', drs([A], [object(A, cat, countable, na, eq, 1)-1/4, drs([B], [predicate(B, smile, A)-1/6])v drs([C], [predicate(C, like, A, A)-1/9])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]], [coord, or], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]], '.']], '2009-10-25-12-35-13', '82.131.106.42', '').
text_drs_eval(0, 3563, 'There is a cat that smiles or that is not the cat that smiles.', drs([A], [object(A, cat, countable, na, eq, 1)-1/4, drs([B], [predicate(B, smile, A)-1/6])v drs([], [-drs([C], [predicate(C, be, A, A)-1/9])])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]], [coord, or], [rel_cl, [comp, that], [vp, [aux, is, not], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]], '.']], '2009-10-25-12-36-26', '82.131.106.42', '').
text_drs_eval(0, 3564, 'There is a man that likes a cat and that sees the cat that smiles.', drs([A, B, C, D, E, F], [object(A, man, countable, na, eq, 1)-1/4, object(B, cat, countable, na, eq, 1)-1/8, predicate(C, like, A, B)-1/6, predicate(F, smile, E)-1/15, object(E, cat, countable, na, eq, 1)-1/13, predicate(D, see, A, E)-1/11]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, a], [nbar, [n, cat]]]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]], '.']], '2009-10-26-00-17-09', '89.206.64.47', '').
text_drs_eval(0, 3565, 'There is a man that likes a cat and that sees the cat.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, object(B, cat, countable, na, eq, 1)-1/8, predicate(C, like, A, B)-1/6, predicate(D, see, A, B)-1/11]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, a], [nbar, [n, cat]]]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, cat]]]]]]]]]]]], '.']], '2009-10-26-00-17-40', '89.206.64.47', '').
text_drs_eval(0, 3566, 'There is a cat that likes the cat that smiles and that smiles.', drs([A, B, C, D, E], [object(A, cat, countable, na, eq, 1)-1/4, predicate(E, smile, C)-1/13, predicate(D, smile, C)-1/10, object(C, cat, countable, na, eq, 1)-1/8, predicate(B, like, A, C)-1/6]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]], [coord, and], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]], '.']], '2009-11-10-23-14-55', '89.206.64.19', '').
text_drs_eval(1, 3567, 'Every dog uses its own feet to run.', drs([], []), [], '2009-11-01-11-47-34', '82.131.19.95', 'Is to-VP is not possible in ditransitive constructs?').
text_drs_eval(0, 3568, 'Every dog uses to run.', drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1/2])=>drs([B, C], [predicate(B, use, A, C)-1/3, C:drs([D], [predicate(D, run, A)-1/5])])]), [[specification, [s, [np, [det, every], [nbar, [n, dog]]], [vp, [vbar, [v, uses], to, [vp, [vbar, [vbar, [v, run]]]]]]], '.']], '2009-11-01-11-49-27', '82.131.19.95', '').
text_drs_eval(0, 3569, 'John tells that a man waits to Mary.', drs([A, B], [predicate(A, tell, named('John'), B)-1/2, B:drs([C, D], [object(C, man, countable, na, eq, 1)-1/5, predicate(D, wait, C)-1/6, modifier_pp(D, to, named('Mary'))-1/7])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]], [vmod, [pp, [prep, to], [np, [pname, 'Mary']]]]]]]]]]], '.']], '2009-11-02-09-37-18', '82.131.73.48', '').
text_drs_eval(0, 3570, 'John wants a man to wait.', drs([], []), [], '2009-11-02-09-46-44', '82.131.73.48', '').
text_drs_eval(0, 3571, 'Every man sees a dog X that sees a cat that sees the dog that sees a rat that sees a mouse.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/2])=>drs([B, C, D, E, F, G, H, I, J, K], [object(B, dog, countable, na, eq, 1)-1/5, object(C, cat, countable, na, eq, 1)-1/10, predicate(I, see, E, F)-1/16, predicate(H, see, F, G)-1/20, object(G, mouse, countable, na, eq, 1)-1/22, object(F, rat, countable, na, eq, 1)-1/18, object(E, dog, countable, na, eq, 1)-1/14, predicate(D, see, C, E)-1/12, predicate(J, see, B, C)-1/8, predicate(K, see, A, B)-1/3])]), [[specification, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, dog], [appos, [var, 'X']], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, dog], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, rat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, mouse]]]]]]]]]]]]]]]]]]]]]]]]]]]]]]], '.']], '2009-11-10-23-19-18', '89.206.64.19', '').
text_drs_eval(0, 3572, 'For every man the man likes himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/3])=>drs([B], [predicate(B, like, A, A)-1/6])]), [[specification, [top_s, [topic, [quant, for], [np, [det, every], [nbar, [n, man]]]], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, likes], [np, [pn, himself]]]]]]], '.']], '2009-11-12-23-58-32', '84.74.139.220', '').
text_drs_eval(0, 3573, 'For all men he likes himself.', drs([], []), [[specification, [top_s, [topic, [quant, for], [np, [det, all], [nbar, [n, men]]]], [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, likes], [np, [pn, himself]]]]]]], '.']], '2009-11-12-23-59-11', '84.74.139.220', '').
text_drs_eval(0, 3574, 'For every man he likes himself.', drs([], [drs([A], [object(A, man, countable, na, eq, 1)-1/3])=>drs([B], [predicate(B, like, A, A)-1/5])]), [[specification, [top_s, [topic, [quant, for], [np, [det, every], [nbar, [n, man]]]], [s, [np, [pn, he]], [vp, [vbar, [vcompl, [v, likes], [np, [pn, himself]]]]]]], '.']], '2009-11-12-23-59-26', '84.74.139.220', '').
text_drs_eval(0, 3575, 'John sees the cat that likes the cat that smiles.', drs([A, B, C, D, E], [predicate(C, like, B, D)-1/6, object(B, cat, countable, na, eq, 1)-1/4, predicate(A, see, named('John'), B)-1/2, predicate(E, smile, D)-1/10, object(D, cat, countable, na, eq, 1)-1/8]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, cat], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, smiles]]]]]]]]]]]]]]]]], '.']], '2009-11-13-00-01-29', '84.74.139.220', '').
text_drs_eval(0, 3576, 'Every man v:giiives a cat is Mary.', drs([], []), [], '2010-01-18-15-20-04', '84.72.61.127', '').
text_drs_eval(0, 3577, 'X is Y and X is Y and X is Y and X is Y and X is.', drs([], []), [], '2010-01-18-19-24-06', '84.72.61.127', '').
text_drs_eval(0, 3578, 'X is Y and X is Y and X is Y and X is Y and X is Y and X is Y and X is Y and X is Y and X is.', drs([], []), [], '2010-01-19-12-16-53', '130.60.155.218', '').
text_drs_eval(0, 3579, 'If p:String-To-Be-Parsed starts with X1 and X1 is "drs" and\nX1 v:immediately-precedes X2 and X2 is "(" and\nX2 v:immediately-precedes X3 and X3 is Y and\nX3 v:immediately-precedes X4 and X4 is "," and\nX4 v:immediately-precedes X5 and X5 is Z and\nX5 v:immediately-precedes X6 and X6 is ")" and\nand Y is a n:domain-definition and Z is a n:conditions-definition \nthen p:String-To-Be-Parsed must be a n:drs-definition.', drs([], []), [], '2010-01-19-13-55-46', '84.74.136.164', '').
text_drs_eval(0, 3580, 'If p:String-To-Be-Parsed starts with X1 and X1 is "drs" and\nX1 v:immediately-precedes X2 and X2 is "(" and\nX2 v:immediately-precedes X3 and X3 is Y and\nX3 v:immediately-precedes X4 and X4 is "," and\nX4 v:immediately-precedes X5 and X5 is Z and\nX5 v:immediately-precedes X6 and X6 is ")" and\nY is a n:domain-definition and Z is a n:conditions-definition \nthen p:String-To-Be-Parsed must be a n:drs-definition.', drs([], [drs([A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X], [object(A, something, dom, na, na, na)-1/7, predicate(B, start, named('String-To-Be-Parsed'))-1/5, modifier_pp(B, with, A)-1/6, predicate(C, be, A, string(drs))-1/10, object(D, something, dom, na, na, na)-1/17, predicate(E, 'immediately-precedes', A, D)-1/16, predicate(F, be, D, string('('))-1/20, object(G, something, dom, na, na, na)-1/27, predicate(H, 'immediately-precedes', D, G)-1/26, object(I, something, dom, na, na, na)-1/31, predicate(J, be, G, I)-1/30, object(K, something, dom, na, na, na)-1/37, predicate(L, 'immediately-precedes', G, K)-1/36, predicate(M, be, K, string(','))-1/40, object(N, something, dom, na, na, na)-1/47, predicate(O, 'immediately-precedes', K, N)-1/46, object(P, something, dom, na, na, na)-1/51, predicate(Q, be, N, P)-1/50, object(R, something, dom, na, na, na)-1/57, predicate(S, 'immediately-precedes', N, R)-1/56, predicate(T, be, R, string(')'))-1/60, object(U, 'domain-definition', countable, na, eq, 1)-1/68, predicate(V, be, I, U)-1/64, object(W, 'conditions-definition', countable, na, eq, 1)-1/75, predicate(X, be, P, W)-1/71])=>drs([], [must(drs([Y, Z], [object(Y, 'drs-definition', countable, na, eq, 1)-1/85, predicate(Z, be, named('String-To-Be-Parsed'), Y)-1/80]))])]), [[specification, [cond_s, if, [s_coord, [s, [np, [pname, 'String-To-Be-Parsed']], [vp, [vbar, [vbar, [v, starts]], [vmod, [pp, [prep, with], [np, [var, 'X1']]]]]]], [coord, and], [s, [np, [var, 'X1']], [vp, [aux, is], [np, [string, '"drs"']]]], [coord, and], [s, [np, [var, 'X1']], [vp, [vbar, [vcompl, [v, 'immediately-precedes'], [np, [var, 'X2']]]]]], [coord, and], [s, [np, [var, 'X2']], [vp, [aux, is], [np, [string, '"("']]]], [coord, and], [s, [np, [var, 'X2']], [vp, [vbar, [vcompl, [v, 'immediately-precedes'], [np, [var, 'X3']]]]]], [coord, and], [s, [np, [var, 'X3']], [vp, [aux, is], [np, [var, 'Y']]]], [coord, and], [s, [np, [var, 'X3']], [vp, [vbar, [vcompl, [v, 'immediately-precedes'], [np, [var, 'X4']]]]]], [coord, and], [s, [np, [var, 'X4']], [vp, [aux, is], [np, [string, '","']]]], [coord, and], [s, [np, [var, 'X4']], [vp, [vbar, [vcompl, [v, 'immediately-precedes'], [np, [var, 'X5']]]]]], [coord, and], [s, [np, [var, 'X5']], [vp, [aux, is], [np, [var, 'Z']]]], [coord, and], [s, [np, [var, 'X5']], [vp, [vbar, [vcompl, [v, 'immediately-precedes'], [np, [var, 'X6']]]]]], [coord, and], [s, [np, [var, 'X6']], [vp, [aux, is], [np, [string, '")"']]]], [coord, and], [s, [np, [var, 'Y']], [vp, [aux, is], [np, [det, a], [nbar, [n, 'domain-definition']]]]], [coord, and], [s, [np, [var, 'Z']], [vp, [aux, is], [np, [det, a], [nbar, [n, 'conditions-definition']]]]]], then, [s, [np, [pname, 'String-To-Be-Parsed']], [vp, [aux, must, be], [np, [det, a], [nbar, [n, 'drs-definition']]]]]], '.']], '2010-11-12-09-02-13', '89.206.69.32', '').
text_drs_eval(0, 3581, 'John says "Mary \\/ says \\"John is lazy!\\" \\\\".', drs([A], [predicate(A, say, named('John'), string('Mary / says "John is lazy!" \\'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, says], [np, [string, '"', 'Mary / says "John is lazy!" \\', '"']]]]]], '.']], '2010-02-13-06-26-30', '89.206.64.6', '').
text_drs_eval(0, 3582, 'A c-comment is "a/*comment*/b".', drs([], []), [], '2011-06-21-13-37-47', '91.176.78.60', '').
text_drs_eval(0, 3583, 'A man waits. /* This is a C-comment that ends with */', drs([A, B], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, wait, A)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2010-03-25-01-10-45', '186.124.170.206', '').
text_drs_eval(1, 3584, 'A man waits. /* This is a C-comment that ends with end_of_file', drs([A, B], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, wait, A)-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2010-03-27-21-32-12', '186.109.191.199', 'Error message should be returned for the missing */').
text_drs_eval(0, 3585, '"\\1" represents 1.', drs([A], [predicate(A, represent, string('1'), int(1))-1/2]), [[specification, [s, [np, [string, '"1"']], [vp, [vbar, [vcompl, [v, represents], [np, [int, 1]]]]]], '.']], '2010-11-12-09-14-50', '89.206.69.32', '').
text_drs_eval(0, 3586, '/* ... /* ... */ Every comment ends with "*/".', drs([], [drs([A], [object(A, comment, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, end, A)-1/3, modifier_pp(B, with, string(*/))-1/4])]), [[specification, [s, [np, [det, every], [nbar, [n, comment]]], [vp, [vbar, [vbar, [v, ends]], [vmod, [pp, [prep, with], [np, [string, '"*/"']]]]]]], '.']], '2011-06-21-13-33-15', '91.176.78.60', '').
text_drs_eval(0, 3587, '/* ... /* ... */ John waits.', drs([A], [predicate(A, wait, named('John'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2010-03-25-01-36-53', '186.124.170.206', '').
text_drs_eval(0, 3588, 'Every dot is ".".', drs([], [drs([A], [object(A, dot, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, be, A, string('.'))-1/3])]), [[specification, [s, [np, [det, every], [nbar, [n, dot]]], [vp, [aux, is], [np, [string, '"."']]]], '.']], '2011-06-21-13-33-37', '91.176.78.60', '').
text_drs_eval(0, 3589, '1 is not 0.5. 1 is bigger.', drs([A, B], [-drs([C], [predicate(C, be, int(1), real(0.5))-1/2]), property(A, big, comp)-2/3, predicate(B, be, int(1), A)-2/2]), [[specification, [s, [np, [int, 1]], [vp, [aux, is, not], [np, [real, 0.5]]]], '.'], [specification, [s, [np, [int, 1]], [vp, [aux, is], [ap_coord, [ap, [adj, bigger]]]]], '.']], '2010-03-26-23-42-42', '190.138.40.240', '').
text_drs_eval(0, 3590, '1 is not 0.5.1 is bigger.', drs([A, B], [-drs([C], [predicate(C, be, int(1), real(0.5))-1/2]), property(A, big, comp)-2/3, predicate(B, be, int(1), A)-2/2]), [[specification, [s, [np, [int, 1]], [vp, [aux, is, not], [np, [real, 0.5]]]], '.'], [specification, [s, [np, [int, 1]], [vp, [aux, is], [ap_coord, [ap, [adj, bigger]]]]], '.']], '2011-06-21-13-34-18', '91.176.78.60', '').
text_drs_eval(1, 3591, '/*', drs([], []), [], '2010-03-26-23-44-58', '190.138.40.240', 'This is an error: every C-comment must be closed with the \'*/\' symbol.').
text_drs_eval(0, 3592, '-0.5 = -.5.', drs([], []), [], '2010-03-28-06-13-08', '190.31.253.75', '').
text_drs_eval(1, 3593, 'If a rectangle R has a length L1 and R has a length L2 then R v:has-surface S, and S = L1 * L2.', drs([], [drs([A, B, C, D, E], [object(A, rectangle, countable, na, eq, 1)-1/3, object(B, length, countable, na, eq, 1)-1/7, predicate(C, have, A, B)-1/5, object(D, length, countable, na, eq, 1)-1/13, predicate(E, have, A, D)-1/11])=>drs([F, G], [object(F, something, dom, na, na, na)-1/20, predicate(G, 'has-surface', A, F)-1/19, formula(F, =, expr(*, B, D))-1/24])]), [[specification, [cond_s, if, [s_coord, [s, [np, [det, a], [nbar, [n, rectangle], [appos, [var, 'R']]]], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, length], [appos, [var, 'L1']]]]]]]], [coord, and], [s, [np, [var, 'R']], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, length], [appos, [var, 'L2']]]]]]]]], then, [s_coord, [s, [np, [var, 'R']], [vp, [vbar, [vcompl, [v, 'has-surface'], [np, [var, 'S']]]]]], [coord, ', and'], [formula, [var, 'S'], =, [expr, [var, 'L1'], [var, 'L2']]]]], '.']], '2010-06-11-07-31-19', '58.9.188.107', 'Paraphrase incorrect (`then\' missing)').
text_drs_eval(0, 3594, 'There is nothing X such that X waits.', drs([A, B], [-drs([C], [object(C, something, dom, na, na, na)-1/4]), object(A, something, dom, na, na, na)-1/8, predicate(B, wait, A)-1/9]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [pn, nothing], [appos, [var, 'X']]]], [conj, 'such that'], [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, waits]]]]]], '.']], '2013-08-15-17-45-25', '89.206.118.100', '').
text_drs_eval(0, 3595, 'John gives something to somebody.', drs([A, B, C], [object(A, something, dom, na, na, na)-1/4, object(B, somebody, countable, na, eq, 1)-1/7, predicate(C, give, named('John'), A, B)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, gives], [np, [pn, something]], [prep, to], [np, [pn, somebody]]]]]], '.']], '2011-06-21-13-53-53', '91.176.78.60', '').
text_drs_eval(0, 3596, 'Pi = 3.14. Pi is not 3.14.', drs([], [formula(named('Pi'), =, real(3.14))-1/2, -drs([A], [predicate(A, be, named('Pi'), real(3.14))-2/2])]), [[specification, [formula, [pname, 'Pi'], =, [real, 3.14]], '.'], [specification, [s, [np, [pname, 'Pi']], [vp, [aux, is, not], [np, [real, 3.14]]]], '.']], '2013-08-15-18-06-12', '89.206.118.100', '').
text_drs_eval(1, 3597, 'p:X1 is a card. p:X2 is a card. p:X3 is a card.', drs([A, B, C, D, E, F], [object(A, card, countable, na, eq, 1)-1/6, predicate(B, be, named('X1'), A)-1/4, object(C, card, countable, na, eq, 1)-2/6, predicate(D, be, named('X2'), C)-2/4, object(E, card, countable, na, eq, 1)-3/6, predicate(F, be, named('X3'), E)-3/4]), [[specification, [s, [np, [pname, 'X1']], [vp, [aux, is], [np, [det, a], [nbar, [n, card]]]]], '.'], [specification, [s, [np, [pname, 'X2']], [vp, [aux, is], [np, [det, a], [nbar, [n, card]]]]], '.'], [specification, [s, [np, [pname, 'X3']], [vp, [aux, is], [np, [det, a], [nbar, [n, card]]]]], '.']], '2010-07-22-16-13-07', '113.170.8.161', 'Paraphrase is incorrect: propernames are translated into variables.').
text_drs_eval(0, 3598, 'Pi = 3.14.\n\nIf there is a circle C and C\'s radius is R and C\'s area is S then S = Pi * (R * R).\n\nThere is a circle C whose radius is 5. What is C\'s surface?', drs([A, B, C], [formula(named('Pi'), =, real(3.14))-1/2, drs([D, E, F, G, H, I, J], [object(D, circle, countable, na, eq, 1)-2/5, relation(E, of, D)-2/9, object(E, radius, countable, na, eq, 1)-2/11, object(F, something, dom, na, na, na)-2/13, predicate(G, be, E, F)-2/12, relation(H, of, D)-2/16, object(H, area, countable, na, eq, 1)-2/18, object(I, something, dom, na, na, na)-2/20, predicate(J, be, H, I)-2/19])=>drs([], [formula(I, =, expr(*, named('Pi'), expr(*, F, F)))-2/23]), object(A, circle, countable, na, eq, 1)-3/4, object(B, radius, countable, na, eq, 1)-3/7, relation(B, of, A)-3/6, predicate(C, be, B, int(5))-3/8, question(drs([K, L, M], [query(K, what)-4/1, relation(L, of, A)-4/4, object(L, surface, countable, na, eq, 1)-4/6, predicate(M, be, K, L)-4/2]))]), [[specification, [formula, [pname, 'Pi'], =, [real, 3.14]], '.'], [specification, [cond_s, if, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, circle], [appos, [var, 'C']]]]]], [coord, and], [s, [np, [poss_np, [var, 'C'], [gen_marker, '\'s']], [nbar, [n, radius]]], [vp, [aux, is], [np, [var, 'R']]]], [coord, and], [s, [np, [poss_np, [var, 'C'], [gen_marker, '\'s']], [nbar, [n, area]]], [vp, [aux, is], [np, [var, 'S']]]]], then, [formula, [var, 'S'], =, [expr, [pname, 'Pi'], [brackets, '(', [expr, [var, 'R'], [var, 'R']], ')']]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, circle], [appos, [var, 'C']], [rel_cl, [np, [posspn, whose], [nbar, [n, radius]]], [vp, [aux, is], [np, [int, 5]]]]]]]], '.'], [query, [question, [np, [qpn, what]], [vp, [aux, is], [np, [poss_np, [var, 'C'], [gen_marker, '\'s']], [nbar, [n, surface]]]]], ?]], '2010-07-23-04-36-53', '113.170.8.161', '').
text_drs_eval(1, 3599, 'Pi is 3.14.', drs([A], [predicate(A, be, named('Pi'), real(3.14))-1/2]), [[specification, [s, [np, [pname, 'Pi']], [vp, [aux, is], [np, [real, 3.14]]]], '.']], '2010-07-29-17-23-30', '183.80.112.53', 'OWL: don\'t create data property \'be\' in this case but rather make Pi into some sort of OWL data constant with value 3.14.').
text_drs_eval(1, 3600, 'If a teenager\'s age is X then X > 12 and X < 20.', drs([], [drs([A, B, C, D], [object(A, teenager, countable, na, eq, 1)-1/3, relation(B, of, A)-1/4, object(B, age, countable, na, eq, 1)-1/6, object(C, something, dom, na, na, na)-1/8, predicate(D, be, B, C)-1/7])=>drs([], [formula(C, >, int(12))-1/11, formula(C, <, int(20))-1/15])]), [[specification, [cond_s, if, [s, [np, [poss_np, [det, a], [nbar, [n, teenager]], [gen_marker, '\'s']], [nbar, [n, age]]], [vp, [aux, is], [np, [var, 'X']]]], then, [s_coord, [formula, [var, 'X'], >, [int, 12]], [coord, and], [formula, [var, 'X'], <, [int, 20]]]], '.']], '2010-07-29-17-29-54', '183.80.112.53', 'Try to invent a shorter form to express this. Also try to map this into OWL, rather than just SWRL.').
text_drs_eval(0, 3601, 'There is no man such that the man waits.', drs([A, B], [-drs([C], [object(C, man, countable, na, eq, 1)-1/4]), object(B, man, countable, na, eq, 1)-1/8, predicate(A, wait, B)-1/9]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, no], [nbar, [n, man]]]], [conj, 'such that'], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]], '.']], '2013-08-15-17-46-03', '89.206.118.100', '').
text_drs_eval(0, 3602, 'There are some men such that the men wait.', drs([A, B], [object(A, man, countable, na, geq, 2)-1/4, predicate(B, wait, A)-1/9]), [[specification, [top_s, [topic, [quant, 'there are'], [np, [det, some], [nbar, [n, men]]]], [conj, '{such that}'], [s, [np, [det, the], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]]], '.']], '2010-08-01-18-58-28', '118.103.176.12', '').
text_drs_eval(0, 3603, 'There are no men such that the men wait.', drs([], []), [], '2010-08-01-18-58-54', '118.103.176.12', '').
text_drs_eval(0, 3604, 'Less than 5 men drink less.', drs([A, B], [[modifier_adv(B, less, pos)-1/6, predicate(B, drink, A)-1/5, object(A, man, countable, na, less, 5)-1/4]]), [[specification, [s, [np, [nump, [genqu, 'less than'], 5], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, drink]], [vmod, [adv, less]]]]], '.']], '2010-08-11-18-01-30', '58.9.200.162', '').
text_drs_eval(0, 3605, 'If X gives Y Z then X hands Y Z.', drs([], [drs([A, B, C, D], [object(A, something, dom, na, na, na)-1/2, object(B, something, dom, na, na, na)-1/4, object(C, something, dom, na, na, na)-1/5, predicate(D, give, A, C, B)-1/3])=>drs([E], [predicate(E, hand, A, C, B)-1/8])]), [[specification, [cond_s, if, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, gives], [np, [var, 'Y']], [np, [var, 'Z']]]]]], then, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, hands], [np, [var, 'Y']], [np, [var, 'Z']]]]]]], '.']], '2010-08-11-18-02-48', '58.9.200.162', '').
text_drs_eval(0, 3606, 'For everything X if X gives Y Z then X hands Y Z.', drs([], [drs([A], [object(A, something, dom, na, na, na)-1/3])=>drs([], [drs([B, C, D], [object(B, something, dom, na, na, na)-1/8, object(C, something, dom, na, na, na)-1/9, predicate(D, give, A, C, B)-1/7])=>drs([E], [predicate(E, hand, A, C, B)-1/12])])]), [[specification, [top_s, [topic, [quant, for], [np, [pn, everything], [appos, [var, 'X']]]], [cond_s, if, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, gives], [np, [var, 'Y']], [np, [var, 'Z']]]]]], then, [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, hands], [np, [var, 'Y']], [np, [var, 'Z']]]]]]]], '.']], '2010-08-11-18-04-17', '58.9.200.162', '').
text_drs_eval(0, 3607, 'John likes Mary a dog of his own friend hates a cat.', drs([], []), [], '2010-10-25-10-10-08', '130.60.156.167', '').
text_drs_eval(0, 3608, 'John likes Mary a dog of her own friend hates a cat.', drs([], []), [], '2010-10-25-10-10-16', '130.60.156.167', '').
text_drs_eval(0, 3609, 'John likes Mary a dog of his friend hates a cat.', drs([], []), [], '2010-10-25-10-10-24', '130.60.156.167', '').
text_drs_eval(0, 3610, 'John likes Mary a dog of her friend hates a cat.', drs([], []), [], '2010-10-25-10-11-26', '130.60.156.167', '').
text_drs_eval(0, 3611, 'John likes Mary a dog of its own friend hates a cat.', drs([], []), [], '2010-10-25-10-10-37', '130.60.156.167', '').
text_drs_eval(0, 3612, 'John likes Mary a dog of its friend hates a cat.', drs([], []), [], '2010-10-25-10-10-45', '130.60.156.167', '').
text_drs_eval(0, 3613, 'John likes Mary a dog of who hates a cat.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/5, relation(A, of, named('Mary'))-1/6, object(B, cat, countable, na, eq, 1)-1/10, predicate(C, hate, A, B)-1/8, predicate(D, like, named('John'), named('Mary'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary'], [rel_cl, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [relpn, who]]]]], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]], '.']], '2010-10-25-09-14-53', '130.60.156.167', '').
text_drs_eval(0, 3614, 'John likes Mary a dog of a friend of who hates a cat.', drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1/5, object(B, friend, countable, na, eq, 1)-1/8, relation(B, of, named('Mary'))-1/9, relation(A, of, B)-1/6, object(C, cat, countable, na, eq, 1)-1/13, predicate(D, hate, A, C)-1/11, predicate(E, like, named('John'), named('Mary'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary'], [rel_cl, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, friend], [pp, [prep, of], [np, [relpn, who]]]]]]]], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]], '.']], '2010-10-25-09-15-39', '130.60.156.167', '').
text_drs_eval(0, 3615, 'John a dog of a friend of who hates a cat likes Mary.', drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1/3, object(B, friend, countable, na, eq, 1)-1/6, relation(B, of, named('John'))-1/7, relation(A, of, B)-1/4, object(C, cat, countable, na, eq, 1)-1/11, predicate(D, hate, A, C)-1/9, predicate(E, like, named('John'), named('Mary'))-1/12]), [[specification, [s, [np, [pname, 'John'], [rel_cl, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, friend], [pp, [prep, of], [np, [relpn, who]]]]]]]], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat]]]]]]]], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary']]]]]], '.']], '2010-10-25-09-16-58', '130.60.156.167', '').
text_drs_eval(0, 3616, 'John likes Mary a dog of whose friend hates a cat.', drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1/5, object(B, friend, countable, na, eq, 1)-1/8, relation(B, of, named('Mary'))-1/7, relation(A, of, B)-1/6, object(C, cat, countable, na, eq, 1)-1/11, predicate(D, hate, A, C)-1/9, predicate(E, like, named('John'), named('Mary'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary'], [rel_cl, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [posspn, whose], [nbar, [n, friend]]]]]], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]], '.']], '2010-10-25-09-27-14', '130.60.156.167', '').
text_drs_eval(0, 3617, 'John likes Mary a dog of whose friends hates a cat.', drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1/5, object(B, friend, countable, na, geq, 2)-1/8, relation(B, of, named('Mary'))-1/7, relation(A, of, B)-1/6, object(C, cat, countable, na, eq, 1)-1/11, predicate(D, hate, A, C)-1/9, predicate(E, like, named('John'), named('Mary'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Mary'], [rel_cl, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [posspn, whose], [nbar, [n, friends]]]]]], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]], '.']], '2010-10-25-09-27-47', '130.60.156.167', '').
text_drs_eval(0, 3618, 'John likes Foo a dog of which hates a cat.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/5, relation(A, of, named('Foo'))-1/6, object(B, cat, countable, na, eq, 1)-1/10, predicate(C, hate, A, B)-1/8, predicate(D, like, named('John'), named('Foo'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, likes], [np, [pname, 'Foo'], [rel_cl, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [relpn, which]]]]], [vp, [vbar, [vcompl, [v, hates], [np, [det, a], [nbar, [n, cat]]]]]]]]]]]], '.']], '2010-10-25-09-30-11', '130.60.156.167', '').
text_drs_eval(0, 3619, 'John likes Foo a dog of which friend hates a cat.', drs([], []), [], '2010-10-25-09-30-40', '130.60.156.167', '').
text_drs_eval(0, 3620, 'f there is a man then it is necessary that a human is the man.', drs([], []), [], '2010-10-27-09-27-06', '89.206.64.27', '').
text_drs_eval(0, 3621, 'A dog of who sleeps?', drs([], [question(drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1/2, query(B, who)-1/4, relation(A, of, B)-1/3, predicate(C, sleep, A)-1/5]))]), [[query, [question, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [qpn, who]]]]], [vp, [vbar, [vbar, [v, sleeps]]]]], ?]], '2010-11-08-14-10-47', '85.253.72.12', '').
text_drs_eval(0, 3622, 'Every period is ".".', drs([], [drs([A], [object(A, period, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, be, A, string('.'))-1/3])]), [[specification, [s, [np, [det, every], [nbar, [n, period]]], [vp, [aux, is], [np, [string, '"."']]]], '.']], '2010-11-12-09-02-44', '89.206.69.32', '').
text_drs_eval(0, 3623, '"." and "?" and "!" are three special characters.', drs([A, B, C], [has_part(C, string('.'))-1/'', object(A, character, countable, na, eq, 3)-1/9, property(A, special, pos)-1/8, predicate(B, be, C, A)-1/6, has_part(C, string(?))-1/'', has_part(C, string(!))-1/'', object(C, na, countable, na, eq, 3)-1/'']), [[specification, [s, [np_coord, [np, [string, '"."']], [coord, and], [np, [string, '"?"']], [coord, and], [np, [string, '"!"']]], [vp, [aux, are], [np, [nump, three], [nbar, [adj, special], [nbar, [n, characters]]]]]], '.']], '2010-11-12-09-03-33', '89.206.69.32', '').
text_drs_eval(0, 3624, 'John is "\\"John".', drs([A], [predicate(A, be, named('John'), string('"John'))-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [string, '""John"']]]], '.']], '2010-11-12-15-06-00', '86.101.31.19', '').
text_drs_eval(0, 3625, '`John"` is John.', drs([A], [predicate(A, be, named('John"'), named('John'))-1/2]), [[specification, [s, [np, [pname, 'John"']], [vp, [aux, is], [np, [pname, 'John']]]], '.']], '2010-11-12-15-52-33', '89.206.65.189', '').
text_drs_eval(0, 3626, 'John\'s good friend is Bill.', drs([A, B], [relation(A, of, named('John'))-1/2, object(A, friend, countable, na, eq, 1)-1/5, property(A, good, pos)-1/4, predicate(B, be, A, named('Bill'))-1/6]), [[specification, [s, [np, [poss_np, [pname, 'John'], [gen_marker, '\'s']], [nbar, [adj, good], [nbar, [n, friend]]]], [vp, [aux, is], [np, [pname, 'Bill']]]], '.']], '2010-11-16-16-22-12', '89.206.70.100', '').
text_drs_eval(0, 3627, 'A man\'s good friend is Bill.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, relation(B, of, A)-1/3, object(B, friend, countable, na, eq, 1)-1/6, property(B, good, pos)-1/5, predicate(C, be, B, named('Bill'))-1/7]), [[specification, [s, [np, [poss_np, [det, a], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [adj, good], [nbar, [n, friend]]]], [vp, [aux, is], [np, [pname, 'Bill']]]], '.']], '2010-11-16-16-22-25', '89.206.70.100', '').
text_drs_eval(0, 3628, 'There is a man whose good friend is Bill.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/4, object(B, friend, countable, na, eq, 1)-1/7, property(B, good, pos)-1/6, relation(B, of, A)-1/5, predicate(C, be, B, named('Bill'))-1/8]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [adj, good], [nbar, [n, friend]]]], [vp, [aux, is], [np, [pname, 'Bill']]]]]]]], '.']], '2010-11-16-16-22-57', '89.206.70.100', '').
text_drs_eval(0, 3629, 'A string is "/* comment */".', drs([A, B], [object(A, string, countable, na, eq, 1)-1/2, predicate(B, be, A, string('/* comment */'))-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, string]]], [vp, [aux, is], [np, [string, '"/* comment */"']]]], '.']], '2010-11-22-01-05-57', '86.101.31.19', '').
text_drs_eval(0, 3630, 'A string is "#".', drs([A, B], [object(A, string, countable, na, eq, 1)-1/2, predicate(B, be, A, string(#))-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, string]]], [vp, [aux, is], [np, [string, '"#"']]]], '.']], '2010-11-22-01-06-30', '86.101.31.19', '').
text_drs_eval(0, 3631, '"#" is not "/**/".', drs([], [-drs([A], [predicate(A, be, string(#), string('/**/'))-1/2])]), [[specification, [s, [np, [string, '"#"']], [vp, [aux, is, not], [np, [string, '"/**/"']]]], '.']], '2010-11-22-01-08-03', '86.101.31.19', '').
text_drs_eval(0, 3632, '"" is /* "/**/"".', drs([A], [predicate(A, be, string(''), string(''))-1/2]), [[specification, [s, [np, [string, '""']], [vp, [aux, is], [np, [string, '""']]]], '.']], '2010-11-22-01-09-12', '86.101.31.19', '').
text_drs_eval(0, 3633, 'X=X.', drs([A], [object(A, something, dom, na, na, na)-1/1, formula(A, =, A)-1/2]), [[specification, [formula, [var, 'X'], =, [var, 'X']], '.']], '2010-11-22-01-10-33', '86.101.31.19', '').
text_drs_eval(1, 3634, 'There is a %man.', drs([A], [object(A, man, countable, na, eq, 1)-1/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.']], '2010-11-23-01-53-27', '86.101.31.19', 'The percent sign is ignored.').
text_drs_eval(1, 3635, 'There is%%%a man.', drs([A], [object(A, man, countable, na, eq, 1)-1/4]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.']], '2010-11-23-01-53-56', '86.101.31.19', 'The percent signs are ignored.').
text_drs_eval(0, 3636, 'for every woman of who everybody waits.', drs([], []), [], '2011-07-20-11-41-30', '89.206.65.171', '').
text_drs_eval(0, 3637, 'for every friend of who Mary asks a woman.', drs([], []), [], '2011-07-20-11-41-56', '89.206.65.171', '').
text_drs_eval(0, 3638, 'For everything of X X waits.', drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1/3, object(B, something, dom, na, na, na)-1/5, relation(A, of, B)-1/4])=>drs([C], [predicate(C, wait, B)-1/7])]), [[specification, [top_s, [topic, [quant, for], [np, [pn, everything], [pp, [prep, of], [np, [var, 'X']]]]], [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, waits]]]]]], '.']], '2010-11-26-15-40-13', '89.206.68.244', '').
text_drs_eval(1, 3639, 'For everything of X who waits?', drs([], [question(drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1/3, object(B, something, dom, na, na, na)-1/5, relation(A, of, B)-1/4])=>drs([C, D], [query(C, who)-1/6, predicate(D, wait, C)-1/7])]))]), [[query, [topicalised_question, [topic, [quant, for], [np, [pn, everything], [pp, [prep, of], [np, [var, 'X']]]]], [question, [np, [qpn, who]], [vp, [vbar, [vbar, [v, waits]]]]]], ?]], '2010-11-26-15-48-16', '89.206.68.244', 'think about it').
text_drs_eval(1, 3640, 'For everything of who X waits?', drs([], []), [], '2010-11-26-15-48-40', '89.206.68.244', 'think about it').
text_drs_eval(0, 3641, 'John is everything of who?', drs([], [question(drs([], [drs([A, B], [object(A, something, dom, na, na, na)-1/4, query(B, who)-1/6, relation(A, of, B)-1/5])=>drs([C], [predicate(C, be, named('John'), A)-1/2])]))]), [[query, [question, [np, [pname, 'John']], [vp, [aux, is], [np, [pn, everything], [pp, [prep, of], [np, [qpn, who]]]]]], ?]], '2010-11-26-20-30-48', '86.101.31.19', '').
text_drs_eval(0, 3642, 'Every card the code of which is correct is valid.', drs([], [drs([A, B, C, D], [object(A, card, countable, na, eq, 1)-1/2, relation(D, of, A)-1/5, object(D, code, countable, na, eq, 1)-1/4, property(B, correct, pos)-1/8, predicate(C, be, D, B)-1/7])=>drs([E, F], [property(E, valid, pos)-1/10, predicate(F, be, A, E)-1/9])]), [[specification, [s, [np, [det, every], [nbar, [n, card], [rel_cl, [np, [det, the], [nbar, [n, code], [pp, [prep, of], [np, [relpn, which]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, correct]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], '.']], '2013-08-15-18-04-08', '89.206.118.100', '').
text_drs_eval(0, 3643, 'There is a code of a card. Every card the code of which is correct is valid.', drs([A, B], [object(A, code, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, relation(A, of, B)-1/5, drs([C, D, E], [object(C, card, countable, na, eq, 1)-2/2, property(D, correct, pos)-2/8, predicate(E, be, A, D)-2/7])=>drs([F, G], [property(F, valid, pos)-2/10, predicate(G, be, C, F)-2/9])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]]]], '.'], [specification, [s, [np, [det, every], [nbar, [n, card], [rel_cl, [np, [det, the], [nbar, [n, code], [pp, [prep, of], [np, [relpn, which]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, correct]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], '.']], '2013-08-15-18-05-46', '89.206.118.100', '').
text_drs_eval(0, 3644, 'There is a code of a card. If the code of a card is correct then the card is valid.', drs([A, B], [object(A, code, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, relation(A, of, B)-1/5, drs([C, D], [property(C, correct, pos)-2/8, predicate(D, be, A, C)-2/7])=>drs([E, F], [property(E, valid, pos)-2/13, predicate(F, be, B, E)-2/12])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]]]], '.'], [specification, [cond_s, if, [s, [np, [det, the], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, correct]]]]], then, [s, [np, [det, the], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]], '.']], '2010-12-21-11-05-34', '82.131.74.36', '').
text_drs_eval(0, 3645, 'There is a code of a card. The code of a card is correct. The card is valid.', drs([A, B, C, D, E, F], [object(A, code, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, relation(A, of, B)-1/5, property(C, correct, pos)-2/7, predicate(D, be, A, C)-2/6, property(E, valid, pos)-3/4, predicate(F, be, B, E)-3/3]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, correct]]]]], '.'], [specification, [s, [np, [det, the], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], '.']], '2010-12-21-11-06-11', '82.131.74.36', '').
text_drs_eval(0, 3646, 'There is a code of a card. Every card whose code is correct is valid.', drs([A, B], [object(A, code, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, relation(A, of, B)-1/5, drs([C, D, E, F], [object(C, card, countable, na, eq, 1)-2/2, object(D, code, countable, na, eq, 1)-2/4, relation(D, of, C)-2/3, property(E, correct, pos)-2/6, predicate(F, be, D, E)-2/5])=>drs([G, H], [property(G, valid, pos)-2/8, predicate(H, be, C, G)-2/7])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]]]], '.'], [specification, [s, [np, [det, every], [nbar, [n, card], [rel_cl, [np, [posspn, whose], [nbar, [n, code]]], [vp, [aux, is], [ap_coord, [ap, [adj, correct]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], '.']], '2010-12-21-11-07-49', '82.131.74.36', '').
text_drs_eval(0, 3647, 'There is a code of a card. Every card a code of which is correct is valid.', drs([A, B], [object(A, code, countable, na, eq, 1)-1/4, object(B, card, countable, na, eq, 1)-1/7, relation(A, of, B)-1/5, drs([C, D, E, F], [object(C, card, countable, na, eq, 1)-2/2, object(D, code, countable, na, eq, 1)-2/4, relation(D, of, C)-2/5, property(E, correct, pos)-2/8, predicate(F, be, D, E)-2/7])=>drs([G, H], [property(G, valid, pos)-2/10, predicate(H, be, C, G)-2/9])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [det, a], [nbar, [n, card]]]]]]]], '.'], [specification, [s, [np, [det, every], [nbar, [n, card], [rel_cl, [np, [det, a], [nbar, [n, code], [pp, [prep, of], [np, [relpn, which]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, correct]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], '.']], '2010-12-21-11-12-57', '82.131.74.36', '').
text_drs_eval(1, 3648, 'There is a man\'s friend who is rich. The man\'s friend who is rich waits.', drs([A, B, C, D, E, F, G, H], [object(A, man, countable, na, eq, 1)-1/4, relation(B, of, A)-1/5, object(B, friend, countable, na, eq, 1)-1/7, property(C, rich, pos)-1/10, predicate(D, be, B, C)-1/9, relation(E, of, A)-2/3, object(E, friend, countable, na, eq, 1)-2/5, property(F, rich, pos)-2/8, predicate(G, be, E, F)-2/7, predicate(H, wait, E)-2/9]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [poss_np, [det, a], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, friend], [rel_cl, [np, [relpn, who]], [vp, [aux, is], [ap_coord, [ap, [adj, rich]]]]]]]]], '.'], [specification, [s, [np, [poss_np, [det, the], [nbar, [n, man]], [gen_marker, '\'s']], [nbar, [n, friend], [rel_cl, [np, [relpn, who]], [vp, [aux, is], [ap_coord, [ap, [adj, rich]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2010-12-21-11-44-31', '82.131.74.36', 'Should we have one friend here?').
text_drs_eval(1, 3649, 'There is X that waits.', drs([], []), [], '2010-12-27-16-01-28', '82.131.73.12', 'Wrong error message.').
text_drs_eval(0, 3650, 'X eats. X drinks.', drs([A, B, C], [object(A, something, dom, na, na, na)-1/1, predicate(B, eat, A)-1/2, predicate(C, drink, A)-2/2]), [[specification, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, eats]]]]], '.'], [specification, [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, drinks]]]]], '.']], '2010-12-27-16-02-43', '82.131.73.12', '').
text_drs_eval(1, 3651, 'John v:dummy an apple between Mary.', drs([A, B], [object(A, apple, countable, na, eq, 1)-1/6, predicate(B, dummy, named('John'), A, named('Mary'))-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, dummy], [np, [det, an], [nbar, [n, apple]]], [prep, between], [np, [pname, 'Mary']]]]]], '.']], '2011-01-04-13-21-23', '78.23.89.41', '\'between\' gets lost in the DRS (because it is considered a transitive verb phrase preposition), bug or feature?').
text_drs_eval(0, 3652, 'John, Mary!', drs([], []), [], '2011-07-20-09-51-01', '89.206.71.27', '').
text_drs_eval(1, 3653, 'John v:verb Mary and John sees Bill.', drs([A, B], [has_part(B, named('Mary'))-1/'', predicate(A, verb, named('John'), B, named('Bill'))-1/4, has_part(B, named('John'))-1/'', object(B, na, countable, na, eq, 2)-1/'']), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, verb], [np_coord, [np, [pname, 'Mary']], [coord, and], [np, [pname, 'John']]], [prep, sees], [np, [pname, 'Bill']]]]]], '.']], '2011-05-08-22-32-41', '91.176.13.34', '\'sees\' is interpreted as a particle of a ditransitive verb. The result is very confusing...').
text_drs_eval(1, 3654, 'John v:verb Mary sees Bill.', drs([A], [predicate(A, verb, named('John'), named('Mary'), named('Bill'))-1/4]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, verb], [np, [pname, 'Mary']], [prep, sees], [np, [pname, 'Bill']]]]]], '.']], '2011-05-08-22-52-02', '89.206.71.170', 'Should fail unless \'sees\' is registered as a preposition in the lexicon.').
text_drs_eval(1, 3655, 'There are 4 men G1.\nThere are 2 pianos G2.\nG1 lifts G2.', drs([], []), [[specification, [top_s, [topic, [quant, 'there are'], [np, [nump, 4], [nbar, [n, men], [appos, [var, 'G1']]]]]], '.'], [specification, [top_s, [topic, [quant, 'there are'], [np, [nump, 2], [nbar, [n, pianos], [appos, [var, 'G2']]]]]], '.'], [specification, [s, [np, [var, 'G1']], [vp, [vbar, [vcompl, [v, lifts], [np, [var, 'G2']]]]]], '.']], '2011-05-26-12-51-04', '91.176.178.97', 'Possibly confusing message: Redefined variable: G1 (because one must use a plural verb here)').
text_drs_eval(0, 3656, '"" = X.', drs([A], [object(A, something, dom, na, na, na)-1/3, formula(string(''), =, A)-1/2]), [[specification, [formula, [string, '""'], =, [var, 'X']], '.']], '2011-06-01-13-22-16', '91.176.130.231', '').
text_drs_eval(1, 3657, 'John meets xunknown. John is xunknown.', drs([A, B, C], [predicate(A, meet, named('John'))-1/2, modifier_adv(A, xunknown, pos)-1/5, property(B, xunknown, pos)-2/5, predicate(C, be, named('John'), B)-2/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, meets]], [vmod, [adv, xunknown]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [aux, is], [ap_coord, [ap, [adj, xunknown]]]]], '.']], '2011-06-03-00-10-20', '91.176.204.180', 'If guessing is used and \'xunknown\' is not in the lexicon then it is interpreted once as a propername and once as an adjective. There could be a tokenizer-mode which requires that the (unknown) prefix of unknown words is always the same, i.e. \'xunknown\' can only interpreted here as a propername.').
text_drs_eval(1, 3658, 'The a:textual n:serialization of an a:XML element is the concatenation of "<" and the name of the element and the a:textual n:serializations of the attributes of the element and ">" and the a:textual n:serialization of the sequence of children of the element and "</" and the name of the element and ">".', drs([], []), [], '2011-06-20-10-06-19', '91.176.235.248', 'It takes very long (28sec on i3) to find out that there is a missing determiner in front of \'children\'. Reported by Ken Jones.').
text_drs_eval(0, 3659, 'There is a man.\nJohn is the man and the man.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, the], [nbar, [n, man]]]]]], '.']], '2011-06-20-11-20-34', '91.176.235.248', '').
text_drs_eval(0, 3660, 'There is a man.\nJohn is the man and a man.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, has_part(D, A)-2/'', predicate(B, be, named('John'), D)-2/2, object(C, man, countable, na, eq, 1)-2/7, has_part(D, C)-2/'', object(D, na, countable, na, eq, 2)-2/'']), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, man]]]]]], '.']], '2011-06-20-11-21-02', '91.176.235.248', '').
text_drs_eval(0, 3661, 'There is a man.\nA group is the man and a dog of the man.', drs([A, B, C, D, E], [object(A, man, countable, na, eq, 1)-1/4, object(B, group, countable, na, eq, 1)-2/2, has_part(E, A)-2/'', predicate(C, be, B, E)-2/3, object(D, dog, countable, na, eq, 1)-2/8, relation(D, of, A)-2/9, has_part(E, D)-2/'', object(E, na, countable, na, eq, 2)-2/'']), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, group]]], [vp, [aux, is], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]]]]], '.']], '2011-06-20-11-26-31', '91.176.235.248', '').
text_drs_eval(0, 3662, 'There is a man.\nJohn is the man and a dog of the man.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/4, has_part(D, A)-2/'', predicate(B, be, named('John'), D)-2/2, object(C, dog, countable, na, eq, 1)-2/7, relation(C, of, A)-2/8, has_part(D, C)-2/'', object(D, na, countable, na, eq, 2)-2/'']), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]]]]], '.']], '2011-06-20-11-23-46', '91.176.235.248', '').
text_drs_eval(1, 3663, 'There is a man.\nA group is a dog of the man and the man.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, group]]], [vp, [aux, is], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, the], [nbar, [n, man]]]]]]]]], '.']], '2011-06-20-11-26-09', '91.176.235.248', 'Why is this an error? Error message is confusing. Changing the order of the conjunction elements removes the error. I think this is an unwanted feature.').
text_drs_eval(0, 3664, 'John is the name of the man and the name of the man.', drs([A, B, C, D, E], [object(E, na, countable, na, eq, 2)-1/'', has_part(E, C)-1/'', has_part(E, D)-1/'', relation(B, of, E)-1/5, object(B, name, countable, na, eq, 1)-1/4, predicate(A, be, named('John'), B)-1/2, relation(D, of, C)-1/11, object(D, name, countable, na, eq, 1)-1/10, object(C, man, countable, na, eq, 1)-1/13]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, the], [nbar, [n, name], [pp, [prep, of], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, the], [nbar, [n, name], [pp, [prep, of], [np, [det, the], [nbar, [n, man]]]]]]]]]]]], '.']], '2011-06-20-11-43-59', '91.176.235.248', '').
text_drs_eval(0, 3665, 'John is a name of a man and a name of a man.', drs([A, B, C, D, E, F], [object(A, name, countable, na, eq, 1)-1/4, object(B, man, countable, na, eq, 1)-1/7, has_part(E, B)-1/'', relation(A, of, E)-1/5, object(C, name, countable, na, eq, 1)-1/10, object(D, man, countable, na, eq, 1)-1/13, relation(C, of, D)-1/11, has_part(E, C)-1/'', object(E, na, countable, na, eq, 2)-1/'', predicate(F, be, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, name], [pp, [prep, of], [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, name], [pp, [prep, of], [np, [det, a], [nbar, [n, man]]]]]]]]]]]], '.']], '2011-06-20-11-44-59', '91.176.235.248', '').
text_drs_eval(0, 3666, 'There is a name.\nThere is a dog.\n"" is the name of the dog of a man and a woman.', drs([A, B, C, D, E, F, G, H], [object(A, name, countable, na, eq, 1)-1/4, object(B, dog, countable, na, eq, 1)-2/4, relation(D, of, E)-3/5, object(D, name, countable, na, eq, 1)-3/4, predicate(C, be, string(''), D)-3/2, object(H, na, countable, na, eq, 2)-3/'', has_part(H, G)-3/'', object(G, woman, countable, na, eq, 1)-3/13, relation(E, of, H)-3/8, has_part(H, F)-3/'', object(F, man, countable, na, eq, 1)-3/10, object(E, dog, countable, na, eq, 1)-3/7]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, name]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], '.'], [specification, [s, [np, [string, '""']], [vp, [aux, is], [np, [det, the], [nbar, [n, name], [pp, [prep, of], [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, woman]]]]]]]]]]]], '.']], '2011-07-22-17-47-05', '89.206.64.230', '').
text_drs_eval(0, 3667, '"Fido" is the name of the dog of a man and a woman.', drs([A, B, C, D, E, F], [relation(B, of, C)-1/5, object(B, name, countable, na, eq, 1)-1/4, predicate(A, be, string('Fido'), B)-1/2, object(F, na, countable, na, eq, 2)-1/'', has_part(F, E)-1/'', object(E, woman, countable, na, eq, 1)-1/13, relation(C, of, F)-1/8, has_part(F, D)-1/'', object(D, man, countable, na, eq, 1)-1/10, object(C, dog, countable, na, eq, 1)-1/7]), [[specification, [s, [np, [string, '"Fido"']], [vp, [aux, is], [np, [det, the], [nbar, [n, name], [pp, [prep, of], [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, woman]]]]]]]]]]]], '.']], '2011-07-20-10-07-13', '89.206.71.56', '').
text_drs_eval(0, 3668, 'There is the name of the dog of a man and a woman.', drs([], []), [], '2011-06-20-12-24-11', '91.176.235.248', '').
text_drs_eval(0, 3669, 'If\nthere is an element, and\nthere is a name N of the element, and\nthere is an n:attributes-serialization A of the element, and\nthere is a n:children-serialization C of the element\nthen\na n:serialization of the element is\n"<" & N & A & ">" & C & "</" & N & ">".', drs([], [drs([A, B, C, D], [object(A, element, countable, na, eq, 1)-1/5, object(B, name, countable, na, eq, 1)-1/11, relation(B, of, A)-1/13, object(C, 'attributes-serialization', countable, na, eq, 1)-1/23, relation(C, of, A)-1/25, object(D, 'children-serialization', countable, na, eq, 1)-1/35, relation(D, of, A)-1/37])=>drs([E, F], [object(E, serialization, countable, na, eq, 1)-1/44, relation(E, of, A)-1/45, predicate(F, be, E, expr(&, expr(&, expr(&, expr(&, expr(&, expr(&, expr(&, string(<), B), C), string(>)), D), string(</)), B), string(>)))-1/48])]), [[specification, [cond_s, if, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, element]]]]], [coord, ', and'], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, name], [appos, [var, 'N']], [pp, [prep, of], [np, [det, the], [nbar, [n, element]]]]]]]], [coord, ', and'], [top_s, [topic, [quant, 'there is'], [np, [det, an], [nbar, [n, 'attributes-serialization'], [appos, [var, 'A']], [pp, [prep, of], [np, [det, the], [nbar, [n, element]]]]]]]], [coord, ', and'], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, 'children-serialization'], [appos, [var, 'C']], [pp, [prep, of], [np, [det, the], [nbar, [n, element]]]]]]]]], then, [s, [np, [det, a], [nbar, [n, serialization], [pp, [prep, of], [np, [det, the], [nbar, [n, element]]]]]], [vp, [aux, is], [np, [expr, [expr, [expr, [expr, [expr, [expr, [expr, [string, '"<"'], [var, 'N']], [var, 'A']], [string, '">"']], [var, 'C']], [string, '"</"']], [var, 'N']], [string, '">"']]]]]], '.']], '2011-06-20-12-54-51', '91.176.235.248', '').
text_drs_eval(1, 3670, 'There is a dog of a man, and a woman.', drs([], []), [], '2011-06-20-13-34-32', '91.176.235.248', 'Feature request: support comma-and also in NP-conjunctions. This is a very natural extension which is easy to learn. In fact, learning that it is not allowed might be a bigger effort.').
text_drs_eval(0, 3671, 'There is a dog of a cat of a rat.', drs([A, B, C], [object(A, dog, countable, na, eq, 1)-1/4, object(B, cat, countable, na, eq, 1)-1/7, object(C, rat, countable, na, eq, 1)-1/10, relation(B, of, C)-1/8, relation(A, of, B)-1/5]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, cat], [pp, [prep, of], [np, [det, a], [nbar, [n, rat]]]]]]]]]]], '.']], '2011-06-20-14-54-02', '89.206.66.237', '').
text_drs_eval(0, 3672, 'There is a dog of a cat and a rat.', drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/4, object(B, cat, countable, na, eq, 1)-1/7, has_part(D, B)-1/'', relation(A, of, D)-1/5, object(C, rat, countable, na, eq, 1)-1/10, has_part(D, C)-1/'', object(D, na, countable, na, eq, 2)-1/'']), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np_coord, [np, [det, a], [nbar, [n, cat]]], [coord, and], [np, [det, a], [nbar, [n, rat]]]]]]]]], '.']], '2011-06-20-14-55-16', '89.206.66.237', '').
text_drs_eval(0, 3673, 'There is a dog and a cat of a rat.', drs([], []), [], '2011-06-20-15-01-49', '89.206.66.237', '').
text_drs_eval(0, 3674, 'A comment is "a/*comment*/b".', drs([A, B], [object(A, comment, countable, na, eq, 1)-1/2, predicate(B, be, A, string('a/*comment*/b'))-1/3]), [[specification, [s, [np, [det, a], [nbar, [n, comment]]], [vp, [aux, is], [np, [string, '"a/*comment*/b"']]]], '.']], '2011-06-21-13-38-03', '91.176.78.60', '').
text_drs_eval(1, 3675, 'A book is v:sent sees Mary by John.', drs([A, B], [object(A, book, countable, na, eq, 1)-1/2, predicate(B, sent, named('John'), A, named('Mary'))-1/6]), [[specification, [s, [np, [det, a], [nbar, [n, book]]], [vp, [aux, is], [vbar, [vcompl, [v, sent], [prep, sees], [np, [pname, 'Mary']], by, [np, [pname, 'John']]]]]], '.']], '2011-07-05-10-13-38', '89.206.66.80', 'Should fail. See also: John v:verb Mary sees Bill.').
text_drs_eval(0, 3676, 'A book is v:sent and Mary by John.', drs([], []), [], '2011-07-05-11-03-20', '89.206.66.80', '').
text_drs_eval(0, 3677, '0- -1 = 1.', drs([], [formula(expr(-, int(0), int(-1)), =, int(1))-1/5]), [[specification, [formula, [expr, [int, 0], [int, -1]], =, [int, 1]], '.']], '2011-07-07-12-44-19', '89.206.69.138', '').
text_drs_eval(0, 3678, '0--1 = 1.', drs([], []), [], '2011-07-07-12-44-30', '89.206.69.138', '').
text_drs_eval(0, 3679, 'John v:verb Mary and John and Bill.', drs([A, B], [has_part(B, named('Mary'))-1/'', predicate(A, verb, named('John'), B)-1/4, has_part(B, named('John'))-1/'', has_part(B, named('Bill'))-1/'', object(B, na, countable, na, eq, 3)-1/'']), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, verb], [np_coord, [np, [pname, 'Mary']], [coord, and], [np, [pname, 'John']], [coord, and], [np, [pname, 'Bill']]]]]]], '.']], '2011-07-18-18-49-38', '89.206.68.117', '').
text_drs_eval(0, 3680, 'Bill is a:_ to Mary by John.', drs([A, B], [property(A, '_', pos)-1/5, predicate(B, be, named('Bill'), A)-1/2, modifier_pp(B, by, named('John'))-1/8, modifier_pp(B, to, named('Mary'))-1/6]), [[specification, [s, [np, [pname, 'Bill']], [vp, [aux, is], [ap_coord, [ap, [adj, '_']]], [vmod, [pp, [prep, to], [np, [pname, 'Mary']]], [pp, [prep, by], [np, [pname, 'John']]]]]], '.']], '2011-07-18-19-02-57', '89.206.68.117', '').
text_drs_eval(0, 3681, 'Bill is v:_ to Mary by John.', drs([A], [predicate(A, '_', named('John'), named('Bill'), named('Mary'))-1/5]), [[specification, [s, [np, [pname, 'Bill']], [vp, [aux, is], [vbar, [vcompl, [v, '_'], [prep, to], [np, [pname, 'Mary']], by, [np, [pname, 'John']]]]]], '.']], '2011-07-18-19-03-11', '89.206.68.117', '').
text_drs_eval(0, 3682, 'A quick and quick man eats.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/5, property(A, quick, pos)-1/4, predicate(B, eat, A)-1/6]), [[specification, [s, [np, [det, a], [nbar, [adj_coord, [adj, quick], [coord, and], [adj, quick]], [nbar, [n, man]]]], [vp, [vbar, [vbar, [v, eats]]]]], '.']], '2011-07-20-10-10-41', '89.206.71.56', '').
text_drs_eval(0, 3683, 'The a:textual n:serialization of an a:XML element is the concatenation of "<" and the name of the element and the a:textual n:serializations of the attributes of the element and ">" and the a:textual n:serialization of the sequence of the children of the element and "".', drs([A, B, C, D, E, F, G, H, I, J, K, L, M, N], [relation(M, of, N)-1/8, property(N, 'XML', pos)-1/12, property(M, textual, pos)-1/4, object(M, serialization, countable, na, eq, 1)-1/7, object(L, na, countable, na, eq, 2)-1/'', has_part(L, C)-1/'', has_part(L, string(<))-1/'', relation(B, of, L)-1/17, object(B, concatenation, countable, na, eq, 1)-1/16, predicate(A, be, M, B)-1/14, object(K, na, countable, na, eq, 2)-1/'', has_part(K, N)-1/'', has_part(K, D)-1/'', relation(C, of, K)-1/22, object(C, name, countable, na, eq, 1)-1/21, property(D, textual, pos)-1/29, relation(D, of, E)-1/33, object(D, serializations, countable, na, eq, 1)-1/32, object(J, na, countable, na, eq, 3)-1/'', has_part(J, N)-1/'', has_part(J, F)-1/'', has_part(J, string(>))-1/'', relation(E, of, J)-1/36, object(E, attribute, countable, na, geq, 2)-1/35, property(F, textual, pos)-1/45, relation(F, of, G)-1/49, object(F, serialization, countable, na, eq, 1)-1/48, relation(G, of, H)-1/52, object(G, sequence, countable, na, eq, 1)-1/51, object(I, na, countable, na, eq, 2)-1/'', has_part(I, string(''))-1/'', relation(H, of, I)-1/55, has_part(I, N)-1/'', object(H, child, countable, na, geq, 2)-1/54, object(N, element, countable, na, eq, 1)-1/57]), [[specification, [s, [np, [det, the], [nbar, [adj, textual], [nbar, [n, serialization], [pp, [prep, of], [np, [det, an], [nbar, [adj, 'XML'], [nbar, [n, element]]]]]]]], [vp, [aux, is], [np, [det, the], [nbar, [n, concatenation], [pp, [prep, of], [np_coord, [np, [string, '"<"']], [coord, and], [np, [det, the], [nbar, [n, name], [pp, [prep, of], [np_coord, [np, [det, the], [nbar, [n, element]]], [coord, and], [np, [det, the], [nbar, [adj, textual], [nbar, [n, serializations], [pp, [prep, of], [np, [det, the], [nbar, [n, attributes], [pp, [prep, of], [np_coord, [np, [det, the], [nbar, [n, element]]], [coord, and], [np, [string, '">"']], [coord, and], [np, [det, the], [nbar, [adj, textual], [nbar, [n, serialization], [pp, [prep, of], [np, [det, the], [nbar, [n, sequence], [pp, [prep, of], [np, [det, the], [nbar, [n, children], [pp, [prep, of], [np_coord, [np, [det, the], [nbar, [n, element]]], [coord, and], [np, [string, '""']]]]]]]]]]]]]]]]]]]]]]]]]]]]]]], '.']], '2011-07-20-09-50-32', '84.74.137.219', '').
text_drs_eval(0, 3684, 'A red and red man runs quickly and quickly.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/5, property(A, red, pos)-1/4, predicate(B, run, A)-1/6, modifier_adv(B, quickly, pos)-1/7]), [[specification, [s, [np, [det, a], [nbar, [adj_coord, [adj, red], [coord, and], [adj, red]], [nbar, [n, man]]]], [vp, [vbar, [vbar, [v, runs]], [vmod, [adv_coord, [adv, quickly], [coord, and], [adv, quickly]]]]]], '.']], '2011-07-20-09-50-41', '84.74.137.219', '').
text_drs_eval(0, 3685, 'A man believes that he sleeps and that he sleeps.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, predicate(B, believe, A, C)-1/3, C:drs([D, E], [predicate(D, sleep, A)-1/6, predicate(E, sleep, A)-1/10])]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [cp, that, [s_coord, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, sleeps]]]]], [coord, and], [cp, that, [s, [np, [pn, he]], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]]]], '.']], '2011-07-26-13-37-16', '84.74.137.199', '').
text_drs_eval(0, 3686, 'A man and he see a cat and it.', drs([], []), [[specification, [s, [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [pn, he]]], [vp, [vbar, [vcompl, [v, see], [np_coord, [np, [det, a], [nbar, [n, cat]]], [coord, and], [np, [pn, it]]]]]]], '.']], '2011-07-20-09-50-52', '84.74.137.219', '').
text_drs_eval(0, 3687, 'Pi is 3.1415926536.', drs([A], [predicate(A, be, named('Pi'), real(3.1415926536))-1/2]), [[specification, [s, [np, [pname, 'Pi']], [vp, [aux, is], [np, [real, 3.1415926536]]]], '.']], '2011-07-20-09-50-59', '84.74.137.219', '').
text_drs_eval(0, 3688, 'There is a man. A group is a dog of the man and the man.', drs([], []), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, group]]], [vp, [aux, is], [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np_coord, [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [det, the], [nbar, [n, man]]]]]]]]], '.']], '2011-07-20-10-09-37', '89.206.71.56', '').
text_drs_eval(0, 3689, 'There is a name. There is a dog. "" is the name of the dog of a man and a woman.', drs([A, B, C, D, E, F, G, H], [object(A, name, countable, na, eq, 1)-1/4, object(B, dog, countable, na, eq, 1)-2/4, relation(D, of, E)-3/5, object(D, name, countable, na, eq, 1)-3/4, predicate(C, be, string(''), D)-3/2, object(H, na, countable, na, eq, 2)-3/'', has_part(H, G)-3/'', object(G, woman, countable, na, eq, 1)-3/13, relation(E, of, H)-3/8, has_part(H, F)-3/'', object(F, man, countable, na, eq, 1)-3/10, object(E, dog, countable, na, eq, 1)-3/7]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, name]]]]], '.'], [specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]], '.'], [specification, [s, [np, [string, '""']], [vp, [aux, is], [np, [det, the], [nbar, [n, name], [pp, [prep, of], [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, a], [nbar, [n, woman]]]]]]]]]]]], '.']], '2011-07-22-17-46-13', '89.206.64.230', '').
text_drs_eval(0, 3690, 'The card of which man whose card is valid is valid?', drs([], [question(drs([A, B, C, D, E, F, G], [relation(C, of, D)-1/3, predicate(G, be, E, F)-1/8, property(F, valid, pos)-1/9, relation(E, of, D)-1/6, object(E, card, countable, na, eq, 1)-1/7, object(D, man, countable, na, eq, 1)-1/5, query(D, which)-1/4, object(C, card, countable, na, eq, 1)-1/2, property(A, valid, pos)-1/11, predicate(B, be, C, A)-1/10]))]), [[query, [question, [np, [det, the], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], ?]], '2011-07-22-17-20-47', '89.206.64.230', '').
text_drs_eval(0, 3691, 'A card of which man whose card is valid is valid?', drs([], [question(drs([A, B, C, D, E, F, G], [object(A, card, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, man, countable, na, eq, 1)-1/5, object(C, card, countable, na, eq, 1)-1/7, relation(C, of, B)-1/6, property(D, valid, pos)-1/9, predicate(E, be, C, D)-1/8, relation(A, of, B)-1/3, property(F, valid, pos)-1/11, predicate(G, be, A, F)-1/10]))]), [[query, [question, [np, [det, a], [nbar, [n, card], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, card]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]], ?]], '2011-07-21-13-37-49', '91.176.21.143', '').
text_drs_eval(0, 3692, 'At most 3 men eat or the men drink.', drs([], [drs([A, B], [[predicate(B, eat, A)-1/5, object(A, man, countable, na, leq, 3)-1/4]])v drs([C], [predicate(C, drink, A)-1/9])]), [[specification, [s_coord, [s, [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, eat]]]]], [coord, or], [s, [np, [det, the], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, drink]]]]]], '.']], '2011-07-21-16-55-37', '89.206.66.1', '').
text_drs_eval(0, 3693, 'At most 3 men eat or drink.', drs([A], [[drs([B], [predicate(B, eat, A)-1/5])v drs([C], [predicate(C, drink, A)-1/7]), object(A, man, countable, na, leq, 3)-1/4]]), [[specification, [s, [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men]]], [vp_coord, [vp, [vbar, [vbar, [v, eat]]]], [coord, or], [vp, [vbar, [vbar, [v, drink]]]]]], '.']], '2011-07-21-16-56-14', '89.206.66.1', '').
text_drs_eval(0, 3694, 'Every dog barks or a cat does not sleep.', drs([], [drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, bark, A)-1/3])])v drs([C], [object(C, cat, countable, na, eq, 1)-1/6, -drs([D], [predicate(D, sleep, C)-1/9])])]), [[specification, [s_coord, [s, [np, [det, every], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]], [coord, or], [s, [np, [det, a], [nbar, [n, cat]]], [vp, [aux, does, not], [vbar, [vbar, [v, sleep]]]]]], '.']], '2011-07-21-18-46-18', '89.206.66.1', '').
text_drs_eval(0, 3695, 'The cat of a man whose dog barks sleeps.', drs([A, B, C, D, E], [relation(B, of, C)-1/3, predicate(E, bark, D)-1/8, relation(D, of, C)-1/6, object(D, dog, countable, na, eq, 1)-1/7, object(C, man, countable, na, eq, 1)-1/5, object(B, cat, countable, na, eq, 1)-1/2, predicate(A, sleep, B)-1/9]), [[specification, [s, [np, [det, the], [nbar, [n, cat], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]]], [vp, [vbar, [vbar, [v, sleeps]]]]], '.']], '2011-07-22-11-43-54', '89.206.65.50', '').
text_drs_eval(0, 3696, 'The dog of a man whose dog barks barks.', drs([A, B, C, D, E], [relation(B, of, C)-1/3, predicate(E, bark, D)-1/8, relation(D, of, C)-1/6, object(D, dog, countable, na, eq, 1)-1/7, object(C, man, countable, na, eq, 1)-1/5, object(B, dog, countable, na, eq, 1)-1/2, predicate(A, bark, B)-1/9]), [[specification, [s, [np, [det, the], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]]], [vp, [vbar, [vbar, [v, barks]]]]], '.']], '2011-07-22-17-19-02', '89.206.64.230', '').
text_drs_eval(0, 3697, 'A dog of a man whose dog barks barks.', drs([A, B, C, D, E], [object(A, dog, countable, na, eq, 1)-1/2, object(B, man, countable, na, eq, 1)-1/5, object(C, dog, countable, na, eq, 1)-1/7, relation(C, of, B)-1/6, predicate(D, bark, C)-1/8, relation(A, of, B)-1/3, predicate(E, bark, A)-1/9]), [[specification, [s, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [det, a], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]]]]], [vp, [vbar, [vbar, [v, barks]]]]], '.']], '2011-07-22-11-53-34', '89.206.65.50', '').
text_drs_eval(0, 3698, 'Which man whose dog barks waits?', drs([], [question(drs([A, B, C, D], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, object(B, dog, countable, na, eq, 1)-1/4, relation(B, of, A)-1/3, predicate(C, bark, B)-1/5, predicate(D, wait, A)-1/6]))]), [[query, [question, [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [posspn, whose], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]]], [vp, [vbar, [vbar, [v, waits]]]]], ?]], '2011-07-22-17-29-33', '89.206.64.230', '').
text_drs_eval(0, 3699, 'A dog of which man who waits barks?', drs([], [question(drs([A, B, C, D], [object(A, dog, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, man, countable, na, eq, 1)-1/5, predicate(C, wait, B)-1/7, relation(A, of, B)-1/3, predicate(D, bark, A)-1/8]))]), [[query, [question, [np, [det, a], [nbar, [n, dog], [pp, [prep, of], [np, [qdet, which], [nbar, [n, man], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vbar, [v, waits]]]]]]]]]], [vp, [vbar, [vbar, [v, barks]]]]], ?]], '2011-07-22-17-32-56', '89.206.64.230', '').
text_drs_eval(0, 3700, 'At most 3 men eat or at most 2 men eat.', drs([], [drs([A, B], [[predicate(B, eat, A)-1/5, object(A, man, countable, na, leq, 3)-1/4]])v drs([C, D], [[object(C, man, countable, na, leq, 2)-1/10, predicate(D, eat, C)-1/11]])]), [[specification, [s_coord, [s, [np, [nump, [genqu, 'at most'], 3], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, eat]]]]], [coord, or], [s, [np, [nump, [genqu, 'at most'], 2], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, eat]]]]]], '.']], '2011-07-22-18-25-58', '89.206.64.230', '').
text_drs_eval(0, 3701, 'Mary knows that John eats or Bill drinks.', drs([], [drs([A, B], [predicate(A, know, named('Mary'), B)-1/2, B:drs([C], [predicate(C, eat, named('John'))-1/5])])v drs([D], [predicate(D, drink, named('Bill'))-1/8])]), [[specification, [s_coord, [s, [np, [pname, 'Mary']], [vp, [vbar, [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]]]]]], [coord, or], [s, [np, [pname, 'Bill']], [vp, [vbar, [vbar, [v, drinks]]]]]], '.']], '2011-07-24-16-27-38', '89.206.66.17', '').
text_drs_eval(0, 3702, 'Mary knows that John eats or that Bill drinks.', drs([A, B], [predicate(A, know, named('Mary'), B)-1/2, B:drs([], [drs([C], [predicate(C, eat, named('John'))-1/5])v drs([D], [predicate(D, drink, named('Bill'))-1/9])])]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [s_coord, [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [pname, 'Bill']], [vp, [vbar, [vbar, [v, drinks]]]]]]]]]], '.']], '2011-07-24-16-27-53', '89.206.66.17', '').
text_drs_eval(0, 3703, 'Mary knows that every man eats or that Bill drinks.', drs([A, B], [predicate(A, know, named('Mary'), B)-1/2, B:drs([], [drs([], [drs([C], [object(C, man, countable, na, eq, 1)-1/5])=>drs([D], [predicate(D, eat, C)-1/6])])v drs([E], [predicate(E, drink, named('Bill'))-1/10])])]), [[specification, [s, [np, [pname, 'Mary']], [vp, [vbar, [s_coord, [cp, that, [s, [np, [det, every], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [pname, 'Bill']], [vp, [vbar, [vbar, [v, drinks]]]]]]]]]], '.']], '2011-07-24-16-28-29', '89.206.66.17', '').
text_drs_eval(0, 3704, 'Bill drinks or Mary knows that John eats.', drs([], [drs([A], [predicate(A, drink, named('Bill'))-1/2])v drs([B, C], [predicate(B, know, named('Mary'), C)-1/5, C:drs([D], [predicate(D, eat, named('John'))-1/8])])]), [[specification, [s_coord, [s, [np, [pname, 'Bill']], [vp, [vbar, [vbar, [v, drinks]]]]], [coord, or], [s, [np, [pname, 'Mary']], [vp, [vbar, [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]]]]]]], '.']], '2011-07-24-16-29-42', '89.206.66.17', '').
text_drs_eval(0, 3705, 'There is a book. A database lists the title of the book and lists the code of the book.', drs([A, B, C, D, E, F], [object(B, database, countable, na, eq, 1)-2/2, relation(D, of, A)-2/6, object(D, title, countable, na, eq, 1)-2/5, predicate(C, list, B, D)-2/3, relation(F, of, A)-2/13, object(F, code, countable, na, eq, 1)-2/12, object(A, book, countable, na, eq, 1)-2/15, predicate(E, list, B, F)-2/10]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, book]]]]], '.'], [specification, [s, [np, [det, a], [nbar, [n, database]]], [vp_coord, [vp, [vbar, [vcompl, [v, lists], [np, [det, the], [nbar, [n, title], [pp, [prep, of], [np, [det, the], [nbar, [n, book]]]]]]]]], [coord, and], [vp, [vbar, [vcompl, [v, lists], [np, [det, the], [nbar, [n, code], [pp, [prep, of], [np, [det, the], [nbar, [n, book]]]]]]]]]]], '.']], '2011-07-24-17-14-33', '89.206.66.17', '').
text_drs_eval(0, 3706, 'Mary does not know that John eats or Bill drinks.', drs([], [drs([], [-drs([A, B], [predicate(A, know, named('Mary'), B)-1/4, B:drs([C], [predicate(C, eat, named('John'))-1/7])])])v drs([D], [predicate(D, drink, named('Bill'))-1/10])]), [[specification, [s_coord, [s, [np, [pname, 'Mary']], [vp, [aux, does, not], [vbar, [cp, that, [s, [np, [pname, 'John']], [vp, [vbar, [vbar, [v, eats]]]]]]]]], [coord, or], [s, [np, [pname, 'Bill']], [vp, [vbar, [vbar, [v, drinks]]]]]], '.']], '2011-07-24-17-02-42', '89.206.66.17', '').
text_drs_eval(0, 3707, 'There is a man X. Every woman likes X or X drinks.', drs([A], [object(A, man, countable, na, eq, 1)-1/4, drs([], [drs([B], [object(B, woman, countable, na, eq, 1)-2/2])=>drs([C], [predicate(C, like, B, A)-2/3])])v drs([D], [predicate(D, drink, A)-2/7])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [s_coord, [s, [np, [det, every], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, likes], [np, [var, 'X']]]]]], [coord, or], [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, drinks]]]]]], '.']], '2011-07-24-18-17-00', '89.206.66.17', '').
text_drs_eval(0, 3708, 'There is a man X. A dog likes X and every woman likes X or X drinks.', drs([A], [object(A, man, countable, na, eq, 1)-1/4, drs([B, C], [object(B, dog, countable, na, eq, 1)-2/2, predicate(C, like, B, A)-2/3, drs([D], [object(D, woman, countable, na, eq, 1)-2/7])=>drs([E], [predicate(E, like, D, A)-2/8])])v drs([F], [predicate(F, drink, A)-2/12])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [s_coord, [s_coord, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [v, likes], [np, [var, 'X']]]]]], [coord, and], [s, [np, [det, every], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, likes], [np, [var, 'X']]]]]]], [coord, or], [s, [np, [var, 'X']], [vp, [vbar, [vbar, [v, drinks]]]]]], '.']], '2011-07-24-18-18-01', '89.206.66.17', '').
text_drs_eval(0, 3709, 'There is a man X. A dog likes X and every woman likes X or X likes the dog.', drs([A], [object(A, man, countable, na, eq, 1)-1/4, drs([B, C], [object(B, dog, countable, na, eq, 1)-2/2, predicate(C, like, B, A)-2/3, drs([D], [object(D, woman, countable, na, eq, 1)-2/7])=>drs([E], [predicate(E, like, D, A)-2/8])])v drs([F], [predicate(F, like, A, B)-2/12])]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man], [appos, [var, 'X']]]]]], '.'], [specification, [s_coord, [s_coord, [s, [np, [det, a], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [v, likes], [np, [var, 'X']]]]]], [coord, and], [s, [np, [det, every], [nbar, [n, woman]]], [vp, [vbar, [vcompl, [v, likes], [np, [var, 'X']]]]]]], [coord, or], [s, [np, [var, 'X']], [vp, [vbar, [vcompl, [v, likes], [np, [det, the], [nbar, [n, dog]]]]]]]], '.']], '2011-07-24-18-18-48', '89.206.66.17', '').
text_drs_eval(0, 3710, 'It is false that a cat sleeps and every dog barks or there is a man.', drs([], [drs([], [-drs([A, B], [object(A, cat, countable, na, eq, 1)-1/6, predicate(B, sleep, A)-1/7]), drs([C], [object(C, dog, countable, na, eq, 1)-1/10])=>drs([D], [predicate(D, bark, C)-1/11])])v drs([E], [object(E, man, countable, na, eq, 1)-1/16])]), [[specification, [s_coord, [s_coord, [s, [neg, 'it is false'], [cp, that, [s, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [vbar, [v, sleeps]]]]]]], [coord, and], [s, [np, [det, every], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]]], '.']], '2011-07-24-19-02-14', '89.206.66.17', '').
text_drs_eval(0, 3711, 'Every dog barks and it is false that a cat sleeps or there is a man.', drs([], [drs([], [drs([A], [object(A, dog, countable, na, eq, 1)-1/2])=>drs([B], [predicate(B, bark, A)-1/3]), -drs([C, D], [object(C, cat, countable, na, eq, 1)-1/10, predicate(D, sleep, C)-1/11])])v drs([E], [object(E, man, countable, na, eq, 1)-1/16])]), [[specification, [s_coord, [s_coord, [s, [np, [det, every], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]], [coord, and], [s, [neg, 'it is false'], [cp, that, [s, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [vbar, [v, sleeps]]]]]]]], [coord, or], [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, man]]]]]], '.']], '2011-07-24-19-02-57', '89.206.66.17', '').
text_drs_eval(0, 3712, '1=1 and every dog barks or a cat sleeps.', drs([], [drs([], [formula(int(1), =, int(1))-1/2, drs([A], [object(A, dog, countable, na, eq, 1)-1/6])=>drs([B], [predicate(B, bark, A)-1/7])])v drs([C, D], [object(C, cat, countable, na, eq, 1)-1/10, predicate(D, sleep, C)-1/11])]), [[specification, [s_coord, [s_coord, [formula, [int, 1], =, [int, 1]], [coord, and], [s, [np, [det, every], [nbar, [n, dog]]], [vp, [vbar, [vbar, [v, barks]]]]]], [coord, or], [s, [np, [det, a], [nbar, [n, cat]]], [vp, [vbar, [vbar, [v, sleeps]]]]]], '.']], '2011-07-24-21-58-39', '89.206.66.17', '').
text_drs_eval(0, 3713, 'It is false that a man eats or that the man drinks and that the man waits.', drs([], [-drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, eat, A)-1/7])v drs([C, D], [predicate(C, drink, A)-1/12, predicate(D, wait, A)-1/17])])]), [[specification, [s, [neg, 'it is false'], [s_coord, [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s_coord, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]], [coord, and], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]]]], '.']], '2011-07-25-12-59-34', '89.206.69.154', '').
text_drs_eval(0, 3714, 'It is false that a man eats and that the man drinks, or that the man waits.', drs([], [-drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, eat, A)-1/7, predicate(C, drink, A)-1/12])v drs([D], [predicate(D, wait, A)-1/18])])]), [[specification, [s, [neg, 'it is false'], [s_coord, [cp, that, [s_coord, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]], [coord, and], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]]]], [coord, ', or'], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]], '.']], '2011-07-25-13-11-17', '89.206.69.154', '').
text_drs_eval(0, 3715, 'It is false that a man eats and that the man drinks or that the man waits.', drs([], [-drs([], [drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, eat, A)-1/7, predicate(C, drink, A)-1/12])v drs([D], [predicate(D, wait, A)-1/17])])]), [[specification, [s, [neg, 'it is false'], [s_coord, [cp, that, [s_coord, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]], [coord, and], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]]]], [coord, or], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]], '.']], '2011-07-25-13-11-27', '89.206.69.154', '').
text_drs_eval(0, 3716, 'It is false that a man eats and that the man drinks, and that the man waits.', drs([], [-drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, eat, A)-1/7, predicate(C, drink, A)-1/12, predicate(D, wait, A)-1/18])]), [[specification, [s, [neg, 'it is false'], [s_coord, [cp, that, [s_coord, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]], [coord, and], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]]]], [coord, ', and'], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]], '.']], '2011-07-25-13-11-55', '89.206.69.154', '').
text_drs_eval(0, 3717, 'It is false that a man eats or that the man drinks or that the man waits.', drs([], [-drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, eat, A)-1/7])v drs([], [drs([C], [predicate(C, drink, A)-1/12])v drs([D], [predicate(D, wait, A)-1/17])])])]), [[specification, [s, [neg, 'it is false'], [s_coord, [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]], [coord, or], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]], '.']], '2011-07-25-13-13-28', '89.206.69.154', '').
text_drs_eval(0, 3718, 'It is false that a man eats or that the man drinks, or that the man waits.', drs([], [-drs([], [drs([], [drs([A, B], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, eat, A)-1/7])v drs([C], [predicate(C, drink, A)-1/12])])v drs([D, E], [object(E, man, countable, na, eq, 1)-1/17, predicate(D, wait, E)-1/18])])]), [[specification, [s, [neg, 'it is false'], [s_coord, [s_coord, [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]]], [coord, ', or'], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]], '.']], '2011-07-25-13-28-00', '89.206.69.154', '').
text_drs_eval(0, 3719, 'It is false that a man eats or that the man drinks, and that the man waits.', drs([], [-drs([A, B], [drs([C, D], [object(C, man, countable, na, eq, 1)-1/6, predicate(D, eat, C)-1/7])v drs([E], [predicate(E, drink, C)-1/12]), object(B, man, countable, na, eq, 1)-1/17, predicate(A, wait, B)-1/18])]), [[specification, [s, [neg, 'it is false'], [s_coord, [s_coord, [cp, that, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]]], [coord, or], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]]], [coord, ', and'], [cp, that, [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]]]], '.']], '2011-07-25-13-27-34', '89.206.69.154', '').
text_drs_eval(0, 3720, 'A man eats or the man drinks, and the man waits.', drs([A, B], [drs([C, D], [object(C, man, countable, na, eq, 1)-1/2, predicate(D, eat, C)-1/3])v drs([E], [predicate(E, drink, C)-1/7]), object(B, man, countable, na, eq, 1)-1/11, predicate(A, wait, B)-1/12]), [[specification, [s_coord, [s_coord, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, eats]]]]], [coord, or], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, drinks]]]]]], [coord, ', and'], [s, [np, [det, the], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, waits]]]]]], '.']], '2011-07-25-13-25-51', '89.206.69.154', '').
text_drs_eval(0, 3721, 'John knows that there is a cat or that there is a dog.', drs([A, B], [predicate(A, know, named('John'), B)-1/2, B:drs([], [drs([C], [object(C, cat, countable, na, eq, 1)-1/7])v drs([D], [object(D, dog, countable, na, eq, 1)-1/13])])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [s_coord, [cp, that, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat]]]]]], [coord, or], [cp, that, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, dog]]]]]]]]]], '.']], '2011-07-25-14-43-11', '89.206.69.154', '').
text_drs_eval(0, 3722, 'John knows that there is a cat and that 1 = 1.', drs([A, B], [predicate(A, know, named('John'), B)-1/2, B:drs([C], [object(C, cat, countable, na, eq, 1)-1/7, formula(int(1), =, int(1))-1/11])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s_coord, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, cat]]]]], [coord, and], [cp, that, [formula, [int, 1], =, [int, 1]]]]]]]], '.']], '2011-07-25-14-45-41', '89.206.69.154', '').
text_drs_eval(0, 3723, 'A man and the man and he see a cat and the cat and it.', drs([], []), [[specification, [s, [np_coord, [np, [det, a], [nbar, [n, man]]], [coord, and], [np, [det, the], [nbar, [n, man]]], [coord, and], [np, [pn, he]]], [vp, [vbar, [vcompl, [v, see], [np_coord, [np, [det, a], [nbar, [n, cat]]], [coord, and], [np, [det, the], [nbar, [n, cat]]], [coord, and], [np, [pn, it]]]]]]], '.']], '2011-07-26-13-36-14', '84.74.137.199', '').
text_drs_eval(0, 3724, 'A man sleeps in the morning and in the morning.', drs([], []), [], '2011-07-26-13-36-49', '84.74.137.199', '').
text_drs_eval(0, 3725, 'A man sleeps in a bed in a bed.', drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/2, object(B, bed, countable, na, eq, 1)-1/6, object(C, bed, countable, na, eq, 1)-1/9, predicate(D, sleep, A)-1/3, modifier_pp(D, in, C)-1/7, modifier_pp(D, in, B)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, sleeps]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]]]]]], '.']], '2011-07-26-13-39-10', '84.74.137.199', '').
text_drs_eval(0, 3726, 'A man sleeps in a bed in the bed.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(B, bed, countable, na, eq, 1)-1/6, predicate(C, sleep, A)-1/3, modifier_pp(C, in, B)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, sleeps]], [vmod, [pp, [prep, in], [np, [det, a], [nbar, [n, bed]]]], [pp, [prep, in], [np, [det, the], [nbar, [n, bed]]]]]]]], '.']], '2011-07-26-13-39-32', '84.74.137.199', '').
text_drs_eval(0, 3727, 'A man sleeps in the morning in the morning.', drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/2, object(C, morning, countable, na, eq, 1)-1/6, predicate(B, sleep, A)-1/3, modifier_pp(B, in, C)-1/4]), [[specification, [s, [np, [det, a], [nbar, [n, man]]], [vp, [vbar, [vbar, [v, sleeps]], [vmod, [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]], [pp, [prep, in], [np, [det, the], [nbar, [n, morning]]]]]]]], '.']], '2011-07-26-13-39-57', '84.74.137.199', '').
text_drs_eval(0, 3728, 'Which film\ncontains a role that a person A performs, and\ncontains a role that depicts A and that a person that is not A performs?', drs([], [question(drs([A, B, C, D, E, F, G, H, I, J], [query(A, which)-1/1, object(A, film, countable, na, eq, 1)-1/2, object(B, role, countable, na, eq, 1)-1/5, object(C, person, countable, na, eq, 1)-1/8, predicate(D, perform, C, B)-1/10, predicate(E, contain, A, B)-1/3, object(F, role, countable, na, eq, 1)-1/15, predicate(G, depict, F, C)-1/17, object(H, person, countable, na, eq, 1)-1/22, -drs([K], [predicate(K, be, H, C)-1/24]), predicate(I, perform, H, F)-1/27, predicate(J, contain, A, F)-1/13]))]), [[query, [question, [np, [qdet, which], [nbar, [n, film]]], [vp_coord, [vp, [vbar, [vcompl, [v, contains], [np, [det, a], [nbar, [n, role], [rel_cl, [comp, that], [np, [det, a], [nbar, [n, person], [appos, [var, 'A']]]], [vp, [vbar, [vcompl, [v, performs]]]]]]]]]], [coord, ', and'], [vp, [vbar, [vcompl, [v, contains], [np, [det, a], [nbar, [n, role], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, depicts], [np, [var, 'A']]]]]], [coord, and], [rel_cl, [comp, that], [np, [det, a], [nbar, [n, person], [rel_cl, [comp, that], [vp, [aux, is, not], [np, [var, 'A']]]]]], [vp, [vbar, [vcompl, [v, performs]]]]]]]]]]]]], ?]], '2011-07-28-13-43-53', '91.176.174.222', '').
text_drs_eval(0, 3729, 'Which film\ncontains a role that which person A performs, and\ncontains a role that depicts A and that a person that is not A performs?', drs([], [question(drs([A, B, C, D, E, F, G, H, I, J], [query(A, which)-1/1, object(A, film, countable, na, eq, 1)-1/2, object(B, role, countable, na, eq, 1)-1/5, query(C, which)-1/7, object(C, person, countable, na, eq, 1)-1/8, predicate(D, perform, C, B)-1/10, predicate(E, contain, A, B)-1/3, object(F, role, countable, na, eq, 1)-1/15, predicate(G, depict, F, C)-1/17, object(H, person, countable, na, eq, 1)-1/22, -drs([K], [predicate(K, be, H, C)-1/24]), predicate(I, perform, H, F)-1/27, predicate(J, contain, A, F)-1/13]))]), [[query, [question, [np, [qdet, which], [nbar, [n, film]]], [vp_coord, [vp, [vbar, [vcompl, [v, contains], [np, [det, a], [nbar, [n, role], [rel_cl, [comp, that], [np, [qdet, which], [nbar, [n, person], [appos, [var, 'A']]]], [vp, [vbar, [vcompl, [v, performs]]]]]]]]]], [coord, ', and'], [vp, [vbar, [vcompl, [v, contains], [np, [det, a], [nbar, [n, role], [rel_cl_coord, [rel_cl, [comp, that], [vp, [vbar, [vcompl, [v, depicts], [np, [var, 'A']]]]]], [coord, and], [rel_cl, [comp, that], [np, [det, a], [nbar, [n, person], [rel_cl, [comp, that], [vp, [aux, is, not], [np, [var, 'A']]]]]], [vp, [vbar, [vcompl, [v, performs]]]]]]]]]]]]], ?]], '2011-07-28-13-51-58', '91.176.174.222', '').
text_drs_eval(0, 3730, 'Which man gives which dog which chases which cat which apple which is what?', drs([], [question(drs([A, B, C, D, E, F, G, H], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, dog, countable, na, eq, 1)-1/5, query(C, which)-1/8, object(C, cat, countable, na, eq, 1)-1/9, predicate(D, chase, B, C)-1/7, query(E, which)-1/10, object(E, apple, countable, na, eq, 1)-1/11, query(F, what)-1/14, predicate(G, be, E, F)-1/13, predicate(H, give, A, E, B)-1/3]))]), [[query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, gives], [np, [qdet, which], [nbar, [n, dog], [rel_cl, [np, [relpn, which]], [vp, [vbar, [vcompl, [v, chases], [np, [qdet, which], [nbar, [n, cat]]]]]]]]], [np, [qdet, which], [nbar, [n, apple], [rel_cl, [np, [relpn, which]], [vp, [aux, is], [np, [qpn, what]]]]]]]]]], ?]], '2011-07-28-14-00-09', '91.176.174.222', '').
text_drs_eval(0, 3731, 'Which man gives which cat which which dog chases which apple which what eats?', drs([], [question(drs([A, B, C, D, E, F, G, H], [query(A, which)-1/1, object(A, man, countable, na, eq, 1)-1/2, query(B, which)-1/4, object(B, cat, countable, na, eq, 1)-1/5, query(C, which)-1/7, object(C, dog, countable, na, eq, 1)-1/8, predicate(D, chase, C, B)-1/9, query(E, which)-1/10, object(E, apple, countable, na, eq, 1)-1/11, query(F, what)-1/13, predicate(G, eat, F, E)-1/14, predicate(H, give, A, E, B)-1/3]))]), [[query, [question, [np, [qdet, which], [nbar, [n, man]]], [vp, [vbar, [vcompl, [v, gives], [np, [qdet, which], [nbar, [n, cat], [rel_cl, [np, [relpn, which]], [np, [qdet, which], [nbar, [n, dog]]], [vp, [vbar, [vcompl, [v, chases]]]]]]], [np, [qdet, which], [nbar, [n, apple], [rel_cl, [np, [relpn, which]], [np, [qpn, what]], [vp, [vbar, [vcompl, [v, eats]]]]]]]]]]], ?]], '2011-07-30-19-06-07', '91.176.59.7', '').
text_drs_eval(0, 3732, 'John has a card every code of which is valid.', drs([A, B], [object(A, card, countable, na, eq, 1)-1/4, drs([C], [object(C, code, countable, na, eq, 1)-1/6, relation(C, of, A)-1/7])=>drs([D, E], [property(D, valid, pos)-1/10, predicate(E, be, C, D)-1/9]), predicate(B, have, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, card], [rel_cl, [np, [det, every], [nbar, [n, code], [pp, [prep, of], [np, [relpn, which]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]]]]]]], '.']], '2011-08-09-08-48-13', '89.206.70.254', '').
text_drs_eval(0, 3733, 'John has a card no code of which is valid.', drs([A, B], [object(A, card, countable, na, eq, 1)-1/4, drs([C], [object(C, code, countable, na, eq, 1)-1/6, relation(C, of, A)-1/7])=>drs([], [-drs([D, E], [property(D, valid, pos)-1/10, predicate(E, be, C, D)-1/9])]), predicate(B, have, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, card], [rel_cl, [np, [det, no], [nbar, [n, code], [pp, [prep, of], [np, [relpn, which]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]]]]]]], '.']], '2011-08-09-08-48-22', '89.206.70.254', '').
text_drs_eval(0, 3734, 'John has a card every code of every copy of which is valid.', drs([A, B], [object(A, card, countable, na, eq, 1)-1/4, drs([C], [object(C, code, countable, na, eq, 1)-1/6, drs([D], [object(D, copy, countable, na, eq, 1)-1/9, relation(D, of, A)-1/10])=>drs([], [relation(C, of, D)-1/7])])=>drs([E, F], [property(E, valid, pos)-1/13, predicate(F, be, C, E)-1/12]), predicate(B, have, named('John'), A)-1/2]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [det, a], [nbar, [n, card], [rel_cl, [np, [det, every], [nbar, [n, code], [pp, [prep, of], [np, [det, every], [nbar, [n, copy], [pp, [prep, of], [np, [relpn, which]]]]]]]], [vp, [aux, is], [ap_coord, [ap, [adj, valid]]]]]]]]]]], '.']], '2011-08-09-08-48-28', '89.206.70.254', '').
text_drs_eval(1, 3735, 'There is a group. John is a part of it.', drs([A, B, C], [object(A, group, countable, na, eq, 1)-1/4, object(B, part, countable, na, eq, 1)-2/4, relation(B, of, B)-2/5, predicate(C, be, named('John'), B)-2/2]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, a], [nbar, [n, group]]]]], '.'], [specification, [s, [np, [pname, 'John']], [vp, [aux, is], [np, [det, a], [nbar, [n, part], [pp, [prep, of], [np, [pn, it]]]]]]], '.']], '2011-09-02-00-50-40', '188.76.165.203', 'I guess this is not a bug, but the resolution (it = part) is confusing nevertheless.').
text_drs_eval(1, 3736, 'Everything that is contained by something is a part of it.', drs([], [drs([A, B, C], [object(A, something, dom, na, na, na)-1/2, object(B, something, dom, na, na, na)-1/8, predicate(C, contain, B, A)-1/5])=>drs([D, E], [object(D, part, countable, na, eq, 1)-1/11, relation(D, of, D)-1/12, predicate(E, be, A, D)-1/9])]), [[specification, [s, [np, [pn, everything], [rel_cl, [comp, that], [vp, [aux, is], [vbar, [vcompl, [v, contained], by, [np, [pn, something]]]]]]], [vp, [aux, is], [np, [det, a], [nbar, [n, part], [pp, [prep, of], [np, [pn, it]]]]]]], '.']], '2011-09-02-00-52-21', '188.76.165.203', 'Resolution (it = part) might be correct but something is definitely wrong with the OWL/SWRL output.').
text_drs_eval(0, 3737, 'Exactly 1 woman waits.', drs([A, B], [[predicate(B, wait, A)-1/4, object(A, woman, countable, na, exactly, 1)-1/3]]), [[specification, [s, [np, [nump, [genqu, exactly], 1], [nbar, [n, woman]]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2011-11-09-19-44-02', '89.206.102.217', '').
text_drs_eval(0, 3738, 'May John not wait?', drs([], [question(drs([], [-drs([], [may(drs([A], [predicate(A, wait, named('John'))-1/4]))])]))]), [[query, [question, may, [np, [pname, 'John']], [vp, [aux, not], [vbar, [vbar, [v, wait]]]]], ?]], '2012-01-04-15-40-44', '82.131.107.30', '').
text_drs_eval(0, 3739, 'Brend is a man.', drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, be, named('Brend'), A)-1/2]), [[specification, [s, [np, [pname, 'Brend']], [vp, [aux, is], [np, [det, a], [nbar, [n, man]]]]], '.']], '2012-01-17-15-32-44', '130.89.12.228', '').
text_drs_eval(0, 3740, 'How many man waits?', drs([], []), [], '2012-01-31-09-56-13', '80.200.30.47', '').
text_drs_eval(0, 3741, 'How many men does which woman who eats how much food like?', drs([], [question(drs([A, B, C, D, E], [query(A, which)-1/5, object(A, woman, countable, na, eq, 1)-1/6, query(B, howm)-1/9, object(B, food, mass, na, na, na)-1/11, predicate(C, eat, A, B)-1/8, query(D, howm)-1/1, object(D, man, countable, na, geq, 2)-1/3, predicate(E, like, A, D)-1/12]))]), [[query, [question, [np, [qdet, 'how many'], [nbar, [n, men]]], does, [np, [qdet, which], [nbar, [n, woman], [rel_cl, [np, [relpn, who]], [vp, [vbar, [vcompl, [v, eats], [np, [qdet, 'how much'], [nbar, [n, food]]]]]]]]], [vp, [vbar, [vcompl, [v, like]]]]], ?]], '2012-01-31-10-47-08', '80.200.30.47', '').
text_drs_eval(0, 3742, 'There are which men of John?', drs([], [question(drs([A], [query(A, which)-1/3, object(A, man, countable, na, geq, 2)-1/4, relation(A, of, named('John'))-1/5]))]), [[query, [question, [topic, [quant, 'there are'], [np, [qdet, which], [nbar, [n, men], [pp, [prep, of], [np, [pname, 'John']]]]]]], ?]], '2012-01-31-10-47-20', '80.200.30.47', '').
text_drs_eval(0, 3743, 'There are how many men of John?', drs([], [question(drs([A], [query(A, howm)-1/3, object(A, man, countable, na, geq, 2)-1/5, relation(A, of, named('John'))-1/6]))]), [[query, [question, [topic, [quant, 'there are'], [np, [qdet, 'how many'], [nbar, [n, men], [pp, [prep, of], [np, [pname, 'John']]]]]]], ?]], '2012-01-31-10-47-51', '80.200.30.47', '').
text_drs_eval(0, 3744, 'There is how much food of John?', drs([], [question(drs([A], [query(A, howm)-1/3, object(A, food, mass, na, na, na)-1/5, relation(A, of, named('John'))-1/6]))]), [[query, [question, [topic, [quant, 'there is'], [np, [qdet, 'how much'], [nbar, [n, food], [pp, [prep, of], [np, [pname, 'John']]]]]]], ?]], '2012-01-31-10-48-10', '80.200.30.47', '').
text_drs_eval(0, 3745, 'How much man waits?', drs([], []), [], '2012-01-31-12-06-23', '80.200.30.47', '').
text_drs_eval(0, 3746, 'How many men wait?', drs([], [question(drs([A, B], [query(A, howm)-1/1, object(A, man, countable, na, geq, 2)-1/3, predicate(B, wait, A)-1/4]))]), [[query, [question, [np, [qdet, 'how many'], [nbar, [n, men]]], [vp, [vbar, [vbar, [v, wait]]]]], ?]], '2012-01-31-12-11-07', '80.200.30.47', '').
text_drs_eval(0, 3747, 'How much food waits?', drs([], [question(drs([A, B], [query(A, howm)-1/1, object(A, food, mass, na, na, na)-1/3, predicate(B, wait, A)-1/4]))]), [[query, [question, [np, [qdet, 'how much'], [nbar, [n, food]]], [vp, [vbar, [vbar, [v, waits]]]]], ?]], '2012-01-31-12-11-26', '80.200.30.47', '').
text_drs_eval(0, 3748, 'How many good men eat how much bad food?', drs([], [question(drs([A, B, C], [query(A, howm)-1/1, object(A, man, countable, na, geq, 2)-1/4, property(A, good, pos)-1/3, query(B, howm)-1/6, object(B, food, mass, na, na, na)-1/9, property(B, bad, pos)-1/8, predicate(C, eat, A, B)-1/5]))]), [[query, [question, [np, [qdet, 'how many'], [nbar, [adj, good], [nbar, [n, men]]]], [vp, [vbar, [vcompl, [v, eat], [np, [qdet, 'how much'], [nbar, [adj, bad], [nbar, [n, food]]]]]]]], ?]], '2012-01-31-15-16-20', '80.200.30.47', '').
text_drs_eval(0, 3749, 'There is some fluid. How many liters of the fluid are there?', drs([A], [object(A, fluid, mass, na, na, na)-1/4, question(drs([B], [query(B, howm)-2/1, object(B, liter, countable, na, geq, 2)-2/3, relation(B, of, A)-2/4]))]), [[specification, [top_s, [topic, [quant, 'there is'], [np, [det, some], [nbar, [n, fluid]]]]], '.'], [query, [question, [topic, [np, [qdet, 'how many'], [nbar, [n, liters], [pp, [prep, of], [np, [det, the], [nbar, [n, fluid]]]]]], [quant, 'are there']]], ?]], '2013-12-14-11-49-49', '87.64.104.15', '').
text_drs_eval(0, 3750, 'There are how many liters of some fluid?', drs([], [question(drs([A, B], [query(A, howm)-1/3, object(A, liter, countable, na, geq, 2)-1/5, object(B, fluid, mass, na, na, na)-1/8, relation(A, of, B)-1/6]))]), [[query, [question, [topic, [quant, 'there are'], [np, [qdet, 'how many'], [nbar, [n, liters], [pp, [prep, of], [np, [det, some], [nbar, [n, fluid]]]]]]]], ?]], '2013-12-14-11-50-21', '87.64.104.15', '').
text_drs_eval(0, 3751, 'Sun is the Sun.', drs([A], [predicate(A, be, named('Sun'), named('Sun'))-1/2]), [[specification, [s, [np, [pname, 'Sun']], [vp, [aux, is], [np, [pname, the, 'Sun']]]], '.']], '2012-04-06-13-56-31', '80.200.46.147', '').
text_drs_eval(0, 3752, 'There is a man that John is not.', drs([], []), [], '2012-04-24-18-52-31', '80.200.26.233', '').
text_drs_eval(0, 3753, 'Does John believe that Mary sleeps?', drs([], [question(drs([A, B], [predicate(A, believe, named('John'), B)-1/3, B:drs([C], [predicate(C, sleep, named('Mary'))-1/6])]))]), [[query, [question, does, [np, [pname, 'John']], [vp, [vbar, [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], ?]], '2012-07-13-19-34-33', '80.200.36.205', '').
text_drs_eval(1, 3754, 'How does John believe that Mary sleeps?', drs([], []), [], '2012-07-13-19-35-05', '80.200.36.205', 'Should be allowed because we allow: Does John believe that Mary sleeps?').
text_drs_eval(1, 3755, 'How does John see a man that waits?', drs([], []), [], '2012-07-14-13-57-58', '80.200.36.205', 'Should succeed because, this does: does John see a man that waits?').
text_drs_eval(0, 3756, 'Does John see a man that waits?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/5, predicate(B, wait, A)-1/7, predicate(C, see, named('John'), A)-1/3]))]), [[query, [question, does, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]]]]]], ?]], '2012-07-14-14-14-24', '80.200.36.205', '').
text_drs_eval(0, 3757, 'How does John that waits see a man?', drs([], [question(drs([A, B, C], [predicate(A, wait, named('John'))-1/5, object(B, man, countable, na, eq, 1)-1/8, predicate(C, see, named('John'), B)-1/6, query(C, how)-1/1]))]), [[query, [question, [qpn, how], does, [np, [pname, 'John'], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]], [vp, [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, man]]]]]]], ?]], '2012-07-15-10-21-59', '80.200.36.205', '').
text_drs_eval(0, 3758, 'John where sees a man that waits?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/5, predicate(B, wait, A)-1/7, query(C, where)-1/2, predicate(C, see, named('John'), A)-1/3]))]), [[query, [question, [np, [pname, 'John']], [vp, [vbar, [vmod, [qpn, where]], [vcompl, [v, sees], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]]]]]], ?]], '2012-07-15-13-20-43', '80.200.36.205', '').
text_drs_eval(0, 3759, 'John how believes that Mary sleeps?', drs([], [question(drs([A, B], [predicate(A, believe, named('John'), B)-1/3, query(A, how)-1/2, B:drs([C], [predicate(C, sleep, named('Mary'))-1/6])]))]), [[query, [question, [np, [pname, 'John']], [vp, [vbar, [vmod, [qpn, how]], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], ?]], '2012-07-15-13-21-18', '80.200.36.205', '').
text_drs_eval(0, 3760, 'John how and when and where believes that Mary sleeps?', drs([], [question(drs([A, B], [predicate(A, believe, named('John'), B)-1/7, query(A, where)-1/6, query(A, when)-1/4, query(A, how)-1/2, B:drs([C], [predicate(C, sleep, named('Mary'))-1/10])]))]), [[query, [question, [np, [pname, 'John']], [vp, [vbar, [vmod, [adv_coord, [qpn, how], [coord, and], [adv_coord, [qpn, when], [coord, and], [qpn, where]]]], [cp, that, [s, [np, [pname, 'Mary']], [vp, [vbar, [vbar, [v, sleeps]]]]]]]]], ?]], '2012-07-15-13-32-53', '80.200.36.205', '').
text_drs_eval(0, 3761, 'How and when and where does John see a man?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/10, predicate(B, see, named('John'), A)-1/8, query(B, where)-1/5, query(B, when)-1/3, query(B, how)-1/1]))]), [[query, [question, [adv_coord, [qpn, how], [coord, and], [adv_coord, [qpn, when], [coord, and], [qpn, where]]], does, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, see], [np, [det, a], [nbar, [n, man]]]]]]], ?]], '2012-07-15-13-35-33', '80.200.36.205', '').
text_drs_eval(0, 3762, 'John sees a man where and when and how?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/4, predicate(B, see, named('John'), A)-1/2, query(B, how)-1/9, query(B, when)-1/7, query(B, where)-1/5]))]), [[query, [question, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, sees], [np, [det, a], [nbar, [n, man]]]], [vmod, [adv_coord, [qpn, where], [coord, and], [adv_coord, [qpn, when], [coord, and], [qpn, how]]]]]]], ?]], '2012-07-15-13-37-04', '80.200.36.205', '').
text_drs_eval(0, 3763, 'John when eats and where drinks?', drs([], [question(drs([A, B], [query(A, when)-1/2, predicate(A, eat, named('John'))-1/3, query(B, where)-1/5, predicate(B, drink, named('John'))-1/6]))]), [[query, [question, [np, [pname, 'John']], [vp_coord, [vp, [vbar, [vmod, [qpn, when]], [vbar, [v, eats]]]], [coord, and], [vp, [vbar, [vmod, [qpn, where]], [vbar, [v, drinks]]]]]], ?]], '2012-07-15-16-01-02', '80.200.36.205', '').
text_drs_eval(0, 3764, 'How is John seen by a man?', drs([], [question(drs([A, B], [object(A, man, countable, na, eq, 1)-1/7, predicate(B, see, A, named('John'))-1/4, query(B, how)-1/1]))]), [[query, [question, [qpn, how], is, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, seen], by, [np, [det, a], [nbar, [n, man]]]]]]], ?]], '2012-07-15-16-53-43', '80.200.36.205', '').
text_drs_eval(0, 3765, 'How is John that waits seen by a man?', drs([], [question(drs([A, B, C], [predicate(A, wait, named('John'))-1/5, object(B, man, countable, na, eq, 1)-1/9, predicate(C, see, B, named('John'))-1/6, query(C, how)-1/1]))]), [[query, [question, [qpn, how], is, [np, [pname, 'John'], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]], [vp, [vbar, [vcompl, [v, seen], by, [np, [det, a], [nbar, [n, man]]]]]]], ?]], '2012-07-15-16-54-10', '80.200.36.205', '').
text_drs_eval(0, 3766, 'Is John seen by a man that waits?', drs([], [question(drs([A, B, C], [object(A, man, countable, na, eq, 1)-1/6, predicate(B, wait, A)-1/8, predicate(C, see, A, named('John'))-1/3]))]), [[query, [question, is, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, seen], by, [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]]]]]], ?]], '2012-07-15-16-55-12', '80.200.36.205', '').
text_drs_eval(1, 3767, 'How is John seen by a man that waits?', drs([], [question(drs([A, B, C, D], [object(A, man, countable, na, eq, 1)-1/7, predicate(B, wait, A)-1/9, property(C, seen, pos)-1/4, predicate(D, be, named('John'), C)-1/2, modifier_pp(D, by, A)-1/5, query(D, how)-1/1]))]), [[query, [question, [qpn, how], is, [np, [pname, 'John']], [vp, [ap_coord, [ap, [adj, seen]]], [vmod, [pp, [prep, by], [np, [det, a], [nbar, [n, man], [rel_cl, [comp, that], [vp, [vbar, [vbar, [v, waits]]]]]]]]]]], ?]], '2012-07-15-16-56-31', '80.200.36.205', 'Wrong DRS: \'see\' should be a transitive verb. Compare: Is John seen by a man that waits?').
text_drs_eval(0, 3768, 'John eats when and where drinks?', drs([], [question(drs([A, B], [predicate(A, eat, named('John'))-1/2, query(A, when)-1/3, query(B, where)-1/5, predicate(B, drink, named('John'))-1/6]))]), [[query, [question, [np, [pname, 'John']], [vp_coord, [vp, [vbar, [vbar, [v, eats]], [vmod, [qpn, when]]]], [coord, and], [vp, [vbar, [vmod, [qpn, where]], [vbar, [v, drinks]]]]]], ?]], '2012-07-16-09-33-19', '80.200.36.231', '').
text_drs_eval(1, 3769, '0.123456789123456789 waits.', drs([A], [predicate(A, wait, real(0.12345678912345678))-1/2]), [[specification, [s, [np, [real, 0.12345678912345678]], [vp, [vbar, [vbar, [v, waits]]]]], '.']], '2012-09-12-18-03-33', '89.206.103.116', 'The last 9 does not make it into the DRS.').
text_drs_eval(0, 3770, 'John has nothing but apples.', drs([], [drs([A, B], [predicate(A, have, named('John'), B)-1/2, object(B, something, dom, na, na, na)-1/4])=>drs([C, D], [object(C, apple, countable, na, eq, 1)-1/6, predicate(D, be, B, C)-1/''])]), [[specification, [s, [np, [pname, 'John']], [vp, [vbar, [vcompl, [v, has], [np, [det, [np, [pn, nothing]], but], [nbar, [n, apples]]]]]]], '.']], '2013-04-11-22-44-00', '89.206.118.109', '').
text_drs_eval(0, 3771, 'A = 2*3^4.', drs([A], [object(A, something, dom, na, na, na)-1/1, formula(A, =, expr(*, int(2), expr(^, int(3), int(4))))-1/2]), [[specification, [formula, [var, 'A'], =, [expr, [int, 2], [expr, [int, 3], [int, 4]]]], '.']], '2013-04-21-22-20-49', '89.206.119.170', '').
text_drs_eval(0, 3772, 'A = 2*3^4.5.', drs([A], [object(A, something, dom, na, na, na)-1/1, formula(A, =, expr(*, int(2), expr(^, int(3), real(4.5))))-1/2]), [[specification, [formula, [var, 'A'], =, [expr, [int, 2], [expr, [int, 3], [real, 4.5]]]], '.']], '2013-04-21-22-20-56', '89.206.119.170', '').
text_drs_eval(0, 3773, 'A = 2*3^(-1).', drs([A], [object(A, something, dom, na, na, na)-1/1, formula(A, =, expr(*, int(2), expr(^, int(3), int(-1))))-1/2]), [[specification, [formula, [var, 'A'], =, [expr, [int, 2], [expr, [int, 3], [brackets, '(', [int, -1], ')']]]], '.']], '2013-04-21-22-21-08', '89.206.119.170', '').
text_drs_eval(0, 3774, 'A = 2*3^(2+B).', drs([A, B], [object(A, something, dom, na, na, na)-1/1, object(B, something, dom, na, na, na)-1/10, formula(A, =, expr(*, int(2), expr(^, int(3), expr(+, int(2), B))))-1/2]), [[specification, [formula, [var, 'A'], =, [expr, [int, 2], [expr, [int, 3], [brackets, '(', [expr, [int, 2], [var, 'B']], ')']]]], '.']], '2013-04-21-22-26-27', '89.206.119.170', '').
text_drs_eval(0, 3775, 'A = 2*3^(2+3^B).', drs([A, B], [object(A, something, dom, na, na, na)-1/1, object(B, something, dom, na, na, na)-1/12, formula(A, =, expr(*, int(2), expr(^, int(3), expr(+, int(2), expr(^, int(3), B)))))-1/2]), [[specification, [formula, [var, 'A'], =, [expr, [int, 2], [expr, [int, 3], [brackets, '(', [expr, [int, 2], [expr, [int, 3], [var, 'B']]], ')']]]], '.']], '2013-04-21-22-28-23', '89.206.119.170', '').
text_drs_eval(0, 3776, 'A = 2*3^4^5.', drs([A], [object(A, something, dom, na, na, na)-1/1, formula(A, =, expr(*, int(2), expr(^, expr(^, int(3), int(4)), int(5))))-1/2]), [[specification, [formula, [var, 'A'], =, [expr, [int, 2], [expr, [expr, [int, 3], [int, 4]], [int, 5]]]], '.']], '2013-04-21-23-09-41', '89.206.119.170', '').
text_drs_eval(0, 3777, 'How many beaches have how much sand?', drs([], [question(drs([A, B, C], [query(A, howm)-1/1, object(A, beach, countable, na, geq, 2)-1/3, query(B, howm)-1/5, object(B, sand, mass, na, na, na)-1/7, predicate(C, have, A, B)-1/4]))]), [[query, [question, [np, [qdet, 'how many'], [nbar, [n, beaches]]], [vp, [vbar, [vcompl, [v, have], [np, [qdet, 'how much'], [nbar, [n, sand]]]]]]], ?]], '2013-12-14-11-52-12', '87.64.104.15', '').
text_drs_eval(0, 3778, 'Errol is not Hedwig. Hedwig is not Errol.\nHarryPotter is not NevilleLongbottom. NevilleLongbottom is not HarryPotter.\nNevilleLongbottom is not RonWeasley. RonWeasley is not NevilleLongbottom.\nNevilleLongbottom is not TomRiddle. TomRiddle is not NevilleLongbottom.', drs([], [-drs([A], [predicate(A, be, named('Errol'), named('Hedwig'))-1/2]), -drs([B], [predicate(B, be, named('Hedwig'), named('Errol'))-2/2]), -drs([C], [predicate(C, be, named('HarryPotter'), named('NevilleLongbottom'))-3/2]), -drs([D], [predicate(D, be, named('NevilleLongbottom'), named('HarryPotter'))-4/2]), -drs([E], [predicate(E, be, named('NevilleLongbottom'), named('RonWeasley'))-5/2]), -drs([F], [predicate(F, be, named('RonWeasley'), named('NevilleLongbottom'))-6/2]), -drs([G], [predicate(G, be, named('NevilleLongbottom'), named('TomRiddle'))-7/2]), -drs([H], [predicate(H, be, named('TomRiddle'), named('NevilleLongbottom'))-8/2])]), [[specification, [s, [np, [pname, 'Errol']], [vp, [aux, is, not], [np, [pname, 'Hedwig']]]], '.'], [specification, [s, [np, [pname, 'Hedwig']], [vp, [aux, is, not], [np, [pname, 'Errol']]]], '.'], [specification, [s, [np, [pname, 'HarryPotter']], [vp, [aux, is, not], [np, [pname, 'NevilleLongbottom']]]], '.'], [specification, [s, [np, [pname, 'NevilleLongbottom']], [vp, [aux, is, not], [np, [pname, 'HarryPotter']]]], '.'], [specification, [s, [np, [pname, 'NevilleLongbottom']], [vp, [aux, is, not], [np, [pname, 'RonWeasley']]]], '.'], [specification, [s, [np, [pname, 'RonWeasley']], [vp, [aux, is, not], [np, [pname, 'NevilleLongbottom']]]], '.'], [specification, [s, [np, [pname, 'NevilleLongbottom']], [vp, [aux, is, not], [np, [pname, 'TomRiddle']]]], '.'], [specification, [s, [np, [pname, 'TomRiddle']], [vp, [aux, is, not], [np, [pname, 'NevilleLongbottom']]]], '.']], '2016-01-12-18-23-27', '203.199.213.3', '').
